@@ -23,16 +23,6 @@
 #include <stdarg.h>
 #include <math.h>
 
-/*
- * Just make sure we include the prototype for strptime as well
- * (needed for glibc 2.2) but make sure we do this only if not
- * yet defined.
- */
-
-#ifndef __USE_XOPEN
-#  define __USE_XOPEN
-#endif
-
 #include <time.h>
 #include <glib.h>
 
@@ -53,10 +43,6 @@
 #include <winsock2.h>
 #endif
 
-#ifndef HAVE_STRPTIME
-# include "wsutil/strptime.h"
-#endif
-
 #include <ui/clopts_common.h>
 #include <ui/cmdarg_err.h>
 #include <ui/exit_codes.h>
@@ -179,6 +165,7 @@ static const struct {
     guint32     id;
 } secrets_types[] = {
     { "tls",    SECRETS_TYPE_TLS },
+    { "ssh",    SECRETS_TYPE_SSH },
     { "wg",     SECRETS_TYPE_WIREGUARD },
 };
 
@@ -196,7 +183,7 @@ abs_time_to_str_with_sec_resolution(const nstime_t *abs_time)
     tmp = localtime(&abs_time->secs);
 
     if (tmp) {
-        g_snprintf(buf, 16, "%d%02d%02d%02d%02d%02d",
+        snprintf(buf, 16, "%d%02d%02d%02d%02d%02d",
             tmp->tm_year + 1900,
             tmp->tm_mon+1,
             tmp->tm_mday,
@@ -218,7 +205,7 @@ fileset_get_filename_by_pattern(guint idx, const wtap_rec *rec,
     gchar *timestr;
     gchar *abs_str;
 
-    g_snprintf(filenum, sizeof(filenum), "%05u", idx % RINGBUFFER_MAX_NUM_FILES);
+    snprintf(filenum, sizeof(filenum), "%05u", idx % RINGBUFFER_MAX_NUM_FILES);
     if (rec->presence_flags & WTAP_HAS_TS) {
         timestr = abs_time_to_str_with_sec_resolution(&rec->ts);
         abs_str = g_strconcat(fprefix, "_", filenum, "_", timestr, fsuffix, NULL);
@@ -749,7 +736,7 @@ print_usage(FILE *output)
     fprintf(output, "\n");
     fprintf(output, "Usage: editcap [options] ... <infile> <outfile> [ <packet#>[-<packet#>] ... ]\n");
     fprintf(output, "\n");
-    fprintf(output, "<infile> and <outfile> must both be present.\n");
+    fprintf(output, "<infile> and <outfile> must both be present; use '-' for stdin or stdout.\n");
     fprintf(output, "A single packet or a range of packets can be selected.\n");
     fprintf(output, "\n");
     fprintf(output, "Packet selection:\n");
@@ -999,7 +986,7 @@ editcap_dump_open(const char *filename, const wtap_dump_params *params,
         return NULL;
 
     /*
-     * If the output file supports identifying the interfaces on which
+     * If the output file supporst identifying the interfaces on which
      * packets arrive, add all the IDBs we've seen so far.
      *
      * That mean that the abstract interface provided by libwiretap
@@ -1036,7 +1023,7 @@ editcap_dump_open(const char *filename, const wtap_dump_params *params,
                 int close_err;
                 gchar *close_err_info;
 
-                wtap_dump_close(pdh, &close_err, &close_err_info);
+                wtap_dump_close(pdh, NULL, &close_err, &close_err_info);
                 g_free(close_err_info);
                 wtap_block_unref(if_data_copy);
                 return NULL;
@@ -1115,7 +1102,7 @@ process_new_idbs(wtap *wth, wtap_dumper *pdh, GArray *idbs_seen,
 int
 main(int argc, char *argv[])
 {
-    char         *init_progfile_dir_error;
+    char         *configuration_init_error;
     static const struct report_message_routines editcap_report_routines = {
         failure_message,
         failure_message,
@@ -1205,7 +1192,7 @@ main(int argc, char *argv[])
 #endif /* _WIN32 */
 
     /* Initialize the version information. */
-    ws_init_version_info("Editcap (Wireshark)", NULL, NULL, NULL);
+    ws_init_version_info("Editcap", NULL, NULL);
 
     /*
      * Get credential information for later use.
@@ -1216,12 +1203,12 @@ main(int argc, char *argv[])
      * Attempt to get the pathname of the directory containing the
      * executable file.
      */
-    init_progfile_dir_error = init_progfile_dir(argv[0]);
-    if (init_progfile_dir_error != NULL) {
+    configuration_init_error = configuration_init(argv[0], NULL);
+    if (configuration_init_error != NULL) {
         fprintf(stderr,
                 "editcap: Can't get pathname of directory containing the editcap program: %s.\n",
-                init_progfile_dir_error);
-        g_free(init_progfile_dir_error);
+                configuration_init_error);
+        g_free(configuration_init_error);
     }
 
     init_report_message("editcap", &editcap_report_routines);
@@ -1297,21 +1284,6 @@ main(int argc, char *argv[])
 
         case LONGOPT_CAPTURE_COMMENT:
         {
-            /*
-             * Make sure this would fit in a pcapng option.
-             *
-             * XXX - 65535 is the maximum size for an option in pcapng;
-             * what if another capture file format supports larger
-             * comments?
-             */
-            if (strlen(ws_optarg) > 65535) {
-                /* It doesn't fit.  Tell the user and give up. */
-                cmdarg_err("Capture comment %u is too large to save in a capture file.",
-                           capture_comments->len + 1);
-                ret = INVALID_OPTION;
-                goto clean_exit;
-            }
-
             /* pcapng supports multiple comments, so support them here too.
              */
             if (!capture_comments) {
@@ -1339,21 +1311,6 @@ main(int argc, char *argv[])
                 goto clean_exit;
             }
 
-            /*
-             * Make sure this would fit in a pcapng option.
-             *
-             * XXX - 65535 is the maximum size for an option in pcapng;
-             * what if another capture file format supports larger
-             * comments?
-             */
-            if (strlen(ws_optarg+string_start_index) > 65535) {
-                /* It doesn't fit.  Tell the user and give up. */
-                cmdarg_err("A comment for frame %u is too large to save in a capture file.",
-                           frame_number);
-                ret = INVALID_OPTION;
-                goto clean_exit;
-            }
-
             /* Lazily create the table */
             if (!frames_user_comments) {
                 frames_user_comments = g_tree_new_full(framenum_compare, NULL, NULL, g_free);
@@ -1370,7 +1327,7 @@ main(int argc, char *argv[])
             nstime_t in_time;
 
             check_startstop = TRUE;
-            if ((0 < iso8601_to_nstime(&in_time, ws_optarg)) || (0 < unix_epoch_to_nstime(&in_time, ws_optarg))) {
+            if ((0 < iso8601_to_nstime(&in_time, ws_optarg, ISO8601_DATETIME)) || (0 < unix_epoch_to_nstime(&in_time, ws_optarg))) {
                 if (opt == 'A') {
                     nstime_copy(&starttime, &in_time);
                     have_starttime = TRUE;
@@ -1834,13 +1791,6 @@ main(int argc, char *argv[])
                                         read_count,
                                         out_file_type_subtype);
             ret = DUMP_ERROR;
-
-            /*
-             * Close the dump file, but don't report an error
-             * or set the exit code, as we've already reported
-             * an error.
-             */
-            wtap_dump_close(pdh, &write_err, &write_err_info);
             goto clean_exit;
         }
 
@@ -1858,11 +1808,7 @@ main(int argc, char *argv[])
                 }
                 while (nstime_cmp(&rec->ts, &block_next) > 0) { /* time for the next file */
 
-                    /* We presumably want to write the DSBs from files given
-                     * on the command line to every file.
-                     */
-                    wtap_block_array_ref(params.dsbs_initial);
-                    if (!wtap_dump_close(pdh, &write_err, &write_err_info)) {
+                    if (!wtap_dump_close(pdh, NULL, &write_err, &write_err_info)) {
                         cfile_close_failure_message(filename, write_err,
                                                     write_err_info);
                         ret = WRITE_ERROR;
@@ -1894,12 +1840,7 @@ main(int argc, char *argv[])
         if (split_packet_count != 0) {
             /* time for the next file? */
             if (written_count > 0 && (written_count % split_packet_count) == 0) {
-
-                /* We presumably want to write the DSBs from files given
-                 * on the command line to every file.
-                 */
-                wtap_block_array_ref(params.dsbs_initial);
-                if (!wtap_dump_close(pdh, &write_err, &write_err_info)) {
+                if (!wtap_dump_close(pdh, NULL, &write_err, &write_err_info)) {
                     cfile_close_failure_message(filename, write_err,
                                                 write_err_info);
                     ret = WRITE_ERROR;
@@ -2295,13 +2236,6 @@ main(int argc, char *argv[])
                                             read_count,
                                             out_file_type_subtype);
                 ret = DUMP_ERROR;
-
-                /*
-                 * Close the dump file, but don't report an error
-                 * or set the exit code, as we've already reported
-                 * an error.
-                 */
-                wtap_dump_close(pdh, &write_err, &write_err_info);
                 goto clean_exit;
             }
             written_count++;
@@ -2322,7 +2256,7 @@ main(int argc, char *argv[])
     }
 
     if (!pdh) {
-        /* No valid packets found, open the outfile so we can write an
+        /* No valid packages found, open the outfile so we can write an
          * empty header */
         g_free (filename);
         filename = g_strdup(argv[ws_optind+1]);
@@ -2338,11 +2272,16 @@ main(int argc, char *argv[])
         }
     }
 
-    if (!wtap_dump_close(pdh, &write_err, &write_err_info)) {
+    if (!wtap_dump_close(pdh, NULL, &write_err, &write_err_info)) {
         cfile_close_failure_message(filename, write_err, write_err_info);
         ret = WRITE_ERROR;
         goto clean_exit;
     }
+    g_free(filename);
+
+    if (frames_user_comments) {
+        g_tree_destroy(frames_user_comments);
+    }
 
     if (dup_detect) {
         fprintf(stderr, "%u packet%s seen, %u packet%s skipped with duplicate window of %i packets.\n",
@@ -2357,12 +2296,6 @@ main(int argc, char *argv[])
     }
 
 clean_exit:
-    if (filename) {
-        g_free(filename);
-    }
-    if (frames_user_comments) {
-        g_tree_destroy(frames_user_comments);
-    }
     if (dsb_filenames) {
         g_array_free(dsb_types, TRUE);
         g_ptr_array_free(dsb_filenames, TRUE);
@@ -2471,7 +2404,7 @@ handle_chopping(chop_t chop, wtap_packet_header *out_phdr,
         if (chop.off_begin_pos > 0) {
             memmove(*buf + chop.off_begin_pos,
                     *buf + chop.off_begin_pos + chop.len_begin,
-                    out_phdr->caplen - (chop.off_begin_pos + chop.len_begin));
+                    out_phdr->caplen - chop.len_begin);
         } else {
             *buf += chop.len_begin;
         }
