@@ -162,7 +162,7 @@ set_host_gui_data(const void *key _U_, void *value, void *userdata)
 
     ui_info.group = REGISTER_STAT_GROUP_ENDPOINT_LIST;
     ui_info.title = NULL;   /* construct this from the protocol info? */
-    ui_info.cli_string = g_strdup_printf("%s,%s", HOSTLIST_TAP_PREFIX, proto_get_protocol_filter_name(table->proto_id));
+    ui_info.cli_string = ws_strdup_printf("%s,%s", HOSTLIST_TAP_PREFIX, proto_get_protocol_filter_name(table->proto_id));
     ui_info.tap_init_cb = dissector_hostlist_init;
     ui_info.nparams = 0;
     ui_info.params = NULL;
@@ -359,7 +359,7 @@ ct_port_to_str(endpoint_type etype, guint32 port)
     case ENDPOINT_UDP:
     case ENDPOINT_SCTP:
     case ENDPOINT_NCP:
-        return g_strdup_printf("%d", port);
+        return ws_strdup_printf("%d", port);
     default:
         break;
     }
@@ -545,7 +545,7 @@ char *get_hostlist_filter(hostlist_talker_t *host)
         src_addr = new_addr;
     }
 
-    str = g_strdup_printf("%s==%s%s%s%s%s",
+    str = ws_strdup_printf("%s==%s%s%s%s%s",
                           hostlist_get_filter_name(host, CONV_FT_ANY_ADDRESS),
                           src_addr,
                           sport?" && ":"",
@@ -580,32 +580,8 @@ add_conversation_table_data_with_conv_id(
     ct_dissector_info_t *ct_info,
     endpoint_type etype)
 {
-    const address *addr1, *addr2;
-    guint32 port1, port2;
     conv_item_t *conv_item = NULL;
-    unsigned int conversation_idx = 0;
-
-    if (src_port > dst_port) {
-        addr1 = src;
-        addr2 = dst;
-        port1 = src_port;
-        port2 = dst_port;
-    } else if (src_port < dst_port) {
-        addr2 = src;
-        addr1 = dst;
-        port2 = src_port;
-        port1 = dst_port;
-    } else if (cmp_address(src, dst) < 0) {
-        addr1 = src;
-        addr2 = dst;
-        port1 = src_port;
-        port2 = dst_port;
-    } else {
-        addr2 = src;
-        addr1 = dst;
-        port2 = src_port;
-        port1 = dst_port;
-    }
+    gboolean is_fwd_direction = FALSE; /* direction of any conversation found */
 
     /* if we don't have any entries at all yet */
     if (ch->conv_array == NULL) {
@@ -616,19 +592,32 @@ add_conversation_table_data_with_conv_id(
                                               g_free,             /* key_destroy_func */
                                               NULL);              /* value_destroy_func */
 
-    } else {
-        /* try to find it among the existing known conversations */
+    } else { /* try to find it among the existing known conversations */
+        /* first, check in the fwd conversations */
         conv_key_t existing_key;
         gpointer conversation_idx_hash_val;
 
-        existing_key.addr1 = *addr1;
-        existing_key.addr2 = *addr2;
-        existing_key.port1 = port1;
-        existing_key.port2 = port2;
+        existing_key.addr1 = *src;
+        existing_key.addr2 = *dst;
+        existing_key.port1 = src_port;
+        existing_key.port2 = dst_port;
         existing_key.conv_id = conv_id;
         if (g_hash_table_lookup_extended(ch->hashtable, &existing_key, NULL, &conversation_idx_hash_val)) {
             conv_item = &g_array_index(ch->conv_array, conv_item_t, GPOINTER_TO_UINT(conversation_idx_hash_val));
         }
+        if (conv_item == NULL) {
+            /* then, check in the rev conversations if not found in 'fwd' */
+            existing_key.addr1 = *dst;
+            existing_key.addr2 = *src;
+            existing_key.port1 = dst_port;
+            existing_key.port2 = src_port;
+            if (g_hash_table_lookup_extended(ch->hashtable, &existing_key, NULL, &conversation_idx_hash_val)) {
+                conv_item = &g_array_index(ch->conv_array, conv_item_t, GPOINTER_TO_UINT(conversation_idx_hash_val));
+            }
+        } else {
+            /* a conversation was found in this same fwd direction */
+            is_fwd_direction = TRUE;
+        }
     }
 
     /* if we still don't know what conversation this is it has to be a new one
@@ -636,19 +625,19 @@ add_conversation_table_data_with_conv_id(
     if (conv_item == NULL) {
         conv_key_t *new_key;
         conv_item_t new_conv_item;
+        unsigned int conversation_idx;
 
-        copy_address(&new_conv_item.src_address, addr1);
-        copy_address(&new_conv_item.dst_address, addr2);
+        copy_address(&new_conv_item.src_address, src);
+        copy_address(&new_conv_item.dst_address, dst);
         new_conv_item.dissector_info = ct_info;
         new_conv_item.etype = etype;
-        new_conv_item.src_port = port1;
-        new_conv_item.dst_port = port2;
+        new_conv_item.src_port = src_port;
+        new_conv_item.dst_port = dst_port;
         new_conv_item.conv_id = conv_id;
         new_conv_item.rx_frames = 0;
         new_conv_item.tx_frames = 0;
         new_conv_item.rx_bytes = 0;
         new_conv_item.tx_bytes = 0;
-        new_conv_item.modified = TRUE;
 
         if (ts) {
             memcpy(&new_conv_item.start_time, ts, sizeof(new_conv_item.start_time));
@@ -667,20 +656,26 @@ add_conversation_table_data_with_conv_id(
         new_key = g_new(conv_key_t, 1);
         set_address(&new_key->addr1, conv_item->src_address.type, conv_item->src_address.len, conv_item->src_address.data);
         set_address(&new_key->addr2, conv_item->dst_address.type, conv_item->dst_address.len, conv_item->dst_address.data);
-        new_key->port1 = port1;
-        new_key->port2 = port2;
+        new_key->port1 = src_port;
+        new_key->port2 = dst_port;
         new_key->conv_id = conv_id;
         g_hash_table_insert(ch->hashtable, new_key, GUINT_TO_POINTER(conversation_idx));
-    }
 
-    /* update the conversation struct */
-    conv_item->modified = TRUE;
-    if ( (!cmp_address(src, addr1)) && (!cmp_address(dst, addr2)) && (src_port==port1) && (dst_port==port2) ) {
+        /* update the conversation struct */
         conv_item->tx_frames += num_frames;
         conv_item->tx_bytes += num_bytes;
     } else {
-        conv_item->rx_frames += num_frames;
-        conv_item->rx_bytes += num_bytes;
+        /*
+         * update an existing conversation
+         * update the conversation struct
+         */
+        if (is_fwd_direction) {
+            conv_item->tx_frames += num_frames;
+            conv_item->tx_bytes += num_bytes;
+        } else {
+            conv_item->rx_frames += num_frames;
+            conv_item->rx_bytes += num_bytes;
+        }
     }
 
     if (ts) {
@@ -732,7 +727,6 @@ void
 add_hostlist_table_data(conv_hash_t *ch, const address *addr, guint32 port, gboolean sender, int num_frames, int num_bytes, hostlist_dissector_info_t *host_info, endpoint_type etype)
 {
     hostlist_talker_t *talker=NULL;
-    int talker_idx=0;
 
     /* XXX should be optimized to allocate n extra entries at a time
        instead of just one */
@@ -762,6 +756,7 @@ add_hostlist_table_data(conv_hash_t *ch, const address *addr, guint32 port, gboo
     if(talker==NULL){
         host_key_t *new_key;
         hostlist_talker_t host;
+        int talker_idx;
 
         copy_address(&host.myaddress, addr);
         host.dissector_info = host_info;
