@@ -41,26 +41,26 @@ range_new(gpointer junk _U_)
 	range->entity = NULL;
 	range->drange = NULL;
 
-	return (gpointer) range;
+	return range;
 }
 
 static gpointer
 range_dup(gconstpointer data)
 {
-	const range_t *org = (const range_t *)data;
+	const range_t *org = data;
 	range_t       *range;
 
-	range = (range_t *)range_new(NULL);
+	range = range_new(NULL);
 	range->entity = stnode_dup(org->entity);
 	range->drange = drange_dup(org->drange);
 
-	return (gpointer) range;
+	return range;
 }
 
 static void
 range_free(gpointer value)
 {
-	range_t	*range = (range_t*)value;
+	range_t *range = value;
 	ws_assert_magic(range, RANGE_MAGIC);
 
 	if (range->drange)
@@ -72,17 +72,63 @@ range_free(gpointer value)
 	g_free(range);
 }
 
+static char *
+slice_tostr(const void *data, gboolean pretty)
+{
+	const range_t *range = data;
+	ws_assert_magic(range, RANGE_MAGIC);
+
+	char *repr, *drange_str;
+
+	drange_str = drange_tostr(range->drange);
+	repr = ws_strdup_printf("%s[%s]",
+			stnode_tostr(range->entity, pretty),
+			drange_str);
+	g_free(drange_str);
+
+	return repr;
+}
+
+static char *
+layer_tostr(const void *data, gboolean pretty)
+{
+	const range_t *range = data;
+	ws_assert_magic(range, RANGE_MAGIC);
+
+	char *repr, *drange_str;
+
+	drange_str = drange_tostr(range->drange);
+	repr = ws_strdup_printf("%s#[%s]",
+			stnode_tostr(range->entity, pretty),
+			drange_str);
+	g_free(drange_str);
+
+	return repr;
+}
+
 void
 sttype_range_remove_drange(stnode_t *node)
 {
 	range_t		*range;
 
-	range = (range_t*)stnode_data(node);
+	range = stnode_data(node);
 	ws_assert_magic(range, RANGE_MAGIC);
 
 	range->drange = NULL;
 }
 
+drange_t *
+sttype_range_drange_steal(stnode_t *node)
+{
+	range_t		*range;
+	drange_t	*dr;
+
+	range = stnode_data(node);
+	ws_assert_magic(range, RANGE_MAGIC);
+	dr = range->drange;
+	range->drange = NULL;
+	return dr;
+}
 
 /* Set a range */
 void
@@ -90,7 +136,7 @@ sttype_range_set(stnode_t *node, stnode_t *entity, GSList* drange_list)
 {
 	range_t		*range;
 
-	range = (range_t*)stnode_data(node);
+	range = stnode_data(node);
 	ws_assert_magic(range, RANGE_MAGIC);
 
 	range->entity = entity;
@@ -104,22 +150,55 @@ sttype_range_set1(stnode_t *node, stnode_t *entity, drange_node *rn)
 	sttype_range_set(node, entity, g_slist_append(NULL, rn));
 }
 
-STTYPE_ACCESSOR(stnode_t*, range, entity, RANGE_MAGIC)
-STTYPE_ACCESSOR(drange_t*, range, drange, RANGE_MAGIC)
+char *
+sttype_range_set_number(stnode_t *node, stnode_t *entity, const char *number_str)
+{
+	char *err_msg = NULL;
+	drange_node *rn = drange_node_from_str(number_str, &err_msg);
+	if (err_msg != NULL)
+		return err_msg;
+	sttype_range_set1(node, entity, rn);
+	return NULL;
+}
 
+stnode_t *
+sttype_range_entity(stnode_t *node)
+{
+	range_t *range = node->data;
+	ws_assert_magic(range, RANGE_MAGIC);
+	return range->entity;
+}
+
+drange_t *
+sttype_range_drange(stnode_t *node)
+{
+	range_t *range = node->data;
+	ws_assert_magic(range, RANGE_MAGIC);
+	return range->drange;
+}
 
 void
 sttype_register_range(void)
 {
-	static sttype_t range_type = {
-		STTYPE_RANGE,
-		"RANGE",
+	static sttype_t slice_type = {
+		STTYPE_SLICE,
+		"SLICE",
 		range_new,
 		range_free,
-		range_dup
+		range_dup,
+		slice_tostr
+	};
+	static sttype_t layer_type = {
+		STTYPE_LAYER,
+		"LAYER",
+		range_new,
+		range_free,
+		range_dup,
+		layer_tostr
 	};
 
-	sttype_register(&range_type);
+	sttype_register(&slice_type);
+	sttype_register(&layer_type);
 }
 
 /*
