@@ -1,4 +1,5 @@
-/*
+/** @file
+ *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 2001 Gerald Combs
@@ -20,6 +21,9 @@ sttype_range_entity(stnode_t *node);
 drange_t *
 sttype_range_drange(stnode_t *node);
 
+drange_t *
+sttype_range_drange_steal(stnode_t *node);
+
 /* Set a range */
 void
 sttype_range_set(stnode_t *node, stnode_t *field, GSList* drange_list);
@@ -27,6 +31,9 @@ sttype_range_set(stnode_t *node, stnode_t *field, GSList* drange_list);
 void
 sttype_range_set1(stnode_t *node, stnode_t *field, drange_node *rn);
 
+char *
+sttype_range_set_number(stnode_t *node, stnode_t *entity, const char *number_str);
+
 /* Clear the 'drange' variable to remove responsibility for
  * freeing it. */
 void
