@@ -1,6 +1,6 @@
 /* packet-f1ap.c
  * Routines for E-UTRAN F1 Application Protocol (F1AP) packet dissection
- * Copyright 2018-2020, Pascal Quantin <pascal@wireshark.org>
+ * Copyright 2018-2022, Pascal Quantin <pascal@wireshark.org>
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -8,7 +8,7 @@
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
- * References: 3GPP TS 38.473 V16.6.0 (2021-07)
+ * References: 3GPP TS 38.473 V16.9.0 (2022-04)
  */
 
 #include "config.h"
@@ -19,7 +19,6 @@
 #include <epan/sctpppids.h>
 #include <epan/proto_data.h>
 #include <epan/stats_tree.h>
-#include <epan/exported_pdu.h>
 
 #include "packet-per.h"
 #include "packet-f1ap.h"
@@ -39,8 +38,6 @@
 void proto_register_f1ap(void);
 void proto_reg_handoff_f1ap(void);
 
-static gint exported_pdu_tap = -1;
-
 #include "packet-f1ap-val.h"
 
 /* Initialize the protocol and registered fields */
@@ -129,6 +126,7 @@ static gint ett_f1ap_SL_ConfigDedicatedEUTRA_Info = -1;
 static gint ett_f1ap_TDD_UL_DLConfigCommonNR = -1;
 static gint ett_f1ap_UEAssistanceInformationEUTRA = -1;
 static gint ett_f1ap_PosAssistance_Information = -1;
+static gint ett_f1ap_LocationMeasurementInformation = -1;
 #include "packet-f1ap-ett.c"
 
 enum{
@@ -417,19 +415,19 @@ static void set_message_label(asn1_ctx_t *actx, int type)
 static void
 f1ap_MaxPacketLossRate_fmt(gchar *s, guint32 v)
 {
-  g_snprintf(s, ITEM_LABEL_LENGTH, "%.1f%% (%u)", (float)v/10, v);
+  snprintf(s, ITEM_LABEL_LENGTH, "%.1f%% (%u)", (float)v/10, v);
 }
 
 static void
 f1ap_PacketDelayBudget_fmt(gchar *s, guint32 v)
 {
-  g_snprintf(s, ITEM_LABEL_LENGTH, "%.1fms (%u)", (float)v/2, v);
+  snprintf(s, ITEM_LABEL_LENGTH, "%.1fms (%u)", (float)v/2, v);
 }
 
 static void
 f1ap_ExtendedPacketDelayBudget_fmt(gchar *s, guint32 v)
 {
-  g_snprintf(s, ITEM_LABEL_LENGTH, "%.2fms (%u)", (float)v/100, v);
+  snprintf(s, ITEM_LABEL_LENGTH, "%.2fms (%u)", (float)v/100, v);
 }
 
 static f1ap_private_data_t*
@@ -540,19 +538,6 @@ static void set_stats_message_type(packet_info *pinfo, int type)
     priv_data->stats_tap->f1ap_mtype = type;
 }
 
-static void
-export_f1ap_pdu(packet_info* pinfo, tvbuff_t* tvb)
-{
-    exp_pdu_data_t* exp_pdu_data = export_pdu_create_common_tags(pinfo, "f1ap", EXP_PDU_TAG_PROTO_NAME);
-
-    exp_pdu_data->tvb_captured_length = tvb_captured_length(tvb);
-    exp_pdu_data->tvb_reported_length = tvb_reported_length(tvb);
-    exp_pdu_data->pdu_tvb = tvb;
-
-    tap_queue_packet(exported_pdu_tap, pinfo, exp_pdu_data);
-
-}
-
 static int
 dissect_f1ap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
@@ -583,7 +568,6 @@ dissect_f1ap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
   dissect_F1AP_PDU_PDU(tvb, pinfo, f1ap_tree, NULL);
 
   tap_queue_packet(f1ap_tap, pinfo, f1ap_info);
-  export_f1ap_pdu(pinfo, tvb);
   return tvb_captured_length(tvb);
 }
 
@@ -749,6 +733,7 @@ void proto_register_f1ap(void) {
     &ett_f1ap_TDD_UL_DLConfigCommonNR,
     &ett_f1ap_UEAssistanceInformationEUTRA,
     &ett_f1ap_PosAssistance_Information,
+    &ett_f1ap_LocationMeasurementInformation,
 #include "packet-f1ap-ettarr.c"
   };
 
@@ -785,7 +770,6 @@ proto_reg_handoff_f1ap(void)
   stats_tree_register("f1ap", "f1ap", "F1AP", 0,
                        f1ap_stats_tree_packet, f1ap_stats_tree_init, NULL);
 
-  exported_pdu_tap = find_tap_id(EXPORT_PDU_TAP_NAME_LAYER_7);
 #include "packet-f1ap-dis-tab.c"
 }
 
