@@ -99,8 +99,8 @@ static dissector_handle_t h4501_handle=NULL;
 static dissector_handle_t nsp_handle;
 static dissector_handle_t tp_handle;
 
-static next_tvb_list_t h245_list;
-static next_tvb_list_t tp_list;
+static next_tvb_list_t *h245_list;
+static next_tvb_list_t *tp_list;
 
 /* Initialize the protocol and registered fields */
 static int h225_tap = -1;
@@ -322,8 +322,8 @@ static void
 h225_frame_end(void)
 {
   /* next_tvb pointers are allocated in packet scope, clear it. */
-  next_tvb_init(&h245_list);
-  next_tvb_init(&tp_list);
+  h245_list = NULL;
+  tp_list = NULL;
 }
 
 static int
@@ -340,8 +340,8 @@ dissect_h225_H323UserInformation(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
   p_add_proto_data(pinfo->pool, pinfo, proto_h225, 0, h225_pi);
 
   register_frame_end_routine(pinfo, h225_frame_end);
-  next_tvb_init(&h245_list);
-  next_tvb_init(&tp_list);
+  h245_list = next_tvb_list_new(pinfo->pool);
+  tp_list = next_tvb_list_new(pinfo->pool);
 
   col_set_str(pinfo->cinfo, COL_PROTOCOL, PSNAME);
   col_clear(pinfo->cinfo, COL_INFO);
@@ -351,13 +351,13 @@ dissect_h225_H323UserInformation(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
 
   offset = dissect_H323_UserInformation_PDU(tvb, pinfo, tr, NULL);
 
-  if (h245_list.count){
+  if (h245_list->count){
     col_append_str(pinfo->cinfo, COL_PROTOCOL, "/");
     col_set_fence(pinfo->cinfo, COL_PROTOCOL);
   }
 
-  next_tvb_call(&h245_list, pinfo, tree, h245dg_handle, data_handle);
-  next_tvb_call(&tp_list, pinfo, tree, NULL, data_handle);
+  next_tvb_call(h245_list, pinfo, tree, h245dg_handle, data_handle);
+  next_tvb_call(tp_list, pinfo, tree, NULL, data_handle);
 
   tap_queue_packet(h225_tap, pinfo, h225_pi);
 
@@ -376,6 +376,8 @@ dissect_h225_h225_RasMessage(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
   p_add_proto_data(pinfo->pool, pinfo, proto_h225, 0, h225_pi);
 
   register_frame_end_routine(pinfo, h225_frame_end);
+  h245_list = next_tvb_list_new(pinfo->pool);
+  tp_list = next_tvb_list_new(pinfo->pool);
 
   col_set_str(pinfo->cinfo, COL_PROTOCOL, PSNAME);
 
@@ -386,6 +388,9 @@ dissect_h225_h225_RasMessage(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
 
   ras_call_matching(tvb, pinfo, tr, h225_pi);
 
+  next_tvb_call(h245_list, pinfo, tree, h245dg_handle, data_handle);
+  next_tvb_call(tp_list, pinfo, tree, NULL, data_handle);
+
   tap_queue_packet(h225_tap, pinfo, h225_pi);
 
   return offset;
@@ -458,6 +463,7 @@ static void h225_stat_init(stat_tap_table_ui* new_stat)
     return;
   }
 
+  memset(items, 0x0, sizeof(items));
   table = stat_tap_init_table(table_name, num_fields, 0, NULL);
   stat_tap_add_table(new_stat, table);
 
