@@ -6,19 +6,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * References: 3GPP TS 25.413 version 10.4.0 Release 10
  */
@@ -79,8 +67,8 @@ static int hf_ranap_transportLayerAddress_nsap = -1;
 
 /* Initialize the subtree pointers */
 static int ett_ranap = -1;
-static int ett_ranap_TransportLayerAddress = -1;
-static int ett_ranap_TransportLayerAddress_nsap = -1;
+static int ett_ranap_transportLayerAddress = -1;
+static int ett_ranap_transportLayerAddress_nsap = -1;
 
 #include "packet-ranap-ett.c"
 
@@ -95,6 +83,7 @@ typedef struct ranap_private_data_t
 {
   guint32 transportLayerAddress_ipv4;
   guint16 binding_id_port;
+  e212_number_type_t number_type;
 } ranap_private_data_t;
 
 
@@ -103,17 +92,14 @@ static ranap_private_data_t* ranap_get_private_data(asn1_ctx_t *actx)
 {
   packet_info *pinfo = actx->pinfo;
   ranap_private_data_t *private_data = (ranap_private_data_t *)p_get_proto_data(pinfo->pool, pinfo, proto_ranap, 0);
-  if(private_data != NULL ) {
-     return private_data;
-  }
-  else {
+  if(private_data == NULL ) {
     private_data = wmem_new0(pinfo->pool, ranap_private_data_t);
     p_add_proto_data(pinfo->pool, pinfo, proto_ranap, 0, private_data);
-    return private_data;
   }
+  return private_data;
 }
 
-/* Helper function to reset the the private data struct */
+/* Helper function to reset the private data struct */
 static void ranap_reset_private_data(packet_info *pinfo)
 {
   p_remove_proto_data(pinfo->pool, pinfo, proto_ranap, 0);
@@ -350,15 +336,19 @@ dissect_sccp_ranap_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
   #define LENGTH_OFFSET 3
   #define CRIT_OFFSET 2
   #define MSG_TYPE_OFFSET 1
+  #define PDU_TYPE_OFFSET 0
   if (tvb_captured_length(tvb) < RANAP_MSG_MIN_LENGTH) { return FALSE; }
 
-  temp = tvb_get_guint8(tvb, 0) & 0x7f;
-  if (temp != 0x00 && temp != 0x20 &&temp != 0x40 && temp != 0x60) {
+  temp = tvb_get_guint8(tvb, PDU_TYPE_OFFSET);
+  if (temp & 0x1F) {
+    /* PDU Type byte is not 0x00 (initiatingMessage), 0x20 (succesfulOutcome),
+       0x40 (unsuccesfulOutcome) or 0x60 (outcome), ignore extension bit (0x80) */
     return FALSE;
   }
 
   temp = tvb_get_guint8(tvb, CRIT_OFFSET);
-  if (temp != 0x00 && temp != 0x40 && temp != 0x80) {
+  if (temp == 0xC0 || temp & 0x3F) {
+    /* Criticality byte is not 0x00 (reject), 0x40 (ignore) or 0x80 (notify) */
     return FALSE;
   }
 
@@ -423,8 +413,8 @@ void proto_register_ranap(void) {
   /* List of subtrees */
   static gint *ett[] = {
     &ett_ranap,
-    &ett_ranap_TransportLayerAddress,
-    &ett_ranap_TransportLayerAddress_nsap,
+    &ett_ranap_transportLayerAddress,
+    &ett_ranap_transportLayerAddress_nsap,
 #include "packet-ranap-ettarr.c"
   };
 
@@ -473,6 +463,8 @@ proto_reg_handoff_ranap(void)
     rrc_t_to_srnc_handle = find_dissector_add_dependency("rrc.t_to_srnc_cont", proto_ranap);
     rrc_ho_to_utran_cmd = find_dissector_add_dependency("rrc.irat.ho_to_utran_cmd", proto_ranap);
     bssgp_handle = find_dissector("bssgp");
+    heur_dissector_add("sccp", dissect_sccp_ranap_heur, "RANAP over SCCP", "ranap_sccp", proto_ranap, HEURISTIC_ENABLE);
+    heur_dissector_add("sua", dissect_sccp_ranap_heur, "RANAP over SUA", "ranap_sua", proto_ranap, HEURISTIC_ENABLE);
     initialized = TRUE;
 #include "packet-ranap-dis-tab.c"
   } else {
@@ -481,9 +473,6 @@ proto_reg_handoff_ranap(void)
 
   dissector_add_uint("sccp.ssn", global_ranap_sccp_ssn, ranap_handle);
   local_ranap_sccp_ssn = global_ranap_sccp_ssn;
-
-  heur_dissector_add("sccp", dissect_sccp_ranap_heur, "RANAP over SCCP", "ranap_sccp", proto_ranap, HEURISTIC_ENABLE);
-  heur_dissector_add("sua", dissect_sccp_ranap_heur, "RANAP over SUA", "ranap_sua", proto_ranap, HEURISTIC_ENABLE);
 }
 
 /*
