@@ -90,9 +90,9 @@ static guint64 asap_total_msgs = 0;
 static guint64 asap_total_bytes = 0;
 
 static void
-dissect_parameters(tvbuff_t *, packet_info *, proto_tree *);
+dissect_parameters(tvbuff_t *, proto_tree *);
 static void
-dissect_parameter(tvbuff_t *, packet_info *, proto_tree *);
+dissect_parameter(tvbuff_t *, proto_tree *);
 static int
 dissect_asap(tvbuff_t *, packet_info *, proto_tree *, void *);
 
@@ -122,16 +122,13 @@ dissect_unknown_cause(tvbuff_t *cause_tvb, proto_tree *cause_tree, proto_item *c
 }
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
-dissect_error_cause(tvbuff_t *cause_tvb, packet_info *pinfo, proto_tree *parameter_tree)
+dissect_error_cause(tvbuff_t *cause_tvb, proto_tree *parameter_tree)
 {
   guint16 code, length, padding_length;
   proto_item *cause_item;
   proto_tree *cause_tree;
   tvbuff_t *parameter_tvb, *message_tvb;
 
-  pinfo->flags.in_error_pkt = true;
-
   code           = tvb_get_ntohs(cause_tvb, CAUSE_CODE_OFFSET);
   length         = tvb_get_ntohs(cause_tvb, CAUSE_LENGTH_OFFSET);
   padding_length = tvb_reported_length(cause_tvb) - length;
@@ -145,27 +142,27 @@ dissect_error_cause(tvbuff_t *cause_tvb, packet_info *pinfo, proto_tree *paramet
   switch(code) {
   case UNRECOGNIZED_PARAMETER_CAUSE_CODE:
     parameter_tvb = tvb_new_subset_remaining(cause_tvb, CAUSE_INFO_OFFSET);
-    dissect_parameter(parameter_tvb, pinfo, cause_tree);
+    dissect_parameter(parameter_tvb, cause_tree);
     break;
   case UNRECONGNIZED_MESSAGE_CAUSE_CODE:
     message_tvb = tvb_new_subset_remaining(cause_tvb, CAUSE_INFO_OFFSET);
-    dissect_asap(message_tvb, pinfo, cause_tree, NULL);
+    dissect_asap(message_tvb, NULL, cause_tree, NULL);
     break;
   case INVALID_VALUES:
     parameter_tvb = tvb_new_subset_remaining(cause_tvb, CAUSE_INFO_OFFSET);
-    dissect_parameter(parameter_tvb, pinfo, cause_tree);
+    dissect_parameter(parameter_tvb, cause_tree);
     break;
   case NON_UNIQUE_PE_IDENTIFIER:
     break;
   case POOLING_POLICY_INCONSISTENT_CAUSE_CODE:
     parameter_tvb = tvb_new_subset_remaining(cause_tvb, CAUSE_INFO_OFFSET);
-    dissect_parameter(parameter_tvb, pinfo, cause_tree);
+    dissect_parameter(parameter_tvb, cause_tree);
     break;
   case LACK_OF_RESOURCES_CAUSE_CODE:
     break;
   case INCONSISTENT_TRANSPORT_TYPE_CAUSE_CODE:
     parameter_tvb = tvb_new_subset_remaining(cause_tvb, CAUSE_INFO_OFFSET);
-    dissect_parameter(parameter_tvb, pinfo, cause_tree);
+    dissect_parameter(parameter_tvb, cause_tree);
     break;
   case INCONSISTENT_DATA_CONTROL_CONFIGURATION_CAUSE_CODE:
     break;
@@ -182,8 +179,7 @@ dissect_error_cause(tvbuff_t *cause_tvb, packet_info *pinfo, proto_tree *paramet
 }
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
-dissect_error_causes(tvbuff_t *error_causes_tvb, packet_info *pinfo, proto_tree *parameter_tree)
+dissect_error_causes(tvbuff_t *error_causes_tvb, proto_tree *parameter_tree)
 {
   guint16 length, total_length;
   gint offset;
@@ -194,7 +190,7 @@ dissect_error_causes(tvbuff_t *error_causes_tvb, packet_info *pinfo, proto_tree
     length          = tvb_get_ntohs(error_causes_tvb, offset + CAUSE_LENGTH_OFFSET);
     total_length    = ADD_PADDING(length);
     error_cause_tvb = tvb_new_subset_length(error_causes_tvb, offset , total_length);
-    dissect_error_cause(error_cause_tvb, pinfo, parameter_tree);
+    dissect_error_cause(error_cause_tvb, parameter_tree);
     offset += total_length;
   }
 }
@@ -216,8 +212,7 @@ dissect_ipv6_parameter(tvbuff_t *parameter_tvb, proto_tree *parameter_tree, prot
 }
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
-dissect_dccp_transport_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *parameter_tree)
+dissect_dccp_transport_parameter(tvbuff_t *parameter_tvb, proto_tree *parameter_tree)
 {
   tvbuff_t *parameters_tvb;
 
@@ -226,12 +221,11 @@ dissect_dccp_transport_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, pr
   proto_tree_add_item(parameter_tree, hf_dccp_service_code, parameter_tvb, DCCP_SERVICE_CODE_OFFSET, DCCP_SERVICE_CODE_LENGTH, ENC_BIG_ENDIAN);
 
   parameters_tvb = tvb_new_subset_remaining(parameter_tvb, DCCP_ADDRESS_OFFSET);
-  dissect_parameters(parameters_tvb, pinfo, parameter_tree);
+  dissect_parameters(parameters_tvb, parameter_tree);
 }
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
-dissect_sctp_transport_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *parameter_tree)
+dissect_sctp_transport_parameter(tvbuff_t *parameter_tvb, proto_tree *parameter_tree)
 {
   tvbuff_t *parameters_tvb;
 
@@ -239,12 +233,11 @@ dissect_sctp_transport_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, pr
   proto_tree_add_item(parameter_tree, hf_transport_use, parameter_tvb, SCTP_TRANSPORT_USE_OFFSET, SCTP_TRANSPORT_USE_LENGTH, ENC_BIG_ENDIAN);
 
   parameters_tvb = tvb_new_subset_remaining(parameter_tvb, SCTP_ADDRESS_OFFSET);
-  dissect_parameters(parameters_tvb, pinfo, parameter_tree);
+  dissect_parameters(parameters_tvb, parameter_tree);
 }
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
-dissect_tcp_transport_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *parameter_tree)
+dissect_tcp_transport_parameter(tvbuff_t *parameter_tvb, proto_tree *parameter_tree)
 {
   tvbuff_t *parameters_tvb;
 
@@ -252,12 +245,11 @@ dissect_tcp_transport_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, pro
   proto_tree_add_item(parameter_tree, hf_transport_use, parameter_tvb, TCP_TRANSPORT_USE_OFFSET, TCP_TRANSPORT_USE_LENGTH, ENC_BIG_ENDIAN);
 
   parameters_tvb = tvb_new_subset_remaining(parameter_tvb, TCP_ADDRESS_OFFSET);
-  dissect_parameters(parameters_tvb, pinfo, parameter_tree);
+  dissect_parameters(parameters_tvb, parameter_tree);
 }
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
-dissect_udp_transport_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *parameter_tree)
+dissect_udp_transport_parameter(tvbuff_t *parameter_tvb, proto_tree *parameter_tree)
 {
   tvbuff_t *parameters_tvb;
 
@@ -265,12 +257,11 @@ dissect_udp_transport_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, pro
   proto_tree_add_item(parameter_tree, hf_udp_reserved, parameter_tvb, UDP_RESERVED_OFFSET, UDP_RESERVED_LENGTH, ENC_BIG_ENDIAN);
 
   parameters_tvb = tvb_new_subset_remaining(parameter_tvb, UDP_ADDRESS_OFFSET);
-  dissect_parameters(parameters_tvb, pinfo, parameter_tree);
+  dissect_parameters(parameters_tvb, parameter_tree);
 }
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
-dissect_udp_lite_transport_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *parameter_tree)
+dissect_udp_lite_transport_parameter(tvbuff_t *parameter_tvb, proto_tree *parameter_tree)
 {
   tvbuff_t *parameters_tvb;
 
@@ -278,7 +269,7 @@ dissect_udp_lite_transport_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo
   proto_tree_add_item(parameter_tree, hf_udp_lite_reserved, parameter_tvb, UDP_LITE_RESERVED_OFFSET, UDP_LITE_RESERVED_LENGTH, ENC_BIG_ENDIAN);
 
   parameters_tvb = tvb_new_subset_remaining(parameter_tvb, UDP_LITE_ADDRESS_OFFSET);
-  dissect_parameters(parameters_tvb, pinfo, parameter_tree);
+  dissect_parameters(parameters_tvb, parameter_tree);
 }
 
 static void
@@ -354,8 +345,7 @@ dissect_pool_handle_parameter(tvbuff_t *parameter_tvb, proto_tree *parameter_tre
 }
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
-dissect_pool_element_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *parameter_tree)
+dissect_pool_element_parameter(tvbuff_t *parameter_tvb, proto_tree *parameter_tree)
 {
   tvbuff_t*   parameters_tvb;
 
@@ -364,29 +354,27 @@ dissect_pool_element_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, prot
   proto_tree_add_item(parameter_tree, hf_reg_life,    parameter_tvb, REGISTRATION_LIFE_OFFSET,     REGISTRATION_LIFE_LENGTH,     ENC_BIG_ENDIAN);
 
   parameters_tvb = tvb_new_subset_remaining(parameter_tvb, USER_TRANSPORT_PARAMETER_OFFSET);
-  dissect_parameters(parameters_tvb, pinfo, parameter_tree);
+  dissect_parameters(parameters_tvb, parameter_tree);
 }
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
-dissect_server_information_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *parameter_tree)
+dissect_server_information_parameter(tvbuff_t *parameter_tvb, proto_tree *parameter_tree)
 {
   tvbuff_t *parameters_tvb;
 
   proto_tree_add_item(parameter_tree, hf_server_identifier, parameter_tvb, SERVER_ID_OFFSET, SERVER_ID_LENGTH, ENC_BIG_ENDIAN);
 
   parameters_tvb = tvb_new_subset_remaining(parameter_tvb, SERVER_TRANSPORT_OFFSET);
-  dissect_parameters(parameters_tvb, pinfo, parameter_tree);
+  dissect_parameters(parameters_tvb, parameter_tree);
 }
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
-dissect_operation_error_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *parameter_tree)
+dissect_operation_error_parameter(tvbuff_t *parameter_tvb, proto_tree *parameter_tree)
 {
   tvbuff_t *error_causes_tvb;
 
   error_causes_tvb = tvb_new_subset_remaining(parameter_tvb, ERROR_CAUSES_OFFSET);
-  dissect_error_causes(error_causes_tvb, pinfo, parameter_tree);
+  dissect_error_causes(error_causes_tvb, parameter_tree);
 }
 
 static void
@@ -435,8 +423,7 @@ dissect_unknown_parameter(tvbuff_t *parameter_tvb, proto_tree *parameter_tree, p
 }
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
-dissect_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *asap_tree)
+dissect_parameter(tvbuff_t *parameter_tvb, proto_tree *asap_tree)
 {
   guint16 type, length, padding_length;
   proto_item *parameter_item;
@@ -455,7 +442,6 @@ dissect_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *asap_
   proto_tree_add_item(parameter_tree, hf_parameter_type,   parameter_tvb, PARAMETER_TYPE_OFFSET,   PARAMETER_TYPE_LENGTH,   ENC_BIG_ENDIAN);
   proto_tree_add_item(parameter_tree, hf_parameter_length, parameter_tvb, PARAMETER_LENGTH_OFFSET, PARAMETER_LENGTH_LENGTH, ENC_BIG_ENDIAN);
 
-  increment_dissection_depth(pinfo);
   switch(type) {
   case IPV4_ADDRESS_PARAMETER_TYPE:
     dissect_ipv4_parameter(parameter_tvb, parameter_tree, parameter_item);
@@ -464,19 +450,19 @@ dissect_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *asap_
     dissect_ipv6_parameter(parameter_tvb, parameter_tree, parameter_item);
     break;
   case DCCP_TRANSPORT_PARAMETER_TYPE:
-    dissect_dccp_transport_parameter(parameter_tvb, pinfo, parameter_tree);
+    dissect_dccp_transport_parameter(parameter_tvb, parameter_tree);
     break;
   case SCTP_TRANSPORT_PARAMETER_TYPE:
-    dissect_sctp_transport_parameter(parameter_tvb, pinfo, parameter_tree);
+    dissect_sctp_transport_parameter(parameter_tvb, parameter_tree);
     break;
   case TCP_TRANSPORT_PARAMETER_TYPE:
-    dissect_tcp_transport_parameter(parameter_tvb, pinfo, parameter_tree);
+    dissect_tcp_transport_parameter(parameter_tvb, parameter_tree);
     break;
   case UDP_TRANSPORT_PARAMETER_TYPE:
-    dissect_udp_transport_parameter(parameter_tvb, pinfo, parameter_tree);
+    dissect_udp_transport_parameter(parameter_tvb, parameter_tree);
     break;
   case UDP_LITE_TRANSPORT_PARAMETER_TYPE:
-    dissect_udp_lite_transport_parameter(parameter_tvb, pinfo, parameter_tree);
+    dissect_udp_lite_transport_parameter(parameter_tvb, parameter_tree);
     break;
   case POOL_MEMBER_SELECTION_POLICY_PARAMETER_TYPE:
     dissect_pool_member_selection_policy_parameter(parameter_tvb, parameter_tree);
@@ -485,13 +471,13 @@ dissect_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *asap_
     dissect_pool_handle_parameter(parameter_tvb, parameter_tree);
     break;
   case POOL_ELEMENT_PARAMETER_TYPE:
-    dissect_pool_element_parameter(parameter_tvb, pinfo, parameter_tree);
+    dissect_pool_element_parameter(parameter_tvb, parameter_tree);
     break;
   case SERVER_INFORMATION_PARAMETER_TYPE:
-    dissect_server_information_parameter(parameter_tvb, pinfo, parameter_tree);
+    dissect_server_information_parameter(parameter_tvb, parameter_tree);
     break;
   case OPERATION_ERROR_PARAMETER_TYPE:
-    dissect_operation_error_parameter(parameter_tvb, pinfo, parameter_tree);
+    dissect_operation_error_parameter(parameter_tvb, parameter_tree);
     break;
   case COOKIE_PARAMETER_TYPE:
     dissect_cookie_parameter(parameter_tvb, parameter_tree, parameter_item);
@@ -509,15 +495,13 @@ dissect_parameter(tvbuff_t *parameter_tvb, packet_info *pinfo, proto_tree *asap_
     dissect_unknown_parameter(parameter_tvb, parameter_tree, parameter_item);
     break;
   };
-  decrement_dissection_depth(pinfo);
 
   if (padding_length > 0)
     proto_tree_add_item(parameter_tree, hf_parameter_padding, parameter_tvb, PARAMETER_HEADER_OFFSET + length, padding_length, ENC_NA);
 }
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
-dissect_parameters(tvbuff_t *parameters_tvb, packet_info *pinfo, proto_tree *tree)
+dissect_parameters(tvbuff_t *parameters_tvb, proto_tree *tree)
 {
   gint offset, length, total_length, remaining_length;
   tvbuff_t *parameter_tvb;
@@ -530,7 +514,7 @@ dissect_parameters(tvbuff_t *parameters_tvb, packet_info *pinfo, proto_tree *tre
       total_length = MIN(total_length, remaining_length);
     /* create a tvb for the parameter including the padding bytes */
     parameter_tvb  = tvb_new_subset_length(parameters_tvb, offset, total_length);
-    dissect_parameter(parameter_tvb, pinfo, tree);
+    dissect_parameter(parameter_tvb, tree);
     /* get rid of the handled parameter */
     offset += total_length;
   }
@@ -587,7 +571,6 @@ static const true_false_string reject_bit_value = {
 };
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
 dissect_asap_message(tvbuff_t *message_tvb, packet_info *pinfo, proto_tree *asap_tree)
 {
   asap_tap_rec_t *tap_rec;
@@ -598,7 +581,7 @@ dissect_asap_message(tvbuff_t *message_tvb, packet_info *pinfo, proto_tree *asap
 
   type = tvb_get_guint8(message_tvb, MESSAGE_TYPE_OFFSET);
   /* pinfo is NULL only if dissect_asap_message is called via dissect_error_cause */
-  if (!pinfo->flags.in_error_pkt) {
+  if (pinfo) {
     tap_rec = wmem_new0(pinfo->pool, asap_tap_rec_t);
     tap_rec->type        = type;
     tap_rec->size        = tvb_get_ntohs(message_tvb, MESSAGE_LENGTH_OFFSET);
@@ -625,21 +608,19 @@ dissect_asap_message(tvbuff_t *message_tvb, packet_info *pinfo, proto_tree *asap
     } else {
       parameters_tvb = tvb_new_subset_remaining(message_tvb, MESSAGE_VALUE_OFFSET);
     }
-    dissect_parameters(parameters_tvb, pinfo, asap_tree);
+    dissect_parameters(parameters_tvb, asap_tree);
     }
 }
 
 static int
-// NOLINTNEXTLINE(misc-no-recursion)
 dissect_asap(tvbuff_t *message_tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
   proto_item *asap_item;
   proto_tree *asap_tree;
 
   /* pinfo is NULL only if dissect_asap is called from dissect_error_cause */
-  if (!pinfo->flags.in_error_pkt) {
+  if (pinfo)
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "ASAP");
-  }
 
   /* create the asap protocol tree */
   asap_item = proto_tree_add_item(tree, proto_asap, message_tvb, 0, -1, ENC_NA);
@@ -697,6 +678,7 @@ static void asap_stat_init(stat_tap_table_ui* new_stat)
   table = stat_tap_init_table(table_name, num_fields, 0, NULL);
   stat_tap_add_table(new_stat, table);
 
+  memset(items, 0x0, sizeof(items));
   /* Add a row for each value type */
   while (message_type_values[i].strptr) {
     items[MESSAGE_TYPE_COLUMN].type                = TABLE_ITEM_STRING;
