@@ -6,6 +6,8 @@
  *
  * Francesco Fondelli <francesco dot fondelli, gmail dot com>
  *
+ * Copyright 2020-2021 by Thomas Dreibholz <dreibh [AT] simula.no>
+ *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
@@ -32,17 +34,25 @@
  *
  * Mar 11, 2012: add support for RFC 5596 (DCCP-Listen Packet)
  * (Francesco Fondelli)
+ *
+ * Feb 19, 2021: added service code types
+ * (Thomas Dreibholz)
  */
 
 #include "config.h"
 
 #include <epan/packet.h>
 #include <epan/addr_resolv.h>
+#include <epan/dccpservicecodes.h>
 #include <epan/ipproto.h>
 #include <epan/in_cksum.h>
 #include <epan/prefs.h>
+#include <epan/follow.h>
 #include <epan/expert.h>
 #include <epan/conversation.h>
+#include <epan/conversation_table.h>
+#include <epan/conversation_filter.h>
+#include <epan/exported_pdu.h>
 #include <epan/tap.h>
 #include <wsutil/str_util.h>
 #include <wsutil/utf8_entities.h>
@@ -64,6 +74,9 @@
 #define DCCP_HDR_LEN_MAX (DCCP_HDR_LEN + DCCP_HDR_PKT_TYPES_LEN_MAX + \
                           DCCP_OPT_LEN_MAX)
 
+/* Static DCCP flags. Set in dccp_flow_t:static_flags */
+#define DCCP_S_BASE_SEQ_SET 0x01
+
 void proto_register_dccp(void);
 void proto_reg_handoff_dccp(void);
 
@@ -92,6 +105,26 @@ static const value_string dccp_packet_type_vals[] = {
     {0,   NULL      }
 };
 
+/*
+ * Based on https://www.iana.org/assignments/service-codes/service-codes.xhtml
+ * as of February 19th, 2021
+ */
+static const value_string dccp_service_code_vals[] = {
+  { NOT_SPECIFIED_SERVICE_CODE, "not specified" },
+  { LTP_SERVICE_CODE,           "LTP: Licklider Transmission Protocol" },
+  { DISC_SERVICE_CODE,          "DISC: Discard" },
+  { RTCP_SERVICE_CODE,          "RTCP: RTCP connection, separate from the corresponding RTP" },
+  { RTPA_SERVICE_CODE,          "RTPA: RTP session conveying audio data (and associated RTCP)" },
+  { RTPO_SERVICE_CODE,          "RTPO: RTP session conveying other media (and associated RTCP)" },
+  { RTPT_SERVICE_CODE,          "RTPT: RTP session conveying text media (and associated RTCP)" },
+  { RTPV_SERVICE_CODE,          "RTPV: RTP session conveying video data (and associated RTCP)" },
+  { SYLG_SERVICE_CODE,          "SYLG: Syslog Protocol" },
+  { BUNDLES_SERVICE_CODE,       "Bundle Protocol" },
+  { NPMP_SERVICE_CODE,          "NPMP: NetPerfMeter Data" },
+  { RESERVED_SERVICE_CODE,      "Reserved (Invalid)" },
+
+  { 0,                          NULL } };
+
 static const value_string dccp_reset_code_vals[] = {
     {0x00, "Unspecified"       },
     {0x01, "Closed"            },
@@ -157,10 +190,12 @@ static const unit_name_string units_bytes_sec = { "bytes/sec", NULL };
 
 static int proto_dccp = -1;
 static int dccp_tap = -1;
+static int dccp_follow_tap = -1;
 
 static int hf_dccp_srcport = -1;
 static int hf_dccp_dstport = -1;
 static int hf_dccp_port = -1;
+static int hf_dccp_stream = -1;
 static int hf_dccp_data_offset = -1;
 static int hf_dccp_ccval = -1;
 static int hf_dccp_cscov = -1;
@@ -171,9 +206,11 @@ static int hf_dccp_type = -1;
 static int hf_dccp_x = -1;
 static int hf_dccp_res2 = -1;
 static int hf_dccp_seq = -1;
+static int hf_dccp_seq_abs = -1;
 
 static int hf_dccp_ack_res = -1;
 static int hf_dccp_ack = -1;
+static int hf_dccp_ack_abs = -1;
 
 static int hf_dccp_service_code = -1;
 static int hf_dccp_reset_code = -1;
@@ -222,6 +259,8 @@ static heur_dissector_list_t heur_subdissector_list;
 static gboolean dccp_summary_in_tree = TRUE;
 static gboolean try_heuristic_first  = FALSE;
 static gboolean dccp_check_checksum  = TRUE;
+static gboolean dccp_relative_seq    = TRUE;
+static guint32  dccp_stream_count;
 
 static void
 decode_dccp_ports(tvbuff_t *tvb, int offset, packet_info *pinfo,
@@ -233,6 +272,11 @@ decode_dccp_ports(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
     next_tvb = tvb_new_subset_remaining(tvb, offset);
 
+    /* If the user has a "Follow DCCP Stream" window loading, pass a pointer
+       to the payload tvb through the tap system. */
+    if (have_tap_listener(dccp_follow_tap))
+        tap_queue_packet(dccp_follow_tap, pinfo, next_tvb);
+
     /*
      * determine if this packet is part of a conversation and call dissector
      * for the conversation if available
@@ -298,6 +342,249 @@ decode_dccp_ports(tvbuff_t *tvb, int offset, packet_info *pinfo,
     call_data_dissector(next_tvb, pinfo, tree);
 }
 
+/* Conversation and process code originally copied from packet-udp.c */
+static struct dccp_analysis *
+init_dccp_conversation_data(packet_info *pinfo)
+{
+  struct dccp_analysis *dccpd;
+
+  /* Initialize the dccp protocol data structure to add to the dccp conversation */
+  dccpd = wmem_new0(wmem_file_scope(), struct dccp_analysis);
+  dccpd->flow1.static_flags = 0;
+  dccpd->flow1.base_seq     = 0;
+  dccpd->flow2.static_flags = 0;
+  dccpd->flow2.base_seq     = 0;
+
+  dccpd->stream   = dccp_stream_count++;
+  dccpd->ts_first = pinfo->abs_ts;
+  dccpd->ts_prev  = pinfo->abs_ts;
+
+  return dccpd;
+}
+
+static struct dccp_analysis *
+get_dccp_conversation_data(conversation_t *conv, packet_info *pinfo)
+{
+  int direction;
+  struct dccp_analysis *dccpd;
+
+  /* Get the data for this conversation */
+  dccpd=(struct dccp_analysis *)conversation_get_proto_data(conv, proto_dccp);
+
+  /* If the conversation was just created or it matched a
+   * conversation with template options, dccpd will not
+   * have been initialized. So, initialize
+   * a new dccpd structure for the conversation.
+   */
+  if (!dccpd) {
+    dccpd = init_dccp_conversation_data(pinfo);
+    conversation_add_proto_data(conv, proto_dccp, dccpd);
+  }
+
+  /* check direction and get ua lists */
+  direction=cmp_address(&pinfo->src, &pinfo->dst);
+  /* if the addresses are equal, match the ports instead */
+  if (direction == 0) {
+    direction= (pinfo->srcport > pinfo->destport) ? 1 : -1;
+  }
+  if (direction >= 0) {
+    dccpd->fwd=&(dccpd->flow1);
+    dccpd->rev=&(dccpd->flow2);
+  } else {
+    dccpd->fwd=&(dccpd->flow2);
+    dccpd->rev=&(dccpd->flow1);
+  }
+
+  return dccpd;
+}
+
+static const char* dccp_conv_get_filter_type(conv_item_t* conv, conv_filter_type_e filter)
+{
+    if (filter == CONV_FT_SRC_PORT)
+        return "dccp.srcport";
+
+    if (filter == CONV_FT_DST_PORT)
+        return "dccp.dstport";
+
+    if (filter == CONV_FT_ANY_PORT)
+        return "dccp.port";
+
+    if(!conv) {
+        return CONV_FILTER_INVALID;
+    }
+
+    if (filter == CONV_FT_SRC_ADDRESS) {
+        if (conv->src_address.type == AT_IPv4)
+            return "ip.src";
+        if (conv->src_address.type == AT_IPv6)
+            return "ipv6.src";
+    }
+
+    if (filter == CONV_FT_DST_ADDRESS) {
+        if (conv->dst_address.type == AT_IPv4)
+            return "ip.dst";
+        if (conv->dst_address.type == AT_IPv6)
+            return "ipv6.dst";
+    }
+
+    if (filter == CONV_FT_ANY_ADDRESS) {
+        if (conv->src_address.type == AT_IPv4)
+            return "ip.addr";
+        if (conv->src_address.type == AT_IPv6)
+            return "ipv6.addr";
+    }
+
+    return CONV_FILTER_INVALID;
+}
+
+static ct_dissector_info_t dccp_ct_dissector_info = {&dccp_conv_get_filter_type};
+
+static tap_packet_status
+dccpip_conversation_packet(void *pct, packet_info *pinfo, epan_dissect_t *edt _U_, const void *vip)
+{
+    conv_hash_t *hash = (conv_hash_t*) pct;
+    const e_dccphdr *dccphdr=(const e_dccphdr *)vip;
+
+    add_conversation_table_data_with_conv_id(hash, &dccphdr->ip_src, &dccphdr->ip_dst, dccphdr->sport, dccphdr->dport, (conv_id_t) dccphdr->stream, 1, pinfo->fd->pkt_len, &pinfo->rel_ts, &pinfo->abs_ts, &dccp_ct_dissector_info, ENDPOINT_DCCP);
+
+    return TAP_PACKET_REDRAW;
+}
+
+static const char* dccp_host_get_filter_type(hostlist_talker_t* host, conv_filter_type_e filter)
+{
+
+    if (filter == CONV_FT_SRC_PORT)
+        return "dccp.srcport";
+
+    if (filter == CONV_FT_DST_PORT)
+        return "dccp.dstport";
+
+    if (filter == CONV_FT_ANY_PORT)
+        return "dccp.port";
+
+    if(!host) {
+        return CONV_FILTER_INVALID;
+    }
+
+
+    if (filter == CONV_FT_SRC_ADDRESS) {
+        if (host->myaddress.type == AT_IPv4)
+            return "ip.src";
+        if (host->myaddress.type == AT_IPv6)
+            return "ipv6.src";
+    }
+
+    if (filter == CONV_FT_DST_ADDRESS) {
+        if (host->myaddress.type == AT_IPv4)
+            return "ip.dst";
+        if (host->myaddress.type == AT_IPv6)
+            return "ipv6.dst";
+    }
+
+    if (filter == CONV_FT_ANY_ADDRESS) {
+        if (host->myaddress.type == AT_IPv4)
+            return "ip.addr";
+        if (host->myaddress.type == AT_IPv6)
+            return "ipv6.addr";
+    }
+
+    return CONV_FILTER_INVALID;
+}
+
+static hostlist_dissector_info_t dccp_host_dissector_info = {&dccp_host_get_filter_type};
+
+static tap_packet_status
+dccpip_hostlist_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, const void *vip)
+{
+    conv_hash_t *hash = (conv_hash_t*) pit;
+    const e_dccphdr *dccphdr=(const e_dccphdr *)vip;
+
+    /* Take two "add" passes per packet, adding for each direction, ensures that all
+    packets are counted properly (even if address is sending to itself)
+    XXX - this could probably be done more efficiently inside hostlist_table */
+    add_hostlist_table_data(hash, &dccphdr->ip_src, dccphdr->sport, TRUE, 1, pinfo->fd->pkt_len, &dccp_host_dissector_info, ENDPOINT_DCCP);
+    add_hostlist_table_data(hash, &dccphdr->ip_dst, dccphdr->dport, FALSE, 1, pinfo->fd->pkt_len, &dccp_host_dissector_info, ENDPOINT_DCCP);
+
+    return TAP_PACKET_REDRAW;
+}
+
+/* Return the current stream count */
+guint32 get_dccp_stream_count(void)
+{
+    return dccp_stream_count;
+}
+
+static gboolean
+dccp_filter_valid(packet_info *pinfo)
+{
+    return proto_is_frame_protocol(pinfo->layers, "dccp");
+}
+
+static gchar*
+dccp_build_filter(packet_info *pinfo)
+{
+    if( pinfo->net_src.type == AT_IPv4 && pinfo->net_dst.type == AT_IPv4 ) {
+        /* DCCP over IPv4 */
+        return ws_strdup_printf("(ip.addr eq %s and ip.addr eq %s) and (dccp.port eq %d and dccp.port eq %d)",
+            address_to_str(pinfo->pool, &pinfo->net_src),
+            address_to_str(pinfo->pool, &pinfo->net_dst),
+            pinfo->srcport, pinfo->destport );
+    }
+
+    if( pinfo->net_src.type == AT_IPv6 && pinfo->net_dst.type == AT_IPv6 ) {
+        /* DCCP over IPv6 */
+        return ws_strdup_printf("(ipv6.addr eq %s and ipv6.addr eq %s) and (dccp.port eq %d and dccp.port eq %d)",
+            address_to_str(pinfo->pool, &pinfo->net_src),
+            address_to_str(pinfo->pool, &pinfo->net_dst),
+            pinfo->srcport, pinfo->destport );
+    }
+
+    return NULL;
+}
+
+static gchar *dccp_follow_conv_filter(epan_dissect_t *edt _U_, packet_info *pinfo, guint *stream, guint *sub_stream _U_)
+{
+    conversation_t *conv;
+    struct dccp_analysis *dccpd;
+
+    if( ((pinfo->net_src.type == AT_IPv4 && pinfo->net_dst.type == AT_IPv4) ||
+            (pinfo->net_src.type == AT_IPv6 && pinfo->net_dst.type == AT_IPv6))
+          && (conv=find_conversation_pinfo(pinfo, 0)) != NULL )
+    {
+        /* DCCP over IPv4/6 */
+        dccpd = get_dccp_conversation_data(conv, pinfo);
+        *stream = dccpd->stream;
+        return ws_strdup_printf("dccp.stream eq %u", dccpd->stream);
+    }
+
+    return NULL;
+}
+
+static gchar *dccp_follow_index_filter(guint stream, guint sub_stream _U_)
+{
+    return ws_strdup_printf("dccp.stream eq %u", stream);
+}
+
+static gchar *dccp_follow_address_filter(address *src_addr, address *dst_addr, int src_port, int dst_port)
+{
+    const gchar  *ip_version = src_addr->type == AT_IPv6 ? "v6" : "";
+    gchar         src_addr_str[WS_INET6_ADDRSTRLEN];
+    gchar         dst_addr_str[WS_INET6_ADDRSTRLEN];
+
+    address_to_str_buf(src_addr, src_addr_str, sizeof(src_addr_str));
+    address_to_str_buf(dst_addr, dst_addr_str, sizeof(dst_addr_str));
+
+    return ws_strdup_printf("((ip%s.src eq %s and dccp.srcport eq %d) and "
+                     "(ip%s.dst eq %s and dccp.dstport eq %d))"
+                     " or "
+                     "((ip%s.src eq %s and dccp.srcport eq %d) and "
+                     "(ip%s.dst eq %s and dccp.dstport eq %d))",
+                     ip_version, src_addr_str, src_port,
+                     ip_version, dst_addr_str, dst_port,
+                     ip_version, dst_addr_str, dst_port,
+                     ip_version, src_addr_str, src_port);
+}
+
 /*
  * decode a variable-length number of nbytes starting at offset.  Based on
  * a concept by Arnaldo de Melo
@@ -383,7 +670,7 @@ dissect_feature_options(proto_tree *dccp_options_tree, tvbuff_t *tvb,
     case 5:       /* Ack Ratio                                     */
 
         if (option_len > 0) /* could be empty Confirm */
-            proto_item_append_text(dccp_item, " %" G_GINT64_MODIFIER "u",
+            proto_item_append_text(dccp_item, " %" PRIu64,
                                    dccp_ntoh_var(tvb, offset, option_len));
         break;
 
@@ -596,6 +883,7 @@ static int
 dissect_dccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
     proto_tree *dccp_tree;
+    proto_item *item;
     proto_tree *dccp_options_tree = NULL;
     proto_item *dccp_item         = NULL;
     proto_item *hidden_item, *offset_item;
@@ -607,9 +895,13 @@ dissect_dccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
     guint      csum_coverage_len;
     guint      advertised_dccp_header_len = 0;
     guint      options_len                = 0;
+    guint64    seq;   /* Absolute or relative seq number (depending on DCCP_S_BASE_SEQ_SET) */
+    guint64    ack;   /* Absolute or relative ack number (depending on DCCP_S_BASE_SEQ_SET) */
     e_dccphdr *dccph;
+    conversation_t *conv = NULL;
+    struct dccp_analysis *dccpd;
 
-    dccph = wmem_new0(wmem_packet_scope(), e_dccphdr);
+    dccph = wmem_new0(pinfo->pool, e_dccphdr);
     dccph->sport = tvb_get_ntohs(tvb, offset);
     dccph->dport = tvb_get_ntohs(tvb, offset + 2);
     copy_address_shallow(&dccph->ip_src, &pinfo->src);
@@ -622,8 +914,8 @@ dissect_dccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
     dccp_item = proto_tree_add_item(tree, proto_dccp, tvb, offset, -1, ENC_NA);
     if (dccp_summary_in_tree) {
         proto_item_append_text(dccp_item, ", Src Port: %s, Dst Port: %s",
-                               port_with_resolution_to_str(wmem_packet_scope(), PT_DCCP, dccph->sport),
-                               port_with_resolution_to_str(wmem_packet_scope(), PT_DCCP, dccph->dport));
+                               port_with_resolution_to_str(pinfo->pool, PT_DCCP, dccph->sport),
+                               port_with_resolution_to_str(pinfo->pool, PT_DCCP, dccph->dport));
     }
     dccp_tree = proto_item_add_subtree(dccp_item, ett_dccp);
 
@@ -645,6 +937,17 @@ dissect_dccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
     pinfo->srcport = dccph->sport;
     pinfo->destport = dccph->dport;
 
+    /* find (or create if needed) the conversation for this DCCP session */
+    conv = find_or_create_conversation(pinfo);
+    dccpd = get_dccp_conversation_data(conv, pinfo);
+    item = proto_tree_add_uint(dccp_tree, hf_dccp_stream, tvb, offset, 0, dccpd->stream);
+    proto_item_set_generated(item);
+
+    /* Copy the stream index into the header as well to make it available
+    * to tap listeners.
+    */
+    dccph->stream = dccpd->stream;
+
     dccph->data_offset = tvb_get_guint8(tvb, offset);
     advertised_dccp_header_len = dccph->data_offset * 4;
     offset_item = proto_tree_add_uint(dccp_tree, hf_dccp_data_offset, tvb, offset, 1,
@@ -743,8 +1046,16 @@ dissect_dccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
         offset += 1;
 
         dccph->seq = tvb_get_ntoh48(tvb, offset);
-        proto_tree_add_uint64(dccp_tree, hf_dccp_seq, tvb, offset, 6,
-                              dccph->seq);
+        if((dccp_relative_seq) && (dccpd->fwd->static_flags & DCCP_S_BASE_SEQ_SET)) {
+            seq = dccph->seq - dccpd->fwd->base_seq;
+            proto_tree_add_uint64_format_value(dccp_tree, hf_dccp_seq, tvb, offset, 6,
+                                               seq, "%" PRIu64 "    (relative sequence number)", seq);
+        }
+        else {
+            seq = dccph->seq;
+        }
+        proto_tree_add_uint64(dccp_tree, hf_dccp_seq_abs, tvb, offset, 6, dccph->seq);
+
         offset += 6;
     } else {
         if (advertised_dccp_header_len < DCCP_GEN_HDR_LEN_NO_X) {
@@ -754,17 +1065,21 @@ dissect_dccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
             return tvb_reported_length(tvb);
         }
         dccph->seq = tvb_get_ntoh24(tvb, offset);
-        proto_tree_add_uint64(dccp_tree, hf_dccp_seq, tvb, offset, 3,
-                              dccph->seq);
+        proto_tree_add_uint64(dccp_tree, hf_dccp_seq, tvb, offset, 3, dccph->seq);
+        if((dccp_relative_seq) && (dccpd->fwd->static_flags & DCCP_S_BASE_SEQ_SET)) {
+            seq = (dccph->seq - dccpd->fwd->base_seq) & 0xffffff;
+            proto_tree_add_uint64_format_value(dccp_tree, hf_dccp_seq, tvb, offset, 3,
+                                               seq, "%" PRIu64 "    (relative sequence number)", seq);
+        }
+        else {
+            seq = dccph->seq;
+        }
         offset += 3;
     }
     if (dccp_summary_in_tree) {
-        proto_item_append_text(dccp_item, " Seq=%" G_GINT64_MODIFIER "u",
-                               dccph->seq);
+        proto_item_append_text(dccp_item, " Seq=%" PRIu64, seq);
     }
-    col_append_fstr(pinfo->cinfo, COL_INFO,
-                    " Seq=%" G_GINT64_MODIFIER "u",
-                    dccph->seq);
+    col_append_fstr(pinfo->cinfo, COL_INFO, " Seq=%" PRIu64, seq);
 
     /* dissecting type dependent additional fields */
     switch (dccph->type) {
@@ -781,9 +1096,15 @@ dissect_dccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
         if (tree)
             proto_tree_add_uint(dccp_tree, hf_dccp_service_code, tvb, offset, 4,
                                 dccph->service_code);
-        col_append_fstr(pinfo->cinfo, COL_INFO, " (service=%u)",
-                        dccph->service_code);
+        col_append_fstr(pinfo->cinfo, COL_INFO, " (service=%s)",
+                        val_to_str(dccph->service_code, dccp_service_code_vals, "Unknown (%u)"));
         offset += 4; /* move offset past the service code */
+
+        if( !(dccpd->fwd->static_flags & DCCP_S_BASE_SEQ_SET) ) {
+            dccpd->fwd->base_seq = dccph->seq;
+            dccpd->fwd->static_flags |= DCCP_S_BASE_SEQ_SET;
+        }
+
         break;
     case 0x1: /* DCCP-Response */
         if (advertised_dccp_header_len < offset + 12) {
@@ -803,22 +1124,36 @@ dissect_dccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
         dccph->ack <<= 32;
         dccph->ack += tvb_get_ntohl(tvb, offset + 4);
 
-        if (tree)
-            proto_tree_add_uint64(dccp_tree, hf_dccp_ack, tvb, offset + 2, 6,
-                                  dccph->ack);
-        col_append_fstr(pinfo->cinfo, COL_INFO,
-                        " (Ack=%" G_GINT64_MODIFIER "u)",
-                        dccph->ack);
+        if((dccp_relative_seq) && (dccpd->rev->static_flags & DCCP_S_BASE_SEQ_SET)) {
+            ack = dccph->ack - dccpd->rev->base_seq;
+        }
+        else {
+            ack = dccph->ack;
+        }
+
+        if (tree) {
+            if((dccp_relative_seq) && (dccpd->rev->static_flags & DCCP_S_BASE_SEQ_SET)) {
+                proto_tree_add_uint64(dccp_tree, hf_dccp_ack, tvb, offset + 2, 6, ack);
+            }
+            proto_tree_add_uint64(dccp_tree, hf_dccp_ack_abs, tvb, offset + 2, 6, dccph->ack);
+        }
+        col_append_fstr(pinfo->cinfo, COL_INFO, " (Ack=%" PRIu64 ")", ack);
         offset += 8; /* move offset past the Acknowledgement Number Subheader */
 
         dccph->service_code = tvb_get_ntohl(tvb, offset);
         if (tree)
             proto_tree_add_uint(dccp_tree, hf_dccp_service_code, tvb, offset, 4,
                                 dccph->service_code);
-        col_append_fstr(pinfo->cinfo, COL_INFO, " (service=%u)",
-                        dccph->service_code);
+        col_append_fstr(pinfo->cinfo, COL_INFO, " (service=%s)",
+                        val_to_str(dccph->service_code, dccp_service_code_vals, "Unknown (%u)"));
 
         offset += 4; /* move offset past the service code */
+
+        if( !(dccpd->fwd->static_flags & DCCP_S_BASE_SEQ_SET) ) {
+            dccpd->fwd->base_seq = dccph->seq;
+            dccpd->fwd->static_flags |= DCCP_S_BASE_SEQ_SET;
+        }
+
         break;
     case 0x2: /* DCCP-Data */
         /* nothing to dissect */
@@ -843,12 +1178,22 @@ dissect_dccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
             dccph->ack = tvb_get_ntohs(tvb, offset + 2);
             dccph->ack <<= 32;
             dccph->ack += tvb_get_ntohl(tvb, offset + 4);
-            if (tree)
-                proto_tree_add_uint64(dccp_tree, hf_dccp_ack, tvb, offset + 2,
-                                      6, dccph->ack);
-            col_append_fstr(pinfo->cinfo, COL_INFO,
-                            " (Ack=%" G_GINT64_MODIFIER "u)",
-                            dccph->ack);
+
+            if((dccp_relative_seq) && (dccpd->rev->static_flags & DCCP_S_BASE_SEQ_SET)) {
+                ack = dccph->ack - dccpd->rev->base_seq;
+            }
+            else {
+                ack = dccph->ack;
+            }
+
+            if (tree) {
+                if((dccp_relative_seq) && (dccpd->rev->static_flags & DCCP_S_BASE_SEQ_SET)) {
+                    proto_tree_add_uint64_format_value(dccp_tree, hf_dccp_ack, tvb, offset + 2, 6,
+                                                       ack, "%" PRIu64 "    (relative acknowledgement number)", ack);
+                }
+                proto_tree_add_uint64(dccp_tree, hf_dccp_ack_abs, tvb, offset + 2, 6, dccph->ack);
+            }
+            col_append_fstr(pinfo->cinfo, COL_INFO, " (Ack=%" PRIu64 ")", ack);
             offset += 8; /* move offset past the Ack Number Subheader */
         } else {
             if (advertised_dccp_header_len < offset + 4) {
@@ -868,11 +1213,22 @@ dissect_dccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
             dccph->ack = tvb_get_guint8(tvb, offset + 1);
             dccph->ack <<= 16;
             dccph->ack += tvb_get_ntohs(tvb, offset + 2);
-            if (tree)
-                proto_tree_add_uint64(dccp_tree, hf_dccp_ack, tvb, offset + 1,
-                                      3, dccph->ack);
-            col_append_fstr(pinfo->cinfo, COL_INFO,
-                            " (Ack=%" G_GINT64_MODIFIER "u)", dccph->ack);
+
+            if((dccp_relative_seq) && (dccpd->rev->static_flags & DCCP_S_BASE_SEQ_SET)) {
+                ack = (dccph->ack - dccpd->rev->base_seq) & 0xffffff;
+            }
+            else {
+                ack = dccph->ack;
+            }
+
+            if (tree) {
+                if((dccp_relative_seq) && (dccpd->rev->static_flags & DCCP_S_BASE_SEQ_SET)) {
+                    proto_tree_add_uint64_format_value(dccp_tree, hf_dccp_ack, tvb, offset + 1, 3,
+                                                       ack, "%" PRIu64 "    (relative acknowledgement number)", ack);
+                }
+                proto_tree_add_uint64(dccp_tree, hf_dccp_ack_abs, tvb, offset + 1, 3, dccph->ack);
+            }
+            col_append_fstr(pinfo->cinfo, COL_INFO, " (Ack=%" PRIu64 ")", ack);
             offset += 4; /* move offset past the Ack. Number Subheader */
         }
         break;
@@ -896,11 +1252,21 @@ dissect_dccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
         dccph->ack <<= 32;
         dccph->ack += tvb_get_ntohl(tvb, offset + 4);
 
-        if (tree)
-            proto_tree_add_uint64(dccp_tree, hf_dccp_ack, tvb, offset + 2, 6,
-                                  dccph->ack);
-        col_append_fstr(pinfo->cinfo, COL_INFO,
-                        " (Ack=%" G_GINT64_MODIFIER "u)", dccph->ack);
+        if((dccp_relative_seq) && (dccpd->rev->static_flags & DCCP_S_BASE_SEQ_SET)) {
+            ack = (dccph->ack - dccpd->rev->base_seq) & 0xffffff;
+        }
+        else {
+            ack = dccph->ack;
+        }
+
+        if (tree) {
+            if((dccp_relative_seq) && (dccpd->rev->static_flags & DCCP_S_BASE_SEQ_SET)) {
+                proto_tree_add_uint64_format_value(dccp_tree, hf_dccp_ack, tvb, offset + 1, 3,
+                                                    ack, "%" PRIu64 "    (relative acknowledgement number)", ack);
+            }
+            proto_tree_add_uint64(dccp_tree, hf_dccp_ack_abs, tvb, offset + 1, 3, dccph->ack);
+        }
+        col_append_fstr(pinfo->cinfo, COL_INFO, " (Ack=%" PRIu64 ")", ack);
         offset += 8; /* move offset past the Ack. Number Subheader */
 
         dccph->reset_code = tvb_get_guint8(tvb, offset);
@@ -945,11 +1311,22 @@ dissect_dccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
         dccph->ack = tvb_get_ntohs(tvb, offset + 2);
         dccph->ack <<= 32;
         dccph->ack += tvb_get_ntohl(tvb, offset + 4);
-        if (tree)
-            proto_tree_add_uint64(dccp_tree, hf_dccp_ack, tvb, offset + 2, 6,
-                                  dccph->ack);
-        col_append_fstr(pinfo->cinfo, COL_INFO,
-                        " (Ack=%" G_GINT64_MODIFIER "u)", dccph->ack);
+
+        if((dccp_relative_seq) && (dccpd->rev->static_flags & DCCP_S_BASE_SEQ_SET)) {
+            ack = (dccph->ack - dccpd->rev->base_seq) & 0xffffff;
+        }
+        else {
+            ack = dccph->ack;
+        }
+
+        if (tree) {
+            if((dccp_relative_seq) && (dccpd->rev->static_flags & DCCP_S_BASE_SEQ_SET)) {
+                proto_tree_add_uint64_format_value(dccp_tree, hf_dccp_ack, tvb, offset + 1, 3,
+                                                    ack, "%" PRIu64 "    (relative acknowledgement number)", ack);
+            }
+            proto_tree_add_uint64(dccp_tree, hf_dccp_ack_abs, tvb, offset + 1, 3, dccph->ack);
+        }
+        col_append_fstr(pinfo->cinfo, COL_INFO, " (Ack=%" PRIu64 ")", ack);
         offset += 8; /* move offset past the Ack. Number Subheader */
         break;
     default:
@@ -1004,6 +1381,12 @@ dissect_dccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
     return tvb_reported_length(tvb);
 }
 
+static void
+dccp_init(void)
+{
+  dccp_stream_count = 0;
+}
+
 void
 proto_register_dccp(void)
 {
@@ -1034,6 +1417,14 @@ proto_register_dccp(void)
                 NULL, HFILL
             }
         },
+        {
+            &hf_dccp_stream,
+            {
+                "Stream index", "dccp.stream",
+                FT_UINT32, BASE_DEC, NULL, 0x0,
+                NULL, HFILL
+            }
+        },
         {
             &hf_dccp_data_offset,
             {
@@ -1114,6 +1505,14 @@ proto_register_dccp(void)
                 NULL, HFILL
             }
         },
+        {
+            &hf_dccp_seq_abs,
+            {
+                "Sequence Number (raw)", "dccp.seq_raw",
+                FT_UINT64, BASE_DEC, NULL, 0x0,
+                NULL, HFILL
+            }
+        },
         {
             &hf_dccp_ack_res,
             {
@@ -1130,11 +1529,19 @@ proto_register_dccp(void)
                 NULL, HFILL
             }
         },
+        {
+            &hf_dccp_ack_abs,
+            {
+                "Acknowledgement Number (raw)", "dccp.ack_raw",
+                FT_UINT64, BASE_DEC, NULL, 0x0,
+                NULL, HFILL
+            }
+        },
         {
             &hf_dccp_service_code,
             {
                 "Service Code", "dccp.service_code",
-                FT_UINT32, BASE_DEC, NULL, 0x0,
+                FT_UINT32, BASE_DEC, VALS(dccp_service_code_vals), 0x0,
                 NULL, HFILL
             }
         },
@@ -1304,6 +1711,19 @@ proto_register_dccp(void)
         "Check the validity of the DCCP checksum when possible",
         "Whether to check the validity of the DCCP checksum",
         &dccp_check_checksum);
+
+    prefs_register_bool_preference(
+        dccp_module, "relative_sequence_numbers",
+        "Relative sequence numbers",
+        "Make the DCCP dissector use relative sequence numbers instead of absolute ones.",
+        &dccp_relative_seq);
+
+    register_conversation_table(proto_dccp, FALSE, dccpip_conversation_packet, dccpip_hostlist_packet);
+    register_conversation_filter("dccp", "DCCP", dccp_filter_valid, dccp_build_filter);
+    register_follow_stream(proto_dccp, "dccp_follow", dccp_follow_conv_filter, dccp_follow_index_filter, dccp_follow_address_filter,
+                           dccp_port_to_display, follow_tvb_tap_listener);
+
+    register_init_routine(dccp_init);
 }
 
 void
@@ -1314,10 +1734,11 @@ proto_reg_handoff_dccp(void)
     dccp_handle = create_dissector_handle(dissect_dccp, proto_dccp);
     dissector_add_uint("ip.proto", IP_PROTO_DCCP, dccp_handle);
     dccp_tap    = register_tap("dccp");
+    dccp_follow_tap = register_tap("dccp_follow");
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
