@@ -36,8 +36,6 @@
 
 #include "config.h"
 
-#include <stdio.h>
-
 #include <epan/packet.h>
 #include <epan/exceptions.h>
 #include <epan/prefs.h>
@@ -51,6 +49,7 @@
 #include <epan/sctpppids.h>
 #include <epan/show_exception.h>
 #include <epan/to_str.h>
+#include <epan/strutil.h>
 #include <epan/afn.h>
 #include <wsutil/filesystem.h>
 #include <wsutil/report_message.h>
@@ -310,6 +309,7 @@ static expert_field ei_diameter_avp_vendor_id = EI_INIT;
 static expert_field ei_diameter_invalid_ipv6_prefix_len = EI_INIT;
 static expert_field ei_diameter_invalid_avp_len = EI_INIT;
 static expert_field ei_diameter_invalid_user_equipment_info_value_len = EI_INIT;
+static expert_field ei_diameter_unexpected_imei_as_user_equipment_info = EI_INIT;
 
 /* Tap for Diameter */
 static int diameter_tap = -1;
@@ -702,12 +702,17 @@ dissect_diameter_user_equipment_info_value(tvbuff_t *tvb, packet_info *pinfo, pr
 	case USER_EQUIPMENT_INFO_TYPE_IMEISV:
 		/* RFC 8506 section 8.53, 3GPP TS 23.003 */
 		len = tvb_reported_length(tvb);
-		/* IMEISV is 16 digits, but often transmitted BCD coded in 8 octets. */
+		/* IMEISV is 16 digits, but often transmitted BCD coded in 8 octets.
+		   Some implementations use IMEI (15 digits) instead of IMEISV */
 		if (len == 8) {
 			proto_tree_add_item(tree, hf_diameter_user_equipment_info_imeisv, tvb, 0, len, ENC_BCD_DIGITS_0_9|ENC_NA);
 			return len;
 		} else if (len == 16) {
-			proto_tree_add_item(tree, hf_diameter_user_equipment_info_imeisv, tvb, 0, len, ENC_ASCII|ENC_NA);
+			proto_tree_add_item(tree, hf_diameter_user_equipment_info_imeisv, tvb, 0, len, ENC_ASCII);
+			return len;
+		} else if (len == 15) {
+			proto_tree_add_item(tree, hf_diameter_user_equipment_info_imeisv, tvb, 0, len, ENC_ASCII);
+			proto_tree_add_expert(tree, pinfo, &ei_diameter_unexpected_imei_as_user_equipment_info, tvb, 0, len);
 			return len;
 		}
 		proto_tree_add_expert(tree, pinfo, &ei_diameter_invalid_user_equipment_info_value_len, tvb, 0, len);
@@ -1690,7 +1695,7 @@ dissect_diameter_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *
 		call_dissector(data_handle, tvb, pinfo, tree);
 	} else if (is_diam == NOT_ENOUGH_DATA) {
 		/* Since we're doing our heuristic checks before
-		 * tcp_dissect_pdus() (since we we can't do heuristics once
+		 * tcp_dissect_pdus() (since we can't do heuristics once
 		 * we're in there) we sometimes have to ask for more data...
 		 */
                 pinfo->desegment_offset = 0;
@@ -2527,7 +2532,8 @@ real_register_diameter_fields(void)
 		{ &ei_diameter_code, { "diameter.cmd.code.unknown", PI_UNDECODED, PI_WARN, "Unknown command, if you know what this is you can add it to dictionary.xml", EXPFILL }},
 		{ &ei_diameter_invalid_ipv6_prefix_len, { "diameter.invalid_ipv6_prefix_len", PI_MALFORMED, PI_ERROR, "Invalid IPv6 Prefix length", EXPFILL }},
 		{ &ei_diameter_invalid_avp_len,{ "diameter.invalid_avp_len", PI_MALFORMED, PI_ERROR, "Invalid AVP length", EXPFILL }},
-		{ &ei_diameter_invalid_user_equipment_info_value_len,{ "diameter.invalid_user_equipment_info_value_len", PI_MALFORMED, PI_ERROR, "Invalid User-Equipment-Info-Value length", EXPFILL }}
+		{ &ei_diameter_invalid_user_equipment_info_value_len,{ "diameter.invalid_user_equipment_info_value_len", PI_MALFORMED, PI_ERROR, "Invalid User-Equipment-Info-Value length", EXPFILL }},
+		{ &ei_diameter_unexpected_imei_as_user_equipment_info,{ "diameter.unexpected_imei_as_user_equipment_info", PI_MALFORMED, PI_ERROR, "Found IMEI as User-Equipment-Info-Value but IMEISV was expected", EXPFILL }},
 	};
 
 	wmem_array_append(build_dict.hf, hf_base, array_length(hf_base));
