@@ -525,15 +525,15 @@ dissect_swils_interconnect_element_info(tvbuff_t *tvb, proto_tree *tree, int off
     if (tree) {
         proto_tree_add_item(tree, hf_swils_interconnect_list_len, tvb, offset+3, 1, ENC_BIG_ENDIAN);
         len = tvb_strsize(tvb, offset+4);
-        proto_tree_add_item(tree, hf_swils_ess_vendorname, tvb, offset+4, len, ENC_ASCII|ENC_NA);
+        proto_tree_add_item(tree, hf_swils_ess_vendorname, tvb, offset+4, len, ENC_ASCII);
         offset += (4 + len);
         max_len -= len;
         len = tvb_strsize(tvb, offset);
-        proto_tree_add_item(tree, hf_swils_ess_modelname, tvb, offset, len, ENC_ASCII|ENC_NA);
+        proto_tree_add_item(tree, hf_swils_ess_modelname, tvb, offset, len, ENC_ASCII);
         offset += len;
         max_len -= len;
         len = tvb_strsize(tvb, offset);
-        proto_tree_add_item(tree, hf_swils_ess_relcode, tvb, offset, len, ENC_ASCII|ENC_NA);
+        proto_tree_add_item(tree, hf_swils_ess_relcode, tvb, offset, len, ENC_ASCII);
         offset += len;
         max_len -= len;
         while (max_len > 0) {
@@ -541,7 +541,7 @@ dissect_swils_interconnect_element_info(tvbuff_t *tvb, proto_tree *tree, int off
              * strings
              */
             len = tvb_strsize(tvb, offset);
-            proto_tree_add_item(tree, hf_swils_ess_vendorspecific, tvb, offset, len, ENC_ASCII|ENC_NA);
+            proto_tree_add_item(tree, hf_swils_ess_vendorspecific, tvb, offset, len, ENC_ASCII);
             offset += len;
             max_len -= len;
         }
@@ -669,7 +669,7 @@ dissect_swils_ess_capability_obj(tvbuff_t *tvb, proto_tree *tree, int offset)
             proto_tree_add_item(capinfo_tree, hf_swils_ess_cap_len, tvb, offset+3,
                                 1, ENC_BIG_ENDIAN);
             proto_tree_add_item(capinfo_tree, hf_swils_ess_cap_t10, tvb, offset+4,
-                                8, ENC_ASCII|ENC_NA);
+                                8, ENC_ASCII);
             i -= 8;          /* reduce length by t10 object size */
             offset += 12;
             len += 12;
@@ -752,19 +752,19 @@ dissect_swils_elp(tvbuff_t *tvb, packet_info* pinfo _U_, proto_tree *elp_tree, g
             flagsbuf=(char *)wmem_alloc(wmem_packet_scope(), MAX_FLAGS_LEN);
             stroff = 0;
 
-            returned_length = g_snprintf(flagsbuf+stroff, MAX_FLAGS_LEN-stroff,
+            returned_length = snprintf(flagsbuf+stroff, MAX_FLAGS_LEN-stroff,
                                          "Class 1 Valid");
             stroff += MIN(returned_length, MAX_FLAGS_LEN-stroff);
             if (cls1_svcparm[0] & 0x40) {
-                returned_length = g_snprintf(flagsbuf+stroff, MAX_FLAGS_LEN-stroff, " | IMX");
+                returned_length = snprintf(flagsbuf+stroff, MAX_FLAGS_LEN-stroff, " | IMX");
                 stroff += MIN(returned_length, MAX_FLAGS_LEN-stroff);
             }
             if (cls1_svcparm[0] & 0x20) {
-                returned_length = g_snprintf(flagsbuf+stroff, MAX_FLAGS_LEN-stroff, " | IPS");
+                returned_length = snprintf(flagsbuf+stroff, MAX_FLAGS_LEN-stroff, " | IPS");
                 stroff += MIN(returned_length, MAX_FLAGS_LEN-stroff);
             }
             if (cls1_svcparm[0] & 0x10) {
-                /*returned_length =*/ g_snprintf(flagsbuf+stroff, MAX_FLAGS_LEN-stroff, " | LKS");
+                /*returned_length =*/ snprintf(flagsbuf+stroff, MAX_FLAGS_LEN-stroff, " | LKS");
             }
             flags=flagsbuf;
         }
@@ -1205,7 +1205,6 @@ dissect_swils_zone_mbr(tvbuff_t *tvb, packet_info* pinfo, proto_tree *zmbr_tree,
 }
 
 static void
-// NOLINTNEXTLINE(misc-no-recursion)
 dissect_swils_zone_obj(tvbuff_t *tvb, packet_info* pinfo, proto_tree *zobj_tree, int offset)
 {
     proto_tree *zmbr_tree;
@@ -1228,7 +1227,6 @@ dissect_swils_zone_obj(tvbuff_t *tvb, packet_info* pinfo, proto_tree *zobj_tree,
     offset += 8 + ZONENAME_LEN(tvb, offset+4);
     for (i = 0; i < numrec; i++) {
         if (objtype == FC_SWILS_ZONEOBJ_ZONESET) {
-            // We recurse here, but we'll run out of packet before we run out of stack.
             dissect_swils_zone_obj(tvb, pinfo, zobj_tree, offset);
             offset += get_zoneobj_len(tvb, offset);
         }
@@ -1475,7 +1473,7 @@ dissect_swils_esc(tvbuff_t *tvb, packet_info* pinfo _U_, proto_tree *esc_tree, g
             plen = tvb_get_ntohs(tvb, offset+2);
             proto_tree_add_item(esc_tree, hf_swils_esc_payload_length, tvb, offset+2, 2, ENC_BIG_ENDIAN);
             proto_tree_add_item(esc_tree, hf_swils_esc_swvendorid, tvb,
-                                offset+4, 8, ENC_ASCII|ENC_NA);
+                                offset+4, 8, ENC_ASCII);
             numrec = (plen - 12)/12;
             offset = 12;
 
@@ -1483,7 +1481,7 @@ dissect_swils_esc(tvbuff_t *tvb, packet_info* pinfo _U_, proto_tree *esc_tree, g
                 pdesc_tree = proto_tree_add_subtree_format(esc_tree, tvb, offset, 12,
                                             ett_fcswils_esc_pdesc, NULL, "Protocol Descriptor %d", i);
                 proto_tree_add_item(pdesc_tree, hf_swils_esc_pdesc_vendorid, tvb,
-                                    offset, 8, ENC_ASCII|ENC_NA);
+                                    offset, 8, ENC_ASCII);
                 proto_tree_add_item(pdesc_tree, hf_swils_esc_protocolid,
                                     tvb, offset+10, 2, ENC_BIG_ENDIAN);
                 offset += 12;
@@ -1491,12 +1489,12 @@ dissect_swils_esc(tvbuff_t *tvb, packet_info* pinfo _U_, proto_tree *esc_tree, g
         }
         else {
             proto_tree_add_item(esc_tree, hf_swils_esc_swvendorid, tvb,
-                                offset+4, 8, ENC_ASCII|ENC_NA);
+                                offset+4, 8, ENC_ASCII);
             pdesc_tree = proto_tree_add_subtree(esc_tree, tvb, offset+12, 12,
                                         ett_fcswils_esc_pdesc, NULL, "Accepted Protocol Descriptor");
 
             proto_tree_add_item(pdesc_tree, hf_swils_esc_pdesc_vendorid, tvb,
-                                offset+12, 8, ENC_ASCII|ENC_NA);
+                                offset+12, 8, ENC_ASCII);
             proto_tree_add_item(pdesc_tree, hf_swils_esc_protocolid,
                                 tvb, offset+22, 2, ENC_BIG_ENDIAN);
         }
@@ -1576,12 +1574,12 @@ dissect_swils_mrra(tvbuff_t *tvb, packet_info* pinfo _U_, proto_tree *tree, guin
     if (isreq) {
         proto_tree_add_item(tree, hf_swils_mrra_rev, tvb, offset+4, 4, ENC_BIG_ENDIAN);
         proto_tree_add_item(tree, hf_swils_mrra_size, tvb, offset+8, 4, ENC_BIG_ENDIAN);
-        proto_tree_add_item(tree, hf_swils_mrra_vendorid, tvb, offset+12, 8, ENC_ASCII|ENC_NA);
+        proto_tree_add_item(tree, hf_swils_mrra_vendorid, tvb, offset+12, 8, ENC_ASCII);
         proto_tree_add_item(tree, hf_swils_mrra_vendorinfo, tvb, offset+20,
                             8, ENC_NA);
     } else {
         proto_tree_add_item(tree, hf_swils_mrra_vendorid, tvb, offset+4,
-                            8, ENC_ASCII|ENC_NA);
+                            8, ENC_ASCII);
         proto_tree_add_item(tree, hf_swils_mrra_reply, tvb, offset+12,
                             4, ENC_BIG_ENDIAN);
         proto_tree_add_item(tree, hf_swils_mrra_reply_size, tvb, offset+16,
