@@ -161,6 +161,8 @@ dissect_fgp_message(tvbuff_t *message_tvb, packet_info *pinfo, proto_tree *fgp_t
   tap_rec->type_string = val_to_str_const(tap_rec->type, message_type_values, "Unknown FractalGeneratorProtocol message type");
   tap_queue_packet(tap_fractalgeneratorprotocol, pinfo, tap_rec);
 
+  col_add_fstr(pinfo->cinfo, COL_INFO, "%s ", tap_rec->type_string);
+
   proto_tree_add_item(fgp_tree, hf_message_type,   message_tvb, MESSAGE_TYPE_OFFSET,   MESSAGE_TYPE_LENGTH,   ENC_BIG_ENDIAN);
   proto_tree_add_item(fgp_tree, hf_message_flags,  message_tvb, MESSAGE_FLAGS_OFFSET,  MESSAGE_FLAGS_LENGTH,  ENC_BIG_ENDIAN);
   proto_tree_add_item(fgp_tree, hf_message_length, message_tvb, MESSAGE_LENGTH_OFFSET, MESSAGE_LENGTH_LENGTH, ENC_BIG_ENDIAN);
@@ -239,6 +241,7 @@ static void fgp_stat_init(stat_tap_table_ui* new_stat)
   table = stat_tap_init_table(table_name, num_fields, 0, NULL);
   stat_tap_add_table(new_stat, table);
 
+  memset(items, 0x0, sizeof(items));
   /* Add a row for each value type */
   while (message_type_values[i].strptr) {
     items[MESSAGE_TYPE_COLUMN].type                = TABLE_ITEM_STRING;
