@@ -75,6 +75,7 @@ static int hf_frame_drop_count = -1;
 static int hf_frame_protocols = -1;
 static int hf_frame_color_filter_name = -1;
 static int hf_frame_color_filter_text = -1;
+static int hf_frame_section_number = -1;
 static int hf_frame_interface_id = -1;
 static int hf_frame_interface_name = -1;
 static int hf_frame_interface_description = -1;
@@ -98,6 +99,9 @@ static int hf_frame_cb_copy_allowed = -1;
 static int hf_frame_bblog = -1;
 static int hf_frame_bblog_ticks = -1;
 static int hf_frame_bblog_serial_nr = -1;
+static int hf_frame_pcaplog_type = -1;
+static int hf_frame_pcaplog_length = -1;
+static int hf_frame_pcaplog_data = -1;
 static int hf_comments_text = -1;
 
 static gint ett_frame = -1;
@@ -106,11 +110,11 @@ static gint ett_flags = -1;
 static gint ett_comments = -1;
 static gint ett_verdict = -1;
 static gint ett_bblog = -1;
+static gint ett_pcaplog_data = -1;
 
 static expert_field ei_comments_text = EI_INIT;
 static expert_field ei_arrive_time_out_of_range = EI_INIT;
 static expert_field ei_incomplete = EI_INIT;
-static expert_field ei_len_lt_caplen = EI_INIT;
 
 static int frame_tap = -1;
 
@@ -118,6 +122,7 @@ static dissector_handle_t docsis_handle;
 static dissector_handle_t sysdig_handle;
 static dissector_handle_t systemd_journal_handle;
 static dissector_handle_t bblog_handle;
+static dissector_handle_t xml_handle;
 
 /* Preferences */
 static gboolean show_file_off       = FALSE;
@@ -293,39 +298,45 @@ frame_add_verdict(wtap_block_t block _U_, guint option_id, wtap_opttype_e option
 	fr_foreach_t *fr_user_data = (fr_foreach_t *)user_data;
 
 	if (option_id == OPT_PKT_VERDICT) {
-		packet_verdict_opt_t *verdict = &option->packet_verdictval;
+		GBytes *verdict = option->byteval;
+		const guint8 *verdict_data;
+		gsize len;
 		char *format = fr_user_data->n_changes ? ", %s (%u)" : "%s (%u)";
 
-		proto_item_append_text(fr_user_data->item, format,
-				       get_verdict_type_string(verdict->type),
-				       verdict->type);
+		if (verdict == NULL)
+			return TRUE;
 
-		switch(verdict->type) {
+		verdict_data = (const guint8 *) g_bytes_get_data(verdict, &len);
+
+		if (len == 0)
+			return TRUE;
+
+		proto_item_append_text(fr_user_data->item, format,
+			 get_verdict_type_string(verdict_data[0]), verdict_data[0]);
+
+		len -= 1;
+		switch(verdict_data[0]) {
+			case OPT_VERDICT_TYPE_HW:
+				proto_tree_add_bytes_with_length(fr_user_data->tree, hf_frame_verdict_hardware,
+						fr_user_data->tvb, 0, 0, verdict_data + 1, (gint) len);
+				break;
 			case OPT_VERDICT_TYPE_TC:
-				proto_tree_add_int64(fr_user_data->tree,
-						     hf_frame_verdict_tc,
-						     fr_user_data->tvb, 0, 0,
-						     verdict->data.verdict_linux_ebpf_tc);
+				if (len == 8) {
+					gint64 val;
+					memcpy(&val, verdict_data + 1, sizeof(val));
+					proto_tree_add_int64(fr_user_data->tree, hf_frame_verdict_tc, fr_user_data->tvb, 0, 0, val);
+				}
 				break;
 			case OPT_VERDICT_TYPE_XDP:
-				proto_tree_add_int64(fr_user_data->tree,
-						     hf_frame_verdict_xdp,
-						     fr_user_data->tvb, 0, 0,
-						     verdict->data.verdict_linux_ebpf_xdp);
-				break;
-			case OPT_VERDICT_TYPE_HW:
-				proto_tree_add_bytes_with_length(fr_user_data->tree,
-								 hf_frame_verdict_hardware,
-								 fr_user_data->tvb, 0, 0,
-								 verdict->data.verdict_bytes->data,
-								 verdict->data.verdict_bytes->len);
+				if (len == 8) {
+					gint64 val;
+					memcpy(&val, verdict_data + 1, sizeof(val));
+					proto_tree_add_int64(fr_user_data->tree, hf_frame_verdict_xdp, fr_user_data->tvb, 0, 0, val);
+				}
 				break;
 			default:
-				proto_tree_add_bytes_with_length(fr_user_data->tree,
-								 hf_frame_verdict_unknown,
-								 fr_user_data->tvb, 0, 0,
-								 verdict->data.verdict_bytes->data,
-								 verdict->data.verdict_bytes->len);
+				proto_tree_add_bytes_with_length(fr_user_data->tree, hf_frame_verdict_unknown,
+						fr_user_data->tvb, 0, 0, verdict_data, (gint) len + 1);
 				break;
 		}
 	}
@@ -515,42 +526,19 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 		wtap_block_foreach_option(fr_data->pkt_block, frame_add_comment, (void *)&fr_user_data);
 	}
 
-	cap_len = tvb_captured_length(tvb);
-	frame_len = tvb_reported_length(tvb);
-
-	/* If FRAME is not referenced from any filters we don't need to
-	   worry about generating any tree items.
-
-	   We do, however, have to worry about generating expert infos,
-	   as those have to show up if, for example, the user requests
-	   the expert info dialog.
-
-	   NOTE: if any expert infos are added in the "frame is referenced"
-	   arm of the conditional, they must also be added to the "frame
-	   is not referenced" arm.  See, for example, issue #18312.
-
-	   XXX - all these tricks to optimize dissection if only some
-	   information is required are fragile.  Something better that
-	   handles this automatically would be useful. */
+	/* if FRAME is not referenced from any filters we don't need to worry about
+	   generating any tree items.  */
 	if (!proto_field_is_referenced(tree, proto_frame)) {
 		tree=NULL;
 		if (pinfo->presence_flags & PINFO_HAS_TS) {
 			if (pinfo->abs_ts.nsecs < 0 || pinfo->abs_ts.nsecs >= 1000000000)
-				expert_add_info_format(pinfo, NULL, &ei_arrive_time_out_of_range,
-								    "Arrival Time: Fractional second %09ld is invalid,"
-								    " the valid range is 0-1000000000",
-								    (long) pinfo->abs_ts.nsecs);
-		}
-		if (frame_len < cap_len) {
-			/*
-			 * A reported length less than a captured length
-			 * is bogus, as you cannot capture more data
-			 * than there is in a packet.
-			 */
-			expert_add_info(pinfo, NULL, &ei_len_lt_caplen);
+				expert_add_info(pinfo, NULL, &ei_arrive_time_out_of_range);
 		}
 	} else {
 		/* Put in frame header information. */
+		cap_len = tvb_captured_length(tvb);
+		frame_len = tvb_reported_length(tvb);
+
 		cap_plurality = plurality(cap_len, "", "s");
 		frame_plurality = plurality(frame_len, "", "s");
 
@@ -632,7 +620,7 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 			 * be preferred?
 			 */
 			ti = proto_tree_add_protocol_format(tree, proto_syscall, tvb, 0, tvb_captured_length(tvb),
-			    "System Call %u: %u byte%s",
+			    "Sysdig Event %u: %u byte%s",
 			    pinfo->num, frame_len, frame_plurality);
 			break;
 
@@ -676,6 +664,13 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 
 		fh_tree = proto_item_add_subtree(ti, ett_frame);
 
+		if (pinfo->rec->presence_flags & WTAP_HAS_SECTION_NUMBER &&
+		   (proto_field_is_referenced(tree, hf_frame_section_number))) {
+			/* Show it as 1-origin */
+			proto_tree_add_uint(fh_tree, hf_frame_section_number, tvb,
+					    0, 0, pinfo->rec->section_number + 1);
+		}
+
 		if (pinfo->rec->presence_flags & WTAP_HAS_INTERFACE_ID &&
 		   (proto_field_is_referenced(tree, hf_frame_interface_id) || proto_field_is_referenced(tree, hf_frame_interface_name) || proto_field_is_referenced(tree, hf_frame_interface_description))) {
 			const char *interface_name = epan_get_interface_name(pinfo->epan, pinfo->rec->rec_header.packet_header.interface_id);
@@ -798,17 +793,9 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 		proto_tree_add_uint(fh_tree, hf_frame_number, tvb,
 				    0, 0, pinfo->num);
 
-		item = proto_tree_add_uint_format(fh_tree, hf_frame_len, tvb,
-						  0, 0, frame_len, "Frame Length: %u byte%s (%u bits)",
-						  frame_len, frame_plurality, frame_len * 8);
-		if (frame_len < cap_len) {
-			/*
-			 * A reported length less than a captured length
-			 * is bogus, as you cannot capture more data
-			 * than there is in a packet.
-			 */
-			expert_add_info(pinfo, item, &ei_len_lt_caplen);
-		}
+		proto_tree_add_uint_format(fh_tree, hf_frame_len, tvb,
+					   0, 0, frame_len, "Frame Length: %u byte%s (%u bits)",
+					   frame_len, frame_plurality, frame_len * 8);
 
 		proto_tree_add_uint_format(fh_tree, hf_frame_capture_len, tvb,
 					   0, 0, cap_len, "Capture Length: %u byte%s (%u bits)",
@@ -864,7 +851,7 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 		if (show_file_off) {
 			proto_tree_add_int64_format_value(fh_tree, hf_frame_file_off, tvb,
 						    0, 0, pinfo->fd->file_off,
-						    "%" G_GINT64_MODIFIER "d (0x%" G_GINT64_MODIFIER "x)",
+						    "%" PRId64 " (0x%" PRIx64 ")",
 						    pinfo->fd->file_off, pinfo->fd->file_off);
 		}
 	}
@@ -876,15 +863,6 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 		return tvb_captured_length(tvb);
 	}
 
-	if (frame_len < cap_len) {
-		/*
-		 * Fix the reported length; a reported length less than
-		 * a captured length is bogus, as you cannot capture
-		 * more data than there is in a packet.
-		 */
-		tvb_fix_reported_length(tvb);
-	}
-
 	/* Portable Exception Handling to trap Wireshark specific exceptions like BoundsError exceptions */
 	TRY {
 #ifdef _MSC_VER
@@ -999,6 +977,32 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 						break;
 					}
 					break;
+				case PEN_VCTR:
+				{
+					guint32 data_type;
+					guint32 data_length;
+					proto_item *pi_tmp;
+					proto_tree *pt_pcaplog_data;
+
+					proto_tree_add_item_ret_uint(fh_tree, hf_frame_pcaplog_type, tvb, 0, 4, ENC_LITTLE_ENDIAN, &data_type);
+					proto_tree_add_item_ret_uint(fh_tree, hf_frame_pcaplog_length, tvb, 4, 4, ENC_LITTLE_ENDIAN, &data_length);
+					pi_tmp = proto_tree_add_item(fh_tree, hf_frame_pcaplog_data, tvb, 8, data_length, ENC_NA);
+					pt_pcaplog_data = proto_item_add_subtree(pi_tmp, ett_pcaplog_data);
+
+					col_set_str(pinfo->cinfo, COL_PROTOCOL, "pcaplog");
+					col_add_fstr(pinfo->cinfo, COL_INFO, "Custom Block: PEN = %s (%d), will%s be copied",
+						enterprises_lookup(pinfo->rec->rec_header.custom_block_header.pen, "Unknown"),
+						pinfo->rec->rec_header.custom_block_header.pen,
+						pinfo->rec->rec_header.custom_block_header.copy_allowed ? "" : " not");
+
+					/* at least data_types 1-3 seem XML-based */
+					if (data_type > 0 && data_type <= 3) {
+						call_dissector(xml_handle, tvb_new_subset_remaining(tvb, 8), pinfo, pt_pcaplog_data);
+					} else {
+						call_data_dissector(tvb_new_subset_remaining(tvb, 8), pinfo, pt_pcaplog_data);
+					}
+				}
+					break;
 				default:
 					col_set_str(pinfo->cinfo, COL_PROTOCOL, "PCAPNG");
 					proto_tree_add_uint_format_value(fh_tree, hf_frame_cb_pen, tvb, 0, 0,
@@ -1038,7 +1042,7 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 				/* XXX - add other hardware exception codes as required */
 			default:
 				show_exception(tvb, pinfo, parent_tree, DissectorError,
-					       g_strdup_printf("dissector caused an unknown exception: 0x%x", GetExceptionCode()));
+					       ws_strdup_printf("dissector caused an unknown exception: 0x%x", GetExceptionCode()));
 			}
 		}
 #endif
@@ -1106,7 +1110,7 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 					/* XXX - add other hardware exception codes as required */
 				default:
 					show_exception(tvb, pinfo, parent_tree, DissectorError,
-						       g_strdup_printf("dissector caused an unknown exception: 0x%x", GetExceptionCode()));
+						       ws_strdup_printf("dissector caused an unknown exception: 0x%x", GetExceptionCode()));
 				}
 			}
 #endif
@@ -1276,6 +1280,11 @@ proto_register_frame(void)
 		    FT_STRING, BASE_NONE, NULL, 0x0,
 		    "The frame matched this coloring rule string", HFILL }},
 
+		{ &hf_frame_section_number,
+		  { "Section number", "frame.section_number",
+		    FT_UINT32, BASE_DEC, NULL, 0x0,
+		    "The number of the file section this frame is in", HFILL }},
+
 		{ &hf_frame_interface_id,
 		  { "Interface id", "frame.interface_id",
 		    FT_UINT32, BASE_DEC, NULL, 0x0,
@@ -1428,6 +1437,20 @@ proto_register_frame(void)
 		    FT_UINT32, BASE_DEC, NULL, 0x0,
 		    NULL, HFILL}},
 
+		{ &hf_frame_pcaplog_type,
+		{ "Date Type", "frame.pcaplog.data_type",
+		    FT_UINT32, BASE_DEC, NULL, 0x0,
+		    NULL, HFILL} },
+
+		{ &hf_frame_pcaplog_length,
+		{ "Data Length", "frame.pcaplog.data_length",
+		    FT_UINT32, BASE_DEC, NULL, 0x0,
+		    NULL, HFILL} },
+
+		{ &hf_frame_pcaplog_data,
+		{ "Data", "frame.pcaplog.data",
+		    FT_BYTES, BASE_NONE, NULL, 0x0,
+		    NULL, HFILL} },
 	};
 
 	static hf_register_info hf_encap =
@@ -1442,14 +1465,14 @@ proto_register_frame(void)
 		&ett_flags,
 		&ett_comments,
 		&ett_verdict,
-		&ett_bblog
+		&ett_bblog,
+		&ett_pcaplog_data
 	};
 
 	static ei_register_info ei[] = {
 		{ &ei_comments_text, { "frame.comment.expert", PI_COMMENTS_GROUP, PI_COMMENT, "Formatted comment", EXPFILL }},
 		{ &ei_arrive_time_out_of_range, { "frame.time_invalid", PI_SEQUENCE, PI_NOTE, "Arrival Time: Fractional second out of range (0-1000000000)", EXPFILL }},
-		{ &ei_incomplete, { "frame.incomplete", PI_UNDECODED, PI_NOTE, "Incomplete dissector", EXPFILL }},
-		{ &ei_len_lt_caplen, { "frame.len_lt_caplen", PI_MALFORMED, PI_ERROR, "Frame length is less than captured length", EXPFILL }}
+		{ &ei_incomplete, { "frame.incomplete", PI_UNDECODED, PI_NOTE, "Incomplete dissector", EXPFILL }}
 	};
 
 	module_t *frame_module;
@@ -1527,6 +1550,7 @@ proto_reg_handoff_frame(void)
 	sysdig_handle = find_dissector_add_dependency("sysdig", proto_frame);
 	systemd_journal_handle = find_dissector_add_dependency("systemd_journal", proto_frame);
 	bblog_handle = find_dissector_add_dependency("bblog", proto_frame);
+	xml_handle = find_dissector_add_dependency("xml", proto_frame);
 }
 
 /*
