@@ -21,6 +21,8 @@
 #include "packet-gre.h"
 #include "packet-wccp.h"
 
+#define GRE_IN_UDP_PORT 4754
+
 void proto_register_gre(void);
 void proto_reg_handoff_gre(void);
 
@@ -29,7 +31,8 @@ void proto_reg_handoff_gre(void);
  * "Generic Routing Encapsulation over IPv4 networks", RFC 2637
  * "Point-to-Point Tunneling Protocol (PPTP)", RFC 2784 "Generic
  * Routing Encapsulation (GRE)", RFC 2890 "Key and Sequence
- * Number Extensions to GRE" and draft-ietf-mpls-in-ip-or-gre-07.txt
+ * Number Extensions to GRE", RFC 8086 "GRE-in-UDP Encapsulation",
+ * and draft-ietf-mpls-in-ip-or-gre-07.txt
  * "Encapsulating MPLS in IP or Generic Routing Encapsulation (GRE)".
  */
 
@@ -61,14 +64,14 @@ static int hf_gre_routing_sre_offset = -1;
 static int hf_gre_routing_information = -1;
 
 /* Ref 3GPP2 A.S0012-C v2.0 and A.S0008-A v1.0 */
-static int hf_gre_3ggp2_attrib = -1;
-static int hf_gre_3ggp2_attrib_id = -1;
-static int hf_gre_3ggp2_attrib_length = -1;
-static int hf_gre_3ggp2_sdi = -1;
-static int hf_gre_3ggp2_fci = -1;
-static int hf_gre_3ggp2_di = -1;
-static int hf_gre_3ggp2_flow_disc = -1;
-static int hf_gre_3ggp2_seg = -1;
+static int hf_gre_3gpp2_attrib = -1;
+static int hf_gre_3gpp2_attrib_id = -1;
+static int hf_gre_3gpp2_attrib_length = -1;
+static int hf_gre_3gpp2_sdi = -1;
+static int hf_gre_3gpp2_fci = -1;
+static int hf_gre_3gpp2_di = -1;
+static int hf_gre_3gpp2_flow_disc = -1;
+static int hf_gre_3gpp2_seg = -1;
 
 static int hf_gre_wccp_redirect_header = -1;
 static int hf_gre_wccp_dynamic_service = -1;
@@ -89,20 +92,7 @@ static expert_field ei_gre_checksum_incorrect = EI_INIT;
 
 static dissector_table_t gre_dissector_table;
 
-/* bit positions for flags in header */
-#define GRE_CHECKSUM            0x8000
-#define GRE_ROUTING             0x4000
-#define GRE_KEY                 0x2000
-#define GRE_SEQUENCE            0x1000
-#define GRE_STRICTSOURCE        0x0800
-#define GRE_RECURSION           0x0700
-#define GRE_ACK                 0x0080  /* only in special PPTPized GRE header */
-#define GRE_RESERVED_PPP        0x0078  /* only in special PPTPized GRE header */
-#define GRE_RESERVED            0x00F8
-#define GRE_VERSION             0x0007
-
-
-const value_string gre_version[] = {
+static const value_string gre_version[] = {
     { 0, "GRE" },                /* [RFC2784] */
     { 1, "Enhanced GRE" },       /* [RFC2637] */
     { 0, NULL}
@@ -162,7 +152,7 @@ const value_string gre_typevals[] = {
 #define ID_3GPP2_FLOW_DISCRIMINATOR 3
 #define ID_3GPP2_SEG 4
 
-static const value_string gre_3ggp2_seg_vals[] = {
+static const value_string gre_3gpp2_seg_vals[] = {
     { 0x00, "Packet Started" },
     { 0x01, "Packet continued" },
     { 0x02, "Packet Ended" },
@@ -171,7 +161,7 @@ static const value_string gre_3ggp2_seg_vals[] = {
 /* 3GPP2 A.S0012-C v2.0
  * 2.6.1 GRE Attributes
  */
-static const value_string gre_3ggp2_attrib_id_vals[] = {
+static const value_string gre_3gpp2_attrib_id_vals[] = {
     { 0x01, "1x SDB/HRPD DOS Indicator" },
     { 0x02, "Flow Control Indication" },
     /* A.S0008-A v1.0 */
@@ -180,17 +170,17 @@ static const value_string gre_3ggp2_attrib_id_vals[] = {
     { 0,    NULL }
 };
 
-static const true_false_string gre_3ggp2_sdi_val = {
+static const true_false_string gre_3gpp2_sdi_val = {
     "Packet suitable for 1x SDB or HRPD DOS transmission",
     "Reserved"
 };
 
-static const true_false_string gre_3ggp2_fci_val = {
+static const true_false_string gre_3gpp2_fci_val = {
     "XOFF",
     "XON"
 };
 
-static const true_false_string gre_3ggp2_di_val = {
+static const true_false_string gre_3gpp2_di_val = {
     "INDEFINITE:",
     "TEMPORARY"
 };
@@ -220,7 +210,7 @@ dissect_gre_3gpp2_attribs(tvbuff_t *tvb, int offset, proto_tree *tree)
     guint8      value;
     int         start_offset = offset;
 
-    proto_item *ti = proto_tree_add_item(tree, hf_gre_3ggp2_attrib, tvb, offset, 0, ENC_NA);
+    proto_item *ti = proto_tree_add_item(tree, hf_gre_3gpp2_attrib, tvb, offset, 0, ENC_NA);
     proto_tree *atree = proto_item_add_subtree(ti, ett_3gpp2_attribs);
 
     while(last_attrib != TRUE)
@@ -229,10 +219,10 @@ dissect_gre_3gpp2_attribs(tvbuff_t *tvb, int offset, proto_tree *tree)
         guint8 attrib_length = tvb_get_guint8(tvb, offset + 1);
 
         attr_tree = proto_tree_add_subtree(atree, tvb, offset, attrib_length + 1 + 1, ett_3gpp2_attr, &attr_item,
-                                        val_to_str((attrib_id&0x7f), gre_3ggp2_attrib_id_vals, "%u (Unknown)"));
+                                        val_to_str((attrib_id&0x7f), gre_3gpp2_attrib_id_vals, "%u (Unknown)"));
 
-        proto_tree_add_item(attr_tree, hf_gre_3ggp2_attrib_id, tvb, offset, 1, ENC_BIG_ENDIAN);
-        proto_tree_add_item(attr_tree, hf_gre_3ggp2_attrib_length, tvb, offset+1, 1, ENC_BIG_ENDIAN);
+        proto_tree_add_item(attr_tree, hf_gre_3gpp2_attrib_id, tvb, offset, 1, ENC_BIG_ENDIAN);
+        proto_tree_add_item(attr_tree, hf_gre_3gpp2_attrib_length, tvb, offset+1, 1, ENC_BIG_ENDIAN);
 
         offset += 2;
         last_attrib = (attrib_id & 0x80)?TRUE:FALSE;
@@ -243,14 +233,14 @@ dissect_gre_3gpp2_attribs(tvbuff_t *tvb, int offset, proto_tree *tree)
         case ID_3GPP2_FLOW_DISCRIMINATOR:
         {
             value = tvb_get_guint8(tvb,offset);
-            proto_tree_add_item(attr_tree, hf_gre_3ggp2_flow_disc, tvb, offset, attrib_length, ENC_NA);
+            proto_tree_add_item(attr_tree, hf_gre_3gpp2_flow_disc, tvb, offset, attrib_length, ENC_NA);
             proto_item_append_text(attr_item," - 0x%x",value);
         }
         break;
         case ID_3GPP2_SDI_FLAG:
         {
             value = tvb_get_guint8(tvb,offset);
-            proto_tree_add_item(attr_tree, hf_gre_3ggp2_sdi, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
+            proto_tree_add_item(attr_tree, hf_gre_3gpp2_sdi, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
             proto_item_append_text(attr_item," - %s",
                                    (value & 0x80) ? "Packet suitable for 1x SDB or HRPD DOS transmission" : "Reserved");
 
@@ -259,17 +249,17 @@ dissect_gre_3gpp2_attribs(tvbuff_t *tvb, int offset, proto_tree *tree)
         case ID_3GPP2_SEG:
         {
             value = tvb_get_guint8(tvb,offset) >>6;
-            proto_tree_add_item(attr_tree, hf_gre_3ggp2_seg, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
-            proto_item_append_text(attr_item," - %s",val_to_str(value, gre_3ggp2_seg_vals, "0x%02X - Unknown"));
+            proto_tree_add_item(attr_tree, hf_gre_3gpp2_seg, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
+            proto_item_append_text(attr_item," - %s",val_to_str(value, gre_3gpp2_seg_vals, "0x%02X - Unknown"));
         }
         break;
         case ID_3GPP2_FLOW_CTRL:
         {
             value = tvb_get_guint8(tvb,offset);
-            proto_tree_add_item(attr_tree, hf_gre_3ggp2_fci, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
+            proto_tree_add_item(attr_tree, hf_gre_3gpp2_fci, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
             proto_item_append_text(attr_item," - %s",
                                    (value & 0x80) ? "XON" : "XOFF");
-            proto_tree_add_item(attr_tree, hf_gre_3ggp2_di, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
+            proto_tree_add_item(attr_tree, hf_gre_3gpp2_di, tvb, offset, attrib_length, ENC_BIG_ENDIAN);
             proto_item_append_text(attr_item,"/%s",
                                    (value & 0x40) ? "INDEFINITE" : "TEMPORARY");
         }
@@ -482,9 +472,6 @@ dissect_gre(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
         if (type == ETHERTYPE_3GPP2) {
             offset = dissect_gre_3gpp2_attribs(tvb, offset, gre_tree);
         }
-        if (type == GRE_ERSPAN_88BE && !(flags_and_ver & GRE_SEQUENCE)) {
-            pinfo->flags.in_erspan_i = TRUE;
-        }
 
         proto_item_set_len(ti, offset);
 
@@ -501,7 +488,7 @@ dissect_gre(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
         }
         next_tvb = tvb_new_subset_remaining(tvb, offset);
         pinfo->flags.in_gre_pkt = TRUE;
-        if (!dissector_try_uint(gre_dissector_table, type, next_tvb, pinfo, tree))
+        if (!dissector_try_uint_new(gre_dissector_table, type, next_tvb, pinfo, tree, TRUE, &flags_and_ver))
             call_data_dissector(next_tvb, pinfo, gre_tree);
     }
     return tvb_captured_length(tvb);
@@ -555,7 +542,7 @@ proto_register_gre(void)
         { &hf_gre_flags_ack,
           { "Acknowledgment", "gre.flags.ack",
             FT_BOOLEAN, 16, TFS(&tfs_yes_no), GRE_ACK,
-            "Indicates if the packet packet contains Acknowledgment Number to be used for acknowledging previously transmitted data", HFILL }
+            "Indicates if the packet contains an Acknowledgment Number to be used for acknowledging previously transmitted data", HFILL }
         },
         { &hf_gre_flags_reserved,
           { "Flags (Reserved)", "gre.flags.reserved",
@@ -637,44 +624,44 @@ proto_register_gre(void)
             FT_BYTES, BASE_NONE, NULL, 0x0,
             "The Routing Information field contains data which may be used in routing this packet", HFILL }
         },
-        { &hf_gre_3ggp2_attrib,
-          { "3GGP2 Attributes", "gre.ggp2_attrib",
+        { &hf_gre_3gpp2_attrib,
+          { "3GPP2 Attributes", "gre.3gpp2_attrib",
             FT_NONE, BASE_NONE, NULL, 0x0,
             NULL, HFILL }
         },
-        { &hf_gre_3ggp2_attrib_id,
-          { "Type", "gre.ggp2_attrib_id",
-            FT_UINT8, BASE_HEX, VALS(gre_3ggp2_attrib_id_vals), 0x7f,
+        { &hf_gre_3gpp2_attrib_id,
+          { "Type", "gre.3gpp2_attrib_id",
+            FT_UINT8, BASE_HEX, VALS(gre_3gpp2_attrib_id_vals), 0x7f,
             NULL, HFILL }
         },
-        { &hf_gre_3ggp2_attrib_length,
-          { "Length", "gre.ggp2_attrib_length",
+        { &hf_gre_3gpp2_attrib_length,
+          { "Length", "gre.3gpp2_attrib_length",
             FT_UINT8, BASE_HEX, NULL, 0x0,
             NULL, HFILL }
         },
-        { &hf_gre_3ggp2_sdi,
-          { "SDI/DOS", "gre.3ggp2_sdi",
-            FT_BOOLEAN, 16, TFS(&gre_3ggp2_sdi_val), 0x8000,
+        { &hf_gre_3gpp2_sdi,
+          { "SDI/DOS", "gre.3gpp2_sdi",
+            FT_BOOLEAN, 16, TFS(&gre_3gpp2_sdi_val), 0x8000,
             "Short Data Indicator(SDI)/Data Over Signaling (DOS)", HFILL }
         },
-        { &hf_gre_3ggp2_fci,
-          { "Flow Control Indicator", "gre.3ggp2_fci",
-            FT_BOOLEAN, 16, TFS(&gre_3ggp2_fci_val), 0x8000,
+        { &hf_gre_3gpp2_fci,
+          { "Flow Control Indicator", "gre.3gpp2_fci",
+            FT_BOOLEAN, 16, TFS(&gre_3gpp2_fci_val), 0x8000,
             NULL, HFILL }
         },
-        { &hf_gre_3ggp2_di,
-          { "Duration Indicator", "gre.3ggp2_di",
-            FT_BOOLEAN, 16, TFS(&gre_3ggp2_di_val), 0x4000,
+        { &hf_gre_3gpp2_di,
+          { "Duration Indicator", "gre.3gpp2_di",
+            FT_BOOLEAN, 16, TFS(&gre_3gpp2_di_val), 0x4000,
             NULL, HFILL }
         },
-        { &hf_gre_3ggp2_flow_disc,
+        { &hf_gre_3gpp2_flow_disc,
           { "Flow ID", "gre.ggp2_flow_disc",
             FT_BYTES, BASE_NONE, NULL, 0x0,
             NULL, HFILL }
         },
-        { &hf_gre_3ggp2_seg,
-          { "Type", "gre.ggp2_3ggp2_seg",
-            FT_UINT16, BASE_HEX, VALS(gre_3ggp2_seg_vals), 0xc000,
+        { &hf_gre_3gpp2_seg,
+          { "Type", "gre.ggp2_3gpp2_seg",
+            FT_UINT16, BASE_HEX, VALS(gre_3gpp2_seg_vals), 0xc000,
             NULL, HFILL }
         },
 
@@ -768,12 +755,13 @@ proto_reg_handoff_gre(void)
 
     gre_handle = create_dissector_handle(dissect_gre, proto_gre);
     dissector_add_uint("ip.proto", IP_PROTO_GRE, gre_handle);
+    dissector_add_uint("udp.port", GRE_IN_UDP_PORT, gre_handle);
     gre_cap_handle = create_capture_dissector_handle(capture_gre, proto_gre);
     capture_dissector_add_uint("ip.proto", IP_PROTO_GRE, gre_cap_handle);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
