@@ -7,19 +7,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 
@@ -36,6 +24,7 @@
 #include <epan/expert.h>
 #include <epan/conversation.h>
 #include <epan/crc10-tvb.h>
+#include <epan/crc6-tvb.h>
 #include <wsutil/crc10.h>
 #include <wsutil/crc6.h>
 
@@ -162,7 +151,7 @@ static dissector_handle_t iuup_handle;
 
 static gboolean dissect_fields = FALSE;
 static gboolean two_byte_pseudoheader = FALSE;
-static guint global_dynamic_payload_type = 0;
+static range_t *global_dynamic_payload_type_range = 0;
 
 
 #define PDUTYPE_DATA_WITH_CRC 0
@@ -353,13 +342,16 @@ iuup_proto_tree_add_bits(proto_tree* tree, int hf, tvbuff_t* tvb, int offset, in
     return pi;
 }
 
-static void dissect_iuup_payload(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint rfci_id _U_, int offset, guint32 circuit_id) {
+static void dissect_iuup_payload(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint rfci_id, int offset, guint32 circuit_id) {
     iuup_circuit_t* iuup_circuit;
     iuup_rfci_t *rfci;
     int last_offset = tvb_reported_length(tvb) - 1;
     guint bit_offset = 0;
     proto_item* pi;
 
+    if (offset == (int)tvb_reported_length(tvb)) /* NO_DATA */
+      return;
+
     pi = proto_tree_add_item(tree,hf_iuup_payload,tvb,offset,-1,ENC_NA);
 
     if ( ! dissect_fields ) {
@@ -564,15 +556,10 @@ static void dissect_iuup_ratectl(tvbuff_t* tvb, packet_info* pinfo _U_, proto_tr
 
 }
 
-static void add_hdr_crc(tvbuff_t* tvb, packet_info* pinfo, proto_item* iuup_tree, guint16 crccheck)
+static void add_hdr_crc(tvbuff_t* tvb, packet_info* pinfo, proto_item* iuup_tree)
 {
-    proto_item *crc_item;
-
-    crc_item = proto_tree_add_item(iuup_tree,hf_iuup_hdr_crc,tvb,2,1,ENC_BIG_ENDIAN);
-    if (crccheck) {
-        proto_item_append_text(crc_item, "%s", " [incorrect]");
-        expert_add_info(pinfo, crc_item, &ei_iuup_hdr_crc_bad);
-    }
+    proto_tree_add_checksum(iuup_tree, tvb, 2, hf_iuup_hdr_crc, -1, &ei_iuup_hdr_crc_bad,
+                            pinfo, crc6_compute_tvb(tvb, 2), ENC_BIG_ENDIAN, PROTO_CHECKSUM_VERIFY);
 }
 
 static guint16
@@ -618,8 +605,6 @@ static int dissect_iuup(tvbuff_t* tvb_in, packet_info* pinfo, proto_tree* tree,
     guint8 second_octet;
     guint8 pdutype;
     guint phdr = 0;
-    guint16  hdrcrc6;
-    guint16  crccheck;
     tvbuff_t* tvb = tvb_in;
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "IuUP");
@@ -641,8 +626,6 @@ static int dissect_iuup(tvbuff_t* tvb_in, packet_info* pinfo, proto_tree* tree,
 
     first_octet =  tvb_get_guint8(tvb,0);
     second_octet =  tvb_get_guint8(tvb,1);
-    hdrcrc6 = tvb_get_guint8(tvb, 2) >> 2;
-    crccheck = update_crc6_by_bytes(hdrcrc6, first_octet, second_octet);
 
     pdutype = ( first_octet & PDUTYPE_MASK ) >> 4;
 
@@ -667,7 +650,7 @@ static int dissect_iuup(tvbuff_t* tvb_in, packet_info* pinfo, proto_tree* tree,
             }
 
             proto_tree_add_item(iuup_tree,hf_iuup_rfci,tvb,1,1,ENC_BIG_ENDIAN);
-            add_hdr_crc(tvb, pinfo, iuup_tree, crccheck);
+            add_hdr_crc(tvb, pinfo, iuup_tree);
             add_payload_crc(tvb, pinfo, iuup_tree);
             dissect_iuup_payload(tvb,pinfo,iuup_tree,second_octet & 0x3f,4, conversation_get_endpoint_by_id(pinfo, ENDPOINT_IUUP, USE_LAST_ENDPOINT));
             return tvb_captured_length(tvb);
@@ -682,7 +665,7 @@ static int dissect_iuup(tvbuff_t* tvb_in, packet_info* pinfo, proto_tree* tree,
             }
 
             proto_tree_add_item(iuup_tree,hf_iuup_rfci,tvb,1,1,ENC_BIG_ENDIAN);
-            add_hdr_crc(tvb, pinfo, iuup_tree, crccheck);
+            add_hdr_crc(tvb, pinfo, iuup_tree);
             dissect_iuup_payload(tvb,pinfo,iuup_tree,second_octet & 0x3f,3, conversation_get_endpoint_by_id(pinfo, ENDPOINT_IUUP, USE_LAST_ENDPOINT));
             return tvb_captured_length(tvb);
         case PDUTYPE_DATA_CONTROL_PROC:
@@ -691,7 +674,7 @@ static int dissect_iuup(tvbuff_t* tvb_in, packet_info* pinfo, proto_tree* tree,
                 proto_tree_add_item(iuup_tree,hf_iuup_frame_number_t14,tvb,0,1,ENC_BIG_ENDIAN);
                 proto_tree_add_item(iuup_tree,hf_iuup_mode_version,tvb,1,1,ENC_BIG_ENDIAN);
                 proc_item = proto_tree_add_item(iuup_tree,hf_iuup_procedure_indicator,tvb,1,1,ENC_BIG_ENDIAN);
-                add_hdr_crc(tvb, pinfo, iuup_tree, crccheck);
+                add_hdr_crc(tvb, pinfo, iuup_tree);
             }
 
             col_append_str(pinfo->cinfo, COL_INFO,
@@ -752,14 +735,14 @@ static int dissect_iuup(tvbuff_t* tvb_in, packet_info* pinfo, proto_tree* tree,
 
                     if (ta >= 1 && ta <= 80) {
                         pi = proto_tree_add_uint(time_tree,hf_iuup_delay,tvb,4,1,ta * 500);
-                        PROTO_ITEM_SET_GENERATED(pi);
+                        proto_item_set_generated(pi);
                         pi = proto_tree_add_float(time_tree,hf_iuup_delta,tvb,4,1,((gfloat)((gint)(ta) * 500))/(gfloat)1000000.0);
-                        PROTO_ITEM_SET_GENERATED(pi);
+                        proto_item_set_generated(pi);
                     } else if (ta >= 129 && ta <= 208) {
                         pi = proto_tree_add_uint(time_tree,hf_iuup_advance,tvb,4,1,(ta-128) * 500);
-                        PROTO_ITEM_SET_GENERATED(pi);
+                        proto_item_set_generated(pi);
                         pi = proto_tree_add_float(time_tree,hf_iuup_delta,tvb,4,1,((gfloat)((gint)(-(((gint)ta)-128))) * 500)/(gfloat)1000000.0);
-                        PROTO_ITEM_SET_GENERATED(pi);
+                        proto_item_set_generated(pi);
                     } else {
                         expert_add_info(pinfo, pi, &ei_iuup_time_align);
                     }
@@ -792,9 +775,10 @@ static gboolean dissect_iuup_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree
 
     guint8 first_octet =  tvb_get_guint8(tvb,0);
     guint8 second_octet =  tvb_get_guint8(tvb,1);
+    guint8 octet_array[] = {first_octet, second_octet};
     guint16 hdrcrc6 = tvb_get_guint8(tvb, 2) >> 2;
 
-    if (update_crc6_by_bytes(hdrcrc6, first_octet, second_octet)) return FALSE;
+    if (crc6_0X6F(hdrcrc6, octet_array, second_octet)) return FALSE;
 
     switch ( first_octet & 0xf0 ) {
         case 0x00: {
@@ -838,22 +822,20 @@ static int find_iuup(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void*
 
 void proto_reg_handoff_iuup(void) {
     static gboolean iuup_prefs_initialized = FALSE;
-    static guint saved_dynamic_payload_type = 0;
+    static range_t *saved_dynamic_payload_type_range = NULL;
 
     if (!iuup_prefs_initialized) {
         dissector_add_string("rtp_dyn_payload_type","VND.3GPP.IUFP", iuup_handle);
         iuup_prefs_initialized = TRUE;
     } else {
-        if ( saved_dynamic_payload_type > 95 ) {
-            dissector_delete_uint("rtp.pt", saved_dynamic_payload_type, iuup_handle);
-        }
+        dissector_delete_uint_range("rtp.pt", saved_dynamic_payload_type_range, iuup_handle);
+        wmem_free(wmem_epan_scope(), saved_dynamic_payload_type_range);
     }
 
-    saved_dynamic_payload_type = global_dynamic_payload_type;
+    saved_dynamic_payload_type_range = range_copy(wmem_epan_scope(), global_dynamic_payload_type_range);
 
-    if ( global_dynamic_payload_type > 95 ) {
-        dissector_add_uint("rtp.pt", global_dynamic_payload_type, iuup_handle);
-    }
+    range_remove_value(wmem_epan_scope(), &saved_dynamic_payload_type_range, 0);
+    dissector_add_uint_range("rtp.pt", saved_dynamic_payload_type_range, iuup_handle);
 }
 
 
@@ -1004,11 +986,11 @@ void proto_register_iuup(void) {
                                    "The payload contains a two byte pseudoheader indicating direction and circuit_id",
                                    &two_byte_pseudoheader);
 
-    prefs_register_uint_preference(iuup_module, "dynamic.payload.type",
+    prefs_register_range_preference(iuup_module, "dynamic.payload.type",
                                    "IuUP dynamic payload type",
-                                   "The dynamic payload type which will be interpreted as IuUP",
-                                   10,
-                                   &global_dynamic_payload_type);
+                                   "Dynamic payload types which will be interpreted as IuUP"
+                                   "; values must be in the range 1 - 127",
+                                   &global_dynamic_payload_type_range, 127);
 }
 
 /*
