@@ -28,10 +28,8 @@
 
 /* TODO:
 - add sequence analysis
-- add AM reassembly
 - take configuration of reordering timer, and stop reassembly if timeout exceeded?
-- add tap info
-- call more upper layer dissectors once they appear
+- add tap info (for stats / SN graph)
 */
 
 void proto_register_rlc_nr(void);
@@ -61,17 +59,20 @@ static gboolean global_rlc_nr_call_rrc_for_ccch = TRUE;
 /* Preference to expect RLC headers without payloads */
 static gboolean global_rlc_nr_headers_expected = FALSE;
 
-/* Attempt reassembly of UM frames.  TODO: if add AM reassembly, might prefer just one preference? */
+/* Attempt reassembly. */
 static gboolean global_rlc_nr_reassemble_um_pdus = FALSE;
+static gboolean global_rlc_nr_reassemble_am_pdus = TRUE;
 
-/* Tree storing UE related parameters */
-typedef struct rlc_ue_parameters {
-    guint32 id;
-    guint8 pdcp_sn_bits_ul;
-    guint8 pdcp_sn_bits_dl;
-} rlc_ue_parameters;
+/* Tree storing UE related parameters (ueid, drbid) -> pdcp_bearer_parameters */
 static wmem_tree_t *ue_parameters_tree;
 
+/* Table storing starting frame for reassembly session during first pass */
+/* Key is (ueId, direction, bearertype, bearerid, sn) */
+static wmem_tree_t *reassembly_start_table;
+
+/* Table storing starting frame for reassembly session during subsequent passes */
+/* Key is (ueId, direction, bearertype, bearerid, sn, frame) */
+static wmem_tree_t *reassembly_start_table_stored;
 
 /**************************************************/
 /* Initialize the protocol and registered fields. */
@@ -285,7 +286,7 @@ static const true_false_string header_only_vals =
 /* Reassembly state */
 static reassembly_table pdu_reassembly_table;
 
-static guint pdu_hash(gconstpointer k _U_)
+static guint pdu_hash(gconstpointer k)
 {
     return GPOINTER_TO_UINT(k);
 }
@@ -295,7 +296,7 @@ static gint pdu_equal(gconstpointer k1, gconstpointer k2)
     return k1 == k2;
 }
 
-static gpointer pdu_temporary_key(const packet_info *pinfo _U_, const guint32 id _U_, const void *data _U_)
+static gpointer pdu_temporary_key(const packet_info *pinfo _U_, const guint32 id _U_, const void *data)
 {
     return (gpointer)data;
 }
@@ -314,7 +315,7 @@ static void pdu_free_persistent_key(gpointer ptr _U_)
 {
 }
 
-reassembly_table_functions pdu_reassembly_table_functions =
+static reassembly_table_functions pdu_reassembly_table_functions =
 {
     pdu_hash,
     pdu_equal,
@@ -343,7 +344,7 @@ static void write_pdu_label_and_info(proto_item *pdu_ti, proto_item *sub_ti,
     va_list ap;
 
     va_start(ap, format);
-    g_vsnprintf(info_buffer, MAX_INFO_BUFFER, format, ap);
+    vsnprintf(info_buffer, MAX_INFO_BUFFER, format, ap);
     va_end(ap);
 
     /* Add to indicated places */
@@ -354,7 +355,7 @@ static void write_pdu_label_and_info(proto_item *pdu_ti, proto_item *sub_ti,
     }
 }
 
-/* Version of function above, where no g_vsnprintf() call needed
+/* Version of function above, where no vsnprintf() call needed
    - the info column
    - the top-level RLC PDU item
    - another subtree item (if supplied) */
@@ -371,10 +372,8 @@ static void write_pdu_label_and_info_literal(proto_item *pdu_ti, proto_item *sub
 
 /* Show in the info column how many bytes are in the UM/AM PDU, and indicate
    whether or not the beginning and end are included in this packet */
-static void show_PDU_in_info(packet_info *pinfo,
-                             proto_item *top_ti,
-                             gint32 length,
-                             guint8 seg_info)
+static void show_PDU_in_info(packet_info *pinfo, proto_item *top_ti,
+                             gint32 length, guint8 seg_info)
 {
     /* Reflect this PDU in the info column */
     if (length > 0) {
@@ -397,9 +396,9 @@ static void show_PDU_in_info(packet_info *pinfo,
 static void show_PDU_in_tree(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, gint offset, gint length,
                              rlc_nr_info *rlc_info, guint32 seg_info, gboolean is_reassembled)
 {
-    wmem_tree_key_t key[3];
+    wmem_tree_key_t key[2];
     guint32 id;
-    rlc_ue_parameters *params;
+    pdcp_bearer_parameters *params;
 
     /* Add raw data (according to mode) */
     if (!is_reassembled) {
@@ -459,22 +458,29 @@ static void show_PDU_in_tree(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb
                             id = (rlc_info->bearerId << 16) | rlc_info->ueid;
                             key[0].length = 1;
                             key[0].key = &id;
-                            key[1].length = 1;
-                            key[1].key = &pinfo->num;
-                            key[2].length = 0;
-                            key[2].key = NULL;
+                            key[1].length = 0;
+                            key[1].key = NULL;
 
-                            params = (rlc_ue_parameters *)wmem_tree_lookup32_array_le(ue_parameters_tree, key);
+                            /* Look up configured params for this PDCP DRB. */
+                            params = (pdcp_bearer_parameters *)wmem_tree_lookup32_array_le(ue_parameters_tree, key);
                             if (params && (params->id != id)) {
                                 params = NULL;
                             }
                             if (params) {
                                 if (p_pdcp_nr_info->direction == DIRECTION_UPLINK) {
                                     p_pdcp_nr_info->seqnum_length = params->pdcp_sn_bits_ul;
+                                    if (params->pdcp_sdap_ul) {
+                                        p_pdcp_nr_info->sdap_header &= PDCP_NR_UL_SDAP_HEADER_PRESENT;
+                                    }
                                 }
                                 else {
                                     p_pdcp_nr_info->seqnum_length = params->pdcp_sn_bits_dl;
+                                    if (params->pdcp_sdap_dl) {
+                                        p_pdcp_nr_info->sdap_header &= PDCP_NR_DL_SDAP_HEADER_PRESENT;
+                                    }
                                 }
+                                p_pdcp_nr_info->maci_present = params->pdcp_integrity;
+                                p_pdcp_nr_info->ciphering_disabled = params->pdcp_ciphering_disabled;
                             }
                             break;
 
@@ -487,8 +493,6 @@ static void show_PDU_in_tree(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb
             }
             p_pdcp_nr_info->bearerId = rlc_info->bearerId;
 
-            /* Assume no SDAP present */
-            p_pdcp_nr_info->sdap_header = 0;
             p_pdcp_nr_info->rohc.rohc_compression = FALSE;
             p_pdcp_nr_info->is_retx = FALSE;
             p_pdcp_nr_info->pdu_length = length;
@@ -568,15 +572,100 @@ static void dissect_rlc_nr_tm(tvbuff_t *tvb, packet_info *pinfo,
     }
 }
 
+/* Look up / set the frame thought to be the start segment of this RLC PDU. */
+/* N.B. this algorithm will not be correct in all cases, but is good enough to be useful.. */
+static guint32 get_reassembly_start_frame(packet_info *pinfo, guint32 seg_info,
+                                          rlc_nr_info *p_rlc_nr_info, guint32 sn)
+{
+    guint32 frame_id = 0;
+
+    guint32 key_values[] = { p_rlc_nr_info->ueid,
+                             p_rlc_nr_info->direction,
+                             p_rlc_nr_info->bearerType,
+                             p_rlc_nr_info->bearerId,
+                             sn,
+                             pinfo->num          /* N.B. only used for subsquent/_stored table */
+                           };
+
+    /* Is this the first segment of SN? */
+    gboolean first_segment = (seg_info & 0x2) == 0;
+
+    /* Set Key. */
+    wmem_tree_key_t key[2];
+    key[0].length = 5;       /* Ignoring this frame num */
+    key[0].key = key_values;
+    key[1].length = 0;
+    key[1].key = NULL;
+
+    guint32 *p_frame_id = NULL;
+
+    if (!PINFO_FD_VISITED(pinfo)) {
+        /* On first pass, maintain reassembly_start_table. */
+
+        /* Look for existing entry. */
+        p_frame_id = (guint32*)wmem_tree_lookup32_array(reassembly_start_table, key);
+
+
+        if (first_segment) {
+            /* Let it start from here */
+            wmem_tree_insert32_array(reassembly_start_table, key, GUINT_TO_POINTER(pinfo->num));
+            frame_id = pinfo->num;
+        }
+        else {
+            if (p_frame_id) {
+                /* Use existing entry (or zero) if not found */
+                frame_id = GPOINTER_TO_UINT(p_frame_id);
+            }
+        }
+
+        /* Store this result for subsequent passes. Don't store 0 though. */
+        if (frame_id) {
+            key[0].length = 6;
+            wmem_tree_insert32_array(reassembly_start_table_stored, key, GUINT_TO_POINTER(frame_id));
+        }
+    }
+    else {
+        /* For subsequent passes, use stored value */
+        key[0].length = 6;  /* i.e. include this framenum in key */
+        p_frame_id = (guint32*)wmem_tree_lookup32_array(reassembly_start_table_stored, key);
+        if (p_frame_id) {
+            /* Use found value */
+            frame_id = GPOINTER_TO_UINT(p_frame_id);
+        }
+    }
+
+    return frame_id;
+}
+
+static void reassembly_frame_complete(packet_info *pinfo,
+                                      rlc_nr_info *p_rlc_nr_info, guint32 sn)
+{
+    if (!PINFO_FD_VISITED(pinfo)) {
+        guint32 key_values[] = { p_rlc_nr_info->ueid,
+                                 p_rlc_nr_info->direction,
+                                 p_rlc_nr_info->bearerType,
+                                 p_rlc_nr_info->bearerId,
+                                 sn
+                               };
+
+        /* Set Key. */
+        wmem_tree_key_t key[2];
+        key[0].length = 4;       /* Ignoring this frame num */
+        key[0].key = key_values;
+        key[1].length = 0;
+        key[1].key = NULL;
+
+        /* Clear entry out */
+        wmem_tree_insert32_array(reassembly_start_table, key, GUINT_TO_POINTER(0));
+    }
+}
 
 
 /***************************************************/
 /* Unacknowledged mode PDU                         */
 static void dissect_rlc_nr_um(tvbuff_t *tvb, packet_info *pinfo,
-                               proto_tree *tree,
-                               int offset,
-                               rlc_nr_info *p_rlc_nr_info,
-                               proto_item *top_ti)
+                              proto_tree *tree, int offset,
+                              rlc_nr_info *p_rlc_nr_info, proto_item *top_ti)
 {
     guint32 seg_info, sn;
     guint64 reserved;
@@ -604,6 +693,7 @@ static void dissect_rlc_nr_um(tvbuff_t *tvb, packet_info *pinfo,
     /* Segmentation Info */
     proto_tree_add_item_ret_uint(um_header_tree, hf_rlc_nr_um_si, tvb, offset, 1, ENC_BIG_ENDIAN, &seg_info);
     if (seg_info == 0) {
+        /* Have all bytes of SDU, so no SN. */
         reserved_ti = proto_tree_add_bits_ret_val(um_header_tree, hf_rlc_nr_um_reserved,
                                                   tvb, (offset<<3)+2, 6, &reserved, ENC_BIG_ENDIAN);
         offset++;
@@ -612,6 +702,7 @@ static void dissect_rlc_nr_um(tvbuff_t *tvb, packet_info *pinfo,
         }
         write_pdu_label_and_info(top_ti, um_header_ti, pinfo, "                             ");
     } else {
+        /* Add sequence number */
         if (p_rlc_nr_info->sequenceNumberLength == UM_SN_LENGTH_6_BITS) {
             proto_tree_add_item_ret_uint(um_header_tree, hf_rlc_nr_um_sn6, tvb, offset, 1, ENC_BIG_ENDIAN, &sn);
             offset++;
@@ -631,14 +722,16 @@ static void dissect_rlc_nr_um(tvbuff_t *tvb, packet_info *pinfo,
             return;
         }
         if (seg_info >= 2) {
+            /* Segment offset */
             proto_tree_add_item_ret_uint(um_header_tree, hf_rlc_nr_um_so, tvb, offset, 2, ENC_BIG_ENDIAN, &so);
             offset += 2;
             write_pdu_label_and_info(top_ti, um_header_ti, pinfo, "            SN=%-6u SO=%-4u", sn, so);
         } else {
+            /* Seg info is 1, so start of SDU - no SO */
             write_pdu_label_and_info(top_ti, um_header_ti, pinfo, "            SN=%-6u        ", sn);
         }
     }
-
+    /* End of header */
     proto_item_set_len(um_header_ti, offset-start_offset);
 
     if (global_rlc_nr_headers_expected) {
@@ -656,44 +749,47 @@ static void dissect_rlc_nr_um(tvbuff_t *tvb, packet_info *pinfo,
         }
     }
 
+    /* Data */
+
+    /* Handle any reassembly. */
     tvbuff_t *next_tvb = NULL;
-    /* Handle reassembly. */
     if (global_rlc_nr_reassemble_um_pdus && seg_info && tvb_reported_length_remaining(tvb, offset) > 0) {
-        // Set fragmented flag.
+        /* Set fragmented flag. */
         gboolean save_fragmented = pinfo->fragmented;
         pinfo->fragmented = TRUE;
         fragment_head *fh;
         gboolean more_frags = seg_info & 0x01;
-        /* TODO: This should be unique enough, but is there a way to get frame number of first frame in reassembly table? */
-        guint32 id = p_rlc_nr_info->direction +       /* 1 bit */
-                    (p_rlc_nr_info->ueid<<1) +        /* 7 bits */
-                    (p_rlc_nr_info->bearerId<<8) +    /* 5 bits */
-                    (sn<<13);                         /* Leave 19 bits for SN - overlaps with other fields but room to overflow into msb */
+        guint32 id = get_reassembly_start_frame(pinfo, seg_info, p_rlc_nr_info, sn);                        /* Leave 19 bits for SN - overlaps with other fields but room to overflow into msb */
+        if (id != 0) {
+            fh = fragment_add(&pdu_reassembly_table, tvb, offset, pinfo,
+                              id,                                         /* id */
+                              GUINT_TO_POINTER(id),                       /* data */
+                              so,                                         /* frag_offset */
+                              tvb_reported_length_remaining(tvb, offset), /* frag_data_len */
+                              more_frags                                  /* more_frags */
+                              );
 
-        fh = fragment_add(&pdu_reassembly_table, tvb, offset, pinfo,
-                          id,                                         /* id */
-                          GUINT_TO_POINTER(id),                       /* data */
-                          so,                                         /* frag_offset */
-                          tvb_reported_length_remaining(tvb, offset), /* frag_data_len */
-                          more_frags                                  /* more_frags */
-                          );
-
-        gboolean update_col_info = TRUE;
-        next_tvb = process_reassembled_data(tvb, offset, pinfo, "Reassembled RLC SDU",
-                                            fh, &rlc_nr_frag_items,
-                                            &update_col_info, tree);
-        pinfo->fragmented = save_fragmented;
+            gboolean update_col_info = TRUE;
+            next_tvb = process_reassembled_data(tvb, offset, pinfo, "Reassembled RLC SDU",
+                                                fh, &rlc_nr_frag_items,
+                                                &update_col_info, tree);
+            pinfo->fragmented = save_fragmented;
+        }
     }
 
     if (tvb_reported_length_remaining(tvb, offset) > 0) {
         show_PDU_in_tree(pinfo, tree, tvb, offset, tvb_reported_length_remaining(tvb, offset),
                          p_rlc_nr_info, seg_info, FALSE);
         show_PDU_in_info(pinfo, top_ti, tvb_reported_length_remaining(tvb, offset), seg_info);
-        /* Also add reassembled PDU */
+
+        /* Also add any reassembled PDU */
         if (next_tvb) {
             add_new_data_source(pinfo, next_tvb, "Reassembled RLC-NR PDU");
             show_PDU_in_tree(pinfo, tree, next_tvb, 0, tvb_captured_length(next_tvb),
                              p_rlc_nr_info, seg_info, TRUE);
+
+            /* Note that PDU is now completed (so won't try to add to it) */
+            reassembly_frame_complete(pinfo, p_rlc_nr_info, sn);
         }
     } else if (!global_rlc_nr_headers_expected) {
         /* Report that expected data was missing (unless we know it might happen) */
@@ -787,7 +883,7 @@ static void dissect_rlc_nr_am_status_pdu(tvbuff_t *tvb,
         /* We shouldn't NACK the ACK_SN! */
         if (nack_sn == ack_sn) {
             expert_add_info_format(pinfo, nack_ti, &ei_rlc_nr_am_nack_sn_ack_same,
-                                   "Status PDU shouldn't ACK and NACK the same sequence number (%" G_GINT64_MODIFIER "u)",
+                                   "Status PDU shouldn't ACK and NACK the same sequence number (%" PRIu64 ")",
                                    ack_sn);
         }
 
@@ -896,10 +992,8 @@ static void dissect_rlc_nr_am_status_pdu(tvbuff_t *tvb,
 /***************************************************/
 /* Acknowledged mode PDU                           */
 static void dissect_rlc_nr_am(tvbuff_t *tvb, packet_info *pinfo,
-                              proto_tree *tree,
-                              int offset,
-                              rlc_nr_info *p_rlc_nr_info,
-                              proto_item *top_ti)
+                              proto_tree *tree, int offset,
+                              rlc_nr_info *p_rlc_nr_info, proto_item *top_ti)
 {
     gboolean dc, polling;
     guint32 seg_info, sn;
@@ -911,6 +1005,7 @@ static void dissect_rlc_nr_am(tvbuff_t *tvb, packet_info *pinfo,
     gboolean is_truncated = FALSE;
     proto_item *truncated_ti;
     proto_item *reserved_ti;
+    guint32 so = 0;
 
     /* Hidden AM root */
     am_ti = proto_tree_add_string_format(tree, hf_rlc_nr_am,
@@ -978,10 +1073,8 @@ static void dissect_rlc_nr_am(tvbuff_t *tvb, packet_info *pinfo,
         return;
     }
 
-    /* Segmentation Information */
+    /* Segment Offset */
     if (seg_info >= 2) {
-        guint32 so;
-
         proto_tree_add_item_ret_uint(am_header_tree, hf_rlc_nr_am_so, tvb,
                                      offset, 2, ENC_BIG_ENDIAN, &so);
         offset += 2;
@@ -1009,10 +1102,45 @@ static void dissect_rlc_nr_am(tvbuff_t *tvb, packet_info *pinfo,
     }
 
     /* Data */
+
+    /* Handle any reassembly. */
+    tvbuff_t *next_tvb = NULL;
+    if (global_rlc_nr_reassemble_am_pdus && seg_info && tvb_reported_length_remaining(tvb, offset) > 0) {
+        /* Set fragmented flag. */
+        gboolean save_fragmented = pinfo->fragmented;
+        pinfo->fragmented = TRUE;
+        fragment_head *fh;
+        gboolean more_frags = seg_info & 0x01;
+        guint32 id = get_reassembly_start_frame(pinfo, seg_info, p_rlc_nr_info, sn);
+        if (id != 0) {
+            fh = fragment_add(&pdu_reassembly_table, tvb, offset, pinfo,
+                              id,                                         /* id */
+                              GUINT_TO_POINTER(id),                       /* data */
+                              so,                                         /* frag_offset */
+                              tvb_reported_length_remaining(tvb, offset), /* frag_data_len */
+                              more_frags                                  /* more_frags */
+                              );
+
+            gboolean update_col_info = TRUE;
+            next_tvb = process_reassembled_data(tvb, offset, pinfo, "Reassembled RLC SDU",
+                                                fh, &rlc_nr_frag_items,
+                                                &update_col_info, tree);
+            pinfo->fragmented = save_fragmented;
+        }
+    }
+
+
     if (tvb_reported_length_remaining(tvb, offset) > 0) {
         show_PDU_in_tree(pinfo, tree, tvb, offset, tvb_reported_length_remaining(tvb, offset),
                          p_rlc_nr_info, seg_info, FALSE);
         show_PDU_in_info(pinfo, top_ti, tvb_reported_length_remaining(tvb, offset), seg_info);
+
+        /* Also add any reassembled PDU */
+        if (next_tvb) {
+            add_new_data_source(pinfo, next_tvb, "Reassembled RLC-NR PDU");
+            show_PDU_in_tree(pinfo, tree, next_tvb, 0, tvb_captured_length(next_tvb),
+                             p_rlc_nr_info, seg_info, TRUE);
+        }
     } else if (!global_rlc_nr_headers_expected) {
         /* Report that expected data was missing (unless we know it might happen) */
         expert_add_info(pinfo, am_header_ti, &ei_rlc_nr_am_data_no_data);
@@ -1111,7 +1239,7 @@ static gboolean dissect_rlc_nr_heur(tvbuff_t *tvb, packet_info *pinfo,
 
     /* Create tvb that starts at actual RLC PDU */
     rlc_tvb = tvb_new_subset_remaining(tvb, offset);
-    dissect_rlc_nr_common(rlc_tvb, pinfo, tree, TRUE);
+    dissect_rlc_nr_common(rlc_tvb, pinfo, tree, TRUE /* udp framing */);
     return TRUE;
 }
 
@@ -1121,7 +1249,7 @@ static gboolean dissect_rlc_nr_heur(tvbuff_t *tvb, packet_info *pinfo,
 
 static int dissect_rlc_nr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
-    dissect_rlc_nr_common(tvb, pinfo, tree, FALSE);
+    dissect_rlc_nr_common(tvb, pinfo, tree, FALSE /* not udp framing */);
     return tvb_captured_length(tvb);
 }
 
@@ -1247,38 +1375,64 @@ static void dissect_rlc_nr_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree
 }
 
 
-/* Configure number of PDCP SN bits to use for DRB channels */
-void set_rlc_nr_drb_pdcp_seqnum_length(packet_info *pinfo, guint16 ueid, guint8 drbid,
-                                       guint8 userplane_seqnum_length_ul,
-                                       guint8 userplane_seqnum_length_dl)
+/* Configure DRB PDCP channel properties. */
+void set_rlc_nr_drb_pdcp_mapping(packet_info *pinfo,
+                                 nr_drb_rlc_pdcp_mapping_t *drb_mapping)
 {
-    wmem_tree_key_t key[3];
+    wmem_tree_key_t key[2];
     guint32 id;
-    rlc_ue_parameters *params;
+    pdcp_bearer_parameters *params;
 
     if (PINFO_FD_VISITED(pinfo)) {
         return;
     }
 
-    id = (drbid << 16) | ueid;
+    id = (drb_mapping->drbid << 16) | drb_mapping->ueid;
     key[0].length = 1;
     key[0].key = &id;
-    key[1].length = 1;
-    key[1].key = &pinfo->num;
-    key[2].length = 0;
-    key[2].key = NULL;
+    key[1].length = 0;
+    key[1].key = NULL;
 
-    params = (rlc_ue_parameters *)wmem_tree_lookup32_array_le(ue_parameters_tree, key);
+    /* Look up entry for this UEId/drbid */
+    params = (pdcp_bearer_parameters *)wmem_tree_lookup32_array_le(ue_parameters_tree, key);
     if (params && (params->id != id)) {
         params = NULL;
     }
     if (params == NULL) {
-        params = (rlc_ue_parameters *)wmem_new(wmem_file_scope(), rlc_ue_parameters);
+        /* Not found so create new entry */
+        params = (pdcp_bearer_parameters *)wmem_new(wmem_file_scope(), pdcp_bearer_parameters);
         params->id = id;
         wmem_tree_insert32_array(ue_parameters_tree, key, (void *)params);
     }
-    params->pdcp_sn_bits_ul = userplane_seqnum_length_ul;
-    params->pdcp_sn_bits_dl = userplane_seqnum_length_dl;
+
+    /* Populate params */
+    params->pdcp_sn_bits_ul = drb_mapping->pdcpUlSnLength;
+    params->pdcp_sn_bits_dl = drb_mapping->pdcpDlSnLength;
+    params->pdcp_sdap_ul = drb_mapping->pdcpUlSdap;
+    params->pdcp_sdap_dl = drb_mapping->pdcpDlSdap;
+    params->pdcp_integrity = drb_mapping->pdcpIntegrityProtection;
+    params->pdcp_ciphering_disabled = drb_mapping->pdcpCipheringDisabled;
+}
+
+pdcp_bearer_parameters* get_rlc_nr_drb_pdcp_mapping(guint16 ue_id, guint8 drb_id)
+{
+    wmem_tree_key_t key[2];
+    guint32 id;
+    pdcp_bearer_parameters *params;
+
+    id = (drb_id << 16) | ue_id;
+    key[0].length = 1;
+    key[0].key = &id;
+    key[1].length = 0;
+    key[1].key = NULL;
+
+    /* Look up configured params for this PDCP DRB. */
+    params = (pdcp_bearer_parameters *)wmem_tree_lookup32_array_le(ue_parameters_tree, key);
+    if (params && (params->id != id)) {
+        params = NULL;
+    }
+
+    return params;
 }
 
 
@@ -1462,7 +1616,6 @@ void proto_register_rlc_nr(void)
               "Acknowledged Mode Data", HFILL
             }
         },
-
         { &hf_rlc_nr_am_cpt,
             { "Control PDU Type",
               "rlc-nr.am.cpt", FT_UINT8, BASE_HEX, VALS(control_pdu_type_vals), 0x70,
@@ -1593,8 +1746,7 @@ void proto_register_rlc_nr(void)
             "rlc-nr.reassembled.data",
             FT_BYTES, BASE_NONE, NULL, 0x0,
             "The reassembled payload", HFILL }
-        },
-
+        }
     };
 
     static gint *ett[] =
@@ -1671,6 +1823,12 @@ void proto_register_rlc_nr(void)
         "add expert info to indicate that headers were omitted",
         &global_rlc_nr_headers_expected);
 
+    prefs_register_bool_preference(rlc_nr_module, "reassemble_am_frames",
+        "Try to reassemble AM frames",
+        "N.B. This should be considered experimental/incomplete, in that it doesn't try to discard reassembled state "
+        "when reestablishment happens, or in certain packet-loss cases",
+        &global_rlc_nr_reassemble_am_pdus);
+
     prefs_register_bool_preference(rlc_nr_module, "reassemble_um_frames",
         "Try to reassemble UM frames",
         "N.B. This should be considered experimental/incomplete, in that it doesn't try to discard reassembled state "
@@ -1678,6 +1836,8 @@ void proto_register_rlc_nr(void)
         &global_rlc_nr_reassemble_um_pdus);
 
     ue_parameters_tree = wmem_tree_new_autoreset(wmem_epan_scope(), wmem_file_scope());
+    reassembly_start_table = wmem_tree_new_autoreset(wmem_epan_scope(), wmem_file_scope());
+    reassembly_start_table_stored = wmem_tree_new_autoreset(wmem_epan_scope(), wmem_file_scope());
 
     /* Register reassembly table. */
     reassembly_table_register(&pdu_reassembly_table, &pdu_reassembly_table_functions);
