@@ -516,7 +516,7 @@ dissect_sametime_content(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, vo
    col_append_str(pinfo->cinfo, COL_INFO, " ");
 
    /* message type statistic */
-   sinfo = wmem_new(wmem_packet_scope(), struct SametimeTap);
+   sinfo = wmem_new(pinfo->pool, struct SametimeTap);
    sinfo->message_type = message_type;
    sinfo->send_type = -1;
    sinfo->user_status = -1;
@@ -738,7 +738,7 @@ proto_register_sametime(void)
       },
       { &hf_sametime_field_text,
          { "text", "sametime.field_text",
-            FT_STRING, STR_ASCII,
+            FT_STRING, BASE_NONE,
             NULL, 0x0,
             NULL, HFILL }
       },
@@ -824,43 +824,43 @@ proto_register_sametime(void)
       /*type location*/
       { &hf_sametime_location_name,
          { "name", "sametime.location.name",
-            FT_STRING, STR_ASCII,
+            FT_STRING, BASE_NONE,
             NULL, 0x0,
             NULL, HFILL }
       },
       { &hf_sametime_location_city,
          { "city", "sametime.location.city",
-            FT_STRING, STR_ASCII,
+            FT_STRING, BASE_NONE,
             NULL, 0x0,
             NULL, HFILL }
       },
       { &hf_sametime_location_province,
          { "province", "sametime.location.province",
-            FT_STRING, STR_ASCII,
+            FT_STRING, BASE_NONE,
             NULL, 0x0,
             NULL, HFILL }
       },
       { &hf_sametime_location_postalcode,
          { "postal code", "sametime.location.postalcode",
-            FT_STRING, STR_ASCII,
+            FT_STRING, BASE_NONE,
             NULL, 0x0,
             NULL, HFILL }
       },
       { &hf_sametime_location_country,
          { "country", "sametime.location.country",
-            FT_STRING, STR_ASCII,
+            FT_STRING, BASE_NONE,
             NULL, 0x0,
             NULL, HFILL }
       },
       { &hf_sametime_location_phone,
          { "phone", "sametime.location.phone",
-            FT_STRING, STR_ASCII,
+            FT_STRING, BASE_NONE,
             NULL, 0x0,
             NULL, HFILL }
       },
       { &hf_sametime_location_timezone,
          { "time zone", "sametime.location.timezone",
-            FT_STRING, STR_ASCII,
+            FT_STRING, BASE_NONE,
             NULL, 0x0,
             NULL, HFILL }
       },
@@ -908,7 +908,7 @@ proto_reg_handoff_sametime(void)
 
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
