@@ -175,9 +175,9 @@ samr_query_dispinfo(void *dummy _U_, packet_info *pinfo, epan_dissect_t *edt, co
 
 		fi_rid=(field_info *)gp_rids->pdata[num_rids-1];
 		fi_name=(field_info *)gp_names->pdata[num_rids-1];
-		g_strlcpy(sid_name_str, sid, 256);
+		(void) g_strlcpy(sid_name_str, sid, 256);
 		sid_name_str[len++]='-';
-		g_snprintf(sid_name_str+len, 256-len, "%d",fi_rid->value.value.sinteger);
+		snprintf(sid_name_str+len, 256-len, "%d",fi_rid->value.value.sinteger);
 		add_sid_name_mapping(sid_name_str, fi_name->value.value.string);
 	}
 	return TAP_PACKET_REDRAW;
@@ -334,7 +334,7 @@ proto_register_smb_sidsnooping(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
