@@ -275,9 +275,9 @@ tftp_dissect_options(tvbuff_t *tvb, packet_info *pinfo, int offset,
                                    ett_tftp_option, NULL, "Option: %s = %s", optionname, optionvalue);
 
     proto_tree_add_item(opt_tree, hf_tftp_option_name, tvb, offset,
-                        option_len, ENC_ASCII|ENC_NA);
+                        option_len, ENC_ASCII);
     proto_tree_add_item(opt_tree, hf_tftp_option_value, tvb, value_offset,
-                        value_len, ENC_ASCII|ENC_NA);
+                        value_len, ENC_ASCII);
 
     offset += option_len + value_len;
 
@@ -295,9 +295,6 @@ tftp_dissect_options(tvbuff_t *tvb, packet_info *pinfo, int offset,
         if (windowsize < 1 || windowsize > 65535) {
           expert_add_info(pinfo, opt_tree, &ei_tftp_windowsize_range);
         }
-      } else if (!g_ascii_strcasecmp((const char *)optionname, "tsize") &&
-               opcode == TFTP_RRQ) {
-        tftp_info->tsize_requested = TRUE;
       }
     } else if (opcode == TFTP_OACK) {
       if (!g_ascii_strcasecmp((const char *)optionname, "blksize")) {
@@ -321,6 +318,9 @@ tftp_dissect_options(tvbuff_t *tvb, packet_info *pinfo, int offset,
           expert_add_info(pinfo, opt_tree, &ei_tftp_msftwindow_unrecognized);
         }
       }
+    } else if (!g_ascii_strcasecmp((const char *)optionname, "tsize") &&
+               opcode == TFTP_RRQ) {
+      tftp_info->tsize_requested = TRUE;
     }
   }
 }
@@ -452,7 +452,7 @@ static void dissect_tftp_message(tftp_conv_info_t *tftp_info,
 
     i1 = tvb_strsize(tvb, offset);
     proto_tree_add_item(tftp_tree, hf_tftp_transfer_type,
-                        tvb, offset, i1, ENC_ASCII|ENC_NA);
+                        tvb, offset, i1, ENC_ASCII);
 
     col_append_fstr(pinfo->cinfo, COL_INFO, ", Transfer type: %s",
                     tvb_format_stringzpad(pinfo->pool, tvb, offset, i1));
@@ -478,7 +478,7 @@ static void dissect_tftp_message(tftp_conv_info_t *tftp_info,
 
     i1 = tvb_strsize(tvb, offset);
     proto_tree_add_item(tftp_tree, hf_tftp_transfer_type,
-                        tvb, offset, i1, ENC_ASCII|ENC_NA);
+                        tvb, offset, i1, ENC_ASCII);
 
     col_append_fstr(pinfo->cinfo, COL_INFO, ", Transfer type: %s",
                     tvb_format_stringzpad(pinfo->pool, tvb, offset, i1));
@@ -588,22 +588,11 @@ static void dissect_tftp_message(tftp_conv_info_t *tftp_info,
         tftp_info->is_simple_file            /* This is a simple file */
         && filename != NULL                  /* There is a file name */
         && !tftp_info->blocks_missing        /* No missing blocks */
-        && (tftp_info->last_package_available || !PINFO_FD_VISITED(pinfo))
-          /* If this is the first pass (i.e., this is tshark one-pass
-           * mode and we're tapping), then we can't know if the last
-           * block is present in the file yet. */
+        && tftp_info->last_package_available /* Last package known */
     ) {
 
-      if (PINFO_FD_VISITED(pinfo)) {
-        if (blocknum == 1 && !tftp_info->payload_data) {
+      if (blocknum == 1 && !tftp_info->payload_data) {
           tftp_info->payload_data = (guint8 *)g_try_malloc((gsize)tftp_info->file_length);
-        }
-      } else {
-        /* We allocate this in file scope so that it doesn't leak if it
-         * turns out we don't have all the blocks so we never send this
-         * to the tap.
-         */
-        tftp_info->payload_data = (guint8 *)wmem_realloc(wmem_file_scope(), tftp_info->payload_data, (gsize)tftp_info->file_length);
       }
 
       if (tftp_info->payload_data == NULL ||
@@ -703,7 +692,7 @@ static void dissect_tftp_message(tftp_conv_info_t *tftp_info,
 
     i1 = tvb_strsize(tvb, offset);
     proto_tree_add_item(tftp_tree, hf_tftp_error_string, tvb, offset,
-                        i1, ENC_ASCII|ENC_NA);
+                        i1, ENC_ASCII);
 
     col_append_fstr(pinfo->cinfo, COL_INFO, ", Message: %s",
                     tvb_format_stringzpad(pinfo->pool, tvb, offset, i1));
@@ -770,7 +759,7 @@ tftp_info_for_conversation(conversation_t *conversation)
 }
 
 static gboolean
-is_valid_request_body(tvbuff_t *tvb)
+is_valid_requerest_body(tvbuff_t *tvb)
 {
   gint offset = 2;
   guint zeros_counter = 0;
@@ -790,7 +779,7 @@ is_valid_request_body(tvbuff_t *tvb)
   guint len = tvb_strsize(tvb, offset);
   const gchar* mode = tvb_format_stringzpad(wmem_packet_scope(), tvb, offset, len);
 
-  const gchar* modes[] = {"netascii", "octet", "mail"};
+  const gchar* modes[] = {"netscii", "octet", "mail"};
   for(guint i = 0; i < array_length(modes); ++i) {
     if (g_ascii_strcasecmp(mode, modes[i]) == 0) return TRUE;
   }
@@ -799,14 +788,14 @@ is_valid_request_body(tvbuff_t *tvb)
 }
 
 static gboolean
-is_valid_request(tvbuff_t *tvb)
+is_valid_requerest(tvbuff_t *tvb)
 {
   if (tvb_captured_length(tvb) < MIN_HDR_LEN)
     return FALSE;
   guint16 opcode = tvb_get_ntohs(tvb, 0);
   if ((opcode != TFTP_RRQ) && (opcode != TFTP_WRQ))
     return FALSE;
-  return is_valid_request_body(tvb);
+  return is_valid_requerest_body(tvb);
 }
 
 static conversation_t* create_tftp_conversation(packet_info *pinfo)
@@ -831,7 +820,7 @@ static conversation_t* create_tftp_conversation(packet_info *pinfo)
 static gboolean
 dissect_tftp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
-  if (is_valid_request_body(tvb)) {
+  if (is_valid_requerest_body(tvb)) {
     conversation_t* conversation = create_tftp_conversation(pinfo);
     dissect_tftp_message(tftp_info_for_conversation(conversation), tvb, pinfo, tree);
     return TRUE;
@@ -861,7 +850,7 @@ dissect_embeddedtftp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, v
     case TFTP_RRQ:
     case TFTP_WRQ:
       /* These 2 opcodes have a NULL-terminated source file name after opcode. Verify */
-      if (!is_valid_request_body(tvb))
+      if (!is_valid_requerest_body(tvb))
         return FALSE;
      /* Intentionally dropping through here... */
     case TFTP_DATA:
@@ -921,7 +910,7 @@ dissect_tftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
    */
   if ((value_is_in_range(global_tftp_port_range, pinfo->destport) ||
        (pinfo->match_uint == pinfo->destport)) &&
-      is_valid_request(tvb))
+      is_valid_requerest(tvb))
   {
     conversation = create_tftp_conversation(pinfo);
   }
@@ -929,41 +918,26 @@ dissect_tftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
   if (conversation == NULL)
   {
     /* Not the initial read or write request */
-    /* Look for wildcarded conversation based upon client port */
-    if ((conversation = find_conversation(pinfo->num, &pinfo->dst, &pinfo->src, ENDPOINT_UDP,
-                                     pinfo->destport, 0, NO_PORT_B)) && conversation_get_dissector(conversation, pinfo->num) == tftp_handle) {
-#if 0
-      /* XXX: While setting the wildcarded port makes sense, if we do that,
-       * it's more complicated to find the correct conversation if ports are
-       * reused. (find_conversation with full information prefers any exact
-       * match, even with an earlier setup frame, to any wildcarded match.)
-       * We would want to find the most recent conversations with one wildcard
-       * and with both ports, and take the latest of those.
-       */
-      /* Set other side of conversation (server port) */
-      if (pinfo->destport == conversation_key_port1(conversation->key_ptr))
-        conversation_set_port2(conversation, pinfo->srcport);
-#endif
-    } else if ((conversation = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst, ENDPOINT_UDP,
-                                     pinfo->srcport, 0, NO_PORT_B)) && conversation_get_dissector(conversation, pinfo->num) == tftp_handle) {
-
-    } else {
-      /* How did we get here? We must have matched one of the TFTP ports
-       * and missed the WRQ/RRQ. While it is contrary to the spirit of
-       * RFC 1350 for the server not to change ports, there appear to be
-       * such servers out there (issue #18122), and since the default port
-       * is IANA assigned it doesn't do harm to process it. Note that in
-       * that case the conversation won't have the tftp dissector set. */
-      conversation = find_conversation_pinfo(pinfo, 0);
-      if (conversation == NULL) {
-        return 0;
+    if (!PINFO_FD_VISITED(pinfo)) {
+      /* During first pass, look for conversation based upon client port */
+      conversation = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst, ENDPOINT_UDP,
+                                       pinfo->destport, 0, NO_PORT2);
+      if (conversation != NULL) {
+        /* Set other side of conversation (server port) */
+        if (pinfo->destport == conversation_key_port1(conversation->key_ptr))
+          conversation_set_port2(conversation, pinfo->srcport);
+        else
+          /* Direction of conv match must have been wrong - ignore! */
+          return 0;
       }
     }
+    if (conversation == NULL) {
+      conversation = find_conversation_pinfo(pinfo, 0);
+      if (conversation == NULL || conversation_get_dissector(conversation, pinfo->num) != tftp_handle)
+        return 0;
+    }
   }
 
-  if (pinfo->num > conversation->last_frame) {
-    conversation->last_frame = pinfo->num;
-  }
   dissect_tftp_message(tftp_info_for_conversation(conversation), tvb, pinfo, tree);
   return tvb_captured_length(tvb);
 }
