@@ -12,7 +12,7 @@
 
 /*---------------------------------------------------------------------------*/
 
-#define G_LOG_DOMAIN "TPNCP"
+#define WS_LOG_DOMAIN "TPNCP"
 #include "config.h"
 
 #include <epan/packet.h>
@@ -23,7 +23,7 @@
 #include <wsutil/file_util.h>
 #include <wsutil/report_message.h>
 #include <wsutil/strtoi.h>
-#include <epan/wmem/wmem.h>
+#include <epan/wmem_scopes.h>
 #include "packet-acdr.h"
 #include "packet-tcp.h"
 
@@ -507,7 +507,7 @@ fill_enums_id_vals(FILE *file)
                     first_entry = FALSE;
                 }
                 tpncp_enums_name_vals[enum_val] = wmem_strdup(wmem_epan_scope(), enum_name);
-                g_strlcpy(enum_type, enum_name, MAX_TPNCP_DB_ENTRY_LEN);
+                (void) g_strlcpy(enum_type, enum_name, MAX_TPNCP_DB_ENTRY_LEN);
             }
             tpncp_enums_id_vals[enum_val][i].strptr = wmem_strdup(wmem_epan_scope(), enum_str);
             tpncp_enums_id_vals[enum_val][i].value = enum_id;
@@ -708,7 +708,7 @@ init_tpncp_data_fields_info(tpncp_data_field_info *data_fields_info, FILE *file)
     while (fgetline(tpncp_db_entry, MAX_TPNCP_DB_ENTRY_LEN, file)) {
         special_type = TPNCP_NORMAL;
         since = 0;
-        g_snprintf(entry_copy, MAX_TPNCP_DB_ENTRY_LEN, "%s", tpncp_db_entry);
+        snprintf(entry_copy, MAX_TPNCP_DB_ENTRY_LEN, "%s", tpncp_db_entry);
         if (!strncmp(tpncp_db_entry, "#####", 5)) {
             hf_size--;
             break;
@@ -824,8 +824,7 @@ init_tpncp_data_fields_info(tpncp_data_field_info *data_fields_info, FILE *file)
             field = &data_fields_info[data_id];
             current_data_id = data_id;
         } else {
-            field->p_next = (tpncp_data_field_info *) wmem_alloc(
-                wmem_epan_scope(), sizeof (tpncp_data_field_info));
+            field->p_next = wmem_new(wmem_epan_scope(), tpncp_data_field_info);
             if (!field->p_next)
                 return (-1);
             field = field->p_next;
@@ -909,7 +908,7 @@ init_tpncp_db(void)
     gchar tpncp_dat_file_path[MAX_TPNCP_DB_ENTRY_LEN];
     FILE *file;
 
-    g_snprintf(tpncp_dat_file_path, MAX_TPNCP_DB_ENTRY_LEN,
+    snprintf(tpncp_dat_file_path, MAX_TPNCP_DB_ENTRY_LEN,
                "%s" G_DIR_SEPARATOR_S "tpncp" G_DIR_SEPARATOR_S "tpncp.dat", get_datafile_dir());
 
     /* Open file with TPNCP data. */
