@@ -33,6 +33,8 @@
 #include <wsutil/wslog.h>
 #include <wsutil/ws_assert.h>
 
+#include <ui/version_info.h>
+
 #include "conversation.h"
 #include "except.h"
 #include "packet.h"
@@ -271,15 +273,6 @@ epan_init(register_cb cb, gpointer client_data, gboolean load_plugins)
 	}
 
 	/* initialize libgcrypt (beware, it won't be thread-safe) */
-#if GCRYPT_VERSION_NUMBER >= 0x010a00
-	/* Ensure FIPS mode is disabled; it makes it impossible to decrypt
-	 * non-NIST approved algorithms. We're decrypting, not promising
-	 * security. This overrides any file or environment variables that
-	 * would normally turn on FIPS mode, and has to be done prior to
-	 * gcry_check_version().
-	 */
-	gcry_control (GCRYCTL_NO_FIPS_MODE);
-#endif
 	gcry_check_version(NULL);
 #if defined(_WIN32)
 	gcry_set_log_handler (quiet_gcrypt_logger, NULL);
@@ -288,11 +281,6 @@ epan_init(register_cb cb, gpointer client_data, gboolean load_plugins)
 	gcry_control (GCRYCTL_INITIALIZATION_FINISHED, 0);
 #ifdef HAVE_LIBGNUTLS
 	gnutls_global_init();
-#if GNUTLS_VERSION_NUMBER >= 0x030602
-	if (gnutls_fips140_mode_enabled()) {
-		gnutls_fips140_set_mode(GNUTLS_FIPS140_LAX, 0);
-	}
-#endif
 #endif
 #ifdef HAVE_LIBXML2
 	xmlInitParser();
@@ -305,6 +293,7 @@ epan_init(register_cb cb, gpointer client_data, gboolean load_plugins)
 #endif
 
 	TRY {
+		export_pdu_init();
 		tap_init();
 		prefs_init();
 		expert_init();
@@ -313,6 +302,7 @@ epan_init(register_cb cb, gpointer client_data, gboolean load_plugins)
 		conversation_init();
 		capture_dissector_init();
 		reassembly_tables_init();
+        conversation_filters_init();
 		g_slist_foreach(epan_plugins, epan_plugin_init, NULL);
 		proto_init(epan_plugin_register_all_procotols, epan_plugin_register_all_handoffs, cb, client_data);
 		g_slist_foreach(epan_plugins, epan_plugin_register_all_tap_listeners, NULL);
@@ -322,7 +312,6 @@ epan_init(register_cb cb, gpointer client_data, gboolean load_plugins)
 		final_registration_all_protocols();
 		print_cache_field_handles();
 		expert_packet_init();
-		export_pdu_init();
 #ifdef HAVE_LUA
 		wslua_init(cb, client_data);
 #endif
@@ -431,17 +420,17 @@ epan_cleanup(void)
 	except_deinit();
 	addr_resolv_cleanup();
 
+#ifdef HAVE_PLUGINS
+	plugins_cleanup(libwireshark_plugins);
+	libwireshark_plugins = NULL;
+#endif
+
 	if (pinfo_pool_cache != NULL) {
 		wmem_destroy_allocator(pinfo_pool_cache);
 		pinfo_pool_cache = NULL;
 	}
 
 	wmem_cleanup_scopes();
-
-#ifdef HAVE_PLUGINS
-	plugins_cleanup(libwireshark_plugins);
-	libwireshark_plugins = NULL;
-#endif
 }
 
 struct epan_session {
@@ -781,91 +770,92 @@ epan_dissect_packet_contains_field(epan_dissect_t* edt,
  * Get compile-time information for libraries used by libwireshark.
  */
 void
-epan_get_compiled_version_info(GString *str)
+epan_gather_compile_info(feature_list l)
 {
-	/* LUA */
+	/* Lua */
 #ifdef HAVE_LUA
-	g_string_append(str, ", with " LUA_RELEASE);
+	with_feature(l, "%s", LUA_RELEASE);
 #else
-	g_string_append(str, ", without Lua");
+	without_feature(l, "Lua");
 #endif /* HAVE_LUA */
 
 	/* GnuTLS */
 #ifdef HAVE_LIBGNUTLS
-	g_string_append(str, ", with GnuTLS " LIBGNUTLS_VERSION);
 #ifdef HAVE_GNUTLS_PKCS11
-	g_string_append(str, " and PKCS #11 support");
+	with_feature(l, "GnuTLS %s and PKCS #11 support", LIBGNUTLS_VERSION);
+#else
+	with_feature(l, "GnuTLS %s", LIBGNUTLS_VERSION);
 #endif /* HAVE_GNUTLS_PKCS11 */
 #else
-	g_string_append(str, ", without GnuTLS");
+	without_feature(l, "GnuTLS");
 #endif /* HAVE_LIBGNUTLS */
 
 	/* Gcrypt */
-	g_string_append(str, ", with Gcrypt " GCRYPT_VERSION);
+	with_feature(l, "Gcrypt %s", GCRYPT_VERSION);
 
 	/* Kerberos */
 #if defined(HAVE_MIT_KERBEROS)
-	g_string_append(str, ", with MIT Kerberos");
+	with_feature(l, "Kerberos (MIT)");
 #elif defined(HAVE_HEIMDAL_KERBEROS)
-	g_string_append(str, ", with Heimdal Kerberos");
+	with_feature(l, "Kerberos (Heimdal)");
 #else
-	g_string_append(str, ", without Kerberos");
+	without_feature(l, "Kerberos");
 #endif /* HAVE_KERBEROS */
 
 	/* MaxMindDB */
 #ifdef HAVE_MAXMINDDB
-	g_string_append(str, ", with MaxMind DB resolver");
+	with_feature(l, "MaxMind");
 #else
-	g_string_append(str, ", without MaxMind DB resolver");
+	without_feature(l, "MaxMind");
 #endif /* HAVE_MAXMINDDB */
 
 	/* nghttp2 */
 #ifdef HAVE_NGHTTP2
-	g_string_append(str, ", with nghttp2 " NGHTTP2_VERSION);
+	with_feature(l, "nghttp2 %s", NGHTTP2_VERSION);
 #else
-	g_string_append(str, ", without nghttp2");
+	without_feature(l, "nghttp2");
 #endif /* HAVE_NGHTTP2 */
 
 	/* brotli */
 #ifdef HAVE_BROTLI
-	g_string_append(str, ", with brotli");
+	with_feature(l, "brotli");
 #else
-	g_string_append(str, ", without brotli");
+	without_feature(l, "brotli");
 #endif /* HAVE_BROTLI */
 
 	/* LZ4 */
 #ifdef HAVE_LZ4
-	g_string_append(str, ", with LZ4");
+	with_feature(l, "LZ4");
 #else
-	g_string_append(str, ", without LZ4");
+	without_feature(l, "LZ4");
 #endif /* HAVE_LZ4 */
 
 	/* Zstandard */
 #ifdef HAVE_ZSTD
-	g_string_append(str, ", with Zstandard");
+	with_feature(l, "Zstandard");
 #else
-	g_string_append(str, ", without Zstandard");
+	without_feature(l, "Zstandard");
 #endif /* HAVE_ZSTD */
 
 	/* Snappy */
 #ifdef HAVE_SNAPPY
-	g_string_append(str, ", with Snappy");
+	with_feature(l, "Snappy");
 #else
-	g_string_append(str, ", without Snappy");
+	without_feature(l, "Snappy");
 #endif /* HAVE_SNAPPY */
 
 	/* libxml2 */
 #ifdef HAVE_LIBXML2
-	g_string_append(str, ", with libxml2 " LIBXML_DOTTED_VERSION);
+	with_feature(l, "libxml2 %s", LIBXML_DOTTED_VERSION);
 #else
-	g_string_append(str, ", without libxml2");
+	without_feature(l, "libxml2");
 #endif /* HAVE_LIBXML2 */
 
 	/* libsmi */
 #ifdef HAVE_LIBSMI
-	g_string_append(str, ", with libsmi " SMI_VERSION_STRING);
+	with_feature(l, "libsmi %s", SMI_VERSION_STRING);
 #else
-	g_string_append(str, ", without libsmi");
+	without_feature(l, "libsmi");
 #endif /* HAVE_LIBSMI */
 }
 
@@ -873,44 +863,44 @@ epan_get_compiled_version_info(GString *str)
  * Get runtime information for libraries used by libwireshark.
  */
 void
-epan_get_runtime_version_info(GString *str)
+epan_gather_runtime_info(feature_list l)
 {
 	/* c-ares */
-	g_string_append_printf(str, ", with c-ares %s", ares_version(NULL));
+	with_feature(l, "c-ares %s", ares_version(NULL));
 
 	/* GnuTLS */
 #ifdef HAVE_LIBGNUTLS
-	g_string_append_printf(str, ", with GnuTLS %s", gnutls_check_version(NULL));
+	with_feature(l, "GnuTLS %s", gnutls_check_version(NULL));
 #endif /* HAVE_LIBGNUTLS */
 
 	/* Gcrypt */
-	g_string_append_printf(str, ", with Gcrypt %s", gcry_check_version(NULL));
+	with_feature(l, "Gcrypt %s", gcry_check_version(NULL));
 
 	/* nghttp2 */
 #if NGHTTP2_VERSION_AGE >= 1
 	nghttp2_info *nghttp2_ptr = nghttp2_version(0);
-	g_string_append_printf(str, ", with nghttp2 %s",  nghttp2_ptr->version_str);
+	with_feature(l, "nghttp2 %s",  nghttp2_ptr->version_str);
 #endif /* NGHTTP2_VERSION_AGE */
 
 	/* brotli */
 #ifdef HAVE_BROTLI
-	g_string_append_printf(str, ", with brotli %d.%d.%d", BrotliDecoderVersion() >> 24,
+	with_feature(l, "brotli %d.%d.%d", BrotliDecoderVersion() >> 24,
 		(BrotliDecoderVersion() >> 12) & 0xFFF, BrotliDecoderVersion() & 0xFFF);
 #endif
 
 	/* LZ4 */
 #if LZ4_VERSION_NUMBER >= 10703
-	g_string_append_printf(str, ", with LZ4 %s", LZ4_versionString());
+	with_feature(l, "LZ4 %s", LZ4_versionString());
 #endif /* LZ4_VERSION_NUMBER */
 
 	/* Zstandard */
 #if ZSTD_VERSION_NUMBER >= 10300
-	g_string_append_printf(str, ", with Zstandard %s", ZSTD_versionString());
+	with_feature(l, "Zstandard %s", ZSTD_versionString());
 #endif /* ZSTD_VERSION_NUMBER */
 
 	/* libsmi */
 #ifdef HAVE_SMI_VERSION_STRING
-	g_string_append_printf(str, ", with libsmi %s", smi_version_string);
+	with_feature(l, "libsmi %s", smi_version_string);
 #endif /* HAVE_SMI_VERSION_STRING */
 }
 
