@@ -1,4 +1,4 @@
-/* epan.h
+/** @file
  *
  * Wireshark Protocol Analyzer Library
  *
@@ -12,6 +12,7 @@
 
 #include <glib.h>
 
+#include <wsutil/feature_list.h>
 #include <epan/tvbuff.h>
 #include <epan/prefs.h>
 #include <epan/frame_data.h>
@@ -179,6 +180,7 @@ WS_DLL_PUBLIC void epan_get_version_number(int *major, int *minor, int *micro);
  * created if create_proto_tree is false in the call to epan_dissect_init().
  * Clearing this reverts the decision to epan_dissect_init() and proto_tree_visible.
  */
+WS_DLL_PUBLIC
 void epan_set_always_visible(gboolean force);
 
 /** initialize an existing single packet dissection */
@@ -272,14 +274,14 @@ epan_custom_set(epan_dissect_t *edt, GSList *ids, gint occurrence,
  */
 WS_DLL_PUBLIC
 void
-epan_get_compiled_version_info(GString *str);
+epan_gather_compile_info(feature_list l);
 
 /**
  * Get runtime information for libraries used by libwireshark.
  */
 WS_DLL_PUBLIC
 void
-epan_get_runtime_version_info(GString *str);
+epan_gather_runtime_info(feature_list l);
 
 #ifdef __cplusplus
 }
