@@ -3,19 +3,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 2001 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -44,11 +32,12 @@ get_guid(const char *s, e_guid_t *guid)
 {
     size_t i, n;
     const char *p;
-    char digits[9];
+    char digits[3];
     static const char fmt[] = "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX";
+    const size_t fmtchars = sizeof(fmt) - 1;
 
-    n = strlen(s);
-    if (n != strlen(fmt))
+    n = strnlen(s, fmtchars);
+    if (n != fmtchars)
         return FALSE;
     for (i=0; i<n; i++) {
         if (fmt[i] == 'X') {
@@ -61,14 +50,11 @@ get_guid(const char *s, e_guid_t *guid)
     }
 
     p = s;
-    g_strlcpy(digits, p, 9);
-    guid->data1 = (guint32)strtoul(digits, NULL, 16);
+    guid->data1 = (guint32)strtoul(p, NULL, 16);
     p += 9;
-    g_strlcpy(digits, p, 5);
-    guid->data2 = (guint16)strtoul(digits, NULL, 16);
+    guid->data2 = (guint16)strtoul(p, NULL, 16);
     p += 5;
-    g_strlcpy(digits, p, 5);
-    guid->data3 = (guint16)strtoul(digits, NULL, 16);
+    guid->data3 = (guint16)strtoul(p, NULL, 16);
     p += 5;
     for (i=0; i < sizeof(guid->data4); i++) {
         if (*p == '-') p++;
@@ -81,13 +67,13 @@ get_guid(const char *s, e_guid_t *guid)
 }
 
 static gboolean
-guid_from_unparsed(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_, gchar **err_msg)
+guid_from_literal(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_, gchar **err_msg)
 {
      e_guid_t guid;
 
     if (!get_guid(s, &guid)) {
         if (err_msg != NULL)
-            *err_msg = g_strdup_printf("\"%s\" is not a valid GUID.", s);
+            *err_msg = ws_strdup_printf("\"%s\" is not a valid GUID.", s);
         return FALSE;
     }
 
@@ -95,28 +81,16 @@ guid_from_unparsed(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_
     return TRUE;
 }
 
+static char *
+guid_to_repr(wmem_allocator_t *scope, const fvalue_t *fv, ftrepr_t rtype _U_, int field_display _U_)
+{
+    return guid_to_str(scope, &fv->value.guid);
+}
+
 static int
-guid_repr_len(fvalue_t *fv _U_, ftrepr_t rtype _U_, int field_display _U_)
+cmp_order(const fvalue_t *a, const fvalue_t *b)
 {
-    return GUID_STR_LEN;
-}
-
-static void
-guid_to_repr(fvalue_t *fv, ftrepr_t rtype _U_, int field_display _U_, char *buf, unsigned int size)
-{
-    guid_to_str_buf(&fv->value.guid, buf, size);
-}
-
-static gboolean
-cmp_eq(const fvalue_t *a, const fvalue_t *b)
-{
-    return memcmp(&a->value.guid, &b->value.guid, sizeof(e_guid_t)) == 0;
-}
-
-static gboolean
-cmp_ne(const fvalue_t *a, const fvalue_t *b)
-{
-    return memcmp(&a->value.guid, &b->value.guid, sizeof(e_guid_t)) != 0;
+    return memcmp(&a->value.guid, &b->value.guid, sizeof(e_guid_t));
 }
 
 void
@@ -129,34 +103,54 @@ ftype_register_guid(void)
         "Globally Unique Identifier",            /* pretty_name */
         GUID_LEN,            /* wire_size */
         NULL,                /* new_value */
+        NULL,                /* copy_value */
         NULL,                /* free_value */
-        guid_from_unparsed,  /* val_from_unparsed */
+        guid_from_literal,   /* val_from_literal */
         NULL,                /* val_from_string */
+        NULL,                /* val_from_charconst */
         guid_to_repr,        /* val_to_string_repr */
-        guid_repr_len,       /* len_string_repr */
 
         { .set_value_guid = guid_fvalue_set_guid }, /* union set_value */
         { .get_value_ptr = value_get },             /* union get_value */
 
-        cmp_eq,
-        cmp_ne,
-        NULL,
-        NULL,
-        NULL,
-        NULL,
-        NULL,
+        cmp_order,
         NULL,
         NULL,                /* cmp_matches */
 
         NULL,
         NULL,
+        NULL,
+        NULL,
+        NULL,
+        NULL,                /* unary_minus */
+        NULL,                /* add */
+        NULL,                /* subtract */
+        NULL,                /* multiply */
+        NULL,                /* divide */
+        NULL,                /* modulo */
     };
 
     ftype_register(FT_GUID, &guid_type);
 }
 
+void
+ftype_register_pseudofields_guid(int proto)
+{
+    static int hf_ft_guid;
+
+    static hf_register_info hf_ftypes[] = {
+            { &hf_ft_guid,
+                { "FT_GUID", "_ws.ftypes.guid",
+                    FT_GUID, BASE_NONE, NULL, 0x00,
+                    NULL, HFILL }
+            },
+    };
+
+    proto_register_field_array(proto, hf_ftypes, array_length(hf_ftypes));
+}
+
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
