@@ -21,33 +21,37 @@ ftype_register_none(void)
 		"Label",			/* pretty_name */
 		0,				/* wire_size */
 		NULL,				/* new_value */
+		NULL,				/* copy_value */
 		NULL,				/* free_value */
-		NULL,				/* val_from_unparsed */
+		NULL,				/* val_from_literal */
 		NULL,				/* val_from_string */
+		NULL,				/* val_from_charconst */
 		NULL,				/* val_to_string_repr */
-		NULL,				/* len_string_repr */
 
 		{ NULL },			/* union set_value */
 		{ NULL },			/* union get_value */
 
-		NULL,				/* cmp_eq */
-		NULL,				/* cmp_ne */
-		NULL,				/* cmp_gt */
-		NULL,				/* cmp_ge */
-		NULL,				/* cmp_lt */
-		NULL,				/* cmp_le */
-		NULL,				/* cmp_bitwise_and */
+		NULL,				/* cmp_order */
 		NULL,				/* cmp_contains */
 		NULL,				/* cmp_matches */
 
-		NULL,
-		NULL,
+		NULL,				/* is_zero */
+		NULL,				/* is_negative */
+		NULL,				/* len */
+		NULL,				/* slice */
+		NULL,				/* biwise_and */
+		NULL,				/* unary_minus */
+		NULL,				/* add */
+		NULL,				/* subtract */
+		NULL,				/* multiply */
+		NULL,				/* divide */
+		NULL,				/* modulo */
 	};
 	ftype_register(FT_NONE, &none_type);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
