@@ -10,29 +10,33 @@
 
 #include <ftypes-int.h>
 #include <epan/strutil.h>
-#include <wsutil/to_str.h>
+#include <epan/to_str.h>
 #include <string.h>
 #include <wsutil/glib-compat.h>
 
 #include <epan/exceptions.h>
 #include <wsutil/ws_assert.h>
 
-#define CMP_MATCHES cmp_matches
-
-#define tvb_is_private	fvalue_gboolean1
-
 static void
 value_new(fvalue_t *fv)
 {
 	fv->value.protocol.tvb = NULL;
 	fv->value.protocol.proto_string = NULL;
-	fv->tvb_is_private = FALSE;
+	fv->value.protocol.tvb_is_private = FALSE;
+}
+
+static void
+value_copy(fvalue_t *dst, const fvalue_t *src)
+{
+	dst->value.protocol.tvb = tvb_clone(src->value.protocol.tvb);
+	dst->value.protocol.proto_string = g_strdup(src->value.protocol.proto_string);
+	dst->value.protocol.tvb_is_private = TRUE;
 }
 
 static void
 value_free(fvalue_t *fv)
 {
-	if (fv->value.protocol.tvb && fv->tvb_is_private) {
+	if (fv->value.protocol.tvb && fv->value.protocol.tvb_is_private) {
 		tvb_free_chain(fv->value.protocol.tvb);
 	}
 	g_free(fv->value.protocol.proto_string);
@@ -68,7 +72,7 @@ val_from_string(fvalue_t *fv, const char *s, gchar **err_msg _U_)
 	tvb_set_free_cb(new_tvb, g_free);
 
 	/* And let us know that we need to free the tvbuff */
-	fv->tvb_is_private = TRUE;
+	fv->value.protocol.tvb_is_private = TRUE;
 	/* This "field" is a value, it has no protocol description, but
 	 * we might compare it to a protocol with NULL tvb.
 	 * (e.g., proto_expert) */
@@ -78,8 +82,9 @@ val_from_string(fvalue_t *fv, const char *s, gchar **err_msg _U_)
 }
 
 static gboolean
-val_from_unparsed(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_, gchar **err_msg)
+val_from_literal(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_, gchar **err_msg)
 {
+	GByteArray *bytes;
 	tvbuff_t *new_tvb;
 
 	/* Free up the old value, if we have one */
@@ -88,8 +93,8 @@ val_from_unparsed(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_,
 	fv->value.protocol.proto_string = NULL;
 
 	/* Does this look like a byte string? */
-	GByteArray *bytes = g_byte_array_new();
-	if (hex_str_to_bytes(s, bytes, TRUE)) {
+	bytes = byte_array_from_literal(s, err_msg);
+	if (bytes != NULL) {
 		/* Make a tvbuff from the bytes */
 		new_tvb = tvb_new_real_data(bytes->data, bytes->len, bytes->len);
 
@@ -100,7 +105,7 @@ val_from_unparsed(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_,
 		g_byte_array_free(bytes, FALSE);
 
 		/* And let us know that we need to free the tvbuff */
-		fv->tvb_is_private = TRUE;
+		fv->value.protocol.tvb_is_private = TRUE;
 		fv->value.protocol.tvb = new_tvb;
 
 		/* This "field" is a value, it has no protocol description, but
@@ -111,50 +116,67 @@ val_from_unparsed(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_,
 	}
 
 	/* Not a byte array, forget about it. */
-	g_byte_array_free(bytes, TRUE);
-
-	/* Treat it as a string. */
-	return val_from_string(fv, s, err_msg);
+	return FALSE;
 }
 
-static int
-val_repr_len(fvalue_t *fv, ftrepr_t rtype, int field_display _U_)
+static gboolean
+val_from_charconst(fvalue_t *fv, unsigned long num, gchar **err_msg)
 {
-	volatile guint length = 0;
+	GByteArray *bytes;
+	tvbuff_t *new_tvb;
 
-	if (rtype != FTREPR_DFILTER) return -1;
+	/* Free up the old value, if we have one */
+	value_free(fv);
+	fv->value.protocol.tvb = NULL;
+	fv->value.protocol.proto_string = NULL;
 
-	TRY {
-		/* 3 bytes for each byte of the byte "NN:" minus 1 byte
-		 * as there's no trailing ":". */
-		length = tvb_captured_length(fv->value.protocol.tvb) * 3 - 1;
+	/* Does this look like a byte string? */
+	bytes = byte_array_from_charconst(num, err_msg);
+	if (bytes != NULL) {
+		/* Make a tvbuff from the bytes */
+		new_tvb = tvb_new_real_data(bytes->data, bytes->len, bytes->len);
+
+		/* Let the tvbuff know how to delete the data. */
+		tvb_set_free_cb(new_tvb, g_free);
+
+		/* Free GByteArray, but keep data. */
+		g_byte_array_free(bytes, FALSE);
+
+		/* And let us know that we need to free the tvbuff */
+		fv->value.protocol.tvb_is_private = TRUE;
+		fv->value.protocol.tvb = new_tvb;
+
+		/* This "field" is a value, it has no protocol description, but
+		 * we might compare it to a protocol with NULL tvb.
+		 * (e.g., proto_expert) */
+		fv->value.protocol.proto_string = g_strdup("");
+		return TRUE;
 	}
-	CATCH_ALL {
-		/* nothing */
-	}
-	ENDTRY;
 
-	return (int) length;
+	/* Not a byte array, forget about it. */
+	return FALSE;
 }
 
-static void
-val_to_repr(fvalue_t *fv, ftrepr_t rtype _U_, int field_display _U_, char * volatile buf, unsigned int size _U_)
+static char *
+val_to_repr(wmem_allocator_t *scope, const fvalue_t *fv, ftrepr_t rtype _U_, int field_display _U_)
 {
 	guint length;
+	char *volatile buf = NULL;
 
-	ws_assert(rtype == FTREPR_DFILTER);
+	if (rtype != FTREPR_DFILTER)
+		return NULL;
 
 	TRY {
 		length = tvb_captured_length(fv->value.protocol.tvb);
 
 		if (length)
-			buf = bytes_to_hexstr_punct(buf, tvb_get_ptr(fv->value.protocol.tvb, 0, length), length, ':');
-		*buf = '\0';
+			buf = bytes_to_str_punct_maxlen(scope, tvb_get_ptr(fv->value.protocol.tvb, 0, length), length, ':', 0);
 	}
 	CATCH_ALL {
 		/* nothing */
 	}
 	ENDTRY;
+	return buf;
 }
 
 static gpointer
@@ -198,46 +220,29 @@ slice(fvalue_t *fv, GByteArray *bytes, guint offset, guint length)
 	}
 }
 
-static gboolean
-cmp_eq(const fvalue_t *fv_a, const fvalue_t *fv_b)
+static int
+_tvbcmp(tvbuff_t *a, tvbuff_t *b)
 {
-	const protocol_value_t	*a = (const protocol_value_t *)&fv_a->value.protocol;
-	const protocol_value_t	*b = (const protocol_value_t *)&fv_b->value.protocol;
-	volatile gboolean	eq = FALSE;
+	guint	a_len = tvb_captured_length(a);
+	guint	b_len = tvb_captured_length(b);
 
-	TRY {
-		if ((a->tvb != NULL) && (b->tvb != NULL)) {
-			guint	a_len = tvb_captured_length(a->tvb);
-
-			if (a_len == tvb_captured_length(b->tvb))
-				eq = (memcmp(tvb_get_ptr(a->tvb, 0, a_len), tvb_get_ptr(b->tvb, 0, a_len), a_len) == 0);
-		} else {
-			eq = (strcmp(a->proto_string, b->proto_string) == 0);
-		}
-	}
-	CATCH_ALL {
-		/* nothing */
-	}
-	ENDTRY;
-
-	return eq;
+	if (a_len != b_len)
+		return a_len < b_len ? -1 : 1;
+	return memcmp(tvb_get_ptr(a, 0, a_len), tvb_get_ptr(b, 0, a_len), a_len);
 }
 
-static gboolean
-cmp_ne(const fvalue_t *fv_a, const fvalue_t *fv_b)
+static int
+cmp_order(const fvalue_t *fv_a, const fvalue_t *fv_b)
 {
 	const protocol_value_t	*a = (const protocol_value_t *)&fv_a->value.protocol;
 	const protocol_value_t	*b = (const protocol_value_t *)&fv_b->value.protocol;
-	volatile gboolean	ne = TRUE;
+	volatile int		c = 0;
 
 	TRY {
 		if ((a->tvb != NULL) && (b->tvb != NULL)) {
-			guint	a_len = tvb_captured_length(a->tvb);
-
-			if (a_len == tvb_captured_length(b->tvb))
-				ne = (memcmp(tvb_get_ptr(a->tvb, 0, a_len), tvb_get_ptr(b->tvb, 0, a_len), a_len) != 0);
+			c = _tvbcmp(a->tvb, b->tvb);
 		} else {
-			ne = (strcmp(a->proto_string, b->proto_string) != 0);
+			c = strcmp(a->proto_string, b->proto_string);
 		}
 	}
 	CATCH_ALL {
@@ -245,123 +250,7 @@ cmp_ne(const fvalue_t *fv_a, const fvalue_t *fv_b)
 	}
 	ENDTRY;
 
-	return ne;
-}
-
-static gboolean
-cmp_gt(const fvalue_t *fv_a, const fvalue_t *fv_b)
-{
-	const protocol_value_t	*a = (const protocol_value_t *)&fv_a->value.protocol;
-	const protocol_value_t	*b = (const protocol_value_t *)&fv_b->value.protocol;
-	volatile gboolean	gt = FALSE;
-
-	TRY {
-		if ((a->tvb != NULL) && (b->tvb != NULL)) {
-			guint	a_len = tvb_captured_length(a->tvb);
-			guint	b_len = tvb_captured_length(b->tvb);
-
-			if (a_len > b_len) {
-				gt = TRUE;
-			} else if (a_len == b_len) {
-				gt = (memcmp(tvb_get_ptr(a->tvb, 0, a_len), tvb_get_ptr(b->tvb, 0, a_len), a_len) > 0);
-			}
-		} else {
-			gt = (strcmp(a->proto_string, b->proto_string) > 0);
-		}
-	}
-	CATCH_ALL {
-		/* nothing */
-	}
-	ENDTRY;
-
-	return gt;
-}
-
-static gboolean
-cmp_ge(const fvalue_t *fv_a, const fvalue_t *fv_b)
-{
-	const protocol_value_t	*a = (const protocol_value_t *)&fv_a->value.protocol;
-	const protocol_value_t	*b = (const protocol_value_t *)&fv_b->value.protocol;
-	volatile gboolean	ge = FALSE;
-
-	TRY {
-		if ((a->tvb != NULL) && (b->tvb != NULL)) {
-			guint	a_len = tvb_captured_length(a->tvb);
-			guint	b_len = tvb_captured_length(b->tvb);
-
-			if (a_len > b_len) {
-				ge = TRUE;
-			} else if (a_len == b_len) {
-				ge = (memcmp(tvb_get_ptr(a->tvb, 0, a_len), tvb_get_ptr(b->tvb, 0, a_len), a_len) >= 0);
-			}
-		} else {
-			ge = (strcmp(a->proto_string, b->proto_string) >= 0);
-		}
-	}
-	CATCH_ALL {
-		/* nothing */
-	}
-	ENDTRY;
-
-	return ge;
-}
-
-static gboolean
-cmp_lt(const fvalue_t *fv_a, const fvalue_t *fv_b)
-{
-	const protocol_value_t	*a = (const protocol_value_t *)&fv_a->value.protocol;
-	const protocol_value_t	*b = (const protocol_value_t *)&fv_b->value.protocol;
-	volatile gboolean	lt = FALSE;
-
-	TRY {
-		if ((a->tvb != NULL) && (b->tvb != NULL)) {
-			guint	a_len = tvb_captured_length(a->tvb);
-			guint	b_len = tvb_captured_length(b->tvb);
-
-			if (a_len < b_len) {
-				lt = TRUE;
-			} else if (a_len == b_len) {
-				lt = (memcmp(tvb_get_ptr(a->tvb, 0, a_len), tvb_get_ptr(b->tvb, 0, a_len), a_len) < 0);
-			}
-		} else {
-			lt = (strcmp(a->proto_string, b->proto_string) < 0);
-		}
-	}
-	CATCH_ALL {
-		/* nothing */
-	}
-	ENDTRY;
-
-	return lt;
-}
-
-static gboolean
-cmp_le(const fvalue_t *fv_a, const fvalue_t *fv_b)
-{
-	const protocol_value_t	*a = (const protocol_value_t *)&fv_a->value.protocol;
-	const protocol_value_t	*b = (const protocol_value_t *)&fv_b->value.protocol;
-	volatile gboolean	le = FALSE;
-
-	TRY {
-		if ((a->tvb != NULL) && (b->tvb != NULL)) {
-			guint	a_len = tvb_captured_length(a->tvb);
-			guint	b_len = tvb_captured_length(b->tvb);
-
-			if (a_len < b_len) {
-				le = TRUE;
-			} else if (a_len == b_len) {
-				le = (memcmp(tvb_get_ptr(a->tvb, 0, a_len), tvb_get_ptr(b->tvb, 0, a_len), a_len) <= 0);
-			}
-		} else {
-			le = (strcmp(a->proto_string, b->proto_string) <= 0);
-		}
-	}
-	CATCH_ALL {
-		/* nothing */
-	}
-	ENDTRY;
-
-	return le;
+	return c;
 }
 
 static gboolean
@@ -392,7 +281,7 @@ cmp_contains(const fvalue_t *fv_a, const fvalue_t *fv_b)
 }
 
 static gboolean
-cmp_matches(const fvalue_t *fv, const GRegex *regex)
+cmp_matches(const fvalue_t *fv, const ws_regex_t *regex)
 {
 	const protocol_value_t *a = (const protocol_value_t *)&fv->value.protocol;
 	volatile gboolean rc = FALSE;
@@ -406,26 +295,9 @@ cmp_matches(const fvalue_t *fv, const GRegex *regex)
 		if (a->tvb != NULL) {
 			tvb_len = tvb_captured_length(a->tvb);
 			data = (const char *)tvb_get_ptr(a->tvb, 0, tvb_len);
-			rc = g_regex_match_full(
-				regex,		/* Compiled PCRE */
-				data,		/* The data to check for the pattern... */
-				tvb_len,	/* ... and its length */
-				0,		/* Start offset within data */
-				(GRegexMatchFlags)0,		/* GRegexMatchFlags */
-				NULL,		/* We are not interested in the match information */
-				NULL		/* We don't want error information */
-				);
-			/* NOTE - DO NOT g_free(data) */
+			rc = ws_regex_matches_length(regex, data, tvb_len);
 		} else {
-			rc = g_regex_match_full(
-			regex,		/* Compiled PCRE */
-			a->proto_string,		/* The data to check for the pattern... */
-			(int)strlen(a->proto_string),	/* ... and its length */
-			0,		/* Start offset within data */
-			(GRegexMatchFlags)0,		/* GRegexMatchFlags */
-			NULL,		/* We are not interested in the match information */
-			NULL		/* We don't want error information */
-			);
+			rc = ws_regex_matches(regex, a->proto_string);
 		}
 	}
 	CATCH_ALL {
@@ -435,6 +307,13 @@ cmp_matches(const fvalue_t *fv, const GRegex *regex)
 	return rc;
 }
 
+static gboolean
+is_zero(const fvalue_t *fv)
+{
+	const protocol_value_t *a = &fv->value.protocol;
+	return a->tvb == NULL && a->proto_string == NULL;
+}
+
 void
 ftype_register_tvbuff(void)
 {
@@ -445,34 +324,53 @@ ftype_register_tvbuff(void)
 		"Protocol",			/* pretty_name */
 		0,				/* wire_size */
 		value_new,			/* new_value */
+		value_copy,			/* copy_value */
 		value_free,			/* free_value */
-		val_from_unparsed,		/* val_from_unparsed */
+		val_from_literal,		/* val_from_literal */
 		val_from_string,		/* val_from_string */
+		val_from_charconst,		/* val_from_charconst */
 		val_to_repr,			/* val_to_string_repr */
-		val_repr_len,			/* len_string_repr */
 
 		{ .set_value_protocol = value_set },	/* union set_value */
 		{ .get_value_ptr = value_get },		/* union get_value */
 
-		cmp_eq,
-		cmp_ne,
-		cmp_gt,
-		cmp_ge,
-		cmp_lt,
-		cmp_le,
-		NULL,				/* cmp_bitwise_and */
+		cmp_order,
 		cmp_contains,
-		CMP_MATCHES,
+		cmp_matches,
 
+		is_zero,
+		NULL,
 		len,
 		slice,
-
+		NULL,
+		NULL,				/* unary_minus */
+		NULL,				/* add */
+		NULL,				/* subtract */
+		NULL,				/* multiply */
+		NULL,				/* divide */
+		NULL,				/* modulo */
 	};
 
 
 	ftype_register(FT_PROTOCOL, &protocol_type);
 }
 
+void
+ftype_register_pseudofields_tvbuff(int proto)
+{
+	static int hf_ft_protocol;
+
+	static hf_register_info hf_ftypes[] = {
+		{ &hf_ft_protocol,
+		    { "FT_PROTOCOL", "_ws.ftypes.protocol",
+			FT_PROTOCOL, BASE_NONE, NULL, 0x00,
+			NULL, HFILL }
+		},
+	};
+
+	proto_register_field_array(proto, hf_ftypes, array_length(hf_ftypes));
+}
+
 /*
  * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
