@@ -12,9 +12,8 @@
 #include <ftypes-int.h>
 #include <string.h>
 
-#define CMP_MATCHES cmp_matches
-
 #include <strutil.h>
+#include <wsutil/ws_assert.h>
 
 static void
 string_fvalue_new(fvalue_t *fv)
@@ -22,6 +21,12 @@ string_fvalue_new(fvalue_t *fv)
 	fv->value.string = NULL;
 }
 
+static void
+string_fvalue_copy(fvalue_t *dst, const fvalue_t *src)
+{
+	dst->value.string = g_strdup(src->value.string);
+}
+
 static void
 string_fvalue_free(fvalue_t *fv)
 {
@@ -39,33 +44,16 @@ string_fvalue_set_string(fvalue_t *fv, const gchar *value)
 	fv->value.string = (gchar *)g_strdup(value);
 }
 
-static int
-string_repr_len(fvalue_t *fv, ftrepr_t rtype, int field_display _U_)
+static char *
+string_to_repr(wmem_allocator_t *scope, const fvalue_t *fv, ftrepr_t rtype, int field_display _U_)
 {
-	switch (rtype) {
-		case FTREPR_DISPLAY:
-			return (int)strlen(fv->value.string);
-
-		case FTREPR_DFILTER:
-			return escape_string_len(fv->value.string);
+	if (rtype == FTREPR_DISPLAY) {
+		return wmem_strdup(scope, fv->value.string);
 	}
-	g_assert_not_reached();
-	return -1;
-}
-
-static void
-string_to_repr(fvalue_t *fv, ftrepr_t rtype, int field_display _U_, char *buf, unsigned int size)
-{
-	switch (rtype) {
-		case FTREPR_DISPLAY:
-			g_strlcpy(buf, fv->value.string, size);
-			return;
-
-		case FTREPR_DFILTER:
-			escape_string(buf, fv->value.string);
-			return;
+	if (rtype == FTREPR_DFILTER) {
+		return ws_escape_string(scope, fv->value.string, TRUE);
 	}
-	g_assert_not_reached();
+	ws_assert_not_reached();
 }
 
 
@@ -86,31 +74,43 @@ val_from_string(fvalue_t *fv, const char *s, gchar **err_msg _U_)
 }
 
 static gboolean
-val_from_unparsed(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_, gchar **err_msg)
+val_from_literal(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_, gchar **err_msg)
 {
-	fvalue_t *fv_bytes;
+	/* Just turn it into a string */
+	/* XXX Should probably be a syntax error instead. It's more user-friendly to ask the
+	 * user to be explicit about the meaning of an unquoted literal than them trying to figure out
+	 * why a valid filter expression is giving wrong results. */
+	return val_from_string(fv, s, err_msg);
+}
 
-	/* Does this look like a byte-string? */
-	fv_bytes = fvalue_from_unparsed(FT_BYTES, s, TRUE, NULL);
-	if (fv_bytes) {
-		/* Free up the old value, if we have one */
-		string_fvalue_free(fv);
+static gboolean
+val_from_charconst(fvalue_t *fv, unsigned long num, gchar **err_msg)
+{
+	/* XXX Should be a syntax error if literal is also a syntax error. */
 
-		/* Copy the bytes over to a string and terminate it
-		 * with a NUL. XXX - what if the user embeds a NUL
-		 * in the middle of the byte string? */
-		int num_bytes = fv_bytes->value.bytes->len;
+	/* Free up the old value, if we have one */
+	string_fvalue_free(fv);
+	fv->value.string = NULL;
 
-		fv->value.string = (gchar *)g_malloc(num_bytes + 1);
-		memcpy(fv->value.string, fv_bytes->value.bytes->data, num_bytes);
-		fv->value.string[num_bytes] = '\0';
-
-		FVALUE_FREE(fv_bytes);
-		return TRUE;
-	} else {
-		/* Just turn it into a string */
-		return val_from_string(fv, s, err_msg);
+	if (num > UINT8_MAX) {
+		if (err_msg) {
+			*err_msg = ws_strdup_printf("%lu is too large for a byte value", num);
+		}
+		return FALSE;
 	}
+
+	char c = (char)num;
+	fv->value.string = g_malloc(2);
+	fv->value.string[0] = c;
+	fv->value.string[1] = '\0';
+
+	return TRUE;
+}
+
+static gboolean
+string_is_zero(const fvalue_t *fv)
+{
+	return fv->value.string == NULL || strlen(fv->value.string) == 0;
 }
 
 static guint
@@ -129,41 +129,10 @@ slice(fvalue_t *fv, GByteArray *bytes, guint offset, guint length)
 	g_byte_array_append(bytes, data, length);
 }
 
-
-static gboolean
-cmp_eq(const fvalue_t *a, const fvalue_t *b)
+static int
+cmp_order(const fvalue_t *a, const fvalue_t *b)
 {
-	return (strcmp(a->value.string, b->value.string) == 0);
-}
-
-static gboolean
-cmp_ne(const fvalue_t *a, const fvalue_t *b)
-{
-	return (strcmp(a->value.string, b->value.string) != 0);
-}
-
-static gboolean
-cmp_gt(const fvalue_t *a, const fvalue_t *b)
-{
-	return (strcmp(a->value.string, b->value.string) > 0);
-}
-
-static gboolean
-cmp_ge(const fvalue_t *a, const fvalue_t *b)
-{
-	return (strcmp(a->value.string, b->value.string) >= 0);
-}
-
-static gboolean
-cmp_lt(const fvalue_t *a, const fvalue_t *b)
-{
-	return (strcmp(a->value.string, b->value.string) < 0);
-}
-
-static gboolean
-cmp_le(const fvalue_t *a, const fvalue_t *b)
-{
-	return (strcmp(a->value.string, b->value.string) <= 0);
+	return strcmp(a->value.string, b->value.string);
 }
 
 static gboolean
@@ -186,30 +155,14 @@ cmp_contains(const fvalue_t *fv_a, const fvalue_t *fv_b)
 }
 
 static gboolean
-cmp_matches(const fvalue_t *fv_a, const fvalue_t *fv_b)
+cmp_matches(const fvalue_t *fv, const ws_regex_t *regex)
 {
-	char *str = fv_a->value.string;
-	GRegex *regex = fv_b->value.re;
+	char *str = fv->value.string;
 
-	/* fv_b is always a FT_PCRE, otherwise the dfilter semcheck() would have
-	 * warned us. For the same reason (and because we're using g_malloc()),
-	 * fv_b->value.re is not NULL.
-	 */
-	if (strcmp(fv_b->ftype->name, "FT_PCRE") != 0) {
-		return FALSE;
-	}
 	if (! regex) {
 		return FALSE;
 	}
-	return g_regex_match_full(
-			regex,		/* Compiled PCRE */
-			str,		/* The data to check for the pattern... */
-			(int)strlen(str),	/* ... and its length */
-			0,		/* Start offset within data */
-			(GRegexMatchFlags)0,		/* GRegexMatchFlags */
-			NULL,		/* We are not interested in the match information */
-			NULL		/* We don't want error information */
-			);
+	return ws_regex_matches(regex, str);
 }
 
 void
@@ -222,27 +175,31 @@ ftype_register_string(void)
 		"Character string",		/* pretty_name */
 		0,				/* wire_size */
 		string_fvalue_new,		/* new_value */
+		string_fvalue_copy,		/* copy_value */
 		string_fvalue_free,		/* free_value */
-		val_from_unparsed,		/* val_from_unparsed */
+		val_from_literal,		/* val_from_literal */
 		val_from_string,		/* val_from_string */
+		val_from_charconst,		/* val_from_charconst */
 		string_to_repr,			/* val_to_string_repr */
-		string_repr_len,		/* len_string_repr */
 
 		{ .set_value_string = string_fvalue_set_string },	/* union set_value */
 		{ .get_value_ptr = value_get },	/* union get_value */
 
-		cmp_eq,
-		cmp_ne,
-		cmp_gt,
-		cmp_ge,
-		cmp_lt,
-		cmp_le,
-		NULL,				/* cmp_bitwise_and */
+		cmp_order,
 		cmp_contains,
-		CMP_MATCHES,
+		cmp_matches,
 
+		string_is_zero,			/* is_zero */
+		NULL,				/* is_negative */
 		len,
 		slice,
+		NULL,				/* bitwise_and */
+		NULL,				/* unary_minus */
+		NULL,				/* add */
+		NULL,				/* subtract */
+		NULL,				/* multiply */
+		NULL,				/* divide */
+		NULL,				/* modulo */
 	};
 	static ftype_t stringz_type = {
 		FT_STRINGZ,			/* ftype */
@@ -250,27 +207,31 @@ ftype_register_string(void)
 		"Character string",		/* pretty name */
 		0,				/* wire_size */
 		string_fvalue_new,		/* new_value */
+		string_fvalue_copy,		/* copy_value */
 		string_fvalue_free,		/* free_value */
-		val_from_unparsed,		/* val_from_unparsed */
+		val_from_literal,		/* val_from_literal */
 		val_from_string,		/* val_from_string */
+		val_from_charconst,		/* val_from_charconst */
 		string_to_repr,			/* val_to_string_repr */
-		string_repr_len,		/* len_string_repr */
 
 		{ .set_value_string = string_fvalue_set_string },	/* union set_value */
 		{ .get_value_ptr = value_get },	/* union get_value */
 
-		cmp_eq,
-		cmp_ne,
-		cmp_gt,
-		cmp_ge,
-		cmp_lt,
-		cmp_le,
-		NULL,				/* cmp_bitwise_and */
+		cmp_order,
 		cmp_contains,			/* cmp_contains */
-		CMP_MATCHES,
+		cmp_matches,
 
+		string_is_zero,			/* is_zero */
+		NULL,				/* is_negative */
 		len,
 		slice,
+		NULL,				/* bitwise_and */
+		NULL,				/* unary_minus */
+		NULL,				/* add */
+		NULL,				/* subtract */
+		NULL,				/* multiply */
+		NULL,				/* divide */
+		NULL,				/* modulo */
 	};
 	static ftype_t uint_string_type = {
 		FT_UINT_STRING,		/* ftype */
@@ -278,27 +239,31 @@ ftype_register_string(void)
 		"Character string",		/* pretty_name */
 		0,				/* wire_size */
 		string_fvalue_new,		/* new_value */
+		string_fvalue_copy,		/* copy_value */
 		string_fvalue_free,		/* free_value */
-		val_from_unparsed,		/* val_from_unparsed */
+		val_from_literal,		/* val_from_literal */
 		val_from_string,		/* val_from_string */
+		val_from_charconst,		/* val_from_charconst */
 		string_to_repr,			/* val_to_string_repr */
-		string_repr_len,		/* len_string_repr */
 
 		{ .set_value_string = string_fvalue_set_string },	/* union set_value */
 		{ .get_value_ptr = value_get },	/* union get_value */
 
-		cmp_eq,
-		cmp_ne,
-		cmp_gt,
-		cmp_ge,
-		cmp_lt,
-		cmp_le,
-		NULL,				/* cmp_bitwise_and */
+		cmp_order,
 		cmp_contains,			/* cmp_contains */
-		CMP_MATCHES,
+		cmp_matches,
 
+		string_is_zero,			/* is_zero */
+		NULL,				/* is_negative */
 		len,
 		slice,
+		NULL,				/* bitwise_and */
+		NULL,				/* unary_minus */
+		NULL,				/* add */
+		NULL,				/* subtract */
+		NULL,				/* multiply */
+		NULL,				/* divide */
+		NULL,				/* modulo */
 	};
 	static ftype_t stringzpad_type = {
 		FT_STRINGZPAD,			/* ftype */
@@ -306,33 +271,110 @@ ftype_register_string(void)
 		"Character string",		/* pretty name */
 		0,				/* wire_size */
 		string_fvalue_new,		/* new_value */
+		string_fvalue_copy,		/* copy_value */
 		string_fvalue_free,		/* free_value */
-		val_from_unparsed,		/* val_from_unparsed */
+		val_from_literal,		/* val_from_literal */
 		val_from_string,		/* val_from_string */
+		val_from_charconst,		/* val_from_charconst */
 		string_to_repr,			/* val_to_string_repr */
-		string_repr_len,		/* len_string_repr */
 
 		{ .set_value_string = string_fvalue_set_string },	/* union set_value */
 		{ .get_value_ptr = value_get },	/* union get_value */
 
-		cmp_eq,
-		cmp_ne,
-		cmp_gt,
-		cmp_ge,
-		cmp_lt,
-		cmp_le,
-		NULL,				/* cmp_bitwise_and */
+		cmp_order,
 		cmp_contains,			/* cmp_contains */
-		CMP_MATCHES,
+		cmp_matches,
 
+		string_is_zero,			/* is_zero */
+		NULL,				/* is_negative */
 		len,
 		slice,
+		NULL,				/* bitwise_and */
+		NULL,				/* unary_minus */
+		NULL,				/* add */
+		NULL,				/* subtract */
+		NULL,				/* multiply */
+		NULL,				/* divide */
+		NULL,				/* modulo */
+	};
+	static ftype_t stringztrunc_type = {
+		FT_STRINGZTRUNC,		/* ftype */
+		"FT_STRINGZTRUNC",		/* name */
+		"Character string",		/* pretty name */
+		0,				/* wire_size */
+		string_fvalue_new,		/* new_value */
+		string_fvalue_copy,		/* copy_value */
+		string_fvalue_free,		/* free_value */
+		val_from_literal,		/* val_from_literal */
+		val_from_string,		/* val_from_string */
+		val_from_charconst,		/* val_from_charconst */
+		string_to_repr,			/* val_to_string_repr */
+
+		{ .set_value_string = string_fvalue_set_string },	/* union set_value */
+		{ .get_value_ptr = value_get },	/* union get_value */
+
+		cmp_order,
+		cmp_contains,			/* cmp_contains */
+		cmp_matches,
+
+		string_is_zero,			/* is_zero */
+		NULL,				/* is_negative */
+		len,
+		slice,
+		NULL,				/* bitwise_and */
+		NULL,				/* unary_minus */
+		NULL,				/* add */
+		NULL,				/* subtract */
+		NULL,				/* multiply */
+		NULL,				/* divide */
+		NULL,				/* modulo */
 	};
 
 	ftype_register(FT_STRING, &string_type);
 	ftype_register(FT_STRINGZ, &stringz_type);
 	ftype_register(FT_UINT_STRING, &uint_string_type);
 	ftype_register(FT_STRINGZPAD, &stringzpad_type);
+	ftype_register(FT_STRINGZTRUNC, &stringztrunc_type);
+}
+
+void
+ftype_register_pseudofields_string(int proto)
+{
+	static int hf_ft_string;
+	static int hf_ft_stringz;
+	static int hf_ft_uint_string;
+	static int hf_ft_stringzpad;
+	static int hf_ft_stringztrunc;
+
+	static hf_register_info hf_ftypes[] = {
+		{ &hf_ft_string,
+		    { "FT_STRING", "_ws.ftypes.string",
+			FT_STRING, BASE_NONE, NULL, 0x00,
+			NULL, HFILL }
+		},
+		{ &hf_ft_stringz,
+		    { "FT_STRINGZ", "_ws.ftypes.stringz",
+			FT_STRINGZ, BASE_NONE, NULL, 0x00,
+			NULL, HFILL }
+		},
+		{ &hf_ft_uint_string,
+		    { "FT_UINT_STRING", "_ws.ftypes.uint_string",
+			FT_UINT_STRING, BASE_NONE, NULL, 0x00,
+			NULL, HFILL }
+		},
+		{ &hf_ft_stringzpad,
+		    { "FT_STRINGZPAD", "_ws.ftypes.stringzpad",
+			FT_STRINGZPAD, BASE_NONE, NULL, 0x00,
+			NULL, HFILL }
+		},
+		{ &hf_ft_stringztrunc,
+		    { "FT_STRINGZTRUNC", "_ws.ftypes.stringztrunc",
+			FT_STRINGZTRUNC, BASE_NONE, NULL, 0x00,
+			NULL, HFILL }
+		},
+	};
+
+	proto_register_field_array(proto, hf_ftypes, array_length(hf_ftypes));
 }
 
 /*
