@@ -1,4 +1,5 @@
-/*
+/** @file
+ *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 2001 Gerald Combs
@@ -9,38 +10,31 @@
 #ifndef FTYPES_INT_H
 #define FTYPES_INT_H
 
-#include <epan/proto.h>
 #include "ftypes.h"
+#include <epan/proto.h>
+#include <epan/packet.h>
 
+extern ftype_t* type_list[FT_NUM_TYPES];
 
-void
-ftype_register(enum ftenum ftype, ftype_t *ft);
+/* Given an ftenum number, return an ftype_t* */
+#define FTYPE_LOOKUP(ftype, result)		\
+	/* Check input */			\
+	ws_assert(ftype < FT_NUM_TYPES);	\
+	result = type_list[ftype];
 
-/* These are the ftype registration functions that need to be called.
- * This list and the initialization function could be produced
- * via a script, like the dissector registration, but there's so few
- * that I don't mind doing it by hand for now. */
-void ftype_register_bytes(void);
-void ftype_register_double(void);
-void ftype_register_ieee_11073_float(void);
-void ftype_register_fc(void);
-void ftype_register_integers(void);
-void ftype_register_ipv4(void);
-void ftype_register_ipv6(void);
-void ftype_register_guid(void);
-void ftype_register_none(void);
-void ftype_register_string(void);
-void ftype_register_time(void);
-void ftype_register_tvbuff(void);
-void ftype_register_pcre(void);
+enum ft_result {
+	FT_OK,
+	FT_ERROR,
+};
 
 typedef void (*FvalueNewFunc)(fvalue_t*);
+typedef void (*FvalueCopyFunc)(fvalue_t*, const fvalue_t*);
 typedef void (*FvalueFreeFunc)(fvalue_t*);
 
-typedef gboolean (*FvalueFromUnparsed)(fvalue_t*, const char*, gboolean, gchar **);
+typedef gboolean (*FvalueFromLiteral)(fvalue_t*, const char*, gboolean, gchar **);
 typedef gboolean (*FvalueFromString)(fvalue_t*, const char*, gchar **);
-typedef void (*FvalueToStringRepr)(fvalue_t*, ftrepr_t, int field_display, char*volatile, unsigned int);
-typedef int (*FvalueStringReprLen)(fvalue_t*, ftrepr_t, int field_display);
+typedef gboolean (*FvalueFromCharConst)(fvalue_t*, unsigned long, gchar **);
+typedef char *(*FvalueToStringRepr)(wmem_allocator_t *, const fvalue_t*, ftrepr_t, int field_display);
 
 typedef void (*FvalueSetByteArrayFunc)(fvalue_t*, GByteArray *);
 typedef void (*FvalueSetBytesFunc)(fvalue_t*, const guint8 *);
@@ -61,10 +55,15 @@ typedef guint64 (*FvalueGetUnsignedInteger64Func)(fvalue_t*);
 typedef gint64 (*FvalueGetSignedInteger64Func)(fvalue_t*);
 typedef double (*FvalueGetFloatingFunc)(fvalue_t*);
 
-typedef gboolean (*FvalueCmp)(const fvalue_t*, const fvalue_t*);
+typedef int (*FvalueCmp)(const fvalue_t*, const fvalue_t*);
+typedef gboolean (*FvalueContains)(const fvalue_t*, const fvalue_t*);
+typedef gboolean (*FvalueMatches)(const fvalue_t*, const ws_regex_t*);
 
+typedef gboolean (*FvalueIs)(const fvalue_t*);
 typedef guint (*FvalueLen)(fvalue_t*);
 typedef void (*FvalueSlice)(fvalue_t*, GByteArray *, guint offset, guint length);
+typedef enum ft_result (*FvalueUnaryOp)(fvalue_t *, const fvalue_t*, gchar **);
+typedef enum ft_result (*FvalueBinaryOp)(fvalue_t *, const fvalue_t*, const fvalue_t*, gchar **);
 
 struct _ftype_t {
 	ftenum_t		ftype;
@@ -72,11 +71,12 @@ struct _ftype_t {
 	const char		*pretty_name;
 	int			wire_size;
 	FvalueNewFunc		new_value;
+	FvalueCopyFunc		copy_value;
 	FvalueFreeFunc		free_value;
-	FvalueFromUnparsed	val_from_unparsed;
+	FvalueFromLiteral	val_from_literal;
 	FvalueFromString	val_from_string;
+	FvalueFromCharConst	val_from_charconst;
 	FvalueToStringRepr	val_to_string_repr;
-	FvalueStringReprLen	len_string_repr;
 
 	union {
 		FvalueSetByteArrayFunc	set_value_byte_array;
@@ -101,43 +101,58 @@ struct _ftype_t {
 		FvalueGetFloatingFunc	get_value_floating;
 	} get_value;
 
-	FvalueCmp		cmp_eq;
-	FvalueCmp		cmp_ne;
-	FvalueCmp		cmp_gt;
-	FvalueCmp		cmp_ge;
-	FvalueCmp		cmp_lt;
-	FvalueCmp		cmp_le;
-	FvalueCmp		cmp_bitwise_and;
-	FvalueCmp		cmp_contains;
-	FvalueCmp		cmp_matches;
+	FvalueCmp		cmp_order;
+	FvalueContains		cmp_contains;
+	FvalueMatches		cmp_matches;
 
+	FvalueIs		is_zero;
+	FvalueIs		is_negative;
 	FvalueLen		len;
 	FvalueSlice		slice;
+	FvalueBinaryOp		bitwise_and;
+	FvalueUnaryOp		unary_minus;
+	FvalueBinaryOp		add;
+	FvalueBinaryOp		subtract;
+	FvalueBinaryOp		multiply;
+	FvalueBinaryOp		divide;
+	FvalueBinaryOp		modulo;
 };
 
-/* Free all memory used by an fvalue_t. With MSVC and a
- * libwireshark.dll, we need a special declaration.
- */
+void ftype_register(enum ftenum ftype, ftype_t *ft);
 
-#define FVALUE_CLEANUP(fv)					\
-	{							\
-		register FvalueFreeFunc	free_value;		\
-		free_value = (fv)->ftype->free_value;	\
-		if (free_value) {				\
-			free_value((fv));			\
-		}						\
-	}
+void ftype_register_bytes(void);
+void ftype_register_double(void);
+void ftype_register_ieee_11073_float(void);
+void ftype_register_integers(void);
+void ftype_register_ipv4(void);
+void ftype_register_ipv6(void);
+void ftype_register_guid(void);
+void ftype_register_none(void);
+void ftype_register_string(void);
+void ftype_register_time(void);
+void ftype_register_tvbuff(void);
 
-#define FVALUE_FREE(fv)						\
-	{							\
-		FVALUE_CLEANUP(fv)				\
-		g_slice_free(fvalue_t, fv);			\
-	}
+void ftype_register_pseudofields_bytes(int proto);
+void ftype_register_pseudofields_double(int proto);
+void ftype_register_pseudofields_ieee_11073_float(int proto);
+void ftype_register_pseudofields_integer(int proto);
+void ftype_register_pseudofields_ipv4(int proto);
+void ftype_register_pseudofields_ipv6(int proto);
+void ftype_register_pseudofields_guid(int proto);
+void ftype_register_pseudofields_string(int proto);
+void ftype_register_pseudofields_time(int proto);
+void ftype_register_pseudofields_tvbuff(int proto);
 
-#endif
+GByteArray *
+byte_array_from_literal(const char *s, gchar **err_msg);
+
+GByteArray *
+byte_array_from_charconst(unsigned long num, gchar **err_msg);
+
+#endif /* FTYPES_INT_H */
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
