@@ -1,4 +1,4 @@
-/* ftypes.h
+/** @file
  * Definitions for field types
  *
  * Wireshark - Network traffic analyzer
@@ -12,9 +12,10 @@
 #ifndef __FTYPES_H__
 #define __FTYPES_H__
 
-#include <glib.h>
-#include "../wmem/wmem.h"
-#include "ws_symbol_export.h"
+#include <wireshark.h>
+
+#include <wsutil/regex.h>
+#include <epan/wmem_scopes.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -48,9 +49,9 @@ enum ftenum {
 	FT_DOUBLE,
 	FT_ABSOLUTE_TIME,
 	FT_RELATIVE_TIME,
-	FT_STRING,
-	FT_STRINGZ,	/* for use with proto_tree_add_item() */
-	FT_UINT_STRING,	/* for use with proto_tree_add_item() */
+	FT_STRING,	/* counted string, with no null terminator */
+	FT_STRINGZ,	/* null-terminated string */
+	FT_UINT_STRING,	/* counted string, with count being the first part of the value */
 	FT_ETHER,
 	FT_BYTES,
 	FT_UINT_BYTES,
@@ -58,7 +59,6 @@ enum ftenum {
 	FT_IPv6,
 	FT_IPXNET,
 	FT_FRAMENUM,	/* a UINT32, but if selected lets you go to frame with that number */
-	FT_PCRE,	/* a compiled Perl-Compatible Regular Expression object */
 	FT_GUID,	/* GUID, UUID */
 	FT_OID,		/* OBJECT IDENTIFIER */
 	FT_EUI64,
@@ -66,8 +66,9 @@ enum ftenum {
 	FT_VINES,
 	FT_REL_OID,	/* RELATIVE-OID */
 	FT_SYSTEM_ID,
-	FT_STRINGZPAD,	/* for use with proto_tree_add_item() */
+	FT_STRINGZPAD,	/* null-padded string */
 	FT_FCWWN,
+	FT_STRINGZTRUNC,	/* null-truncated string */
 	FT_NUM_TYPES /* last item number plus one */
 };
 
@@ -98,7 +99,8 @@ enum ftenum {
 #define IS_FT_TIME(ft) \
 	((ft) == FT_ABSOLUTE_TIME || (ft) == FT_RELATIVE_TIME)
 #define IS_FT_STRING(ft) \
-	((ft) == FT_STRING || (ft) == FT_STRINGZ || (ft) == FT_STRINGZPAD)
+	((ft) == FT_STRING || (ft) == FT_STRINGZ || (ft) == FT_STRINGZPAD || \
+	 (ft) == FT_STRINGZTRUNC)
 
 /* field types lengths */
 #define FT_ETHER_LEN		6
@@ -142,6 +144,9 @@ typedef enum ftrepr ftrepr_t;
 void
 ftypes_initialize(void);
 
+void
+ftypes_register_pseudofields(void);
+
 /* ---------------- FTYPE ----------------- */
 
 /* given two types, are they similar - for example can two
@@ -175,27 +180,29 @@ ftype_can_eq(enum ftenum ftype);
 
 WS_DLL_PUBLIC
 gboolean
-ftype_can_ne(enum ftenum ftype);
-
-WS_DLL_PUBLIC
-gboolean
-ftype_can_gt(enum ftenum ftype);
-
-WS_DLL_PUBLIC
-gboolean
-ftype_can_ge(enum ftenum ftype);
-
-WS_DLL_PUBLIC
-gboolean
-ftype_can_lt(enum ftenum ftype);
-
-WS_DLL_PUBLIC
-gboolean
-ftype_can_le(enum ftenum ftype);
+ftype_can_cmp(enum ftenum ftype);
 
 gboolean
 ftype_can_bitwise_and(enum ftenum ftype);
 
+gboolean
+ftype_can_unary_minus(enum ftenum ftype);
+
+gboolean
+ftype_can_add(enum ftenum ftype);
+
+gboolean
+ftype_can_subtract(enum ftenum ftype);
+
+gboolean
+ftype_can_multiply(enum ftenum ftype);
+
+gboolean
+ftype_can_divide(enum ftenum ftype);
+
+gboolean
+ftype_can_modulo(enum ftenum ftype);
+
 WS_DLL_PUBLIC
 gboolean
 ftype_can_contains(enum ftenum ftype);
@@ -204,6 +211,14 @@ WS_DLL_PUBLIC
 gboolean
 ftype_can_matches(enum ftenum ftype);
 
+WS_DLL_PUBLIC
+gboolean
+ftype_can_is_zero(enum ftenum ftype);
+
+WS_DLL_PUBLIC
+gboolean
+ftype_can_is_negative(enum ftenum ftype);
+
 /* ---------------- FVALUE ----------------- */
 
 #include <epan/ipv4.h>
@@ -218,6 +233,7 @@ typedef struct _protocol_value_t
 {
 	tvbuff_t	*tvb;
 	gchar		*proto_string;
+	gboolean	tvb_is_private;
 } protocol_value_t;
 
 typedef struct _fvalue_t {
@@ -226,7 +242,6 @@ typedef struct _fvalue_t {
 		/* Put a few basic types in here */
 		guint32			uinteger;
 		gint32			sinteger;
-		guint64			integer64;
 		guint64			uinteger64;
 		gint64			sinteger64;
 		gdouble			floating;
@@ -238,39 +253,35 @@ typedef struct _fvalue_t {
 		e_guid_t		guid;
 		nstime_t		time;
 		protocol_value_t 	protocol;
-		GRegex			*re;
 		guint16			sfloat_ieee_11073;
 		guint32			float_ieee_11073;
 	} value;
-
-	/* The following is provided for private use
-	 * by the fvalue. */
-	gboolean	fvalue_gboolean1;
-
 } fvalue_t;
 
 fvalue_t*
 fvalue_new(ftenum_t ftype);
 
+fvalue_t*
+fvalue_dup(const fvalue_t *fv);
+
 void
 fvalue_init(fvalue_t *fv, ftenum_t ftype);
 
+void
+fvalue_cleanup(fvalue_t *fv);
+
+void
+fvalue_free(fvalue_t *fv);
+
 WS_DLL_PUBLIC
 fvalue_t*
-fvalue_from_unparsed(ftenum_t ftype, const char *s, gboolean allow_partial_value, gchar **err_msg);
+fvalue_from_literal(ftenum_t ftype, const char *s, gboolean allow_partial_value, gchar **err_msg);
 
 fvalue_t*
 fvalue_from_string(ftenum_t ftype, const char *s, gchar **err_msg);
 
-/* Returns the length of the string required to hold the
- * string representation of the the field value.
- *
- * Returns -1 if the string cannot be represented in the given rtype.
- *
- * The length DOES NOT include the terminating NUL. */
-WS_DLL_PUBLIC
-int
-fvalue_string_repr_len(fvalue_t *fv, ftrepr_t rtype, int field_display);
+fvalue_t*
+fvalue_from_charconst(ftenum_t ftype, unsigned long number, gchar **err_msg);
 
 /* Creates the string representation of the field value.
  * Memory for the buffer is allocated based on wmem allocator
@@ -281,13 +292,16 @@ fvalue_string_repr_len(fvalue_t *fv, ftrepr_t rtype, int field_display);
  *
  * Returns NULL if the string cannot be represented in the given rtype.*/
 WS_DLL_PUBLIC char *
-fvalue_to_string_repr(wmem_allocator_t *scope, fvalue_t *fv, ftrepr_t rtype, int field_display);
+fvalue_to_string_repr(wmem_allocator_t *scope, const fvalue_t *fv, ftrepr_t rtype, int field_display);
+
+#define fvalue_to_debug_repr(scope, fv) \
+	fvalue_to_string_repr(scope, fv, FTREPR_DFILTER, 0)
 
 WS_DLL_PUBLIC ftenum_t
 fvalue_type_ftenum(fvalue_t *fv);
 
 const char*
-fvalue_type_name(fvalue_t *fv);
+fvalue_type_name(const fvalue_t *fv);
 
 void
 fvalue_set_byte_array(fvalue_t *fv, GByteArray *value);
@@ -361,14 +375,17 @@ fvalue_lt(const fvalue_t *a, const fvalue_t *b);
 gboolean
 fvalue_le(const fvalue_t *a, const fvalue_t *b);
 
-gboolean
-fvalue_bitwise_and(const fvalue_t *a, const fvalue_t *b);
-
 gboolean
 fvalue_contains(const fvalue_t *a, const fvalue_t *b);
 
 gboolean
-fvalue_matches(const fvalue_t *a, const fvalue_t *b);
+fvalue_matches(const fvalue_t *a, const ws_regex_t *re);
+
+gboolean
+fvalue_is_zero(const fvalue_t *a);
+
+gboolean
+fvalue_is_negative(const fvalue_t *a);
 
 guint
 fvalue_length(fvalue_t *fv);
@@ -376,6 +393,27 @@ fvalue_length(fvalue_t *fv);
 fvalue_t*
 fvalue_slice(fvalue_t *fv, drange_t *dr);
 
+fvalue_t*
+fvalue_bitwise_and(const fvalue_t *a, const fvalue_t *b, char **err_msg);
+
+fvalue_t*
+fvalue_unary_minus(const fvalue_t *fv, char **err_msg);
+
+fvalue_t*
+fvalue_add(const fvalue_t *a, const fvalue_t *b, gchar **err_msg);
+
+fvalue_t*
+fvalue_subtract(const fvalue_t *a, const fvalue_t *b, gchar **err_msg);
+
+fvalue_t*
+fvalue_multiply(const fvalue_t *a, const fvalue_t *b, gchar **err_msg);
+
+fvalue_t*
+fvalue_divide(const fvalue_t *a, const fvalue_t *b, gchar **err_msg);
+
+fvalue_t*
+fvalue_modulo(const fvalue_t *a, const fvalue_t *b, gchar **err_msg);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
