@@ -19,7 +19,6 @@ my $WSROOT = shift;
 die "'$WSROOT' is not a directory" unless -d $WSROOT;
 
 my $wtap_encaps_table = '';
-my $wtap_filetypes_table = '';
 my $wtap_tsprecs_table = '';
 my $wtap_commenttypes_table = '';
 my $ft_types_table = '';
@@ -36,7 +35,6 @@ my $menu_groups = '';
 
 my %replacements = %{{
     WTAP_ENCAPS => \$wtap_encaps_table,
-    WTAP_FILETYPES => \$wtap_filetypes_table,
     WTAP_TSPRECS => \$wtap_tsprecs_table,
     WTAP_COMMENTTYPES => \$wtap_commenttypes_table,
     FT_TYPES => \$ft_types_table,
@@ -70,7 +68,6 @@ close TEMPLATE;
 #
 
 $wtap_encaps_table = "-- Wiretap encapsulations XXX\nwtap_encaps = {\n";
-$wtap_filetypes_table = "-- Wiretap file types\nwtap_filetypes = {\n";
 $wtap_tsprecs_table = "-- Wiretap timestamp precision types\nwtap_tsprecs = {\n";
 $wtap_commenttypes_table = "-- Wiretap file comment types\nwtap_comments = {\n";
 $wtap_rec_types_table = "-- Wiretap record_types\nwtap_rec_types = {\n";
@@ -83,14 +80,8 @@ while(<WTAP_H>) {
         $wtap_encaps_table .= "\t[\"$1\"] = $2,\n";
     }
 
-    if ( /^#define WTAP_FILE_TYPE_SUBTYPE_([A-Z0-9_]+)\s+(\d+)/ ) {
-        $wtap_filetypes_table .= "\t[\"$1\"] = $2,\n";
-    }
-
     if ( /^#define WTAP_TSPREC_([A-Z0-9_]+)\s+(\d+)/ ) {
         $wtap_tsprecs_table .= "\t[\"$1\"] = $2,\n";
-        # for backwards compatibility we need to add them to the filetypes table too
-        $wtap_filetypes_table .= "\t[\"TSPREC_$1\"] = $2,\n";
     }
 
     if ( /^#define WTAP_COMMENT_([A-Z0-9_]+)\s+(0x\d+)/ ) {
@@ -108,7 +99,6 @@ while(<WTAP_H>) {
 }
 
 $wtap_encaps_table =~ s/,\n$/\n}\nwtap = wtap_encaps -- for bw compatibility\n/msi;
-$wtap_filetypes_table =~ s/,\n$/\n}\n/msi;
 $wtap_tsprecs_table =~ s/,\n$/\n}\n/msi;
 $wtap_commenttypes_table =~ s/,\n$/\n}\n/msi;
 # wtap_rec_types_table has comments at the end (not a comma),
@@ -168,7 +158,7 @@ my $skip_this = 0;
 while(<PROTO_H>) {
     $skip_this = 0;
 
-    if (/^\s+(?:BASE|STR|SEP)_([A-Z_]+)[ ]*=[ ]*([0-9]+)[,\s]+(?:\/\*\*< (.*?) \*\/)?/) {
+    if (/^\s+(?:BASE|SEP|ABSOLUTE_TIME)_([A-Z_]+)[ ]*=[ ]*([0-9]+)[,\s]+(?:\/\*\*< (.*?) \*\/)?/) {
         $bases_table .= "\t[\"$1\"] = $2,  -- $3\n";
     }
 
@@ -220,26 +210,6 @@ while(<PROTO_H>) {
 }
 close PROTO_H;
 
-#
-# Extract values from time_fmt.h:
-#
-#	ABSOLUTE_TIME_XXX values for absolute time bases
-#
-
-my $absolute_time_num = 0;
-
-open TIME_FMT_H, "< $WSROOT/epan/time_fmt.h" or die "cannot open '$WSROOT/epan/time_fmt.h':  $!";
-while(<TIME_FMT_H>) {
-    if (/^\s+ABSOLUTE_TIME_([A-Z_]+)[ ]*=[ ]*([0-9]+)[,\s]+(?:\/\* (.*?) \*\/)?/) {
-        $bases_table .= "\t[\"$1\"] = $2,  -- $3\n";
-        $absolute_time_num = $2 + 1;
-    } elsif (/^\s+ABSOLUTE_TIME_([A-Z_]+)[,\s]+(?:\/\* (.*?) \*\/)?/) {
-        $bases_table .= "\t[\"$1\"] = $absolute_time_num,  -- $2\n";
-        $absolute_time_num++;
-    }
-}
-close TIME_FTM_H;
-
 #
 # Extract values from stat_groups.h:
 #
@@ -250,12 +220,13 @@ $menu_groups .= "-- menu groups for register_menu\n";
 my $menu_i = 0;
 
 open STAT_GROUPS, "< $WSROOT/epan/stat_groups.h" or die "cannot open '$WSROOT/epan/stat_groups.h':  $!";
-my $foundit = 0;
+my $in_stat_group_enum = 0;
 while(<STAT_GROUPS>) {
     # need to skip matching words in comments, and get to the enum
-    if (/^typedef enum \{/) { $foundit = 1; }
+    if (/^typedef enum register_stat_group_e \{/) { $in_stat_group_enum = 1; }
+    if (/^\} register_stat_group_t\;/) { $in_stat_group_enum = 0; }
     # the problem here is we need to pick carefully, so we don't break existing scripts
-    if ($foundit && /REGISTER_([A-Z]+)_GROUP_(CONVERSATION|RESPONSE|ENDPOINT|[A-Z_]+)/) {
+    if ($in_stat_group_enum && /REGISTER_([A-Z0-9_]+)_GROUP_([A-Z0-9_]+),? /) {
         $menu_groups .= "MENU_$1_$2 = $menu_i\n";
         $menu_groups =~ s/_NONE//;
         $menu_i++;
@@ -263,6 +234,15 @@ while(<STAT_GROUPS>) {
 }
 close STAT_GROUPS;
 
+$menu_groups .= <<'FIN';
+-- Old / deprecated menu groups. These shoudn't be used in new code.
+MENU_ANALYZE_UNSORTED = MENU_PACKET_ANALYZE_UNSORTED
+MENU_ANALYZE_CONVERSATION = MENU_ANALYZE_CONVERSATION_FILTER
+MENU_STAT_CONVERSATION = MENU_STAT_CONVERSATION_LIST
+MENU_STAT_ENDPOINT = MENU_STAT_ENDPOINT_LIST
+MENU_STAT_RESPONSE = MENU_STAT_RESPONSE_TIME
+MENU_STAT_UNSORTED = MENU_PACKET_STAT_UNSORTED
+FIN
 
 $bases_table .= "}\n";
 $encodings .= "\n";
