@@ -302,7 +302,7 @@ WSLUA_METHOD Dumper_close(lua_State* L) {
 
     g_hash_table_remove(dumper_encaps,*dp);
 
-    if (!wtap_dump_close(*dp, &err, &err_info)) {
+    if (!wtap_dump_close(*dp, NULL, &err, &err_info)) {
         if (err_info != NULL) {
             luaL_error(L,"error closing: %s (%s)",
                        wtap_strerror(err), err_info);
@@ -547,11 +547,11 @@ WSLUA_METHOD Dumper_dump_current(lua_State* L) {
     if (lua_pinfo->fd->has_modified_block) {
         rec.block = epan_get_modified_block(lua_pinfo->epan, lua_pinfo->fd);
         rec.block_was_modified = TRUE;
-    } else if (lua_pinfo->fd->has_phdr_block) {
+    } else {
         rec.block = lua_pinfo->rec->block;
     }
 
-    data = (const guchar *)tvb_memdup(wmem_packet_scope(),tvb,0,rec.rec_header.packet_header.caplen);
+    data = (const guchar *)tvb_memdup(lua_pinfo->pool,tvb,0,rec.rec_header.packet_header.caplen);
 
     if (! wtap_dump(d, &rec, data, &err, &err_info)) {
         switch (err) {
@@ -585,7 +585,7 @@ static int Dumper__gc(lua_State* L) {
 
     g_hash_table_remove(dumper_encaps,*dp);
 
-    if (!wtap_dump_close(*dp, &err, &err_info)) {
+    if (!wtap_dump_close(*dp, NULL, &err, &err_info)) {
         if (err_info != NULL) {
             luaL_error(L,"error closing: %s (%s)",
                        wtap_strerror(err), err_info);
