@@ -67,21 +67,39 @@ static void lua_menu_callback(gpointer data) {
 WSLUA_FUNCTION wslua_register_menu(lua_State* L) { /*  Register a menu item in one of the main menus. Requires a GUI. */
 #define WSLUA_ARG_register_menu_NAME 1 /* The name of the menu item. Use slashes to separate submenus. (e.g. menu:Lua Scripts[My Fancy Statistics]). (string) */
 #define WSLUA_ARG_register_menu_ACTION 2 /* The function to be called when the menu item is invoked. The function must take no arguments and return nothing. */
-#define WSLUA_OPTARG_register_menu_GROUP 3 /* Where to place the item in the menu hierarchy. If omitted, defaults to MENU_STAT_GENERIC. One of:
-                                              * MENU_STAT_UNSORTED: menu:Statistics[]
-                                              * MENU_STAT_GENERIC: menu:Statistics[], first section
-                                              * MENU_STAT_CONVERSATION: menu:Statistics[Conversation List]
-                                              * MENU_STAT_ENDPOINT: menu:Statistics[Endpoint List]
-                                              * MENU_STAT_RESPONSE: menu:Statistics[Service Response Time]
-                                              * MENU_STAT_TELEPHONY: menu:Telephony[]
-                                              * MENU_STAT_TELEPHONY_ANSI: menu:Telephony[ANSI]
-                                              * MENU_STAT_TELEPHONY_GSM: menu:Telephony[GSM]
-                                              * MENU_STAT_TELEPHONY_LTE: menu:Telephony[LTE]
-                                              * MENU_STAT_TELEPHONY_MTP3: menu:Telephony[MTP3]
-                                              * MENU_STAT_TELEPHONY_SCTP: menu:Telephony[SCTP]
-                                              * MENU_ANALYZE: menu:Analyze[]
-                                              * MENU_ANALYZE_CONVERSATION: menu:Analyze[Conversation Filter]
-                                              * MENU_TOOLS_UNSORTED: menu:Tools[] */
+#define WSLUA_OPTARG_register_menu_GROUP 3 /*
+    Where to place the item in the menu hierarchy.
+    If omitted, defaults to MENU_STAT_GENERIC.
+    Valid packet (Wireshark) items are:
+    * MENU_PACKET_ANALYZE_UNSORTED: menu:Analyze[]
+    * MENU_PACKET_STAT_UNSORTED: menu:Statistics[]
+    * MENU_STAT_GENERIC: menu:Statistics[], first section
+    * MENU_STAT_CONVERSATION_LIST: menu:Statistics[Conversation List]
+    * MENU_STAT_ENDPOINT_LIST: menu:Statistics[Endpoint List]
+    * MENU_STAT_RESPONSE_TIME: menu:Statistics[Service Response Time]
+    * MENU_STAT_RSERPOOL = menu:Statistics[Reliable Server Pooling (RSerPool)]
+    * MENU_STAT_TELEPHONY: menu:Telephony[]
+    * MENU_STAT_TELEPHONY_ANSI: menu:Telephony[ANSI]
+    * MENU_STAT_TELEPHONY_GSM: menu:Telephony[GSM]
+    * MENU_STAT_TELEPHONY_LTE: menu:Telephony[LTE]
+    * MENU_STAT_TELEPHONY_MTP3: menu:Telephony[MTP3]
+    * MENU_STAT_TELEPHONY_SCTP: menu:Telephony[SCTP]
+    * MENU_ANALYZE: menu:Analyze[]
+    * MENU_ANALYZE_CONVERSATION: menu:Analyze[Conversation Filter]
+    * MENU_TOOLS_UNSORTED: menu:Tools[]
+
+    Valid log (Logwolf) items are:
+    * MENU_LOG_ANALYZE_UNSORTED: menu:Analyze[]
+    * MENU_LOG_STAT_UNSORTED = 16
+
+    The following are deprecated and shouldn't be used in new code:
+    * MENU_ANALYZE_UNSORTED, superseded by MENU_PACKET_ANALYZE_UNSORTED
+    * MENU_ANALYZE_CONVERSATION, superseded by MENU_ANALYZE_CONVERSATION_FILTER
+    * MENU_STAT_CONVERSATION, superseded by MENU_STAT_CONVERSATION_LIST
+    * MENU_STAT_ENDPOINT, superseded by MENU_STAT_ENDPOINT_LIST
+    * MENU_STAT_RESPONSE, superseded by MENU_STAT_RESPONSE_TIME
+    * MENU_STAT_UNSORTED, superseded by MENU_PACKET_STAT_UNSORTED
+ */
 
     const gchar* name = luaL_checkstring(L,WSLUA_ARG_register_menu_NAME);
     struct _lua_menu_data* md;
@@ -219,7 +237,7 @@ WSLUA_FUNCTION wslua_new_dialog(lua_State* L) { /*
     Displays a dialog, prompting for input. The dialog includes an btn:[OK] button and btn:[Cancel] button. Requires a GUI.
 
     .An input dialog in action
-    image::images/wslua-new-dialog.png[{small-screenshot-attrs}]
+    image::wsdg_graphics/wslua-new-dialog.png[{small-screenshot-attrs}]
 
     ===== Example
 
@@ -341,7 +359,7 @@ Instead of a strings it is possible to provide tables with fields 'name' and 'va
     g_ptr_array_add(field_names, NULL);
     g_ptr_array_add(field_values, NULL);
 
-    ops->new_dialog(title, (const gchar**)(field_names->pdata), (const gchar**)(field_values->pdata), lua_dialog_cb, dcbd, g_free);
+    ops->new_dialog(ops->ops_id, title, (const gchar**)(field_names->pdata), (const gchar**)(field_values->pdata), lua_dialog_cb, dcbd, g_free);
 
     g_ptr_array_free(field_names, TRUE);
     g_ptr_array_free(field_values, TRUE);
@@ -358,7 +376,7 @@ WSLUA_CLASS_DEFINE(ProgDlg,FAIL_ON_NULL("ProgDlg"));
     The main thread checks the status of the btn:[Cancel] button and if it's not set, returns control to the coroutine.
 
     .A progress bar in action
-    image::images/wslua-progdlg.png[{medium-screenshot-attrs}]
+    image::wsdg_graphics/wslua-progdlg.png[{medium-screenshot-attrs}]
 
     The legacy (GTK+) user interface displayed this as a separate dialog, hence the “Dlg” suffix.
     The Qt user interface shows a progress bar inside the main status bar.
@@ -554,7 +572,7 @@ WSLUA_CLASS_DEFINE(TextWindow,FAIL_ON_NULL_OR_EXPIRED("TextWindow")); /*
     The text can be read-only or editable, and buttons can be added below the text.
 
     .A text window in action
-    image::images/wslua-textwindow.png[{medium-screenshot-attrs}]
+    image::wsdg_graphics/wslua-textwindow.png[{medium-screenshot-attrs}]
 */
 
 /* XXX: button and close callback data is being leaked */
@@ -606,7 +624,7 @@ WSLUA_CONSTRUCTOR TextWindow_new(lua_State* L) { /*
     title = luaL_optstring(L,WSLUA_OPTARG_TextWindow_new_TITLE, "Untitled Window");
     tw = g_new(struct _wslua_tw, 1);
     tw->expired = FALSE;
-    tw->ws_tw = ops->new_text_window(title);
+    tw->ws_tw = ops->new_text_window(ops->ops_id, title);
 
     default_cbd = g_new(struct _close_cb_data, 1);
 
