@@ -99,9 +99,6 @@ static const struct field_display_string_t base_displays[] = {
     {"base.DEC_HEX", BASE_DEC_HEX},
     {"base.HEX_DEC", BASE_HEX_DEC},
     {"base.UNIT_STRING", BASE_UNIT_STRING},
-    /* String types */
-    {"base.ASCII", STR_ASCII},
-    {"base.UNICODE", STR_UNICODE},
     /* Byte separators */
     {"base.DOT", SEP_DOT},
     {"base.DASH", SEP_DASH},
@@ -112,7 +109,7 @@ static const struct field_display_string_t base_displays[] = {
     {"16",16},
     {"24",24},
     {"32",32},
-    /* for FT_ABSOLUTE_TIME use values in absolute_time_display_e */
+    /* FT_ABSOLUTE_TIME */
     {"base.LOCAL", ABSOLUTE_TIME_LOCAL},
     {"base.UTC", ABSOLUTE_TIME_UTC},
     {"base.DOY_UTC", ABSOLUTE_TIME_DOY_UTC},
@@ -207,9 +204,9 @@ static range_string * range_string_from_table(lua_State* L, int idx) {
                     return NULL;
                 }
                 if (key_count == 1) /* We incremented it above */
-                    r.value_min = wslua_toguint32(L, -1);
+                    r.value_min = wslua_toguint64(L, -1);
                 else
-                    r.value_max = wslua_toguint32(L, -1);
+                    r.value_max = wslua_toguint64(L, -1);
                 break;
 
             case 3:
@@ -391,7 +388,7 @@ static true_false_string* true_false_string_from_table(lua_State* L, int idx) {
             return NULL;
         }
 
-        /* Arrays in LUA start with index number 1 */
+        /* Arrays in Lua start with index number 1 */
         switch (lua_tointeger(L,-2)) {
         case 1:
             g_free(true_string);
@@ -411,7 +408,7 @@ static true_false_string* true_false_string_from_table(lua_State* L, int idx) {
         lua_pop(L, 1);
     }
 
-    tfs = (true_false_string *) g_malloc(sizeof(true_false_string));
+    tfs = g_new(true_false_string, 1);
     tfs->true_string = true_string;
     tfs->false_string = false_string;
 
@@ -428,7 +425,7 @@ static unit_name_string* unit_name_string_from_table(lua_State* L, int idx) {
         return NULL;
     }
 
-    units = (unit_name_string *) g_malloc0(sizeof(unit_name_string));
+    units = g_new0(unit_name_string, 1);
 
     lua_pushnil(L);
 
@@ -450,7 +447,7 @@ static unit_name_string* unit_name_string_from_table(lua_State* L, int idx) {
             return NULL;
         }
 
-        /* Arrays in LUA start with index number 1 */
+        /* Arrays in Lua start with index number 1 */
         switch (lua_tointeger(L,-2)) {
         case 1:
             g_free((gchar *)units->singular);
@@ -667,7 +664,7 @@ WSLUA_CONSTRUCTOR ProtoField_new(lua_State* L) {
     case FT_ABSOLUTE_TIME:
         if (base == BASE_NONE) {
             base = ABSOLUTE_TIME_LOCAL;  /* Default base for FT_ABSOLUTE_TIME */
-        } else if (base < ABSOLUTE_TIME_LOCAL || base > ABSOLUTE_TIME_DOY_UTC) {
+        } else if (!FIELD_DISPLAY_IS_ABSOLUTE_TIME(base)) {
             WSLUA_OPTARG_ERROR(ProtoField_new,BASE,"Base must be either base.LOCAL, base.UTC, or base.DOY_UTC");
             return 0;
         }
@@ -678,8 +675,8 @@ WSLUA_CONSTRUCTOR ProtoField_new(lua_State* L) {
         break;
     case FT_STRING:
     case FT_STRINGZ:
-        if (base != STR_ASCII && base != STR_UNICODE) {
-            WSLUA_OPTARG_ERROR(ProtoField_new,BASE,"Display must be either base.ASCII or base.UNICODE");
+        if (base != BASE_NONE) {
+            WSLUA_OPTARG_ERROR(ProtoField_new,BASE,"Display must be base.NONE");
             return 0;
         }
         if (mask) {
@@ -746,8 +743,6 @@ WSLUA_CONSTRUCTOR ProtoField_new(lua_State* L) {
     case FT_STRINGZTRUNC:
         WSLUA_ARG_ERROR(ProtoField_new,TYPE,"Unsupported ProtoField field type");
         break;
-    /* FT_PCRE isn't a valid field type. */
-    case FT_PCRE:
     default:
         WSLUA_ARG_ERROR(ProtoField_new,TYPE,"Invalid ProtoField field type");
         break;
@@ -1136,7 +1131,7 @@ static int ProtoField_time(lua_State* L,enum ftenum type) {
     }
 
     if (type == FT_ABSOLUTE_TIME) {
-        if (base < ABSOLUTE_TIME_LOCAL || base > ABSOLUTE_TIME_DOY_UTC) {
+        if (!FIELD_DISPLAY_IS_ABSOLUTE_TIME(base)) {
             luaL_argerror(L, 3, "Base must be either base.LOCAL, base.UTC, or base.DOY_UTC");
             return 0;
         }
@@ -1258,8 +1253,8 @@ static int ProtoField_other_display(lua_State* L,enum ftenum type) {
     if (lua_isnumber(L, 3)) {
         base = (unsigned)luaL_optinteger(L,3,BASE_NONE);
         if (type == FT_STRING || type == FT_STRINGZ) {
-            if (base != STR_ASCII && base != STR_UNICODE) {
-                luaL_argerror(L, 3, "Display must be either base.ASCII or base.UNICODE");
+            if (base != BASE_NONE) {
+                luaL_argerror(L, 3, "Display must be base.NONE");
                 return 0;
             }
         } else if (type == FT_BYTES || type == FT_UINT_BYTES) {
@@ -1439,7 +1434,7 @@ PROTOFIELD_OTHER(eui64,FT_EUI64)
 WSLUA_METAMETHOD ProtoField__tostring(lua_State* L) {
     /* Returns a string with info about a protofield (for debugging purposes). */
     ProtoField f = checkProtoField(L,1);
-    gchar* s = g_strdup_printf("ProtoField(%i): %s %s %s %s %p %.8x %s",
+    gchar* s = ws_strdup_printf("ProtoField(%i): %s %s %s %s %p %.8x %s",
                                          f->hfid,f->name,f->abbrev,
                                          ftenum_to_string(f->type),
                                          base_to_string(f->base),
