@@ -11,6 +11,7 @@
  */
 
 #include <config.h>
+#define WS_LOG_DOMAIN LOG_DOMAIN_EXTCAP
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -31,7 +32,6 @@
 #endif
 
 #include <glib.h>
-#include <log.h>
 
 #include <epan/prefs.h>
 
@@ -40,15 +40,16 @@
 #include <wsutil/file_util.h>
 #include <wsutil/filesystem.h>
 #include <wsutil/ws_pipe.h>
-#include <wsutil/ws_printf.h>
 #include <wsutil/tempfile.h>
+#include <wsutil/wslog.h>
+#include <wsutil/ws_assert.h>
 
 #include "capture_opts.h"
 
 #include "extcap.h"
 #include "extcap_parser.h"
 
-#include "version_info.h"
+#include "ui/version_info.h"
 
 static void extcap_child_watch_cb(GPid pid, gint status, gpointer user_data);
 
@@ -73,7 +74,7 @@ static GHashTable *_toolbars = NULL;
  * values. These ensure that preferences can survive extcap if garbage
  * collection, and does not lead to dangling pointers in the prefs subsystem.
  */
-static GHashTable *extcap_prefs_dynamic_vals = NULL;
+static GHashTable *_extcap_prefs_dynamic_vals = NULL;
 
 typedef struct _extcap_callback_info_t
 {
@@ -127,6 +128,12 @@ typedef struct extcap_run_extcaps_info {
 
 static void extcap_load_interface_list(void);
 
+/* Used for lazily loading our interfaces. */
+static void extcap_ensure_all_interfaces_loaded(void) {
+    if ( !_loaded_interfaces || g_hash_table_size(_loaded_interfaces) == 0 )
+        extcap_load_interface_list();
+}
+
 static gboolean
 thread_pool_push(thread_pool_t *pool, gpointer data, GError **error)
 {
@@ -152,8 +159,7 @@ extcap_loaded_interfaces(void)
     if (prefs.capture_no_extcap)
         return NULL;
 
-    if ( !_loaded_interfaces || g_hash_table_size(_loaded_interfaces) == 0 )
-        extcap_load_interface_list();
+    extcap_ensure_all_interfaces_loaded();
 
     return _loaded_interfaces;
 }
@@ -179,6 +185,8 @@ compare_tools(gconstpointer a, gconstpointer b)
 void
 extcap_get_descriptions(plugin_description_callback callback, void *callback_data)
 {
+    extcap_ensure_all_interfaces_loaded();
+
     GHashTable * tools = extcap_loaded_interfaces();
     GPtrArray *tools_array = g_ptr_array_new();
 
@@ -210,7 +218,7 @@ print_extcap_description(const char *basename, const char *version,
                         const char *description, const char *filename,
                         void *user_data _U_)
 {
-    ws_debug_printf("%-16s\t%s\t%s\t%s\n", basename, version, description, filename);
+    printf("%-16s\t%s\t%s\t%s\n", basename, version, description, filename);
 }
 
 void
@@ -230,7 +238,7 @@ extcap_get_extcap_paths_from_dir(GSList * list, const char * dirname)
     if ((dir = g_dir_open(dirname, 0, NULL)) != NULL) {
         while ((file = g_dir_read_name(dir)) != NULL) {
             /* full path to extcap binary */
-            gchar *extcap_path = g_strdup_printf("%s" G_DIR_SEPARATOR_S "%s", dirname, file);
+            gchar *extcap_path = ws_strdup_printf("%s" G_DIR_SEPARATOR_S "%s", dirname, file);
             /* treat anything executable as an extcap binary */
             if (g_file_test(extcap_path, G_FILE_TEST_IS_REGULAR) &&
                 g_file_test(extcap_path, G_FILE_TEST_IS_EXECUTABLE)) {
@@ -450,17 +458,11 @@ static gpointer
 extcap_run_all(const char *argv[], extcap_run_cb_t output_cb, gsize data_size, guint *count)
 {
     /* Need enough space for at least 'extcap_path'. */
-    g_assert(data_size >= sizeof(char *));
+    ws_assert(data_size >= sizeof(char *));
 
     GSList *paths = extcap_get_extcap_paths();
     int i = 0;
-#if GLIB_CHECK_VERSION(2,36,0)
     int max_threads = (int)g_get_num_processors();
-#else
-    // If the number of processors is unavailable, just use some sane maximum.
-    // extcap should not be CPU bound, so -1 could also be used for unlimited.
-    int max_threads = 8;
-#endif
 
     if (!paths) {
         *count = 0;
@@ -498,7 +500,7 @@ extcap_run_all(const char *argv[], extcap_run_cb_t output_cb, gsize data_size, g
     g_cond_clear(&pool.cond);
     g_thread_pool_free(pool.pool, FALSE, TRUE);
 
-    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "extcap: completed discovery of %d tools in %.3fms",
+    ws_debug("extcap: completed discovery of %d tools in %.3fms",
             paths_count, (g_get_monotonic_time() - start_time) / 1000.0);
     *count = paths_count;
     return infos;
@@ -534,7 +536,7 @@ static gboolean cb_dlt(extcap_callback_info_t cb_info)
     dlts = extcap_parse_dlts(cb_info.output);
     temp = dlts;
 
-    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "Extcap pipe %s ", cb_info.extcap);
+    ws_debug("Extcap pipe %s ", cb_info.extcap);
 
     /*
      * Allocate the interface capabilities structure.
@@ -548,8 +550,7 @@ static gboolean cb_dlt(extcap_callback_info_t cb_info)
         dlt_item = (extcap_dlt *)dlts->data;
         if (dlt_item)
         {
-            g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG,
-                  "  DLT %d name=\"%s\" display=\"%s\" ", dlt_item->number,
+            ws_debug("  DLT %d name=\"%s\" display=\"%s\" ", dlt_item->number,
                   dlt_item->name, dlt_item->display);
 
             data_link_info = g_new(data_link_info_t, 1);
@@ -572,7 +573,7 @@ static gboolean cb_dlt(extcap_callback_info_t cb_info)
     {
         if (cb_info.err_str)
         {
-            g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "  returned no DLTs");
+            ws_debug("  returned no DLTs");
             *(cb_info.err_str) = g_strdup("Extcap returned no DLTs");
         }
         g_free(caps);
@@ -594,6 +595,9 @@ extcap_get_if_dlts(const gchar *ifname, char **err_str)
         *err_str = NULL;
     }
 
+    /* Update the extcap interfaces and get a list of their if_infos */
+    extcap_ensure_all_interfaces_loaded();
+
     extcap_interface *interface = extcap_find_interface_for_ifname(ifname);
     if (interface)
     {
@@ -655,6 +659,8 @@ if_info_compare(gconstpointer a, gconstpointer b)
 gchar *
 extcap_get_help_for_ifname(const char *ifname)
 {
+    extcap_ensure_all_interfaces_loaded();
+
     extcap_interface *interface = extcap_find_interface_for_ifname(ifname);
     return interface != NULL ? interface->help : NULL;
 }
@@ -670,8 +676,7 @@ append_extcap_interface_list(GList *list, char **err_str _U_)
         return list;
 
     /* Update the extcap interfaces and get a list of their if_infos */
-    if ( !_loaded_interfaces || g_hash_table_size(_loaded_interfaces) == 0 )
-        extcap_load_interface_list();
+    extcap_ensure_all_interfaces_loaded();
 
     ifutilkeys_head = g_hash_table_get_keys(_loaded_interfaces);
     ifutilkeys = ifutilkeys_head;
@@ -727,7 +732,7 @@ void extcap_register_preferences(void)
     }
 
     // Will load information about extcaps and their supported config.
-    extcap_load_interface_list();
+    extcap_ensure_all_interfaces_loaded();
 }
 
 /**
@@ -736,8 +741,8 @@ void extcap_register_preferences(void)
  */
 void extcap_cleanup(void)
 {
-    if (extcap_prefs_dynamic_vals)
-        g_hash_table_destroy(extcap_prefs_dynamic_vals);
+    if (_extcap_prefs_dynamic_vals)
+        g_hash_table_destroy(_extcap_prefs_dynamic_vals);
 
     if (_loaded_interfaces)
         g_hash_table_destroy(_loaded_interfaces);
@@ -759,19 +764,19 @@ void extcap_cleanup(void)
 static gchar **extcap_prefs_dynamic_valptr(const char *name, char **pref_name)
 {
     gchar **valp;
-    if (!extcap_prefs_dynamic_vals)
+    if (!_extcap_prefs_dynamic_vals)
     {
         /* Initialize table only as needed, most preferences are not dynamic */
-        extcap_prefs_dynamic_vals = g_hash_table_new_full(g_str_hash, g_str_equal,
+        _extcap_prefs_dynamic_vals = g_hash_table_new_full(g_str_hash, g_str_equal,
                                     g_free, g_free);
     }
-    if (!g_hash_table_lookup_extended(extcap_prefs_dynamic_vals, name,
+    if (!g_hash_table_lookup_extended(_extcap_prefs_dynamic_vals, name,
                                       (gpointer *)pref_name, (gpointer *)&valp))
     {
         /* New dynamic pref, allocate, initialize and store. */
         valp = g_new0(gchar *, 1);
         *pref_name = g_strdup(name);
-        g_hash_table_insert(extcap_prefs_dynamic_vals, *pref_name, valp);
+        g_hash_table_insert(_extcap_prefs_dynamic_vals, *pref_name, valp);
     }
     return valp;
 }
@@ -803,6 +808,8 @@ extcap_pref_for_argument(const gchar *ifname, struct _extcap_arg *arg)
 {
     struct preference *pref = NULL;
 
+    extcap_ensure_all_interfaces_loaded();
+
     GRegex *regex_name = g_regex_new("[-]+", G_REGEX_RAW, (GRegexMatchFlags) 0, NULL);
     GRegex *regex_ifname = g_regex_new("(?![a-zA-Z0-9_]).", G_REGEX_RAW, (GRegexMatchFlags) 0, NULL);
     if (regex_name && regex_ifname)
@@ -859,14 +866,12 @@ static gboolean cb_preference(extcap_callback_info_t cb_info)
 
                 if (arg->save)
                 {
-                    struct preference *pref = NULL;
-
                     gchar *pref_name = g_regex_replace(regex_name, arg->call, strlen(arg->call), 0, "", (GRegexMatchFlags) 0, NULL);
                     gchar *ifname_underscore = g_regex_replace(regex_ifname, cb_info.ifname, strlen(cb_info.ifname), 0, "_", (GRegexMatchFlags) 0, NULL);
                     gchar *ifname_lowercase = g_ascii_strdown(ifname_underscore, -1);
                     gchar *pref_ifname = g_strconcat(ifname_lowercase, ".", pref_name, NULL);
 
-                    if ((pref = prefs_find_preference(dev_module, pref_ifname)) == NULL)
+                    if (prefs_find_preference(dev_module, pref_ifname) == NULL)
                     {
                         char *pref_name_for_prefs;
                         char *pref_title = wmem_strdup(wmem_epan_scope(), arg->display);
@@ -878,15 +883,21 @@ static gboolean cb_preference(extcap_callback_info_t cb_info)
                             *arg->pref_valptr = arg->default_complex->_val;
                         }
 
-                        prefs_register_string_preference(dev_module, pref_name_for_prefs,
+                        if (arg->arg_type == EXTCAP_ARG_PASSWORD)
+                        {
+                            prefs_register_password_preference(dev_module, pref_name_for_prefs,
                                                          pref_title, pref_title, (const char **)arg->pref_valptr);
+                        } else {
+                            prefs_register_string_preference(dev_module, pref_name_for_prefs,
+                                                         pref_title, pref_title, (const char **)arg->pref_valptr);
+                        }
                     }
                     else
                     {
                         /* Been here before, restore stored value */
                         if (arg->pref_valptr == NULL)
                         {
-                            arg->pref_valptr = (gchar**)g_hash_table_lookup(extcap_prefs_dynamic_vals, pref_ifname);
+                            arg->pref_valptr = (gchar**)g_hash_table_lookup(_extcap_prefs_dynamic_vals, pref_ifname);
                         }
                     }
 
@@ -921,11 +932,12 @@ extcap_get_if_configuration(const char *ifname)
     GList * arguments = NULL;
     GList *ret = NULL;
 
+    extcap_ensure_all_interfaces_loaded();
+
     extcap_interface *interface = extcap_find_interface_for_ifname(ifname);
     if (interface)
     {
-        g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "Extcap path %s",
-              get_extcap_dir());
+        ws_debug("Extcap path %s", get_extcap_dir());
 
         arguments = g_list_append(arguments, g_strdup(EXTCAP_ARGUMENT_CONFIG));
         arguments = g_list_append(arguments, g_strdup(EXTCAP_ARGUMENT_INTERFACE));
@@ -965,11 +977,12 @@ extcap_get_if_configuration_values(const char * ifname, const char * argname, GH
     GList * args = NULL;
     GList *ret = NULL;
 
+    extcap_ensure_all_interfaces_loaded();
+
     extcap_interface *interface = extcap_find_interface_for_ifname(ifname);
     if (interface)
     {
-        g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "Extcap path %s",
-              get_extcap_dir());
+        ws_debug("Extcap path %s", get_extcap_dir());
 
         args = g_list_append(args, g_strdup(EXTCAP_ARGUMENT_CONFIG));
         args = g_list_append(args, g_strdup(EXTCAP_ARGUMENT_INTERFACE));
@@ -999,21 +1012,15 @@ extcap_get_if_configuration_values(const char * ifname, const char * argname, GH
     return ret;
 }
 
-/**
- * If is_required is FALSE: returns TRUE if the extcap interface has
- * configurable options.
- * If is_required is TRUE: returns TRUE when the extcap interface has
- * configurable options that required modification. (For example, when an
- * argument is required but empty.)
- */
 gboolean
 extcap_has_configuration(const char *ifname, gboolean is_required)
 {
     GList *arguments = 0;
     GList *walker = 0, * item = 0;
-
     gboolean found = FALSE;
 
+    extcap_ensure_all_interfaces_loaded();
+
     arguments = extcap_get_if_configuration(ifname);
     walker = g_list_first(arguments);
 
@@ -1106,11 +1113,12 @@ extcap_verify_capture_filter(const char *ifname, const char *filter, gchar **err
     GList * arguments = NULL;
     extcap_filter_status status = EXTCAP_FILTER_UNKNOWN;
 
+    extcap_ensure_all_interfaces_loaded();
+
     extcap_interface *interface = extcap_find_interface_for_ifname(ifname);
     if (interface)
     {
-        g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "Extcap path %s",
-              get_extcap_dir());
+        ws_debug("Extcap path %s", get_extcap_dir());
 
         arguments = g_list_append(arguments, g_strdup(EXTCAP_ARGUMENT_CAPTURE_FILTER));
         arguments = g_list_append(arguments, g_strdup(filter));
@@ -1132,6 +1140,8 @@ extcap_has_toolbar(const char *ifname)
         return FALSE;
     }
 
+    extcap_ensure_all_interfaces_loaded();
+
     GList *toolbar_list = g_hash_table_get_values (_toolbars);
     for (GList *walker = toolbar_list; walker; walker = walker->next)
     {
@@ -1169,14 +1179,12 @@ void extcap_if_cleanup(capture_options *capture_opts, gchar **errormsg)
 
         overwrite_exitcode = FALSE;
 
-        g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG,
-              "Extcap [%s] - Cleaning up fifo: %s; PID: %d", interface_opts->name,
+        ws_debug("Extcap [%s] - Cleaning up fifo: %s; PID: %d", interface_opts->name,
               interface_opts->extcap_fifo, interface_opts->extcap_pid);
 #ifdef _WIN32
         if (interface_opts->extcap_pipe_h != INVALID_HANDLE_VALUE)
         {
-            g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG,
-                  "Extcap [%s] - Closing pipe", interface_opts->name);
+            ws_debug("Extcap [%s] - Closing pipe", interface_opts->name);
             FlushFileBuffers(interface_opts->extcap_pipe_h);
             DisconnectNamedPipe(interface_opts->extcap_pipe_h);
             CloseHandle(interface_opts->extcap_pipe_h);
@@ -1184,8 +1192,7 @@ void extcap_if_cleanup(capture_options *capture_opts, gchar **errormsg)
         }
         if (interface_opts->extcap_control_in_h != INVALID_HANDLE_VALUE)
         {
-            g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG,
-                  "Extcap [%s] - Closing control_in pipe", interface_opts->name);
+            ws_debug("Extcap [%s] - Closing control_in pipe", interface_opts->name);
             FlushFileBuffers(interface_opts->extcap_control_in_h);
             DisconnectNamedPipe(interface_opts->extcap_control_in_h);
             CloseHandle(interface_opts->extcap_control_in_h);
@@ -1193,8 +1200,7 @@ void extcap_if_cleanup(capture_options *capture_opts, gchar **errormsg)
         }
         if (interface_opts->extcap_control_out_h != INVALID_HANDLE_VALUE)
         {
-            g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG,
-                  "Extcap [%s] - Closing control_out pipe", interface_opts->name);
+            ws_debug("Extcap [%s] - Closing control_out pipe", interface_opts->name);
             FlushFileBuffers(interface_opts->extcap_control_out_h);
             DisconnectNamedPipe(interface_opts->extcap_control_out_h);
             CloseHandle(interface_opts->extcap_control_out_h);
@@ -1217,11 +1223,17 @@ void extcap_if_cleanup(capture_options *capture_opts, gchar **errormsg)
             ws_unlink(interface_opts->extcap_control_out);
             interface_opts->extcap_control_out = NULL;
         }
+        /* Send termination signal to child. On Linux and OSX the child will not notice that the
+         * pipe has been closed before writing to the pipe.
+         */
+        if (interface_opts->extcap_pid != WS_INVALID_PID)
+        {
+            kill(interface_opts->extcap_pid, SIGTERM);
+        }
 #endif
         /* Maybe the client closed and removed fifo, but ws should check if
          * pid should be closed */
-        g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG,
-              "Extcap [%s] - Closing spawned PID: %d", interface_opts->name,
+        ws_debug("Extcap [%s] - Closing spawned PID: %d", interface_opts->name,
               interface_opts->extcap_pid);
 
         pipedata = (ws_pipe_t *) interface_opts->extcap_pipedata;
@@ -1261,7 +1273,7 @@ void extcap_if_cleanup(capture_options *capture_opts, gchar **errormsg)
                 {
                     if (*errormsg == NULL)
                     {
-                        *errormsg = g_strdup_printf("Error by extcap pipe: %s", pipedata->stderr_msg);
+                        *errormsg = ws_strdup_printf("Error by extcap pipe: %s", pipedata->stderr_msg);
                     }
                     else
                     {
@@ -1522,26 +1534,26 @@ static gboolean extcap_create_pipe(const gchar *ifname, gchar **fifo, HANDLE *ha
 
     if (*handle_out == INVALID_HANDLE_VALUE)
     {
-        g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "\nError creating pipe => (%d)", GetLastError());
+        ws_debug("Error creating pipe => (%d)", GetLastError());
         g_free (pipename);
         return FALSE;
     }
     else
     {
-        g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "\nWireshark Created pipe =>(%s) handle (%" G_GUINTPTR_FORMAT ")", pipename, *handle_out);
+        ws_debug("Wireshark Created pipe =>(%s) handle (%" PRIuPTR ")", pipename, *handle_out);
         *fifo = g_strdup(pipename);
     }
 
     return TRUE;
 }
 #else
-static gboolean extcap_create_pipe(const gchar *ifname, gchar **fifo, const gchar *pipe_prefix)
+static gboolean extcap_create_pipe(const gchar *ifname, gchar **fifo, const gchar *temp_dir, const gchar *pipe_prefix)
 {
     gchar *temp_name = NULL;
     int fd = 0;
 
     gchar *pfx = g_strconcat(pipe_prefix, "_", ifname, NULL);
-    if ((fd = create_tempfile(&temp_name, pfx, NULL)) < 0)
+    if ((fd = create_tempfile(temp_dir, &temp_name, pfx, NULL, NULL)) < 0)
     {
         g_free(pfx);
         return FALSE;
@@ -1550,8 +1562,7 @@ static gboolean extcap_create_pipe(const gchar *ifname, gchar **fifo, const gcha
 
     ws_close(fd);
 
-    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG,
-          "Extcap - Creating fifo: %s", temp_name);
+    ws_debug("Extcap - Creating fifo: %s", temp_name);
 
     if (file_exists(temp_name))
     {
@@ -1560,9 +1571,12 @@ static gboolean extcap_create_pipe(const gchar *ifname, gchar **fifo, const gcha
 
     if (mkfifo(temp_name, 0600) == 0)
     {
-        *fifo = g_strdup(temp_name);
+        *fifo = temp_name;
+    }
+    else
+    {
+        g_free(temp_name);
     }
-
     return TRUE;
 }
 #endif
@@ -1576,6 +1590,8 @@ extcap_init_interfaces(capture_options *capture_opts)
     interface_options *interface_opts;
     ws_pipe_t *pipedata;
 
+    extcap_ensure_all_interfaces_loaded();
+
     for (i = 0; i < capture_opts->ifaces->len; i++)
     {
         GPtrArray *args = NULL;
@@ -1595,11 +1611,15 @@ extcap_init_interfaces(capture_options *capture_opts)
             extcap_create_pipe(interface_opts->name, &interface_opts->extcap_control_in,
 #ifdef _WIN32
                                &interface_opts->extcap_control_in_h,
+#else
+                               capture_opts->temp_dir,
 #endif
                                EXTCAP_CONTROL_IN_PREFIX);
             extcap_create_pipe(interface_opts->name, &interface_opts->extcap_control_out,
 #ifdef _WIN32
                                &interface_opts->extcap_control_out_h,
+#else
+                               capture_opts->temp_dir,
 #endif
                                EXTCAP_CONTROL_OUT_PREFIX);
         }
@@ -1608,6 +1628,8 @@ extcap_init_interfaces(capture_options *capture_opts)
         if (!extcap_create_pipe(interface_opts->name, &interface_opts->extcap_fifo,
 #ifdef _WIN32
                                 &interface_opts->extcap_pipe_h,
+#else
+                               capture_opts->temp_dir,
 #endif
                                 EXTCAP_PIPE_PREFIX))
         {
@@ -1720,6 +1742,8 @@ extcap_ensure_interface(const gchar * toolname, gboolean create_if_nonexist)
 extcap_info *
 extcap_get_tool_by_ifname(const gchar *ifname)
 {
+    extcap_ensure_all_interfaces_loaded();
+
     if ( ifname && _tool_for_ifname )
     {
         gchar * toolname = (gchar *)g_hash_table_lookup(_tool_for_ifname, ifname);
@@ -1733,6 +1757,8 @@ extcap_get_tool_by_ifname(const gchar *ifname)
 extcap_info *
 extcap_get_tool_info(const gchar * toolname)
 {
+    extcap_ensure_all_interfaces_loaded();
+
     return extcap_ensure_interface(toolname, FALSE);
 }
 
@@ -1758,12 +1784,12 @@ process_new_extcap(const char *extcap, char *output)
     /* Load interfaces from utility */
     interfaces = extcap_parse_interfaces(output, &control_items);
 
-    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "Loading interface list for %s ", extcap);
+    ws_debug("Loading interface list for %s ", extcap);
 
     /* Seems, that there where no interfaces to be loaded */
     if ( ! interfaces || g_list_length(interfaces) == 0 )
     {
-        g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "Cannot load interfaces for %s", extcap );
+        ws_debug("Cannot load interfaces for %s", extcap );
         g_list_free(interface_keys);
         g_free(toolname);
         return;
@@ -1773,8 +1799,7 @@ process_new_extcap(const char *extcap, char *output)
     element = extcap_ensure_interface(toolname, TRUE);
     if ( element == NULL )
     {
-        g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_WARNING,
-            "Cannot store interface %s, already loaded as personal plugin", extcap );
+        ws_warning("Cannot store interface %s, already loaded as personal plugin", extcap );
         g_list_foreach(interfaces, remove_extcap_entry, NULL);
         g_list_free(interfaces);
         g_list_free(interface_keys);
@@ -1795,7 +1820,7 @@ process_new_extcap(const char *extcap, char *output)
         int_iter = (extcap_interface *)walker->data;
 
         if (int_iter->call != NULL)
-            g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "Interface found %s\n", int_iter->call);
+            ws_debug("Interface found %s\n", int_iter->call);
 
         /* Help is not necessarily stored with the interface, but rather with the version string.
          * As the version string allways comes in front of the interfaces, this ensures, that it get's
@@ -1803,7 +1828,7 @@ process_new_extcap(const char *extcap, char *output)
         if (int_iter->if_type == EXTCAP_SENTENCE_EXTCAP)
         {
             if (int_iter->call != NULL)
-                g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "  Extcap [%s] ", int_iter->call);
+                ws_debug("  Extcap [%s] ", int_iter->call);
 
             /* Only initialize values if none are set. Need to check only one element here */
             if ( ! element->version )
@@ -1832,14 +1857,14 @@ process_new_extcap(const char *extcap, char *output)
         {
             if ( g_list_find(interface_keys, int_iter->call) )
             {
-                g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_WARNING, "Extcap interface \"%s\" is already provided by \"%s\" ",
+                ws_warning("Extcap interface \"%s\" is already provided by \"%s\" ",
                       int_iter->call, extcap_if_executable(int_iter->call));
                 walker = g_list_next(walker);
                 continue;
             }
 
             if ((int_iter->call != NULL) && (int_iter->display))
-                g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "  Interface [%s] \"%s\" ", int_iter->call, int_iter->display);
+                ws_debug("  Interface [%s] \"%s\" ", int_iter->call, int_iter->display);
 
             int_iter->extcap_path = g_strdup(extcap);
 
@@ -1866,9 +1891,8 @@ process_new_extcap(const char *extcap, char *output)
     if (toolbar_entry && toolbar_entry->menu_title)
     {
         iface_toolbar_add(toolbar_entry);
-        if (!extcap_iface_toolbar_add(extcap, toolbar_entry))
+        if (extcap_iface_toolbar_add(extcap, toolbar_entry))
         {
-            extcap_free_toolbar(toolbar_entry);
             toolbar_entry = NULL;
         }
     }
@@ -2026,7 +2050,7 @@ extcap_load_interface_list(void)
         }
 
         get_ws_version_number(&major, &minor, NULL);
-        char *arg_version = g_strdup_printf("%s=%d.%d", EXTCAP_ARGUMENT_VERSION, major, minor);
+        char *arg_version = ws_strdup_printf("%s=%d.%d", EXTCAP_ARGUMENT_VERSION, major, minor);
         const char *argv[] = {
             EXTCAP_ARGUMENT_LIST_INTERFACES,
             arg_version,
