@@ -64,7 +64,8 @@
 #include "packet-pn.h"
 
 
-#define F_MESSAGE_TRAILER_4BYTE  4      /* PROFIsafe: Defines the Amount of Bytes for CRC and Status-/Controlbyte */
+#define F_MESSAGE_TRAILER_4BYTE  4      /* PROFIsafe: Defines the Amount of Bytes for CRC and Status-/Controlbyte in PROFIsafe 2.4 */
+#define F_MESSAGE_TRAILER_5BYTE  5      /* PROFIsafe: Defines the Amount of Bytes for CRC and Status-/Controlbyte in PROFIsafe 2.6 */
 #define PN_INPUT_CR              1      /* PROFINET Input Connect Request value */
 #define PN_INPUT_DATADESCRITPION 1      /* PROFINET Input Data Description value */
 
@@ -381,6 +382,7 @@ dissect_PNIO_C_SDU_RTC1(tvbuff_t *tvb, int offset,
 
     guint8  statusbyte;
     guint8  controlbyte;
+    guint8  safety_io_data_length;
 
     guint16 number_io_data_objects_input_cr;
     guint16 number_iocs_input_cr;
@@ -460,15 +462,15 @@ dissect_PNIO_C_SDU_RTC1(tvbuff_t *tvb, int offset,
             if (addresses_equal(&(pinfo->src), conversation_key_addr1(conversation->key_ptr)) && addresses_equal(&(pinfo->dst), conversation_key_addr2(conversation->key_ptr))) {
                 inputFlag = TRUE;
                 outputFlag = FALSE;
-                number_io_data_objects_input_cr = station_info->ioDataObjectNr;
-                number_iocs_input_cr = station_info->iocsNr;
+                number_io_data_objects_input_cr = station_info->ioDataObjectNr_in;
+                number_iocs_input_cr = station_info->iocsNr_in;
             }
 
             if (addresses_equal(&(pinfo->dst), conversation_key_addr1(conversation->key_ptr)) && addresses_equal(&(pinfo->src), conversation_key_addr2(conversation->key_ptr))) {
                 outputFlag = TRUE;
                 inputFlag = FALSE;
-                number_io_data_objects_output_cr = station_info->ioDataObjectNr;
-                number_iocs_output_cr = station_info->iocsNr;
+                number_io_data_objects_output_cr = station_info->ioDataObjectNr_out;
+                number_iocs_output_cr = station_info->iocsNr_out;
             }
         }
     }
@@ -556,9 +558,15 @@ dissect_PNIO_C_SDU_RTC1(tvbuff_t *tvb, int offset,
                             proto_tree_add_uint(IODataObject_tree, hf_pn_io_ps_f_dest_adr, tvb, 0, 0, io_data_object->f_dest_adr);
 
                             /* Get Safety IO Data */
-                            if ((io_data_object->length - F_MESSAGE_TRAILER_4BYTE) > 0) {
+                            if (io_data_object->f_crc_seed == FALSE) {
+                                safety_io_data_length = io_data_object->length - F_MESSAGE_TRAILER_4BYTE;
+                            } else {
+                                safety_io_data_length = io_data_object->length - F_MESSAGE_TRAILER_5BYTE;
+                            }
+
+                            if (safety_io_data_length > 0) {
                                 offset = dissect_pn_io_ps_uint(tvb, offset, pinfo, IODataObject_tree, drep, hf_pn_io_ps_f_data,
-                                    (io_data_object->length - F_MESSAGE_TRAILER_4BYTE), &f_data);
+                                    safety_io_data_length, &f_data);
                             }
 
                             /* ---- Check for new PNIO data using togglebit ---- */
@@ -604,10 +612,10 @@ dissect_PNIO_C_SDU_RTC1(tvbuff_t *tvb, int offset,
                         /* ModuleIdentNr appears not only once in GSD-file -> set module name more generally */
                         if (io_data_object->amountInGSDML > 1) {    /* if ModuleIdentNr only appears once in GSD-file, use the found GSD-file-ModuleName, else ... */
                             if (io_data_object->slotNr == 0) {
-                                moduleName = wmem_strbuf_new(wmem_packet_scope(), "Headstation");
+                                moduleName = wmem_strbuf_new(pinfo->pool, "Headstation");
                             }
                             else {
-                                moduleName = wmem_strbuf_new(wmem_packet_scope(), "Module");
+                                moduleName = wmem_strbuf_new(pinfo->pool, "Module");
                             }
 
                             if (io_data_object->profisafeSupported == TRUE) {
@@ -751,9 +759,15 @@ dissect_PNIO_C_SDU_RTC1(tvbuff_t *tvb, int offset,
                             proto_tree_add_uint(IODataObject_tree, hf_pn_io_ps_f_dest_adr, tvb, 0, 0, io_data_object->f_dest_adr);
 
                             /* Get Safety IO Data */
-                            if ((io_data_object->length - F_MESSAGE_TRAILER_4BYTE) > 0) {
+                            if (io_data_object->f_crc_seed == FALSE) {
+                                safety_io_data_length = io_data_object->length - F_MESSAGE_TRAILER_4BYTE;
+                            } else {
+                                safety_io_data_length = io_data_object->length - F_MESSAGE_TRAILER_5BYTE;
+                            }
+
+                            if (safety_io_data_length > 0) {
                                 offset = dissect_pn_io_ps_uint(tvb, offset, pinfo, IODataObject_tree, drep, hf_pn_io_ps_f_data,
-                                    (io_data_object->length - F_MESSAGE_TRAILER_4BYTE), &f_data);
+                                    safety_io_data_length, &f_data);
                             }
 
                             /* ---- Check for new PNIO data using togglebit ---- */
@@ -798,10 +812,10 @@ dissect_PNIO_C_SDU_RTC1(tvbuff_t *tvb, int offset,
                         /* ModuleIdentNr appears not only once in GSD-file -> set module name more generally */
                         if (io_data_object->amountInGSDML > 1) {    /* if ModuleIdentNr only appears once in GSD-file, use the found GSD-file-ModuleName, else ... */
                             if (io_data_object->slotNr == 0) {
-                                moduleName = wmem_strbuf_new(wmem_packet_scope(), "Headstation");
+                                moduleName = wmem_strbuf_new(pinfo->pool, "Headstation");
                             }
                             else {
-                                moduleName = wmem_strbuf_new(wmem_packet_scope(), "Module");
+                                moduleName = wmem_strbuf_new(pinfo->pool, "Module");
                             }
 
                             if (io_data_object->profisafeSupported == TRUE) {
