@@ -261,14 +261,14 @@ class case_wslua(subprocesstest.SubprocessTestCase):
             '-X', 'lua_script1:' + os.path.join(dirs.lua_dir, 'globals_2.2.txt'),
         )
 
-    @unittest.skip('GRegex tests are broken since PCRE 8.34, see bug 12997.')
-    def test_wslua_gregex(self, check_lua_script, dirs):
-        '''wslua GRegex'''
-        check_lua_script(self, 'gregex.lua', empty_pcap, True,
-            '-X', 'lua_script1:' + os.path.join(dirs.lua_dir, ''),
-            '-X', 'lua_script1:glib',
-            '-X', 'lua_script1:-V',
-        )
+#    @unittest.skip('GRegex tests are broken since PCRE 8.34, see bug 12997.')
+#    def test_wslua_gregex(self, check_lua_script, dirs):
+#        '''wslua GRegex'''
+#        check_lua_script(self, 'gregex.lua', empty_pcap, True,
+#            '-X', 'lua_script1:-d' + os.path.join(dirs.lua_dir, ''),
+#            '-X', 'lua_script1:glib',
+#            '-X', 'lua_script1:-V',
+#        )
 
     def test_wslua_struct(self, check_lua_script):
         '''wslua struct'''
