@@ -15,58 +15,16 @@
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
+use v5.10;
+
 use warnings;
 use strict;
-use Getopt::Long;
-use Encode qw(encode decode);
+use open ':std', ':encoding(UTF-8)';
 
 my $state = "";
 my %contributors = ();
-my $is_contributing = 0;
 
-my $header = "
-
-= Original Author =
-
-Gerald Combs            <gerald[AT]wireshark.org>
-
-
-";
-
-my $trailer = "
-
-= Acknowledgements =
-
-Dan Lasley <dlasley[AT]promus.com> gave permission for his
-dumpit() hex-dump routine to be used.
-
-Mattia Cazzola <mattiac[AT]alinet.it> provided a patch to the
-hex dump display routine.
-
-We use the exception module from Kazlib, a C library written by
-Kaz Kylheku <kaz[AT]kylheku.com>. Thanks go to him for
-his well-written library. The Kazlib home page can be found at
-http://www.kylheku.com/~kaz/kazlib.html
-
-We use Lua BitOp, written by Mike Pall, for bitwise operations
-on numbers in Lua. The Lua BitOp home page can be found at
-http://bitop.luajit.org/
-
-snax <snax[AT]shmoo.com> gave permission to use his(?) weak key
-detection code from Airsnort.
-
-IANA gave permission for their port-numbers file to be used.
-
-We use the natural order string comparison algorithm, written by
-Martin Pool <mbp[AT]sourcefrog.net>.
-
-Emanuel Eichhammer <support[AT]qcustomplot.com> granted permission
-to use QCustomPlot.
-
-Insecure.Com LLC (\"The Nmap Project\") has granted the Wireshark
-Foundation permission to distribute Npcap with our Windows
-installers.
-";
+my $acknowledgements_heading = "= Acknowledgements =";
 
 my $git_log_text = "
 = From git log =
@@ -91,11 +49,11 @@ sub parse_author_name {
 		if ($3 ne "gerald[AT]wireshark.org") {
 			$email_key = lc($3);
 			$contributors{$email_key} = $1;
-			print encode('UTF-8', "$full_name\n");
+			say $full_name;
 		}
 	} elsif ($full_name =~ /^([\w\.\-\'\x80-\xff]+(\s*[\w+\.\-\'\x80-\xff])*)\s+\(/) {
 		$contributors{"<no_email>"} = $1;
-		print encode('UTF-8', "$full_name\n");
+		say $full_name;
 	}
 }
 
@@ -128,7 +86,7 @@ sub parse_git_name {
 					$line = $name . "\t" x $ntab . "<$email>";
 				}
 				$contributors{$email_key} = $1;
-				print encode('UTF-8', "$line\n");
+				say $line;
 			}
 		}
 	}
@@ -139,52 +97,61 @@ sub parse_git_name {
 # MAIN
 #
 
-print $header;
-
 open( my $author_fh, '<', $ARGV[0] ) or die "Can't open $ARGV[0]: $!";
-while ( my $line = decode('UTF-8', <$author_fh>) ) {
+
+while ( my $line = <$author_fh> ) {
 	chomp $line;
 
-	last if ($line =~ "Acknowledgements");
+	say $line;
 
-	if ($line =~ "Contributors") {
-		$is_contributing = 1;
-	} elsif ($is_contributing == 0) {
-		next;
-	}
+	last if $line eq "= Contributors =";
+}
+
+while ( my $line = <$author_fh> ) {
+	chomp $line;
+
+	last if ($line eq $acknowledgements_heading);
 
 	if ($line =~ /([^\{]*)\{/) {
 		parse_author_name($line);
 		$state = "s_in_bracket";
 	} elsif ($state eq "s_in_bracket") {
 		if ($line =~ /([^\}]*)\}/) {
-			print encode('UTF-8', "$line\n");
+			say $line;
 			$state = "";
 		} else {
-			print encode('UTF-8', "$line\n");
+			say $line;
 		}
 	} elsif ($line =~ /</) {
 		parse_author_name($line);
 	} elsif ($line =~ "(e-mail address removed at contributor's request)") {
 		parse_author_name($line);
 	} else {
-		print encode('UTF-8', "$line\n");
+		say $line;
 	}
 }
-close $author_fh;
 
 print $git_log_text;
 
 open( my $git_author_fh, 'git --no-pager shortlog -se HEAD|')
         or die "Can't execute git shortlog: $!";
 
-while ( my $git_line = decode('UTF-8', <$git_author_fh>) ) {
+while ( my $git_line = <$git_author_fh> ) {
 	chomp $git_line;
 
 	parse_git_name($git_line);
 }
 close $git_author_fh;
 
-print $trailer;
+print "\n\n";
+
+say $acknowledgements_heading;
+
+while ( my $line = <$author_fh> ) {
+	chomp $line;
+	say $line;
+}
+
+close $author_fh;
 
 __END__
