@@ -94,8 +94,8 @@ sub read_repo_info {
 
 	# Tarball produced by 'git archive' will have the $Format string
 	# substituted due to the use of 'export-subst' in .gitattributes.
-	my $git_archive_commit = '4a56d5a2775c868d50697262184b479d4fac0882';
-	my @git_refs = split(/, /, '');
+	my $git_archive_commit = 'c5b983c93a68d14eea00614d5c3b3eb6abc00174';
+	my @git_refs = split(/, /, 'HEAD, tag: v3.7.0, refs/pipelines/536837477');
 	if (substr($git_archive_commit, 0, 1) eq '$') {
 		# If $Format is still present, then this is not a git archive.
 		$git_archive_commit = undef;
@@ -483,8 +483,8 @@ sub update_attributes_asciidoc
 sub update_docinfo_asciidoc
 {
 	my $line;
-	my @paths = ("$src_dir/docbook/wsdg_src/developer-guide-docinfo.xml",
-			"$src_dir/docbook/wsug_src/user-guide-docinfo.xml");
+	my @paths = ("$src_dir/docbook/developer-guide-docinfo.xml",
+			"$src_dir/docbook/user-guide-docinfo.xml");
 
 	foreach my $filepath (@paths) {
 		my $contents = "";
@@ -506,13 +506,13 @@ sub update_docinfo_asciidoc
 	}
 }
 
-# Read debian/changelog, then write back out an updated version.
+# Read packaging/debian/changelog, then write back out an updated version.
 sub update_debian_changelog
 {
 	my $line;
 	my $contents = "";
 	my $version = "";
-	my $filepath = "$src_dir/debian/changelog";
+	my $filepath = "$src_dir/packaging/debian/changelog";
 
 	open(CHANGELOG, "< $filepath") || die "Can't read $filepath!";
 	while ($line = <CHANGELOG>) {
@@ -782,7 +782,7 @@ Print the vcs version to standard output
 
 Set the major, minor, and micro versions in the top-level
 CMakeLists.txt, configure.ac, docbook/attributes.adoc,
-debian/changelog, and the CMakeLists.txt for all libraries
+packaging/debian/changelog, and the CMakeLists.txt for all libraries
 to the provided version number.
 
 =item --set-release, -r
