@@ -17,6 +17,7 @@
 #include <epan/tap.h>
 #include <epan/stat_tap_ui.h>
 #include "globals.h"
+#include <wsutil/ws_assert.h>
 
 #define CALC_TYPE_FRAMES 0
 #define CALC_TYPE_BYTES  1
@@ -115,7 +116,7 @@ iostat_packet(void *arg, packet_info *pinfo, epan_dissect_t *edt, const void *du
     *  struct will be created for it. */
     rt = relative_time;
     while (rt >= it->start_time + parent->interval) {
-        it->next = (io_stat_item_t *)g_malloc(sizeof(io_stat_item_t));
+        it->next = g_new(io_stat_item_t, 1);
         it->next->prev = it;
         it->next->next = NULL;
         it = it->next;
@@ -195,7 +196,7 @@ iostat_packet(void *arg, packet_info *pinfo, epan_dissect_t *edt, const void *du
                      * "Can't happen"; see the checks
                      * in register_io_tap().
                      */
-                    g_assert_not_reached();
+                    ws_assert_not_reached();
                     break;
                 }
             }
@@ -271,7 +272,7 @@ iostat_packet(void *arg, packet_info *pinfo, epan_dissect_t *edt, const void *du
                      * "Can't happen"; see the checks
                      * in register_io_tap().
                      */
-                    g_assert_not_reached();
+                    ws_assert_not_reached();
                     break;
                 }
             }
@@ -340,7 +341,7 @@ iostat_packet(void *arg, packet_info *pinfo, epan_dissect_t *edt, const void *du
                      * "Can't happen"; see the checks
                      * in register_io_tap().
                      */
-                    g_assert_not_reached();
+                    ws_assert_not_reached();
                     break;
                 }
             }
@@ -399,7 +400,7 @@ iostat_packet(void *arg, packet_info *pinfo, epan_dissect_t *edt, const void *du
                      * "Can't happen"; see the checks
                      * in register_io_tap().
                      */
-                    g_assert_not_reached();
+                    ws_assert_not_reached();
                     break;
                 }
             }
@@ -572,7 +573,7 @@ iostat_draw(void *arg)
     mit = (io_stat_item_t *)arg;
     iot = mit->parent;
     num_cols = iot->num_cols;
-    col_w = (column_width *)g_malloc(sizeof(column_width) * num_cols);
+    col_w = g_new(column_width, num_cols);
     fmts = (char **)g_malloc(sizeof(char *) * num_cols);
     duration = ((guint64)cfile.elapsed_time.secs * G_GUINT64_CONSTANT(1000000)) +
                 (guint64)((cfile.elapsed_time.nsecs + 500) / 1000);
@@ -597,7 +598,7 @@ iostat_draw(void *arg)
     dur_nsecs = (int)(duration%G_GUINT64_CONSTANT(1000000));
     dur_nsecs_orig = dur_nsecs;
     dur_mag = magnitude((guint64)dur_secs, 5);
-    g_snprintf(dur_mag_s, 3, "%u", dur_mag);
+    snprintf(dur_mag_s, 3, "%u", dur_mag);
 
     /* Calc the interval's magnitude */
     invl_mag = magnitude(interval/G_GUINT64_CONSTANT(1000000), 5);
@@ -677,7 +678,7 @@ iostat_draw(void *arg)
             fr_mag = MAX(6, fr_mag);
             col_w[j].fr = fr_mag;
             tabrow_w += col_w[j].fr + 3;
-            g_snprintf(fr_mag_s, 3, "%u", fr_mag);
+            snprintf(fr_mag_s, 3, "%u", fr_mag);
 
             if (type == CALC_TYPE_FRAMES) {
                 fmt = g_strconcat(" %", fr_mag_s, "u |", NULL);
@@ -688,8 +689,8 @@ iostat_draw(void *arg)
                 val_mag = MAX(5, val_mag);
                 col_w[j].val = val_mag;
                 tabrow_w += (col_w[j].val + 3);
-                g_snprintf(val_mag_s, 3, "%u", val_mag);
-                fmt = g_strconcat(" %", fr_mag_s, "u |", " %", val_mag_s, G_GINT64_MODIFIER, "u |", NULL);
+                snprintf(val_mag_s, 3, "%u", val_mag);
+                fmt = g_strconcat(" %", fr_mag_s, "u |", " %", val_mag_s, PRIu64 " |", NULL);
             }
             if (fmt)
                 fmts[j] = fmt;
@@ -702,8 +703,8 @@ iostat_draw(void *arg)
             val_mag = magnitude(iot->max_vals[j], 15);
             val_mag = MAX(5, val_mag);
             col_w[j].val = val_mag;
-            g_snprintf(val_mag_s, 3, "%u", val_mag);
-            fmt = g_strconcat(" %", val_mag_s, G_GINT64_MODIFIER, "u |", NULL);
+            snprintf(val_mag_s, 3, "%u", val_mag);
+            fmt = g_strconcat(" %", val_mag_s, PRIu64 " |", NULL);
             break;
 
         default:
@@ -712,7 +713,7 @@ iostat_draw(void *arg)
                 case FT_FLOAT:
                 case FT_DOUBLE:
                     val_mag = magnitude(iot->max_vals[j], 15);
-                    g_snprintf(val_mag_s, 3, "%u", val_mag);
+                    snprintf(val_mag_s, 3, "%u", val_mag);
                     fmt = g_strconcat(" %", val_mag_s, ".6f |", NULL);
                     col_w[j].val = val_mag + 7;
                     break;
@@ -725,7 +726,7 @@ iostat_draw(void *arg)
                         iot->max_vals[j] = (iot->max_vals[j] + G_GUINT64_CONSTANT(500000000)) / NANOSECS_PER_SEC;
                     }
                     val_mag = magnitude(iot->max_vals[j], 15);
-                    g_snprintf(val_mag_s, 3, "%u", val_mag);
+                    snprintf(val_mag_s, 3, "%u", val_mag);
                     fmt = g_strconcat(" %", val_mag_s, "u.%06u |", NULL);
                     col_w[j].val = val_mag + 7;
                    break;
@@ -734,7 +735,7 @@ iostat_draw(void *arg)
                     val_mag = magnitude(iot->max_vals[j], 15);
                     val_mag = MAX(namelen, val_mag);
                     col_w[j].val = val_mag;
-                    g_snprintf(val_mag_s, 3, "%u", val_mag);
+                    snprintf(val_mag_s, 3, "%u", val_mag);
 
                     switch (ftype) {
                     case FT_UINT8:
@@ -742,14 +743,14 @@ iostat_draw(void *arg)
                     case FT_UINT24:
                     case FT_UINT32:
                     case FT_UINT64:
-                        fmt = g_strconcat(" %", val_mag_s, G_GINT64_MODIFIER, "u |", NULL);
+                        fmt = g_strconcat(" %", val_mag_s, PRIu64 " |", NULL);
                         break;
                     case FT_INT8:
                     case FT_INT16:
                     case FT_INT24:
                     case FT_INT32:
                     case FT_INT64:
-                        fmt = g_strconcat(" %", val_mag_s, G_GINT64_MODIFIER, "d |", NULL);
+                        fmt = g_strconcat(" %", val_mag_s, PRId64 " |", NULL);
                         break;
                     }
             } /* End of ftype switch */
@@ -809,7 +810,7 @@ iostat_draw(void *arg)
         spaces_s = &spaces[18 + dur_mag];
         printf(full_fmt, (guint32)(interval/G_GUINT64_CONSTANT(1000000)), spaces_s);
     } else {
-        g_snprintf(invl_prec_s, 3, "%u", invl_prec);
+        snprintf(invl_prec_s, 3, "%u", invl_prec);
         invl_fmt = g_strconcat("%", dur_mag_s, "u.%0", invl_prec_s, "u", NULL);
         full_fmt = g_strconcat("| Duration: ", invl_fmt, " secs%s|\n", NULL);
         spaces_s = &spaces[19 + dur_mag + invl_prec];
@@ -1082,7 +1083,7 @@ iostat_draw(void *arg)
                   int maxw;
                   maxw = dur_mag >= 3 ? dur_mag+1 : 3;
                   g_free(full_fmt);
-                  g_snprintf(dur_mag_s, 3, "%u", maxw);
+                  snprintf(dur_mag_s, 3, "%u", maxw);
                   full_fmt = g_strconcat( dur_mag == 1 ? "|  " : "| ",
                                           invl_fmt, " <> ", "%-",
                                           dur_mag_s, "s|", NULL);
@@ -1423,7 +1424,7 @@ iostat_init(const char *opt_arg, void *userdata _U_)
         break;
     }
 
-    io = (io_stat_t *)g_malloc(sizeof(io_stat_t));
+    io = g_new(io_stat_t, 1);
 
     /* If interval is 0, calculate statistics over the whole file by setting the interval to
     *  G_MAXUINT64 */
@@ -1484,10 +1485,10 @@ iostat_init(const char *opt_arg, void *userdata _U_)
         }
     }
 
-    io->items     = (io_stat_item_t *)g_malloc(sizeof(io_stat_item_t) * io->num_cols);
+    io->items     = g_new(io_stat_item_t, io->num_cols);
     io->filters   = (const char **)g_malloc(sizeof(char *) * io->num_cols);
-    io->max_vals  = (guint64 *)g_malloc(sizeof(guint64) * io->num_cols);
-    io->max_frame = (guint32 *)g_malloc(sizeof(guint32) * io->num_cols);
+    io->max_vals  = g_new(guint64, io->num_cols);
+    io->max_frame = g_new(guint32, io->num_cols);
 
     for (i=0; i<io->num_cols; i++) {
         io->max_vals[i]  = 0;
@@ -1514,7 +1515,7 @@ iostat_init(const char *opt_arg, void *userdata _U_)
                     register_io_tap(io, i, NULL);
             } else {
                 filter = (gchar *)g_malloc((pos-str)+1);
-                g_strlcpy( filter, str, (gsize) ((pos-str)+1));
+                (void) g_strlcpy( filter, str, (gsize) ((pos-str)+1));
                 filter = g_strstrip(filter);
                 register_io_tap(io, i, (char *) filter);
             }
@@ -1538,16 +1539,3 @@ register_tap_listener_iostat(void)
 {
     register_stat_tap_ui(&iostat_ui, NULL);
 }
-
-/*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
- *
- * Local variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * vi: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
