@@ -25,6 +25,8 @@
 #include <epan/stat_tap_ui.h>
 #include <epan/dissectors/packet-rpc.h>
 
+#include <ui/cmdarg_err.h>
+
 #define MICROSECS_PER_SEC   1000000
 #define NANOSECS_PER_SEC    1000000000
 
@@ -44,7 +46,7 @@ typedef struct _rpc_program_t {
 static rpc_program_t *prog_list = NULL;
 static int already_enabled = 0;
 
-static int
+static tap_packet_status
 rpcprogs_packet(void *dummy1 _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const void *pri)
 {
 	const rpc_call_info_value *ri = (const rpc_call_info_value *)pri;
@@ -118,7 +120,7 @@ rpcprogs_packet(void *dummy1 _U_, packet_info *pinfo, epan_dissect_t *edt _U_, c
 
 	/* we are only interested in reply packets */
 	if (ri->request || !rp) {
-		return 0;
+		return TAP_PACKET_DONT_REDRAW;
 	}
 
 	/* calculate time delta between request and reply */
@@ -158,7 +160,7 @@ rpcprogs_packet(void *dummy1 _U_, packet_info *pinfo, epan_dissect_t *edt _U_, c
 	}
 	rp->num++;
 
-	return 1;
+	return TAP_PACKET_REDRAW;
 }
 
 
@@ -182,8 +184,8 @@ rpcprogs_draw(void *dummy _U_)
 		td = ((guint64)(rp->tot.secs)) * NANOSECS_PER_SEC + rp->tot.nsecs;
 		td = ((td / rp->num) + 500) / 1000;
 
-		g_snprintf(str, sizeof(str), "%s(%d)", rpc_prog_name(rp->program), rp->program);
-		printf("%-15s %2u %6d %3d.%06d %3d.%06d %3" G_GINT64_MODIFIER "u.%06" G_GINT64_MODIFIER "u\n",
+		snprintf(str, sizeof(str), "%s(%d)", rpc_prog_name(rp->program), rp->program);
+		printf("%-15s %2u %6d %3d.%06d %3d.%06d %3" PRIu64 ".%06" PRIu64 "\n",
 		       str,
 		       rp->version,
 		       rp->num,
@@ -208,7 +210,7 @@ rpcprogs_init(const char *opt_arg _U_, void *userdata _U_)
 
 	error_string = register_tap_listener("rpc", NULL, NULL, 0, NULL, rpcprogs_packet, rpcprogs_draw, NULL);
 	if (error_string) {
-		fprintf(stderr, "tshark: Couldn't register rpc,programs tap: %s\n",
+		cmdarg_err("Couldn't register rpc,programs tap: %s",
 			error_string->str);
 		g_string_free(error_string, TRUE);
 		exit(1);
@@ -231,7 +233,7 @@ register_tap_listener_rpcprogs(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
