@@ -12,7 +12,7 @@
 #include "about_dialog.h"
 #include <ui_about_dialog.h>
 
-#include "wireshark_application.h"
+#include "main_application.h"
 #include <wsutil/filesystem.h>
 
 #include <QDesktopServices>
@@ -23,13 +23,12 @@
 #endif
 
 #include <epan/maxmind_db.h>
+#include <epan/prefs.h>
 
 #ifdef HAVE_LUA
 #include <epan/wslua/init_wslua.h>
 #endif
 
-#include "log.h"
-
 #include "ui/alert_box.h"
 #include "ui/last_open_dir.h"
 #include "ui/help_url.h"
@@ -40,7 +39,8 @@
 #include "wsutil/tempfile.h"
 #include "wsutil/plugins.h"
 #include "wsutil/copyright_info.h"
-#include "version_info.h"
+#include "ui/version_info.h"
+#include "ui/capture_globals.h"
 
 #include "extcap.h"
 
@@ -55,7 +55,7 @@
 #include <QKeySequence>
 #include <QTextStream>
 #include <QUrl>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QAbstractItemModel>
 #include <QHash>
 #include <QDesktopServices>
@@ -73,9 +73,13 @@ AStringListListModel(parent)
     f_authors.setFileName(get_datafile_path("AUTHORS-SHORT"));
     f_authors.open(QFile::ReadOnly | QFile::Text);
     QTextStream ReadFile_authors(&f_authors);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    ReadFile_authors.setEncoding(QStringConverter::Utf8);
+#else
     ReadFile_authors.setCodec("UTF-8");
+#endif
 
-    QRegExp rx("(.*)[<(]([\\s'a-zA-Z0-9._%+-]+(\\[[Aa][Tt]\\])?[a-zA-Z0-9._%+-]+)[>)]");
+    QRegularExpression rx("(.*)[<(]([\\s'a-zA-Z0-9._%+-]+(\\[[Aa][Tt]\\])?[a-zA-Z0-9._%+-]+)[>)]");
     acknowledgement_.clear();
     while (!ReadFile_authors.atEnd()) {
         QString line = ReadFile_authors.readLine();
@@ -85,13 +89,14 @@ AStringListListModel(parent)
         if (line.startsWith("------"))
             continue;
 
-        if (line.contains("Acknowledgements"))
-        {
+        if (line.contains("Acknowledgements")) {
             readAck = true;
             continue;
+        } else {
+            QRegularExpressionMatch match = rx.match(line);
+            if (match.hasMatch())
+                appendRow(QStringList() << match.captured(1).trimmed() << match.captured(2).trimmed());
         }
-        else if (rx.indexIn(line) != -1)
-            appendRow(QStringList() << rx.cap(1).trimmed() << rx.cap(2).trimmed());
 
         if (readAck && (!line.isEmpty() || !acknowledgement_.isEmpty()))
             acknowledgement_.append(QString("%1\n").arg(line));
@@ -160,7 +165,7 @@ ShortcutListModel::ShortcutListModel(QObject * parent):
         AStringListListModel(parent)
 {
     QMap<QString, QPair<QString, QString> > shortcuts; // name -> (shortcut, description)
-    foreach (const QWidget *child, wsApp->mainWindow()->findChildren<QWidget *>()) {
+    foreach (const QWidget *child, mainApp->mainWindow()->findChildren<QWidget *>()) {
         // Recent items look funny here.
         if (child->objectName().compare("menuOpenRecentCaptureFile") == 0) continue;
         foreach (const QAction *action, child->actions()) {
@@ -194,18 +199,18 @@ FolderListModel::FolderListModel(QObject * parent):
     appendRow(QStringList() << tr("\"File\" dialogs") << get_last_open_dir() << tr("capture files"));
 
     /* temp */
-    appendRow(QStringList() << tr("Temp") << g_get_tmp_dir() << tr("untitled capture files"));
+    appendRow(QStringList() << tr("Temp") << (global_capture_opts.temp_dir && global_capture_opts.temp_dir[0] ? global_capture_opts.temp_dir : g_get_tmp_dir()) << tr("untitled capture files"));
 
     /* pers conf */
     appendRow(QStringList() << tr("Personal configuration")
             << gchar_free_to_qstring(get_persconffile_path("", FALSE))
-            << tr("dfilters, preferences, ethers, " UTF8_HORIZONTAL_ELLIPSIS));
+            << tr("dfilters, preferences, ethers, …"));
 
     /* global conf */
     QString dirPath = get_datafile_dir();
     if (! dirPath.isEmpty()) {
         appendRow (QStringList() << tr("Global configuration") << dirPath
-                << tr("dfilters, preferences, manuf, " UTF8_HORIZONTAL_ELLIPSIS));
+                << tr("dfilters, preferences, manuf, …"));
     }
 
     /* system */
@@ -252,7 +257,7 @@ FolderListModel::FolderListModel(QObject * parent):
 
 #ifdef Q_OS_MAC
     /* Mac Extras */
-    QString extras_path = wsApp->applicationDirPath() + "/../Resources/Extras";
+    QString extras_path = mainApp->applicationDirPath() + "/../Resources/Extras";
     appendRow(QStringList() << tr("macOS Extras") << QDir::cleanPath(extras_path) << tr("Extra macOS packages"));
 
 #endif
@@ -287,8 +292,8 @@ AboutDialog::AboutDialog(QWidget *parent) :
     ui->pte_Authors->moveCursor(QTextCursor::Start);
 
     ui->tblAuthors->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(ui->tblAuthors, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(handleCopyMenu(QPoint)));
-    connect(ui->searchAuthors, SIGNAL(textChanged(QString)), proxyAuthorModel, SLOT(setFilter(QString)));
+    connect(ui->tblAuthors, &QTreeView::customContextMenuRequested, this, &AboutDialog::handleCopyMenu);
+    connect(ui->searchAuthors, &QLineEdit::textChanged, proxyAuthorModel, &AStringListListSortFilterProxyModel::setFilter);
 
     /* Wireshark tab */
     updateWiresharkText();
@@ -315,9 +320,11 @@ AboutDialog::AboutDialog(QWidget *parent) :
     ui->tblFolders->setItemDelegateForColumn(1, new UrlLinkDelegate(this));
     ui->tblFolders->setContextMenuPolicy(Qt::CustomContextMenu);
     ui->tblFolders->setTextElideMode(Qt::ElideMiddle);
-    connect(ui->tblFolders, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(handleCopyMenu(QPoint)));
-    connect(ui->searchFolders, SIGNAL(textChanged(QString)), folderProxyModel, SLOT(setFilter(QString)));
-    connect(ui->tblFolders, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(urlDoubleClicked(QModelIndex)));
+    ui->tblFolders->setSortingEnabled(true);
+    ui->tblFolders->sortByColumn(0, Qt::AscendingOrder);
+    connect(ui->tblFolders, &QTreeView::customContextMenuRequested, this, &AboutDialog::handleCopyMenu);
+    connect(ui->searchFolders, &QLineEdit::textChanged, folderProxyModel, &AStringListListSortFilterProxyModel::setFilter);
+    connect(ui->tblFolders, &QTreeView::doubleClicked, this, &AboutDialog::urlDoubleClicked);
 
 
     /* Plugins */
@@ -338,9 +345,11 @@ AboutDialog::AboutDialog(QWidget *parent) :
     ui->cmbType->addItems(pluginModel->typeNames());
     ui->tblPlugins->setContextMenuPolicy(Qt::CustomContextMenu);
     ui->tblPlugins->setTextElideMode(Qt::ElideMiddle);
-    connect(ui->tblPlugins, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(handleCopyMenu(QPoint)));
-    connect(ui->searchPlugins, SIGNAL(textChanged(QString)), pluginFilterModel, SLOT(setFilter(QString)));
-    connect(ui->cmbType, SIGNAL(currentIndexChanged(QString)), pluginTypeModel, SLOT(setFilter(QString)));
+    ui->tblPlugins->setSortingEnabled(true);
+    ui->tblPlugins->sortByColumn(0, Qt::AscendingOrder);
+    connect(ui->tblPlugins, &QTreeView::customContextMenuRequested, this, &AboutDialog::handleCopyMenu);
+    connect(ui->searchPlugins, &QLineEdit::textChanged, pluginFilterModel, &AStringListListSortFilterProxyModel::setFilter);
+    connect(ui->cmbType, &QComboBox::currentTextChanged, pluginTypeModel, &AStringListListSortFilterProxyModel::setFilter);
     if (ui->tblPlugins->model()->rowCount() < 1) {
         foreach (QWidget *w, ui->tab_plugins->findChildren<QWidget *>()) {
             w->hide();
@@ -360,8 +369,10 @@ AboutDialog::AboutDialog(QWidget *parent) :
     ui->tblShortcuts->setModel(shortcutProxyModel);
     ui->tblShortcuts->setRootIsDecorated(false);
     ui->tblShortcuts->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(ui->tblShortcuts, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(handleCopyMenu(QPoint)));
-    connect(ui->searchShortcuts, SIGNAL(textChanged(QString)), shortcutProxyModel, SLOT(setFilter(QString)));
+    ui->tblShortcuts->setSortingEnabled(true);
+    ui->tblShortcuts->sortByColumn(1, Qt::AscendingOrder);
+    connect(ui->tblShortcuts, &QTreeView::customContextMenuRequested, this, &AboutDialog::handleCopyMenu);
+    connect(ui->searchShortcuts, &QLineEdit::textChanged, shortcutProxyModel, &AStringListListSortFilterProxyModel::setFilter);
 
     /* License */
 #if defined(_WIN32)
@@ -431,9 +442,8 @@ void AboutDialog::updateWiresharkText()
 {
     QString vcs_version_info_str = get_ws_vcs_version_info();
     QString copyright_info_str = get_copyright_info();
-    QString comp_info_str = gstring_free_to_qbytearray(get_compiled_version_info(get_wireshark_qt_compiled_info,
-                                              get_gui_compiled_info));
-    QString runtime_info_str = gstring_free_to_qbytearray(get_runtime_version_info(get_wireshark_runtime_info));
+    QString comp_info_str = gstring_free_to_qbytearray(get_compiled_version_info(gather_wireshark_qt_compiled_info));
+    QString runtime_info_str = gstring_free_to_qbytearray(get_runtime_version_info(gather_wireshark_runtime_info));
 
     QString message = ColorUtils::themeLinkStyle();
 
@@ -451,9 +461,8 @@ void AboutDialog::updateWiresharkText()
     /* Save the info for the clipboard copy */
     clipboardInfo = "";
     clipboardInfo += vcs_version_info_str + "\n\n";
-    clipboardInfo += gstring_free_to_qbytearray(get_compiled_version_info(get_wireshark_qt_compiled_info,
-                                                                          get_gui_compiled_info)) + "\n";
-    clipboardInfo += gstring_free_to_qbytearray(get_runtime_version_info(get_wireshark_runtime_info));
+    clipboardInfo += gstring_free_to_qbytearray(get_compiled_version_info(gather_wireshark_qt_compiled_info)) + "\n";
+    clipboardInfo += gstring_free_to_qbytearray(get_runtime_version_info(gather_wireshark_runtime_info));
 }
 
 void AboutDialog::on_copyToClipboard_clicked()
@@ -517,17 +526,17 @@ void AboutDialog::handleCopyMenu(QPoint pos)
 #endif
         QAction * showInFolderAction = menu->addAction(show_in_str);
         showInFolderAction->setData(VariantPointer<QTreeView>::asQVariant(tree));
-        connect(showInFolderAction, SIGNAL(triggered()), this, SLOT(showInFolderActionTriggered()));
+        connect(showInFolderAction, &QAction::triggered, this, &AboutDialog::showInFolderActionTriggered);
     }
 
     QAction * copyColumnAction = menu->addAction(tr("Copy"));
     copyColumnAction->setData(VariantPointer<QTreeView>::asQVariant(tree));
-    connect(copyColumnAction, SIGNAL(triggered()), this, SLOT(copyActionTriggered()));
+    connect(copyColumnAction, &QAction::triggered, this, &AboutDialog::copyActionTriggered);
 
     QModelIndexList selectedRows = tree->selectionModel()->selectedRows();
-    QAction * copyRowAction = menu->addAction(tr("Copy Row(s)", "", selectedRows.count()));
+    QAction * copyRowAction = menu->addAction(tr("Copy Row(s)", "", static_cast<int>(selectedRows.count())));
     copyRowAction->setData(VariantPointer<QTreeView>::asQVariant(tree));
-    connect(copyRowAction, SIGNAL(triggered()), this, SLOT(copyRowActionTriggered()));
+    connect(copyRowAction, &QAction::triggered, this, &AboutDialog::copyRowActionTriggered);
 
     menu->popup(tree->viewport()->mapToGlobal(pos));
 }
@@ -622,20 +631,7 @@ void AboutDialog::on_tblPlugins_doubleClicked(const QModelIndex &index)
     }
     const int row = index.row();
     const QAbstractItemModel *model = index.model();
-    if (model->index(row, path_col).data().toString().contains(QRegExp(script_pattern))) {
+    if (model->index(row, path_col).data().toString().contains(QRegularExpression(script_pattern))) {
         QDesktopServices::openUrl(QUrl::fromLocalFile(model->index(row, path_col).data().toString()));
     }
 }
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
