@@ -110,12 +110,12 @@ BluetoothDevicesDialog::~BluetoothDevicesDialog()
 }
 
 
-void BluetoothDevicesDialog::captureFileClosing()
+void BluetoothDevicesDialog::captureFileClosed()
 {
     ui->interfaceComboBox->setEnabled(FALSE);
     ui->showInformationStepsCheckBox->setEnabled(FALSE);
 
-    WiresharkDialog::captureFileClosing();
+    WiresharkDialog::captureFileClosed();
 }
 
 
@@ -274,7 +274,7 @@ tap_packet_status BluetoothDevicesDialog::tapPacket(void *tapinfo_ptr, packet_in
         const char  *interface_name;
 
         interface_name = epan_get_interface_name(pinfo->epan, pinfo->rec->rec_header.packet_header.interface_id);
-        interface = wmem_strdup_printf(wmem_packet_scope(), "%u: %s", pinfo->rec->rec_header.packet_header.interface_id, interface_name);
+        interface = wmem_strdup_printf(pinfo->pool, "%u: %s", pinfo->rec->rec_header.packet_header.interface_id, interface_name);
 
         if (dialog->ui->interfaceComboBox->findText(interface) == -1)
             dialog->ui->interfaceComboBox->addItem(interface);
@@ -286,14 +286,16 @@ tap_packet_status BluetoothDevicesDialog::tapPacket(void *tapinfo_ptr, packet_in
     }
 
     if (tap_device->has_bd_addr) {
-        bd_addr.sprintf("%02x:%02x:%02x:%02x:%02x:%02x", tap_device->bd_addr[0], tap_device->bd_addr[1], tap_device->bd_addr[2], tap_device->bd_addr[3], tap_device->bd_addr[4], tap_device->bd_addr[5]);
-
+        for (int i = 0; i < 6; ++i) {
+            bd_addr += QString("%1:").arg(tap_device->bd_addr[i], 2, 16, QChar('0'));
+        }
+        bd_addr.chop(1); // remove extra character ":" from the end of the string
         manuf = get_ether_name(tap_device->bd_addr);
         if (manuf) {
             int pos;
 
             bd_addr_oui = QString(manuf);
-            pos = bd_addr_oui.indexOf('_');
+            pos = static_cast<int>(bd_addr_oui.indexOf('_'));
             if (pos < 0) {
                 manuf = NULL;
             } else {
@@ -353,14 +355,14 @@ tap_packet_status BluetoothDevicesDialog::tapPacket(void *tapinfo_ptr, packet_in
 
     if (tap_device->type == BLUETOOTH_DEVICE_LOCAL_VERSION) {
         item->setText(column_number_hci_version,    val_to_str_const(tap_device->data.local_version.hci_version, bthci_evt_hci_version, "Unknown 0x%02x"));
-        item->setText(column_number_hci_revision,   QString("").sprintf("%u", tap_device->data.local_version.hci_revision));
+        item->setText(column_number_hci_revision,   QString::number(tap_device->data.local_version.hci_revision));
         item->setText(column_number_lmp_version,    val_to_str_const(tap_device->data.local_version.lmp_version, bthci_evt_lmp_version, "Unknown 0x%02x"));
-        item->setText(column_number_lmp_subversion, QString("").sprintf("%u", tap_device->data.local_version.lmp_subversion));
+        item->setText(column_number_lmp_subversion, QString::number(tap_device->data.local_version.lmp_subversion));
         item->setText(column_number_manufacturer,   val_to_str_ext_const(tap_device->data.local_version.manufacturer, &bluetooth_company_id_vals_ext, "Unknown 0x%04x"));
     }
     if (tap_device->type == BLUETOOTH_DEVICE_REMOTE_VERSION) {
         item->setText(column_number_lmp_version,    val_to_str_const(tap_device->data.remote_version.lmp_version, bthci_evt_lmp_version, "Unknown 0x%02x"));
-        item->setText(column_number_lmp_subversion, QString("").sprintf("%u", tap_device->data.remote_version.lmp_subversion));
+        item->setText(column_number_lmp_subversion, QString::number(tap_device->data.remote_version.lmp_subversion));
         item->setText(column_number_manufacturer,   val_to_str_ext_const(tap_device->data.remote_version.manufacturer, &bluetooth_company_id_vals_ext, "Unknown 0x%04x"));
     }
 
@@ -451,16 +453,3 @@ void BluetoothDevicesDialog::on_buttonBox_clicked(QAbstractButton *)
 {
 /*    if (button == foo_button_) */
 }
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
