@@ -10,6 +10,7 @@
 #include "conversation_dialog.h"
 
 #include <epan/prefs.h>
+#include <epan/to_str.h>
 #include <epan/dissectors/packet-tcp.h>
 
 #include "ui/recent.h"
@@ -20,7 +21,7 @@
 
 #include <ui/qt/utils/qt_ui_utils.h>
 #include <ui/qt/models/timeline_delegate.h>
-#include "wireshark_application.h"
+#include "main_application.h"
 
 #include <QCheckBox>
 #include <QDateTime>
@@ -64,7 +65,7 @@ ConversationDialog::ConversationDialog(QWidget &parent, CaptureFile &cf, int cli
     graph_bt_->setToolTip(tr("Graph a TCP conversation."));
     connect(graph_bt_, SIGNAL(clicked()), this, SLOT(graphTcp()));
 
-    connect(wsApp->mainWindow(), SIGNAL(displayFilterSuccess(bool)),
+    connect(mainApp->mainWindow(), SIGNAL(displayFilterSuccess(bool)),
             this, SLOT(displayFilterSuccess(bool)));
 
     absoluteTimeCheckBox()->show();
@@ -306,7 +307,7 @@ void ConversationDialog::on_displayFilterCheckBox_toggled(bool checked)
 
 void ConversationDialog::on_buttonBox_helpRequested()
 {
-    wsApp->helpTopicAction(HELP_STATS_CONVERSATIONS_DIALOG);
+    mainApp->helpTopicAction(HELP_STATS_CONVERSATIONS_DIALOG);
 }
 
 void ConversationDialog::displayFilterSuccess(bool success)
@@ -323,7 +324,7 @@ void ConversationDialog::displayFilterSuccess(bool success)
 
 void init_conversation_table(struct register_ct* ct, const char *filter)
 {
-    wsApp->emitStatCommandSignal("Conversations", filter, GINT_TO_POINTER(get_conversation_proto_id(ct)));
+    mainApp->emitStatCommandSignal("Conversations", filter, GINT_TO_POINTER(get_conversation_proto_id(ct)));
 }
 
 
@@ -369,15 +370,15 @@ public:
             case CONV_COLUMN_PACKETS:
                 return QString("%L1").arg(conv_item->tx_frames + conv_item->rx_frames);
             case CONV_COLUMN_BYTES:
-                return gchar_free_to_qstring(format_size(conv_item->tx_bytes + conv_item->rx_bytes, format_size_unit_none|format_size_prefix_si));
+                return gchar_free_to_qstring(format_size(conv_item->tx_bytes + conv_item->rx_bytes, FORMAT_SIZE_UNIT_NONE, FORMAT_SIZE_PREFIX_SI));
             case CONV_COLUMN_PKT_AB:
                 return QString("%L1").arg(conv_item->tx_frames);
             case CONV_COLUMN_BYTES_AB:
-                return gchar_free_to_qstring(format_size(conv_item->tx_bytes, format_size_unit_none|format_size_prefix_si));
+                return gchar_free_to_qstring(format_size(conv_item->tx_bytes, FORMAT_SIZE_UNIT_NONE, FORMAT_SIZE_PREFIX_SI));
             case CONV_COLUMN_PKT_BA:
                 return QString("%L1").arg(conv_item->rx_frames);
             case CONV_COLUMN_BYTES_BA:
-                return gchar_free_to_qstring(format_size(conv_item->rx_bytes, format_size_unit_none|format_size_prefix_si));
+                return gchar_free_to_qstring(format_size(conv_item->rx_bytes, FORMAT_SIZE_UNIT_NONE, FORMAT_SIZE_PREFIX_SI));
             case CONV_COLUMN_START:
             {
                 bool use_ns = treeWidget()->window()->property("nanosecond_precision").toBool();
@@ -406,12 +407,12 @@ public:
             }
             case CONV_COLUMN_BPS_AB:
                 if (duration > min_bw_calc_duration_) {
-                    bps_ab = gchar_free_to_qstring(format_size((gint64) conv_item->tx_bytes * 8 / duration, format_size_unit_none|format_size_prefix_si));
+                    bps_ab = gchar_free_to_qstring(format_size((gint64) conv_item->tx_bytes * 8 / duration, FORMAT_SIZE_UNIT_NONE, FORMAT_SIZE_PREFIX_SI));
                 }
                 return bps_ab;
             case CONV_COLUMN_BPS_BA:
                 if (duration > min_bw_calc_duration_) {
-                    bps_ba = gchar_free_to_qstring(format_size((gint64) conv_item->rx_bytes * 8 / duration, format_size_unit_none|format_size_prefix_si));
+                    bps_ba = gchar_free_to_qstring(format_size((gint64) conv_item->rx_bytes * 8 / duration, FORMAT_SIZE_UNIT_NONE, FORMAT_SIZE_PREFIX_SI));
                 }
                 return bps_ba;
             default:
@@ -528,17 +529,42 @@ public:
         conv_item_t *conv_item = &g_array_index(conv_array_, conv_item_t, conv_idx_);
         conv_item_t *other_item = &g_array_index(other_row->conv_array_, conv_item_t, other_row->conv_idx_);
 
+        bool resolve_names = false;
+        if (resolve_names_ptr_ && *resolve_names_ptr_) resolve_names = true;
+
         int sort_col = treeWidget()->sortColumn();
         double conv_duration = nstime_to_sec(&conv_item->stop_time) - nstime_to_sec(&conv_item->start_time);
         double other_duration = nstime_to_sec(&other_item->stop_time) - nstime_to_sec(&other_item->start_time);
 
         switch(sort_col) {
         case CONV_COLUMN_SRC_ADDR:
-            return cmp_address(&conv_item->src_address, &other_item->src_address) < 0 ? true : false;
+            if (resolve_names) {
+                char* addr_str = address_to_display(NULL, &conv_item->src_address);
+                char* otheraddr_str = address_to_display(NULL, &other_item->src_address);
+                bool ret;
+
+                ret = g_ascii_strcasecmp(addr_str, otheraddr_str) < 0 ? true : false;
+                wmem_free(NULL, otheraddr_str);
+                wmem_free(NULL, addr_str);
+                return ret;
+	    } else {
+                return cmp_address(&conv_item->src_address, &other_item->src_address) < 0 ? true : false;
+            }
         case CONV_COLUMN_SRC_PORT:
             return conv_item->src_port < other_item->src_port;
         case CONV_COLUMN_DST_ADDR:
-            return cmp_address(&conv_item->dst_address, &other_item->dst_address) < 0 ? true : false;
+            if (resolve_names) {
+                char* addr_str = address_to_display(NULL, &conv_item->dst_address);
+                char* otheraddr_str = address_to_display(NULL, &other_item->dst_address);
+                bool ret;
+
+                ret = g_ascii_strcasecmp(addr_str, otheraddr_str) < 0 ? true : false;
+                wmem_free(NULL, otheraddr_str);
+                wmem_free(NULL, addr_str);
+                return ret;
+	    } else {
+                return cmp_address(&conv_item->dst_address, &other_item->dst_address) < 0 ? true : false;
+            }
         case CONV_COLUMN_DST_PORT:
             return conv_item->dst_port < other_item->dst_port;
         case CONV_COLUMN_PACKETS:
