@@ -12,6 +12,7 @@
 #include <epan/maxmind_db.h>
 
 #include <epan/prefs.h>
+#include <epan/to_str.h>
 
 #include "ui/recent.h"
 #include "ui/traffic_table_ui.h"
@@ -24,7 +25,7 @@
 #include <ui/qt/utils/qt_ui_utils.h>
 #include <ui/qt/utils/variant_pointer.h>
 #include <ui/qt/widgets/wireshark_file_dialog.h>
-#include "wireshark_application.h"
+#include "main_application.h"
 
 #include <QCheckBox>
 #include <QDesktopServices>
@@ -117,9 +118,14 @@ void EndpointDialog::captureFileClosing()
         disconnect(cur_tree, SIGNAL(filterAction(QString,FilterAction::Action,FilterAction::ActionType)),
                    this, SIGNAL(filterAction(QString,FilterAction::Action,FilterAction::ActionType)));
     }
+    TrafficTableDialog::captureFileClosing();
+}
+
+void EndpointDialog::captureFileClosed()
+{
     displayFilterCheckBox()->setEnabled(false);
     enabledTypesPushButton()->setEnabled(false);
-    TrafficTableDialog::captureFileClosing();
+    TrafficTableDialog::captureFileClosed();
 }
 
 bool EndpointDialog::addTrafficTable(register_ct_t *table)
@@ -288,12 +294,12 @@ void EndpointDialog::saveMap()
 
 void EndpointDialog::on_buttonBox_helpRequested()
 {
-    wsApp->helpTopicAction(HELP_STATS_ENDPOINTS_DIALOG);
+    mainApp->helpTopicAction(HELP_STATS_ENDPOINTS_DIALOG);
 }
 
 void init_endpoint_table(struct register_ct* ct, const char *filter)
 {
-    wsApp->emitStatCommandSignal("Endpoints", filter, GINT_TO_POINTER(get_conversation_proto_id(ct)));
+    mainApp->emitStatCommandSignal("Endpoints", filter, GINT_TO_POINTER(get_conversation_proto_id(ct)));
 }
 
 // EndpointTreeWidgetItem
@@ -326,15 +332,15 @@ public:
             case ENDP_COLUMN_PACKETS:
                 return QString("%L1").arg(endp_item->tx_frames + endp_item->rx_frames);
             case ENDP_COLUMN_BYTES:
-                return gchar_free_to_qstring(format_size(endp_item->tx_bytes + endp_item->rx_bytes, format_size_unit_none|format_size_prefix_si));
+                return gchar_free_to_qstring(format_size(endp_item->tx_bytes + endp_item->rx_bytes, FORMAT_SIZE_UNIT_NONE, FORMAT_SIZE_PREFIX_SI));
             case ENDP_COLUMN_PKT_AB:
                 return QString("%L1").arg(endp_item->tx_frames);
             case ENDP_COLUMN_BYTES_AB:
-                return gchar_free_to_qstring(format_size(endp_item->tx_bytes, format_size_unit_none|format_size_prefix_si));
+                return gchar_free_to_qstring(format_size(endp_item->tx_bytes, FORMAT_SIZE_UNIT_NONE, FORMAT_SIZE_PREFIX_SI));
             case ENDP_COLUMN_PKT_BA:
                 return QString("%L1").arg(endp_item->rx_frames);
             case ENDP_COLUMN_BYTES_BA:
-                return gchar_free_to_qstring(format_size(endp_item->rx_bytes, format_size_unit_none|format_size_prefix_si));
+                return gchar_free_to_qstring(format_size(endp_item->rx_bytes, FORMAT_SIZE_UNIT_NONE, FORMAT_SIZE_PREFIX_SI));
             default:
                 QVariant col_data = colData(column, resolve_names);
                 if (col_data.isValid()) return col_data;
@@ -429,11 +435,25 @@ public:
         hostlist_talker_t *endp_item = &g_array_index(conv_array_, hostlist_talker_t, conv_idx_);
         hostlist_talker_t *other_item = &g_array_index(other_row->conv_array_, hostlist_talker_t, other_row->conv_idx_);
 
+        bool resolve_names = false;
+        if (resolve_names_ptr_ && *resolve_names_ptr_) resolve_names = true;
+
         int sort_col = treeWidget()->sortColumn();
 
         switch(sort_col) {
         case ENDP_COLUMN_ADDR:
-            return cmp_address(&endp_item->myaddress, &other_item->myaddress) < 0 ? true : false;
+            if (resolve_names) {
+                char* addr_str = address_to_display(NULL, &endp_item->myaddress);
+                char* otheraddr_str = address_to_display(NULL, &other_item->myaddress);
+                bool ret;
+
+                ret = g_ascii_strcasecmp(addr_str, otheraddr_str) < 0 ? true : false;
+                wmem_free(NULL, otheraddr_str);
+                wmem_free(NULL, addr_str);
+                return ret;
+	    } else {
+                return cmp_address(&endp_item->myaddress, &other_item->myaddress) < 0 ? true : false;
+            }
         case ENDP_COLUMN_PORT:
             return endp_item->port < other_item->port;
         case ENDP_COLUMN_PACKETS:
@@ -662,16 +682,3 @@ void EndpointTreeWidget::filterActionTriggered()
     QString filter = get_hostlist_filter(endp_item);
     emit filterAction(filter, fa->action(), fa->actionType());
 }
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
