@@ -1,4 +1,4 @@
-/* endpoint_dialog.h
+/** @file
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -59,8 +59,9 @@ public:
 
 signals:
 
-public slots:
+protected:
     void captureFileClosing();
+    void captureFileClosed();
 
 private:
 #ifdef HAVE_MAXMINDDB
@@ -82,16 +83,3 @@ private slots:
 void init_endpoint_table(struct register_ct* ct, const char *filter);
 
 #endif // ENDPOINT_DIALOG_H
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
