@@ -1,10 +1,11 @@
-/* expert_info_dialog.h
+/** @file
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * SPDX-License-Identifier: GPL-2.0-or-later*/
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #ifndef EXPERT_INFO_DIALOG_H
 #define EXPERT_INFO_DIALOG_H
@@ -53,7 +54,7 @@ private:
 
 private slots:
     void retapPackets();
-    void captureEvent(CaptureEvent *e);
+    void captureEvent(CaptureEvent e);
 
     void updateWidgets();
 
@@ -75,16 +76,3 @@ private slots:
 };
 
 #endif // EXPERT_INFO_DIALOG_H
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
