@@ -31,7 +31,7 @@
 #endif // Q_OS_WIN
 
 #include <epan/prefs.h>
-#include "wireshark_application.h"
+#include "main_application.h"
 
 #if !defined(Q_OS_WIN)
 static const QStringList export_extensions = QStringList()
@@ -56,7 +56,7 @@ ExportDissectionDialog::ExportDissectionDialog(QWidget *parent, capture_file *ca
     , sel_range_(selRange)
 #endif /* Q_OS_WIN */
 {
-    setWindowTitle(wsApp->windowTitleString(tr("Export Packet Dissections")));
+    setWindowTitle(mainApp->windowTitleString(tr("Export Packet Dissections")));
 
     switch (prefs.gui_fileopen_style) {
 
@@ -67,7 +67,7 @@ ExportDissectionDialog::ExportDissectionDialog(QWidget *parent, capture_file *ca
          * use the "last opened" directory saved in the preferences file if
          * there was one.
          */
-        setDirectory(wsApp->lastOpenDir());
+        setDirectory(mainApp->lastOpenDir());
         break;
 
     case FO_STYLE_SPECIFIED:
@@ -81,10 +81,10 @@ ExportDissectionDialog::ExportDissectionDialog(QWidget *parent, capture_file *ca
     }
 
 #if !defined(Q_OS_WIN)
+    QDialogButtonBox *button_box = findChild<QDialogButtonBox *>();
     // Add extra widgets
     // https://wiki.qt.io/Qt_project_org_faq#How_can_I_add_widgets_to_my_QFileDialog_instance.3F
     setOption(QFileDialog::DontUseNativeDialog, true);
-    QDialogButtonBox *button_box = findChild<QDialogButtonBox *>();
     QGridLayout *fd_grid = qobject_cast<QGridLayout*>(layout());
     QHBoxLayout *h_box = new QHBoxLayout();
     QStringList name_filters;
@@ -201,6 +201,7 @@ void ExportDissectionDialog::dialogAccepted()
                     print_args_.print_dissections = print_dissections_expanded;
             }
             print_args_.print_hex = packet_format_group_box_.bytesEnabled();
+            print_args_.hexdump_options = packet_format_group_box_.getHexdumpOptions();
             print_args_.stream = print_stream_text_new(TRUE, print_args_.file);
             if (print_args_.stream == NULL) {
                 open_failure_alert_box(print_args_.file, errno, TRUE);
@@ -283,6 +284,6 @@ void ExportDissectionDialog::checkValidity()
 
 void ExportDissectionDialog::on_buttonBox_helpRequested()
 {
-    wsApp->helpTopicAction(HELP_EXPORT_FILE_DIALOG);
+    mainApp->helpTopicAction(HELP_EXPORT_FILE_DIALOG);
 }
 #endif // Q_OS_WIN
