@@ -14,7 +14,7 @@
 #include "interface_toolbar.h"
 #include <ui/qt/widgets/interface_toolbar_lineedit.h>
 #include "simple_dialog.h"
-#include "wireshark_application.h"
+#include "main_application.h"
 #include <ui_interface_toolbar.h>
 
 #include "capture_opts.h"
@@ -554,7 +554,7 @@ void InterfaceToolbar::controlReceived(QString ifname, int num, int command, QBy
             break;
 
         case commandStatusMessage:
-            wsApp->pushStatus(WiresharkApplication::TemporaryStatus, payload);
+            mainApp->pushStatus(MainApplication::TemporaryStatus, payload);
             break;
 
         case commandInformationMessage:
@@ -666,7 +666,7 @@ void InterfaceToolbar::onLogButtonClicked()
 
     if (!interface_[ifname].log_dialog.contains(num))
     {
-        interface_[ifname].log_dialog[num] = new FunnelTextDialog(ifname + " " + button->text());
+        interface_[ifname].log_dialog[num] = new FunnelTextDialog(window(), ifname + " " + button->text());
         connect(interface_[ifname].log_dialog[num], SIGNAL(accepted()), this, SLOT(closeLog()));
         connect(interface_[ifname].log_dialog[num], SIGNAL(rejected()), this, SLOT(closeLog()));
 
@@ -803,8 +803,7 @@ void InterfaceToolbar::stopCapture()
 
         if (interface_[ifname].out_fd != -1)
         {
-            ws_close_if_possible (interface_[ifname].out_fd);
-
+            ws_close (interface_[ifname].out_fd);
             interface_[ifname].out_fd = -1;
         }
 
