@@ -15,7 +15,7 @@
 #include "file.h"
 
 #include <ui/qt/utils/qt_ui_utils.h>
-#include "wireshark_application.h"
+#include "main_application.h"
 
 #include <QClipboard>
 #include <QMenu>
@@ -1214,7 +1214,8 @@ LBMLBTRMTransportDialog::LBMLBTRMTransportDialog(QWidget * parent, capture_file
     m_ui->sources_TreeWidget->setColumnHidden(Source_NCFFramesCountBytes_Column, true);
     m_ui->sources_TreeWidget->setColumnHidden(Source_SMFramesBytes_Column, true);
 
-    setAttribute(Qt::WA_DeleteOnClose, true);
+    connect(this, SIGNAL(accepted()), this, SLOT(closeDialog()));
+    connect(this, SIGNAL(rejected()), this, SLOT(closeDialog()));
     fillTree();
 }
 
@@ -1343,6 +1344,11 @@ void LBMLBTRMTransportDialog::on_applyFilterButton_clicked(void)
     fillTree();
 }
 
+void LBMLBTRMTransportDialog::closeDialog(void)
+{
+    delete this;
+}
+
 void LBMLBTRMTransportDialog::sourcesDetailCurrentChanged(int index)
 {
     // Index 0: Data
