@@ -1,4 +1,4 @@
-/* lbm_lbtrm_transport_dialog.h
+/** @file
  *
  * Copyright (c) 2005-2014 Informatica Corporation. All Rights Reserved.
  *
@@ -76,6 +76,7 @@ class LBMLBTRMTransportDialog : public QDialog
         void loadReceiverNAKDetails(LBMLBTRMReceiverTransportEntry * transport);
 
     private slots:
+        void closeDialog(void);
         void on_applyFilterButton_clicked(void);
 
         void sourcesDetailCurrentChanged(int Index);
