@@ -15,7 +15,7 @@
 #include "file.h"
 
 #include <ui/qt/utils/qt_ui_utils.h>
-#include "wireshark_application.h"
+#include "main_application.h"
 
 #include <QClipboard>
 #include <QMessageBox>
@@ -1629,7 +1629,8 @@ LBMLBTRUTransportDialog::LBMLBTRUTransportDialog(QWidget * parent, capture_file
     m_ui->receivers_TreeWidget->setColumnHidden(Receiver_ACKFramesBytes_Column, true);
     m_ui->receivers_TreeWidget->setColumnHidden(Receiver_CREQFramesBytes_Column, true);
 
-    setAttribute(Qt::WA_DeleteOnClose, true);
+    connect(this, SIGNAL(accepted()), this, SLOT(closeDialog()));
+    connect(this, SIGNAL(rejected()), this, SLOT(closeDialog()));
     fillTree();
 }
 
@@ -1762,6 +1763,11 @@ void LBMLBTRUTransportDialog::on_applyFilterButton_clicked(void)
     fillTree();
 }
 
+void LBMLBTRUTransportDialog::closeDialog(void)
+{
+    delete this;
+}
+
 void LBMLBTRUTransportDialog::sourcesDetailCurrentChanged(int index)
 {
     // Index 0: Data
