@@ -17,7 +17,7 @@
 #include "file.h"
 
 #include <ui/qt/utils/qt_ui_utils.h>
-#include "wireshark_application.h"
+#include "main_application.h"
 
 #include <QClipboard>
 #include <QMessageBox>
@@ -332,7 +332,8 @@ LBMStreamDialog::LBMStreamDialog(QWidget * parent, capture_file * cfile) :
 {
     m_ui->setupUi(this);
     m_dialog_info = new LBMStreamDialogInfo();
-    setAttribute(Qt::WA_DeleteOnClose, true);
+    connect(this, &LBMStreamDialog::accepted, this, &LBMStreamDialog::closeDialog);
+    connect(this, &LBMStreamDialog::rejected, this, &LBMStreamDialog::closeDialog);
     fillTree();
 }
 
@@ -418,3 +419,8 @@ void LBMStreamDialog::on_applyFilterButton_clicked(void)
 {
     fillTree();
 }
+
+void LBMStreamDialog::closeDialog(void)
+{
+    delete this;
+}
