@@ -1,4 +1,4 @@
-/* lbm_stream_dialog.h
+/** @file
  *
  * Copyright (c) 2005-2014 Informatica Corporation. All Rights Reserved.
  *
@@ -54,6 +54,7 @@ class LBMStreamDialog : public QDialog
         static void drawTreeItems(void * tap_data);
 
     private slots:
+        void closeDialog(void);
         void on_applyFilterButton_clicked(void);
 };
 
