@@ -19,7 +19,7 @@
 #include <QTreeWidgetItem>
 #include <QPushButton>
 
-#include "wireshark_application.h"
+#include "main_application.h"
 
 #include "ui/recent.h"
 
@@ -915,7 +915,6 @@ void LteRlcStatisticsDialog::updateHeaderLabels()
 void LteRlcStatisticsDialog::captureFileClosing()
 {
     remove_tap_listener(this);
-    updateWidgets();
 
     WiresharkDialog::captureFileClosing();
 }
@@ -986,7 +985,7 @@ lte_rlc_statistics_init(const char *args, void*) {
     if (args_l.length() > 2) {
         filter = QStringList(args_l.mid(2)).join(",").toUtf8();
     }
-    wsApp->emitStatCommandSignal("LteRlcStatistics", filter.constData(), NULL);
+    mainApp->emitStatCommandSignal("LteRlcStatistics", filter.constData(), NULL);
 }
 
 static stat_tap_ui lte_rlc_statistics_ui = {
@@ -999,22 +998,13 @@ static stat_tap_ui lte_rlc_statistics_ui = {
 };
 
 extern "C" {
+
+void register_tap_listener_qt_lte_rlc_statistics(void);
+
 void
 register_tap_listener_qt_lte_rlc_statistics(void)
 {
     register_stat_tap_ui(&lte_rlc_statistics_ui, NULL);
 }
-}
 
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
+}
