@@ -36,6 +36,7 @@
 #include <QHBoxLayout>
 #include <QSplitter>
 #include <QToolButton>
+#include <QLatin1Char>
 
 // To do:
 // - Use the CaptureFile class.
@@ -63,7 +64,7 @@ statusbar_push_temporary_msg(const gchar *msg_format, ...)
     push_msg = QString::vasprintf(msg_format, ap);
     va_end(ap);
 
-    wsApp->pushStatus(WiresharkApplication::TemporaryStatus, push_msg);
+    mainApp->pushStatus(WiresharkApplication::TemporaryStatus, push_msg);
 }
 
 /*
@@ -166,11 +167,11 @@ MainStatusBar::MainStatusBar(QWidget *parent) :
     progress_frame_.enableTaskbarUpdates(true);
 #endif
 
-    connect(wsApp, SIGNAL(appInitialized()), splitter, SLOT(show()));
-    connect(wsApp, SIGNAL(appInitialized()), this, SLOT(appInitialized()));
+    connect(mainApp, SIGNAL(appInitialized()), splitter, SLOT(show()));
+    connect(mainApp, SIGNAL(appInitialized()), this, SLOT(appInitialized()));
     connect(&info_status_, SIGNAL(toggleTemporaryFlash(bool)),
             this, SLOT(toggleBackground(bool)));
-    connect(wsApp, SIGNAL(profileNameChanged(const gchar *)),
+    connect(mainApp, SIGNAL(profileNameChanged(const gchar *)),
             this, SLOT(setProfileName()));
     connect(&profile_status_, SIGNAL(clickedAt(QPoint,Qt::MouseButton)),
             this, SLOT(showProfileMenu(QPoint,Qt::MouseButton)));
@@ -351,7 +352,7 @@ void MainStatusBar::setProfileName()
 void MainStatusBar::appInitialized()
 {
     setProfileName();
-    connect(wsApp->mainWindow(), SIGNAL(framesSelected(QList<int>)), this, SLOT(selectedFrameChanged(QList<int>)));
+    connect(mainApp->mainWindow(), SIGNAL(framesSelected(QList<int>)), this, SLOT(selectedFrameChanged(QList<int>)));
 }
 
 void MainStatusBar::selectedFrameChanged(QList<int>)
@@ -364,7 +365,7 @@ void MainStatusBar::showCaptureStatistics()
     QString packets_str;
 
     QList<int> rows;
-    MainWindow * mw = qobject_cast<MainWindow *>(wsApp->mainWindow());
+    MainWindow * mw = qobject_cast<MainWindow *>(mainApp->mainWindow());
     if (mw)
         rows = mw->selectedRows(true);
 
@@ -424,9 +425,9 @@ void MainStatusBar::showCaptureStatistics()
                 gulong computed_elapsed = cf_get_computed_elapsed(cap_file_);
                 packets_str.append(QString(tr(" %1  Load time: %2:%3.%4"))
                                    .arg(UTF8_MIDDLE_DOT)
-                                   .arg(computed_elapsed/60000)
-                                   .arg(computed_elapsed%60000/1000)
-                                   .arg(computed_elapsed%1000));
+                                   .arg(computed_elapsed/60000, 2, 10, QLatin1Char('0'))
+                                   .arg(computed_elapsed%60000/1000, 2, 10, QLatin1Char('0'))
+                                   .arg(computed_elapsed%1000, 3, 10, QLatin1Char('0')));
             }
         }
     }
@@ -606,7 +607,7 @@ void MainStatusBar::switchToProfile()
 
     if (pa && pa->property("profile_name").isValid()) {
         QString profile = pa->property("profile_name").toString();
-        wsApp->setConfigurationProfile(profile.toUtf8().constData());
+        mainApp->setConfigurationProfile(profile.toUtf8().constData());
     }
 }
 
