@@ -88,7 +88,6 @@ QWidget *ColumnTypeDelegate::createEditor(QWidget *parent,
     else if (index.column() == ColumnListModel::COL_FIELDS)
     {
         FieldFilterEdit * ff_editor = new FieldFilterEdit(parent);
-        connect(ff_editor, &FieldFilterEdit::textChanged, ff_editor, &FieldFilterEdit::checkCustomColumn);
         ff_editor->setText(index.data().toString());
         editor = ff_editor;
     }
@@ -150,7 +149,8 @@ void ColumnTypeDelegate::setModelData(QWidget *editor, QAbstractItemModel *model
         FieldFilterEdit * ffe = qobject_cast<FieldFilterEdit *>(editor);
         if (ffe)
         {
-            if (ffe->syntaxState() == SyntaxLineEdit::Valid) {
+            if (ffe->checkFilter())
+            {
                 QModelIndex typeIndex = index.sibling(index.row(), ColumnListModel::COL_TYPE);
                 model->setData(typeIndex, COL_CUSTOM, Qt::EditRole);
                 model->setData(index, ffe->text(), Qt::EditRole);
@@ -225,7 +225,7 @@ QVariant ColumnListModel::headerData(int section, Qt::Orientation orientation, i
 
 int ColumnListModel::rowCount(const QModelIndex &/*parent*/) const
 {
-    return store_.count();
+    return static_cast<int>(store_.count());
 }
 
 int ColumnListModel::columnCount(const QModelIndex &/*parent*/) const
@@ -275,7 +275,7 @@ void ColumnListModel::populate()
 
 QVariant ColumnListModel::data(const QModelIndex &index, int role) const
 {
-    if (! index.isValid() || index.row() >= store_.count())
+    if (! index.isValid() || index.column() >= store_.count())
         return QVariant();
 
     ListElement ne = store_.at(index.row());
@@ -382,7 +382,7 @@ bool ColumnListModel::dropMimeData(const QMimeData *data,
         moveTo = moveTo - 1;
 
     if (moveTo >= store_.count())
-        moveTo = store_.count() - 1;
+        moveTo = static_cast<int>(store_.count()) - 1;
 
     emit beginResetModel();
     store_.move(moveFrom, moveTo);
