@@ -8,6 +8,8 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
+#include <errno.h>
+
 #include "decode_as_model.h"
 #include <epan/to_str.h>
 #include <epan/decode_as.h>
@@ -18,6 +20,8 @@
 #include <epan/dissectors/packet-dcerpc.h>
 
 #include <ui/qt/utils/qt_ui_utils.h>
+#include <wsutil/file_util.h>
+#include <wsutil/ws_assert.h>
 
 #include <QVector>
 
@@ -47,10 +51,17 @@ DecodeAsModel::DecodeAsModel(QObject *parent, capture_file *cf) :
 {
 }
 
+DecodeAsModel::~DecodeAsModel()
+{
+    foreach(DecodeAsItem* item, decode_as_items_)
+        delete item;
+    decode_as_items_.clear();
+}
+
 Qt::ItemFlags DecodeAsModel::flags(const QModelIndex &index) const
 {
     if (!index.isValid())
-        return 0;
+        return Qt::ItemFlags();
 
     DecodeAsItem* item = decode_as_items_[index.row()];
 
@@ -90,13 +101,13 @@ QVariant DecodeAsModel::data(const QModelIndex &index, int role) const
         case colTable:
             return tr("Match using this field");
         case colSelector:
-            return tr("Current\"Decode As\" behavior");
+            return tr("Change behavior when the field matches this value");
         case colType:
-            return QVariant();
+            return tr("Field value type (and base, if Integer)");
         case colDefault:
             return tr("Default \"Decode As\" behavior");
         case colProtocol:
-            return tr("Change behavior when the protocol field matches this value");
+            return tr("Current\"Decode As\" behavior");
         }
         return QVariant();
     case Qt::DisplayRole:
@@ -189,7 +200,7 @@ QVariant DecodeAsModel::headerData(int section, Qt::Orientation orientation, int
     case colProtocol:
         return tr("Current");
     default:
-        g_assert_not_reached();
+        ws_assert_not_reached();
     }
 
     return QVariant();
@@ -202,7 +213,7 @@ int DecodeAsModel::rowCount(const QModelIndex &parent) const
         return 0;
     }
 
-    return decode_as_items_.count();
+    return static_cast<int>(decode_as_items_.count());
 }
 
 int DecodeAsModel::columnCount(const QModelIndex &parent) const
@@ -397,6 +408,8 @@ void DecodeAsModel::clearAll()
         return;
 
     beginResetModel();
+    foreach(DecodeAsItem* item, decode_as_items_)
+        delete item;
     decode_as_items_.clear();
     endResetModel();
 }
@@ -421,7 +434,81 @@ bool DecodeAsModel::copyRow(int dst_row, int src_row)
 
     QVector<int> roles;
     roles << Qt::EditRole << Qt::BackgroundRole;
-    emit dataChanged(index(dst_row, 0), index(dst_row, columnCount()), roles );
+    emit dataChanged(index(dst_row, 0), index(dst_row, columnCount()), roles);
+
+    return true;
+}
+
+prefs_set_pref_e DecodeAsModel::readDecodeAsEntry(gchar *key, const gchar *value, void *private_data, gboolean)
+{
+    DecodeAsModel *model = (DecodeAsModel*)private_data;
+    if (model == NULL)
+        return PREFS_SET_OK;
+
+    if (strcmp(key, DECODE_AS_ENTRY) != 0) {
+        return PREFS_SET_NO_SUCH_PREF;
+    }
+
+    /* Parse into table, selector, initial, current */
+    gchar **values = g_strsplit_set(value, ",", 4);
+    DecodeAsItem *item = new DecodeAsItem();
+
+    dissector_table_t dissector_table = find_dissector_table(values[0]);
+
+    QString tableName(values[0]);
+    bool tableNameFound = false;
+    // Get the table values from the Decode As list because they are persistent
+    for (GList *cur = decode_as_list; cur; cur = cur->next) {
+        decode_as_t *entry = (decode_as_t *) cur->data;
+        if (tableName.compare(entry->table_name) == 0) {
+            item->tableName_ = entry->table_name;
+            item->tableUIName_ = get_dissector_table_ui_name(entry->table_name);
+            tableNameFound = true;
+            break;
+        }
+    }
+
+    if (!tableNameFound || !dissector_table) {
+        delete item;
+        g_strfreev(values);
+        return PREFS_SET_SYNTAX_ERR;
+    }
+
+    QString selector(values[1]);
+    ftenum_t selector_type = get_dissector_table_selector_type(item->tableName_);
+
+    if (IS_FT_STRING(selector_type)) {
+        item->selectorString_ = selector;
+    } else if (IS_FT_UINT(selector_type)) {
+        item->selectorUint_ = selector.toUInt(Q_NULLPTR, 0);
+    }
+
+    item->default_proto_ = values[2];
+    item->dissector_handle_ = dissector_table_get_dissector_handle(dissector_table, values[3]);
+    if (item->dissector_handle_) {
+        item->current_proto_ = values[3];
+    }
+
+    model->decode_as_items_ << item;
+    g_strfreev(values);
+
+    return PREFS_SET_OK;
+}
+
+bool DecodeAsModel::copyFromProfile(QString filename, const gchar **err)
+{
+    FILE *fp = ws_fopen(filename.toUtf8().constData(), "r");
+
+    if (fp == NULL) {
+        *err = g_strerror(errno);
+        return false;
+    }
+
+    beginInsertRows(QModelIndex(), rowCount(), rowCount());
+    read_prefs_file(filename.toUtf8().constData(), fp, readDecodeAsEntry, this);
+    endInsertRows();
+
+    fclose(fp);
 
     return true;
 }
@@ -462,7 +549,7 @@ QString DecodeAsModel::entryString(const gchar *table_name, gconstpointer value)
                 break;
 
             default:
-                g_assert_not_reached();
+                ws_assert_not_reached();
                 break;
             }
             entry_str = QString("%1").arg(int_to_qstring(num_val, width, 16));
@@ -479,6 +566,7 @@ QString DecodeAsModel::entryString(const gchar *table_name, gconstpointer value)
     case FT_STRINGZ:
     case FT_UINT_STRING:
     case FT_STRINGZPAD:
+    case FT_STRINGZTRUNC:
         entry_str = (const char *)value;
         break;
 
@@ -491,7 +579,7 @@ QString DecodeAsModel::entryString(const gchar *table_name, gconstpointer value)
         return "0";
 
     default:
-        g_assert_not_reached();
+        ws_assert_not_reached();
         break;
     }
     return entry_str;
@@ -609,6 +697,7 @@ void DecodeAsModel::gatherChangedEntries(const gchar *table_name,
     case FT_STRINGZ:
     case FT_UINT_STRING:
     case FT_STRINGZPAD:
+    case FT_STRINGZTRUNC:
         model->changed_string_entries_ << CharPtrPair(table_name, (const char *) key);
         break;
     default:
@@ -680,6 +769,7 @@ void DecodeAsModel::applyChanges()
                 case FT_STRINGZ:
                 case FT_UINT_STRING:
                 case FT_STRINGZPAD:
+                case FT_STRINGZTRUNC:
                     byteArray = item->selectorString_.toUtf8();
                     selector_value = (gconstpointer) byteArray.constData();
                     break;
@@ -733,16 +823,5 @@ void DecodeAsModel::applyChanges()
             }
         }
     }
+    prefs_apply_all();
 }
-
-/* * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
