@@ -12,7 +12,7 @@
 
 #include <ui/qt/utils/qt_ui_utils.h>
 #include <ui/qt/utils/variant_pointer.h>
-#include <ui/export_object_ui.h>
+#include <wsutil/filesystem.h>
 #include <epan/prefs.h>
 
 #include <QDir>
@@ -115,7 +115,7 @@ int ExportObjectModel::rowCount(const QModelIndex &parent) const
         return 0;
     }
 
-    return objects_.count();
+    return static_cast<int>(objects_.count());
 }
 
 int ExportObjectModel::columnCount(const QModelIndex&) const
@@ -128,7 +128,7 @@ void ExportObjectModel::addObjectEntry(export_object_entry_t *entry)
     if (entry == NULL)
         return;
 
-    int count = objects_.count();
+    int count = static_cast<int>(objects_.count());
     beginInsertRows(QModelIndex(), count, count);
     objects_.append(VariantPointer<export_object_entry_t>::asQVariant(entry));
     endInsertRows();
@@ -149,7 +149,7 @@ bool ExportObjectModel::saveEntry(QModelIndex &index, QString filename)
         return false;
 
     if (filename.length() > 0) {
-        eo_save_entry(filename.toUtf8().constData(), entry);
+        write_file_binary_mode(qUtf8Printable(filename), entry->payload_data, entry->payload_len);
     }
 
     return true;
@@ -182,7 +182,7 @@ void ExportObjectModel::saveAllEntries(QString path)
                 char generic_name[EXPORT_OBJECT_MAXFILELEN+1];
                 const char *ext;
                 ext = eo_ct2ext(entry->content_type);
-                g_snprintf(generic_name, sizeof(generic_name),
+                snprintf(generic_name, sizeof(generic_name),
                     "object%u%s%s", entry->pkt_num, ext ? "." : "",
                     ext ? ext : "");
                 safe_filename = eo_massage_str(generic_name,
@@ -191,7 +191,8 @@ void ExportObjectModel::saveAllEntries(QString path)
             filename = QString::fromUtf8(safe_filename->str);
             g_string_free(safe_filename, TRUE);
         } while (save_dir.exists(filename) && ++count < prefs.gui_max_export_objects);
-        eo_save_entry(save_dir.filePath(filename).toUtf8().constData(), entry);
+        write_file_binary_mode(qUtf8Printable(save_dir.filePath(filename)),
+                               entry->payload_data, entry->payload_len);
     }
 }
 
@@ -266,16 +267,43 @@ bool ExportObjectProxyModel::lessThan(const QModelIndex &source_left, const QMod
     return QSortFilterProxyModel::lessThan(source_left, source_right);
 }
 
+void ExportObjectProxyModel::setContentFilterString(QString filter_)
+{
+    contentFilter_ = filter_;
+    invalidateFilter();
+}
 
+void ExportObjectProxyModel::setTextFilterString(QString filter_)
+{
+    textFilter_ = filter_;
+    invalidateFilter();
+}
 
-/* * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
+bool ExportObjectProxyModel::filterAcceptsRow(int source_row, const QModelIndex &/*source_parent*/) const
+{
+    if (contentFilter_.length() > 0)
+    {
+        QModelIndex idx = sourceModel()->index(source_row, ExportObjectModel::colContent);
+        if (!idx.isValid())
+            return false;
+
+        if (contentFilter_.compare(idx.data().toString()) != 0)
+            return false;
+    }
+
+    if (textFilter_.length() > 0)
+    {
+        QModelIndex hostIdx = sourceModel()->index(source_row, ExportObjectModel::colHostname);
+        QModelIndex fileIdx = sourceModel()->index(source_row, ExportObjectModel::colFilename);
+        if (!hostIdx.isValid() || !fileIdx.isValid())
+            return false;
+
+        QString host = hostIdx.data().toString();
+        QString file = fileIdx.data().toString();
+
+        if (!host.contains(textFilter_) && !file.contains(textFilter_))
+            return false;
+    }
+
+    return true;
+}
