@@ -1,4 +1,5 @@
-/* path_chooser_delegate.h
+/** @file
+ *
  * Delegate to select a file path for a treeview entry
  *
  * Wireshark - Network traffic analyzer
@@ -27,20 +28,7 @@ protected:
     void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &idx) const;
 
 private slots:
-    void browse_button_clicked();
+    void browseButtonClicked();
 };
 
 #endif /* PATH_CHOOSER_DELEGATE_H_ */
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
