@@ -12,6 +12,7 @@
 #include <QPalette>
 #include <QApplication>
 #include <QBrush>
+#include <QRegularExpression>
 
 #include <ui/qt/models/supported_protocols_model.h>
 
@@ -209,7 +210,7 @@ bool SupportedProtocolsProxyModel::lessThan(const QModelIndex &left, const QMode
 
 bool SupportedProtocolsProxyModel::filterAcceptItem(SupportedProtocolsItem& item) const
 {
-    QRegExp regex(filter_, Qt::CaseInsensitive);
+    QRegularExpression regex(filter_, QRegularExpression::CaseInsensitiveOption);
 
     if (item.name().contains(regex))
         return true;
@@ -256,17 +257,3 @@ void SupportedProtocolsProxyModel::setFilter(const QString& filter)
     filter_ = filter;
     invalidateFilter();
 }
-
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
