@@ -13,6 +13,7 @@
 #include <ui/qt/models/uat_delegate.h>
 #include "epan/value_string.h"
 #include <wsutil/ws_assert.h>
+#include <QRegularExpression>
 #include <QComboBox>
 #include <QEvent>
 #include <QFileDialog>
@@ -23,7 +24,6 @@
 #include <ui/qt/widgets/display_filter_edit.h>
 #include <ui/qt/widgets/field_filter_edit.h>
 #include <ui/qt/widgets/editor_file_dialog.h>
-#include <ui/qt/widgets/path_selection_edit.h>
 
 // The Qt docs suggest overriding updateEditorGeometry, but the
 // defaults seem sane.
@@ -46,14 +46,31 @@ QWidget *UatDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &
 
     switch (field->mode) {
     case PT_TXTMOD_DIRECTORYNAME:
+        if (index.isValid()) {
+            QString filename_old = index.model()->data(index, Qt::EditRole).toString();
+            EditorFileDialog* fileDialog = new EditorFileDialog(index, EditorFileDialog::Directory, parent, QString(field->title), filename_old);
+
+            // Use signals to accept data from cell
+            connect(fileDialog, &EditorFileDialog::acceptEdit, this, &UatDelegate::applyFilename);
+            // Don't fall through and set setAutoFillBackground(true)
+            return fileDialog;
+        }
+        break;
+
     case PT_TXTMOD_FILENAME:
         if (index.isValid()) {
             QString filename_old = index.model()->data(index, Qt::EditRole).toString();
-            PathSelectionEdit * pathEdit = new PathSelectionEdit(field->title, QString(), field->mode != PT_TXTMOD_DIRECTORYNAME, parent);
-            connect(pathEdit, &PathSelectionEdit::pathChanged, this, &UatDelegate::pathHasChanged);
-            return pathEdit;
+            EditorFileDialog* fileDialog = new EditorFileDialog(index, EditorFileDialog::ExistingFile, parent, QString(field->title), filename_old);
+
+            fileDialog->setOption(QFileDialog::DontConfirmOverwrite);
+
+            // Use signals to accept data from cell
+            connect(fileDialog, &EditorFileDialog::acceptEdit, this, &UatDelegate::applyFilename);
+            // Don't fall through and set setAutoFillBackground(true)
+            return fileDialog;
         }
         break;
+
    case PT_TXTMOD_COLOR:
         if (index.isValid()) {
             QColor color(index.model()->data(index, Qt::DecorationRole).toString());
@@ -93,14 +110,14 @@ QWidget *UatDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &
     {
         // Requires input of the form "ab cd ef" (with possibly no or a colon
         // separator instead of a single whitespace) for the editor to accept.
-        QRegExp hexbytes_regex("([0-9a-f]{2}[ :]?)*");
-        hexbytes_regex.setCaseSensitivity(Qt::CaseInsensitive);
+        QRegularExpression hexbytes_regex("([0-9a-f]{2}[ :]?)*");
+        hexbytes_regex.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
         // QString types from QStyledItemDelegate are documented to return a
         // QLineEdit. Note that Qt returns a subclass from QLineEdit which
         // automatically adapts the width to the typed contents.
         QLineEdit *le_editor = static_cast<QLineEdit *>(
                 QStyledItemDelegate::createEditor(parent, option, index));
-        le_editor->setValidator(new QRegExpValidator(hexbytes_regex, le_editor));
+        le_editor->setValidator(new QRegularExpressionValidator(hexbytes_regex, le_editor));
         editor = le_editor;
         break;
     }
@@ -128,11 +145,6 @@ void UatDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
     uat_field_t *field = indexToField(index);
 
     switch (field->mode) {
-    case PT_TXTMOD_DIRECTORYNAME:
-    case PT_TXTMOD_FILENAME:
-        if (index.isValid() && qobject_cast<PathSelectionEdit *>(editor))
-            qobject_cast<PathSelectionEdit *>(editor)->setPath(index.model()->data(index, Qt::EditRole).toString());
-        break;
     case PT_TXTMOD_ENUM:
     {
         QComboBox *combobox = static_cast<QComboBox *>(editor);
@@ -162,11 +174,6 @@ void UatDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
     uat_field_t *field = indexToField(index);
 
     switch (field->mode) {
-    case PT_TXTMOD_DIRECTORYNAME:
-    case PT_TXTMOD_FILENAME:
-        if (index.isValid() && qobject_cast<PathSelectionEdit *>(editor))
-            const_cast<QAbstractItemModel *>(index.model())->setData(index, qobject_cast<PathSelectionEdit *>(editor)->path(), Qt::EditRole);
-        break;
     case PT_TXTMOD_ENUM:
     {
         QComboBox *combobox = static_cast<QComboBox *>(editor);
@@ -188,25 +195,10 @@ void UatDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
     }
 }
 
-void UatDelegate::updateEditorGeometry(QWidget *editor,
-                                           const QStyleOptionViewItem &option,
-                                           const QModelIndex &index) const
+void UatDelegate::applyFilename(const QModelIndex& index)
 {
-    uat_field_t *field = indexToField(index);
-
-    switch (field->mode) {
-    case PT_TXTMOD_DIRECTORYNAME:
-    case PT_TXTMOD_FILENAME:
-        editor->setGeometry(option.rect);
-        break;
-    default:
-        QStyledItemDelegate::updateEditorGeometry(editor, option, index);
+    if (index.isValid()) {
+        EditorFileDialog* fileDialog = static_cast<EditorFileDialog*>(sender());
+        const_cast<QAbstractItemModel *>(index.model())->setData(index, fileDialog->text(), Qt::EditRole);
     }
 }
-
-void UatDelegate::pathHasChanged(QString)
-{
-    PathSelectionEdit * editor = qobject_cast<PathSelectionEdit *>(sender());
-    if (editor)
-        emit commitData(editor);
-}
