@@ -1,4 +1,5 @@
-/* uat_delegate.h
+/** @file
+ *
  * Delegates for editing various field types in a UAT record.
  *
  * Copyright 2016 Peter Wu <peter@lekensteyn.nl>
@@ -27,13 +28,14 @@ class UatDelegate : public QStyledItemDelegate
 public:
     UatDelegate(QObject *parent = 0);
 
-    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
-    void setEditorData(QWidget *editor, const QModelIndex &index) const override;
-    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
-    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
+                          const QModelIndex &index) const;
+    void setEditorData(QWidget *editor, const QModelIndex &index) const;
+    void setModelData(QWidget *editor, QAbstractItemModel *model,
+                      const QModelIndex &index) const;
 
-protected slots:
-    void pathHasChanged(QString newPath);
+private slots:
+    void applyFilename(const QModelIndex& index);
 
 private:
     uat_field_t *indexToField(const QModelIndex &index) const;
