@@ -16,16 +16,19 @@
 
 #include "wsutil/utf8_entities.h"
 
-#include "wireshark_application.h"
+#include "main_application.h"
 
 #include "ui/qt/main_window.h"
+#include "ui/qt/capture_file_dialog.h"
 #include "ui/qt/utils/proto_node.h"
 #include "ui/qt/utils/variant_pointer.h"
+#include "ui/recent.h"
 
-
+#include <QClipboard>
 #include <QContextMenuEvent>
 #include <QGraphicsItem>
 #include <QMenu>
+#include <QStyleOptionGraphicsItem>
 
 #if defined(QT_SVG_LIB) && 0
 #include <QBuffer>
@@ -48,10 +51,9 @@ public:
         small_font_rems_(0.75),
         bit_width_rems_(1.0),
         padding_rems_(0.5),
-        span_mark_offset_rems_(0.2),
-        show_fields_(false)
+        span_mark_offset_rems_(0.2)
     {
-        setFont(wsApp->font());
+        setFont(mainApp->font());
     }
 
     void setFont(QFont font) {
@@ -62,7 +64,7 @@ public:
         QFontMetrics fm(regular_font_);
         root_em_ = fm.height();
     }
-    void setShowFields(bool show_fields = false) { show_fields_ = show_fields; }
+    void setShowFields(bool show_fields = false) { recent.gui_packet_diagram_field_values = show_fields; }
 
     int bitsPerRow() const { return bits_per_row_; }
     const QFont regularFont() const { return regular_font_; }
@@ -73,17 +75,16 @@ public:
     int vPadding() const { return root_em_ * padding_rems_; }
     int spanMarkOffset() const { return root_em_ * span_mark_offset_rems_; }
     int rowHeight() const {
-        int rows = show_fields_ ? 2 : 1;
+        int rows = recent.gui_packet_diagram_field_values ? 2 : 1;
         return ((lineHeight() * rows) + (vPadding() * 2));
     }
-    bool showFields() const { return show_fields_; }
+    bool showFields() const { return recent.gui_packet_diagram_field_values; }
 private:
     int bits_per_row_;
     double small_font_rems_;
     double bit_width_rems_;
     double padding_rems_;
     double span_mark_offset_rems_; // XXX Make this padding_rems_ / 2 instead?
-    bool show_fields_;
     QFont regular_font_;
     QFont small_font_;
     int root_em_;
@@ -116,7 +117,7 @@ public:
         if (bits_remain + row1_start > bits_per_row) {
             row1_bits = bits_per_row - row1_start;
             bits_remain -= row1_bits;
-            if (row1_start == 0 && bits_remain > bits_per_row) {
+            if (row1_start == 0 && bits_remain >= bits_per_row) {
                 // Collapse first row
                 bits_remain %= bits_per_row;
                 collapsed_row_ = 0;
@@ -344,7 +345,7 @@ private:
 };
 
 PacketDiagram::PacketDiagram(QWidget *parent) :
-    QGraphicsView(new QGraphicsScene(), parent),
+    QGraphicsView(parent),
     layout_(new DiagramLayout),
     cap_file_(nullptr),
     root_node_(nullptr),
@@ -358,11 +359,10 @@ PacketDiagram::PacketDiagram(QWidget *parent) :
     // XXX Move to setMonospaceFont similar to ProtoTree
     layout_->setFont(font());
 
-    connect(wsApp, &WiresharkApplication::appInitialized, this, &PacketDiagram::connectToMainWindow);
-    QGraphicsScene *this_scene = scene();
-    connect(this_scene, &QGraphicsScene::selectionChanged, this, &PacketDiagram::sceneSelectionChanged);
+    connect(mainApp, &MainApplication::appInitialized, this, &PacketDiagram::connectToMainWindow);
+    connect(mainApp, &MainApplication::zoomRegularFont, this, &PacketDiagram::setFont);
 
-    connect(wsApp, &WiresharkApplication::zoomRegularFont, this, &PacketDiagram::setFont);
+    resetScene();
 }
 
 PacketDiagram::~PacketDiagram()
@@ -372,15 +372,21 @@ PacketDiagram::~PacketDiagram()
 
 void PacketDiagram::setRootNode(proto_node *root_node)
 {
-    root_node_ = root_node;
-    if (!isVisible()) {
-        return;
-    }
-
+    // As https://doc.qt.io/qt-5/qgraphicsscene.html#clear says, this
+    // "Removes and deletes all items from the scene, but otherwise leaves
+    // the state of the scene unchanged."
+    // This means that the scene rect grows but doesn't shrink, which is
+    // useful in our case because it gives us a cheap way to retain our
+    // scroll position between packets.
     scene()->clear();
     selected_field_ = nullptr;
     y_pos_ = 0;
 
+    root_node_ = root_node;
+    if (!isVisible() || !root_node) {
+        return;
+    }
+
     ProtoNode parent_node(root_node_);
     if (!parent_node.isValid()) {
         return;
@@ -414,12 +420,16 @@ void PacketDiagram::setCaptureFile(capture_file *cf)
     // dissection (EDT) ready.
     // The packet dialog sets a fixed EDT context and MUST NOT use this.
     cap_file_ = cf;
+
+    if (!cf) {
+        resetScene();
+    }
 }
 
 void PacketDiagram::setFont(const QFont &font)
 {
     layout_->setFont(font);
-    setRootNode(root_node_);
+    resetScene(false);
 }
 
 void PacketDiagram::selectedFieldChanged(FieldInformation *finfo)
@@ -437,6 +447,19 @@ void PacketDiagram::selectedFrameChanged(QList<int> frames)
     }
 }
 
+bool PacketDiagram::event(QEvent *event)
+{
+    switch (event->type()) {
+    case QEvent::ApplicationPaletteChange:
+        resetScene(false);
+        break;
+    default:
+        break;
+
+    }
+    return QGraphicsView::event(event);
+}
+
 void PacketDiagram::contextMenuEvent(QContextMenuEvent *event)
 {
     if (!event) {
@@ -453,14 +476,14 @@ void PacketDiagram::contextMenuEvent(QContextMenuEvent *event)
 
     ctx_menu.addSeparator();
 
-    action = ctx_menu.addAction(tr("Save Diagram As" UTF8_HORIZONTAL_ELLIPSIS));
+    action = ctx_menu.addAction(tr("Save Diagram As…"));
     connect(action, &QAction::triggered, this, &PacketDiagram::saveAsTriggered);
 
     action = ctx_menu.addAction(tr("Copy as Raster Image"));
     connect(action, &QAction::triggered, this, &PacketDiagram::copyAsRasterTriggered);
 
 #if defined(QT_SVG_LIB) && !defined(Q_OS_MAC)
-    action = ctx_menu.addAction(tr(UTF8_HORIZONTAL_ELLIPSIS "as SVG"));
+    action = ctx_menu.addAction(tr("…as SVG"));
     connect(action, &QAction::triggered, this, &PacketDiagram::copyAsSvgTriggered);
 #endif
 
@@ -469,7 +492,7 @@ void PacketDiagram::contextMenuEvent(QContextMenuEvent *event)
 
 void PacketDiagram::connectToMainWindow()
 {
-    MainWindow *main_window = qobject_cast<MainWindow *>(wsApp->mainWindow());
+    MainWindow *main_window = qobject_cast<MainWindow *>(mainApp->mainWindow());
     if (!main_window) {
         return;
     }
@@ -495,8 +518,21 @@ void PacketDiagram::sceneSelectionChanged()
     }
 }
 
-struct WireItem {
-    proto_item *item;
+void PacketDiagram::resetScene(bool reset_root)
+{
+    // As noted in setRootNode, scene()->clear() doesn't clear everything.
+    // Do a "hard" clear, which resets our various rects and scroll position.
+    if (scene()) {
+        delete scene();
+    }
+    QGraphicsScene *new_scene = new QGraphicsScene();
+    setScene(new_scene);
+    connect(new_scene, &QGraphicsScene::selectionChanged, this, &PacketDiagram::sceneSelectionChanged);
+    setRootNode(reset_root ? nullptr : root_node_);
+}
+
+struct DiagramItemSpan {
+    field_info *finfo;
     int start_bit;
     int length;
 };
@@ -563,10 +599,10 @@ void PacketDiagram::addDiagram(proto_node *tl_node)
     y_pos_ = y_bottom;
     x = layout_->hPadding();
 
-    // Top-level fields
+    // Collect our top-level fields
     int last_start_bit = -1;
     int max_l_y = y_bottom;
-    QList<WireItem>wire_items;
+    QList<DiagramItemSpan>item_spans;
     for (proto_item *cur_item = tl_node->first_child; cur_item; cur_item = cur_item->next) {
         if (proto_item_is_generated(cur_item) || proto_item_is_hidden(cur_item)) {
             continue;
@@ -578,52 +614,56 @@ void PacketDiagram::addDiagram(proto_node *tl_node)
 
         if (start_bit <= last_start_bit || length <= 0) {
 #ifdef DEBUG_PACKET_DIAGRAM
-            qDebug() << "Skipping pass 1" << fi->hfinfo->abbrev << start_bit << last_start_bit << length;
+            qDebug() << "Skipping item" << fi->hfinfo->abbrev << start_bit << last_start_bit << length;
 #endif
             continue;
         }
         last_start_bit = start_bit;
 
-        WireItem wire_item = { cur_item, start_bit, length };
-        wire_items << wire_item;
-    }
-    qreal z_value = tl_item->zValue();
-    for (int idx = 0; idx < wire_items.size(); idx++) {
-        WireItem *wire_item = &wire_items[idx];
-        field_info *fi = wire_item->item->finfo;
-
-        if (idx < wire_items.size() - 1) {
-            WireItem *next_item = &wire_items[idx + 1];
-            if (wire_item->start_bit + wire_item->length > next_item->start_bit) {
-                wire_item->length = next_item->start_bit - wire_item->start_bit;
+        if (item_spans.size() > 0) {
+            DiagramItemSpan prev_span = item_spans.last();
+            // Get rid of overlaps.
+            if (prev_span.start_bit + prev_span.length > start_bit) {
 #ifdef DEBUG_PACKET_DIAGRAM
-                qDebug() << "Resized pass 2" << fi->hfinfo->abbrev << wire_item->start_bit << wire_item->length << next_item->start_bit;
+                qDebug() << "Resized prev" << prev_span.finfo->hfinfo->abbrev << prev_span.start_bit << prev_span.length << "->" << start_bit - prev_span.start_bit;
 #endif
-                if (wire_item->length <= 0) {
+                prev_span.length = start_bit - prev_span.start_bit;
+            }
+            if (prev_span.length < 1) {
 #ifdef DEBUG_PACKET_DIAGRAM
-                    qDebug() << "Skipping pass 2" << fi->hfinfo->abbrev << wire_item->start_bit << wire_item->length;
-#endif
+                qDebug() << "Removed prev" << prev_span.finfo->hfinfo->abbrev << prev_span.start_bit << prev_span.length;
+                item_spans.removeLast();
+                if (item_spans.size() < 1) {
                     continue;
                 }
+                prev_span = item_spans.last();
+#endif
             }
-
-            if (next_item->start_bit > wire_item->start_bit + wire_item->length) {
-                int gap_start_bit = wire_item->start_bit + wire_item->length;
-                int gap_len = next_item->start_bit - gap_start_bit;
-                int y_off = (gap_start_bit / bits_per_row) * layout_->rowHeight();
-                // Stack each item behind the previous one.
-                z_value -= .01;
-                FieldInformationGraphicsItem *gap_item = new FieldInformationGraphicsItem(nullptr, gap_start_bit, gap_len, layout_);
-                gap_item->setPos(x, y_bottom + y_off);
-                gap_item->setZValue(z_value);
-                scene()->addItem(gap_item);
+            // Fill in gaps.
+            if (prev_span.start_bit + prev_span.length < start_bit) {
+#ifdef DEBUG_PACKET_DIAGRAM
+                qDebug() << "Adding gap" << prev_span.finfo->hfinfo->abbrev << prev_span.start_bit << prev_span.length << start_bit;
+#endif
+                int gap_start = prev_span.start_bit + prev_span.length;
+                DiagramItemSpan gap_span = { nullptr, gap_start, start_bit - gap_start };
+                item_spans << gap_span;
             }
         }
 
-        int y_off = (wire_item->start_bit / bits_per_row) * layout_->rowHeight();
+        DiagramItemSpan item_span = { cur_item->finfo, start_bit, length };
+        item_spans << item_span;
+    }
+
+    qreal z_value = tl_item->zValue();
+    int start_bit = 0;
+    for (int idx = 0; idx < item_spans.size(); idx++) {
+        DiagramItemSpan *item_span = &item_spans[idx];
+
+        int y_off = (start_bit / bits_per_row) * layout_->rowHeight();
         // Stack each item behind the previous one.
         z_value -= .01;
-        FieldInformationGraphicsItem *fi_item = new FieldInformationGraphicsItem(fi, wire_item->start_bit, wire_item->length, layout_);
+        FieldInformationGraphicsItem *fi_item = new FieldInformationGraphicsItem(item_span->finfo, start_bit, item_span->length, layout_);
+        start_bit += fi_item->collapsedLength();
         fi_item->setPos(x, y_bottom + y_off);
         fi_item->setFlag(QGraphicsItem::ItemIsSelectable);
         fi_item->setAcceptedMouseButtons(Qt::LeftButton);
@@ -719,7 +759,7 @@ void PacketDiagram::showFieldsToggled(bool checked)
 void PacketDiagram::saveAsTriggered()
 {
     QString file_name, extension;
-    QDir path(wsApp->lastOpenDir());
+    QDir path(mainApp->lastOpenDir());
     QString png_filter = tr("Portable Network Graphics (*.png)");
     QString bmp_filter = tr("Windows Bitmap (*.bmp)");
     // Gaze upon my beautiful graph with lossy artifacts!
@@ -731,7 +771,7 @@ void PacketDiagram::saveAsTriggered()
 #endif
     QString filter = fl.join(";;");
 
-    file_name = WiresharkFileDialog::getSaveFileName(this, wsApp->windowTitleString(tr("Save Graph As" UTF8_HORIZONTAL_ELLIPSIS)),
+    file_name = WiresharkFileDialog::getSaveFileName(this, mainApp->windowTitleString(tr("Save Graph As…")),
                                              path.canonicalPath(), filter, &extension);
 
     if (file_name.length() > 0) {
@@ -758,8 +798,7 @@ void PacketDiagram::saveAsTriggered()
 #endif
         // else error dialog?
         if (save_ok) {
-            path = QDir(file_name);
-            wsApp->setLastOpenDir(path.canonicalPath().toUtf8().constData());
+            mainApp->setLastOpenDirFromFilename(file_name);
         }
     }
 }
@@ -767,7 +806,7 @@ void PacketDiagram::saveAsTriggered()
 void PacketDiagram::copyAsRasterTriggered()
 {
     QImage raster_diagram = exportToImage();
-    wsApp->clipboard()->setImage(raster_diagram);
+    mainApp->clipboard()->setImage(raster_diagram);
 }
 
 #if defined(QT_SVG_LIB) && !defined(Q_OS_MAC) && 0
@@ -780,6 +819,6 @@ void PacketDiagram::copyAsSvgTriggered()
     // It might be easier to just do "Save As" instead.
     QMimeData *md = new QMimeData();
     md->setData("image/svg+xml", svg_buf);
-    wsApp->clipboard()->setMimeData(md);
+    mainApp->clipboard()->setMimeData(md);
 }
 #endif
