@@ -1,4 +1,4 @@
-/* rtp_player_dialog.h
+/** @file
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,7 +26,10 @@
 #include <QTreeWidgetItem>
 #include <QMetaType>
 #include <ui/qt/widgets/qcustomplot.h>
+
+#ifdef QT_MULTIMEDIA_LIB
 #include <QAudioDeviceInfo>
+#endif
 
 namespace Ui {
 class RtpPlayerDialog;
@@ -116,8 +119,10 @@ public slots:
     void rtpAnalysisAdd();
     void rtpAnalysisRemove();
 
+#endif
 protected:
     explicit RtpPlayerDialog(QWidget &parent, CaptureFile &cf, bool capture_running);
+#ifdef QT_MULTIMEDIA_LIB
     ~RtpPlayerDialog();
 
     virtual void showEvent(QShowEvent *);
@@ -194,10 +199,13 @@ private slots:
     void on_actionPrepareFilter_triggered();
     void on_actionReadCapture_triggered();
 
+#endif
 private:
     static RtpPlayerDialog *pinstance_;
-    static std::mutex mutex_;
+    static std::mutex init_mutex_;
+    static std::mutex run_mutex_;
 
+#ifdef QT_MULTIMEDIA_LIB
     Ui::RtpPlayerDialog *ui;
     QMenu *graph_ctx_menu_;
     QMenu *list_ctx_menu_;
