@@ -23,7 +23,7 @@
 #include "progress_frame.h"
 #include <ui/qt/utils/qt_ui_utils.h>
 #include "sequence_diagram.h"
-#include "wireshark_application.h"
+#include "main_application.h"
 #include <ui/qt/utils/variant_pointer.h>
 #include <ui/alert_box.h>
 #include "ui/qt/widgets/wireshark_file_dialog.h"
@@ -78,7 +78,6 @@ SequenceDialog::SequenceDialog(QWidget &parent, CaptureFile &cf, SequenceInfo *i
     QAction *action;
 
     ui->setupUi(this);
-    ui->hintLabel->setSmallText();
 
     QCustomPlot *sp = ui->sequencePlot;
     setWindowSubtitle(info_ ? tr("Call Flow") : tr("Flow"));
@@ -201,6 +200,8 @@ SequenceDialog::SequenceDialog(QWidget &parent, CaptureFile &cf, SequenceInfo *i
     connect(sp, SIGNAL(mouseMove(QMouseEvent*)), this, SLOT(mouseMoved(QMouseEvent*)));
     connect(sp, SIGNAL(mouseWheel(QWheelEvent*)), this, SLOT(mouseWheeled(QWheelEvent*)));
 
+    disconnect(ui->buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+
     // Button must be enabled by VoIP dialogs
     player_button_->setVisible(false);
     player_button_->setEnabled(false);
@@ -360,7 +361,11 @@ void SequenceDialog::diagramClicked(QMouseEvent *event)
             on_actionGoToPacket_triggered();
             break;
         case Qt::RightButton:
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0 ,0)
+            ctx_menu_.exec(event->globalPosition().toPoint());
+#else
             ctx_menu_.exec(event->globalPos());
+#endif
             break;
         default:
             break;
@@ -383,7 +388,8 @@ void SequenceDialog::mouseMoved(QMouseEvent *event)
                 current_rtp_sai_hovered_ = sai;
             }
             packet_num_ = sai->frame_number;
-            hint = QString("Packet %1: %2").arg(packet_num_).arg(sai->comment);
+            QString raw_comment = html_escape(sai->comment);
+            hint = QString("Packet %1: %2").arg(packet_num_).arg(raw_comment);
         }
     }
 
@@ -396,6 +402,8 @@ void SequenceDialog::mouseMoved(QMouseEvent *event)
         }
     }
 
+    hint.prepend("<small><i>");
+    hint.append("</i></small>");
     ui->hintLabel->setText(hint);
 }
 
@@ -428,7 +436,7 @@ void SequenceDialog::on_buttonBox_clicked(QAbstractButton *button)
 void SequenceDialog::exportDiagram()
 {
     QString file_name, extension;
-    QDir path(wsApp->lastOpenDir());
+    QDir path(mainApp->lastOpenDir());
     QString pdf_filter = tr("Portable Document Format (*.pdf)");
     QString png_filter = tr("Portable Network Graphics (*.png)");
     QString bmp_filter = tr("Windows Bitmap (*.bmp)");
@@ -445,7 +453,7 @@ void SequenceDialog::exportDiagram()
         filter.append(QString(";;%5").arg(ascii_filter));
     }
 
-    file_name = WiresharkFileDialog::getSaveFileName(this, wsApp->windowTitleString(tr("Save Graph As…")),
+    file_name = WiresharkFileDialog::getSaveFileName(this, mainApp->windowTitleString(tr("Save Graph As…")),
                                              path.canonicalPath(), filter, &extension);
 
     if (file_name.length() > 0) {
@@ -470,7 +478,7 @@ void SequenceDialog::exportDiagram()
         }
         // else error dialog?
         if (save_ok) {
-            wsApp->setLastOpenDirFromFilename(file_name);
+            mainApp->setLastOpenDirFromFilename(file_name);
         } else {
             open_failure_alert_box(file_name.toUtf8().constData(), errno, TRUE);
         }
@@ -531,20 +539,12 @@ void SequenceDialog::panAxes(int x_pixels, int y_pixels)
     double v_pan = 0.0;
 
     h_pan = sp->xAxis2->range().size() * x_pixels / sp->xAxis2->axisRect()->width();
-    // The nodes are placed on integer x values from 0 to num_nodes - 1.
-    // We allow 0.5 of margin around a node (also reflected in the
-    // horizontalScrollBar range.)
     if (h_pan < 0) {
         h_pan = qMax(h_pan, min_left_ - sp->xAxis2->range().lower);
     } else {
-        h_pan = qMin(h_pan, info_->sainfo()->num_nodes - 0.5 - sp->xAxis2->range().upper);
+        h_pan = qMin(h_pan, info_->sainfo()->num_nodes - sp->xAxis2->range().upper);
     }
 
-    if (sp->yAxis->rangeReversed()) {
-        // For reversed axes, lower still references the mathemathetically
-        // smaller number than upper, so reverse the direction.
-        y_pixels = -y_pixels;
-    }
     v_pan = sp->yAxis->range().size() * y_pixels / sp->yAxis->axisRect()->height();
     if (v_pan < 0) {
         v_pan = qMax(v_pan, min_top_ - sp->yAxis->range().lower);
@@ -552,7 +552,7 @@ void SequenceDialog::panAxes(int x_pixels, int y_pixels)
         v_pan = qMin(v_pan, num_items_ - sp->yAxis->range().upper);
     }
 
-    if (h_pan && !(sp->xAxis2->range().contains(min_left_) && sp->xAxis2->range().contains(info_->sainfo()->num_nodes - 0.5))) {
+    if (h_pan && !(sp->xAxis2->range().contains(min_left_) && sp->xAxis2->range().contains(info_->sainfo()->num_nodes))) {
         sp->xAxis2->moveRange(h_pan);
         sp->replot();
     }
@@ -853,7 +853,7 @@ void SequenceDialog::rtpPlayerRemove()
 
 void SequenceDialog::on_buttonBox_helpRequested()
 {
-    wsApp->helpTopicAction(HELP_STAT_FLOW_GRAPH);
+    mainApp->helpTopicAction(HELP_STAT_FLOW_GRAPH);
 }
 
 SequenceInfo::SequenceInfo(seq_analysis_info_t *sainfo) :
