@@ -11,7 +11,7 @@
 #include <ui_show_packet_bytes_dialog.h>
 
 #include "main_window.h"
-#include "wireshark_application.h"
+#include "main_application.h"
 #include "ui/qt/widgets/wireshark_file_dialog.h"
 
 #include "epan/charsets.h"
@@ -19,7 +19,9 @@
 #include "wsutil/utf8_entities.h"
 
 #include <QAction>
+#include <QClipboard>
 #include <QImage>
+#include <QJsonDocument>
 #include <QKeyEvent>
 #include <QMenu>
 #include <QPrintDialog>
@@ -72,7 +74,9 @@ ShowPacketBytesDialog::ShowPacketBytesDialog(QWidget &parent, CaptureFile &cf) :
     ui->cbShowAs->addItem(tr("Hex Dump"), ShowAsHexDump);
     ui->cbShowAs->addItem(tr("HTML"), ShowAsHTML);
     ui->cbShowAs->addItem(tr("Image"), ShowAsImage);
+    ui->cbShowAs->addItem(tr("Json"), ShowAsJson);
     ui->cbShowAs->addItem(tr("Raw"), ShowAsRAW);
+    ui->cbShowAs->addItem(tr("Rust Array"), ShowAsRustArray);
     // UTF-8 is guaranteed to exist as a QTextCodec
     ui->cbShowAs->addItem(tr("UTF-8"), ShowAsCodec);
     ui->cbShowAs->addItem(tr("YAML"), ShowAsYAML);
@@ -80,7 +84,7 @@ ShowPacketBytesDialog::ShowPacketBytesDialog(QWidget &parent, CaptureFile &cf) :
     ui->cbShowAs->blockSignals(false);
 
     ui->sbStart->setMinimum(0);
-    ui->sbEnd->setMaximum(finfo_->length);
+    ui->sbEnd->setMaximum(finfo_->length - 1);
 
     print_button_ = ui->buttonBox->addButton(tr("Print"), QDialogButtonBox::ActionRole);
     connect(print_button_, SIGNAL(clicked()), this, SLOT(printBytes()));
@@ -93,7 +97,7 @@ ShowPacketBytesDialog::ShowPacketBytesDialog(QWidget &parent, CaptureFile &cf) :
 
     connect(ui->buttonBox, SIGNAL(helpRequested()), this, SLOT(helpButton()));
 
-    setStartAndEnd(0, finfo_->length);
+    setStartAndEnd(0, (finfo_->length - 1));
     updateFieldBytes(true);
 }
 
@@ -108,11 +112,7 @@ void ShowPacketBytesDialog::addCodecs(const QMap<QString, QTextCodec *> &codecMa
     // Make the combobox respect max visible items?
     //ui->cbShowAs->setStyleSheet("QComboBox { combobox-popup: 0;}");
     ui->cbShowAs->insertSeparator(ui->cbShowAs->count());
-#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
     for (const auto &codec : qAsConst(codecMap)) {
-#else
-    foreach (const QTextCodec *codec, codecMap) {
-#endif
         // This is already placed in the menu and handled separately
         if (codec->name() != "US-ASCII" && codec->name() != "UTF-8")
             ui->cbShowAs->addItem(tr(codec->name()), ShowAsCodec);
@@ -124,13 +124,13 @@ void ShowPacketBytesDialog::showSelected(int start, int end)
 {
     if (end == -1) {
         // end set to -1 means show all packet bytes
-        setStartAndEnd(0, finfo_->length);
+        setStartAndEnd(0, (finfo_->length - 1));
     } else {
         if (show_as_ == ShowAsRAW) {
             start /= 2;
             end = (end + 1) / 2;
         }
-        setStartAndEnd(start_ + start, start_ + end);
+        setStartAndEnd(start_ + start, start_ + end - 1);
     }
     updateFieldBytes();
 }
@@ -176,9 +176,9 @@ void ShowPacketBytesDialog::updateHintLabel()
 {
     QString hint = hint_label_;
 
-    if (start_ > 0 || end_ < finfo_->length) {
+    if (start_ > 0 || end_ < (finfo_->length - 1)) {
         hint.append(" <span style=\"color: red\">" +
-                    tr("Displaying %Ln byte(s).", "", end_ - start_) +
+                    tr("Displaying %Ln byte(s).", "", end_ - start_ + 1) +
                     "</span>");
     }
 
@@ -244,7 +244,11 @@ void ShowPacketBytesDialog::findText(bool go_back)
 
     bool found;
     if (use_regex_find_) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 13, 0))
+        QRegularExpression regex(ui->leFind->text(), QRegularExpression::UseUnicodePropertiesOption);
+#else
         QRegExp regex(ui->leFind->text());
+#endif
         found = ui->tePacketBytes->find(regex);
     } else {
         found = ui->tePacketBytes->find(ui->leFind->text());
@@ -276,36 +280,38 @@ void ShowPacketBytesDialog::copyBytes()
     {
         QByteArray ba(field_bytes_);
         sanitizeBuffer(ba, true);
-        wsApp->clipboard()->setText(ba);
+        mainApp->clipboard()->setText(ba);
         break;
     }
 
     case ShowAsASCIIandControl:
     case ShowAsCArray:
+    case ShowAsRustArray:
     case ShowAsEBCDIC:
     case ShowAsHexDump:
+    case ShowAsJson:
     case ShowAsRAW:
     case ShowAsYAML:
-        wsApp->clipboard()->setText(ui->tePacketBytes->toPlainText());
+        mainApp->clipboard()->setText(ui->tePacketBytes->toPlainText());
         break;
 
     case ShowAsHTML:
-        wsApp->clipboard()->setText(ui->tePacketBytes->toHtml());
+        mainApp->clipboard()->setText(ui->tePacketBytes->toHtml());
         break;
 
     case ShowAsImage:
-        wsApp->clipboard()->setImage(image_);
+        mainApp->clipboard()->setImage(image_);
         break;
 
     case ShowAsCodec:
-        wsApp->clipboard()->setText(ui->tePacketBytes->toPlainText().toUtf8());
+        mainApp->clipboard()->setText(ui->tePacketBytes->toPlainText().toUtf8());
         break;
     }
 }
 
 void ShowPacketBytesDialog::saveAs()
 {
-    QString file_name = WiresharkFileDialog::getSaveFileName(this, wsApp->windowTitleString(tr("Save Selected Packet Bytes As…")));
+    QString file_name = WiresharkFileDialog::getSaveFileName(this, mainApp->windowTitleString(tr("Save Selected Packet Bytes As…")));
 
     if (file_name.isEmpty())
         return;
@@ -315,9 +321,11 @@ void ShowPacketBytesDialog::saveAs()
     case ShowAsASCII:
     case ShowAsASCIIandControl:
     case ShowAsCArray:
+    case ShowAsRustArray:
     // We always save as UTF-8, so set text mode as we would for UTF-8
     case ShowAsCodec:
     case ShowAsHexDump:
+    case ShowAsJson:
     case ShowAsYAML:
     case ShowAsHTML:
         open_mode |= QFile::Text;
@@ -340,8 +348,10 @@ void ShowPacketBytesDialog::saveAs()
 
     case ShowAsASCIIandControl:
     case ShowAsCArray:
+    case ShowAsRustArray:
     case ShowAsEBCDIC:
     case ShowAsHexDump:
+    case ShowAsJson:
     case ShowAsYAML:
     {
         QTextStream out(&file);
@@ -374,7 +384,7 @@ void ShowPacketBytesDialog::saveAs()
 
 void ShowPacketBytesDialog::helpButton()
 {
-    wsApp->helpTopicAction(HELP_SHOW_PACKET_BYTES_DIALOG);
+    mainApp->helpTopicAction(HELP_SHOW_PACKET_BYTES_DIALOG);
 }
 
 void ShowPacketBytesDialog::on_bFind_clicked()
@@ -459,43 +469,19 @@ void ShowPacketBytesDialog::sanitizeBuffer(QByteArray &ba, bool keep_CR)
 
 void ShowPacketBytesDialog::symbolizeBuffer(QByteArray &ba)
 {
-    // Replace all octets that don't correspond to an ASCII
-    // character with MIDDLE DOT.  An octet corresponds to an
-    // ASCII character iff the 0x80 bit isn't set in its
-    // value; if char is signed (which it is *not* guaranteed
-    // to be; it is, for example, unsigned on non-Apple ARM
-    // platforms), sign-extension won't affect that bit, so
-    // simply testing the 0x80 bit suffices on all platforms.
     for (int i = 0; i < ba.length(); i++) {
-        if (ba[i] & 0x80) {
+        if ((ba[i] < '\0' || ba[i] >= ' ') && ba[i] != (char)0x7f && !g_ascii_isprint(ba[i])) {
             ba.replace(i, 1, UTF8_MIDDLE_DOT);
             i += sizeof(UTF8_MIDDLE_DOT) - 2;
         }
     }
 
-    // Replace all control characters (NUL through US, i.e. [0, ' '),
-    // and DEL, i.e. 0x7f) with the code point for the symbol for that
-    // character, i.e. the character's abbreviation in small letters.
-    //
-    // The UTF-8 encodings for those code points are all three octets
-    // long, from 0xe2 0x90 0x80 through 0xe2 0x90 0xa1, so we initialize
-    // a QByteArray with the octets for the symbol for NUL and, for
-    // each of the octets from 0x00 through 0x1f, replace all
-    // occurrences of that value with that sequence, and then add 1 to
-    // the last octet of the sequence to get the symbol for the next
-    // value and continue.
-    //
     QByteArray symbol(UTF8_SYMBOL_FOR_NULL);
     for (char i = 0; i < ' '; i++) {
-    	// Replace all occurrences of that value with that symbol.
         ba.replace(i, symbol);
-        // Get the symbol for the next value.
         symbol[2] = symbol[2] + 1;
     }
-    // symbol now has the UTF-8 for the symbol for SP, as that follows
-    // the symbol for US; skip it - the next code point is for the
-    // symbol for DEL.
-    symbol[2] = symbol[2] + 1;
+    symbol[2] = symbol[2] + 1;      // Skip SP
     ba.replace((char)0x7f, symbol); // DEL
 }
 
@@ -536,7 +522,7 @@ void ShowPacketBytesDialog::rot13(QByteArray &ba)
 void ShowPacketBytesDialog::updateFieldBytes(bool initialization)
 {
     int start = finfo_->start + start_;
-    int length = end_ - start_;
+    int length = end_ - start_ + 1;
     const guint8 *bytes;
     gsize new_length = 0;
 
@@ -607,7 +593,7 @@ void ShowPacketBytesDialog::updatePacketBytes(void)
     static const gchar hexchars[16] = {'0','1','2','3','4','5','6','7','8','9','a','b','c','d','e','f'};
 
     ui->tePacketBytes->clear();
-    ui->tePacketBytes->setCurrentFont(wsApp->monospaceFont());
+    ui->tePacketBytes->setCurrentFont(mainApp->monospaceFont());
 
     switch (show_as_) {
 
@@ -631,7 +617,7 @@ void ShowPacketBytesDialog::updatePacketBytes(void)
 
     case ShowAsCArray:
     {
-        int pos = 0, len = field_bytes_.length();
+        int pos = 0, len = static_cast<int>(field_bytes_.length());
         QString text("char packet_bytes[] = {\n");
 
         while (pos < len) {
@@ -666,6 +652,43 @@ void ShowPacketBytesDialog::updatePacketBytes(void)
         break;
     }
 
+    case ShowAsRustArray:
+    {
+        int pos = 0, len = static_cast<int>(field_bytes_.length());
+        QString text("let packet_bytes: [u8; _] = [\n");
+
+        while (pos < len) {
+            gchar hexbuf[256];
+            char *cur = hexbuf;
+            int i;
+
+            *cur++ = ' ';
+            for (i = 0; i < 8 && pos + i < len; i++) {
+                // Prepend entries with " 0x"
+                *cur++ = ' ';
+                *cur++ = '0';
+                *cur++ = 'x';
+                *cur++ = hexchars[(field_bytes_[pos + i] & 0xf0) >> 4];
+                *cur++ = hexchars[field_bytes_[pos + i] & 0x0f];
+
+                // Delimit array entries with a comma
+                if (pos + i + 1 < len)
+                    *cur++ = ',';
+            }
+
+            pos += i;
+            *cur++ = '\n';
+            *cur = 0;
+
+            text.append(hexbuf);
+        }
+
+        text.append("];\n");
+        ui->tePacketBytes->setLineWrapMode(QTextEdit::NoWrap);
+        ui->tePacketBytes->setPlainText(text);
+        break;
+    }
+
     case ShowAsCodec:
     {
         // The QTextCodecs docs say that there's a flag to cause invalid
@@ -683,7 +706,7 @@ void ShowPacketBytesDialog::updatePacketBytes(void)
     case ShowAsEBCDIC:
     {
         QByteArray ba(field_bytes_);
-        EBCDIC_to_ASCII((guint8*)ba.data(), ba.length());
+        EBCDIC_to_ASCII((guint8*)ba.data(), static_cast<int>(ba.length()));
         sanitizeBuffer(ba, false);
         ui->tePacketBytes->setLineWrapMode(QTextEdit::WidgetWidth);
         ui->tePacketBytes->setPlainText(ba);
@@ -692,7 +715,7 @@ void ShowPacketBytesDialog::updatePacketBytes(void)
 
     case ShowAsHexDump:
     {
-        int pos = 0, len = field_bytes_.length();
+        int pos = 0, len = static_cast<int>(field_bytes_.length());
         // Use 16-bit offset if there are <= 65536 bytes, 32-bit offset if there are more
         unsigned int offset_chars = (len - 1 <= 0xFFFF) ? 4 : 8;
         QString text;
@@ -704,7 +727,7 @@ void ShowPacketBytesDialog::updatePacketBytes(void)
             int i;
 
             // Dump offset
-            cur += g_snprintf(cur, 20, "%0*X  ", offset_chars, pos);
+            cur += snprintf(cur, 20, "%0*X  ", offset_chars, pos);
 
             // Dump bytes as hex
             for (i = 0; i < 16 && pos + i < len; i++) {
@@ -764,10 +787,15 @@ void ShowPacketBytesDialog::updatePacketBytes(void)
         break;
     }
 
+    case ShowAsJson:
+        ui->tePacketBytes->setLineWrapMode(QTextEdit::NoWrap);
+        ui->tePacketBytes->setPlainText(QJsonDocument::fromJson(field_bytes_).toJson());
+        break;
+
     case ShowAsYAML:
     {
         const int base64_raw_len = 57; // Encodes to 76 bytes, common in RFCs
-        int pos = 0, len = field_bytes_.length();
+        int pos = 0, len = static_cast<int>(field_bytes_.length());
         QString text("# Packet Bytes: !!binary |\n");
 
         while (pos < len) {
