@@ -7,7 +7,6 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#include "log.h"
 #include "traffic_table_dialog.h"
 #include <ui_traffic_table_dialog.h>
 
@@ -17,7 +16,7 @@
 #include "ui/recent.h"
 
 #include "progress_frame.h"
-#include "wireshark_application.h"
+#include "main_application.h"
 
 #include <QCheckBox>
 #include <QClipboard>
@@ -43,7 +42,6 @@
 TrafficTableDialog::TrafficTableDialog(QWidget &parent, CaptureFile &cf, const char *filter, const QString &table_name) :
     WiresharkDialog(parent, cf),
     ui(new Ui::TrafficTableDialog),
-    cap_file_(cf),
     filter_(filter),
     nanosecond_timestamps_(false)
 {
@@ -72,8 +70,8 @@ TrafficTableDialog::TrafficTableDialog(QWidget &parent, CaptureFile &cf, const c
         nanosecond_timestamps_ = true;
     }
 
-    connect(wsApp, SIGNAL(addressResolutionChanged()), this, SLOT(currentTabChanged()));
-    connect(wsApp, SIGNAL(addressResolutionChanged()), this, SLOT(updateWidgets()));
+    connect(mainApp, SIGNAL(addressResolutionChanged()), this, SLOT(currentTabChanged()));
+    connect(mainApp, SIGNAL(addressResolutionChanged()), this, SLOT(updateWidgets()));
     connect(ui->trafficTableTabWidget, SIGNAL(currentChanged(int)),
             this, SLOT(currentTabChanged()));
     connect(&cap_file_, SIGNAL(captureEvent(CaptureEvent)),
@@ -311,15 +309,15 @@ void TrafficTableDialog::copyAsCsv()
         foreach (QVariant v, curTreeRowData(row)) {
             if (!v.isValid()) {
                 rdsl << "\"\"";
-            } else if (v.type() == QVariant::String) {
+            } else if (v.userType() == QMetaType::QString) {
                 rdsl << QString("\"%1\"").arg(v.toString());
             } else {
                 rdsl << v.toString();
             }
         }
-        stream << rdsl.join(",") << endl;
+        stream << rdsl.join(",") << '\n';
     }
-    wsApp->clipboard()->setText(stream.readAll());
+    mainApp->clipboard()->setText(stream.readAll());
 }
 
 void TrafficTableDialog::copyAsYaml()
@@ -331,14 +329,14 @@ void TrafficTableDialog::copyAsYaml()
 
     QString yaml;
     QTextStream stream(&yaml, QIODevice::Text);
-    stream << "---" << endl;
+    stream << "---" << '\n';
     for (int row = -1; row < cur_tree->topLevelItemCount(); row ++) {
-        stream << "-" << endl;
+        stream << "-" << '\n';
         foreach (QVariant v, curTreeRowData(row)) {
-            stream << " - " << v.toString() << endl;
+            stream << " - " << v.toString() << '\n';
         }
     }
-    wsApp->clipboard()->setText(stream.readAll());
+    mainApp->clipboard()->setText(stream.readAll());
 }
 
 TrafficTableTreeWidget::TrafficTableTreeWidget(QWidget *parent, register_ct_t *table) :
@@ -350,7 +348,7 @@ TrafficTableTreeWidget::TrafficTableTreeWidget(QWidget *parent, register_ct_t *t
     setRootIsDecorated(false);
     sortByColumn(0, Qt::AscendingOrder);
 
-    connect(wsApp, SIGNAL(addressResolutionChanged()), this, SLOT(updateItemsForSettingChange()));
+    connect(mainApp, SIGNAL(addressResolutionChanged()), this, SLOT(updateItemsForSettingChange()));
 }
 
 QList<QVariant> TrafficTableTreeWidget::rowData(int row) const
@@ -422,16 +420,3 @@ void TrafficTableTreeWidget::updateItemsForSettingChange()
 {
     updateItems();
 }
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
