@@ -1,4 +1,4 @@
-/* traffic_table_dialog.h
+/** @file
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -123,7 +123,7 @@ signals:
 protected:
     Ui::TrafficTableDialog *ui;
 
-    CaptureFile &cap_file_;
+//    CaptureFile &cap_file_;
     QString filter_;
     QMenu traffic_type_menu_;
     QPushButton *copy_bt_;
@@ -168,16 +168,3 @@ private slots:
 };
 
 #endif // TRAFFIC_TABLE_DIALOG_H
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
