@@ -335,10 +335,6 @@ static GList *recent_cfilter_list;
 static GHashTable *per_interface_cfilter_lists_hash;
 
 /* XXX: use a preference for this setting! */
-/* N.B.: If we use a pref, we will read the recent_common file
- * before the pref, so don't truncate the list when reading
- * (see the similar #16782 for the recent files.)
- */
 static guint cfilter_combo_max_recent = 20;
 
 /**
@@ -404,7 +400,7 @@ recent_add_cfilter(const gchar *ifname, const gchar *s)
         /* The filter wasn't already in the list; make a copy to add. */
         newfilter = g_strdup(s);
     }
-    cfilter_list = g_list_prepend(cfilter_list, newfilter);
+    cfilter_list = g_list_append(cfilter_list, newfilter);
 
     if (ifname == NULL)
         recent_cfilter_list = cfilter_list;
@@ -604,33 +600,6 @@ cfilter_recent_write_all(FILE *rf)
     }
 }
 
-/** Reverse the order of all the capture filter lists after
- *  reading recent_common (we want the latest first).
- *  Note this is O(N), whereas appendng N items to a GList is O(N^2),
- *  since it doesn't have a pointer to the end like a GQueue.
- */
-static void
-cfilter_recent_reverse_all(void)
-{
-    recent_cfilter_list = g_list_reverse(recent_cfilter_list);
-
-    /* Reverse all the per-interface lists. */
-    if (per_interface_cfilter_lists_hash != NULL) {
-        GHashTableIter iter;
-        gpointer key, value;
-        g_hash_table_iter_init(&iter, per_interface_cfilter_lists_hash);
-        GList *li;
-        while (g_hash_table_iter_next(&iter, &key, &value)) {
-            li = (GList *)value;
-            li = g_list_reverse(li);
-            /* per_interface_cfilter_lists_hash was created without a
-             * value_destroy_func, so this is fine.
-             */
-            g_hash_table_iter_replace(&iter, li);
-        }
-    }
-}
-
 /* Write out recent settings of particular types. */
 static void
 write_recent_boolean(FILE *rf, const char *description, const char *name,
@@ -705,19 +674,21 @@ write_recent(void)
     }
     g_free(rf_path);
 
-    fputs("# Common recent settings file for Wireshark " VERSION ".\n"
+    fprintf(rf, "# Common recent settings file for %s " VERSION ".\n"
             "#\n"
-            "# This file is regenerated each time Wireshark is quit\n"
+            "# This file is regenerated each time %s is quit\n"
             "# and when changing configuration profile.\n"
             "# So be careful, if you want to make manual changes here.\n"
             "\n"
             "######## Recent capture files (latest last), cannot be altered through command line ########\n"
-            "\n", rf);
+            "\n",
+            get_configuration_namespace(), get_configuration_namespace());
+
 
     menu_recent_file_write_all(rf);
 
     fputs("\n"
-            "######## Recent capture filters (latest first), cannot be altered through command line ########\n"
+            "######## Recent capture filters (latest last), cannot be altered through command line ########\n"
             "\n", rf);
 
     cfilter_recent_write_all(rf);
@@ -847,12 +818,13 @@ write_profile_recent(void)
     }
     g_free(rf_path);
 
-    fputs("# Recent settings file for Wireshark " VERSION ".\n"
+    fprintf(rf, "# Recent settings file for %s " VERSION ".\n"
             "#\n"
-            "# This file is regenerated each time Wireshark is quit\n"
+            "# This file is regenerated each time %s is quit\n"
             "# and when changing configuration profile.\n"
             "# So be careful, if you want to make manual changes here.\n"
-            "\n", rf);
+            "\n",
+            get_configuration_namespace(), get_configuration_namespace());
 
     write_recent_boolean(rf, "Main Toolbar show (hide)",
             RECENT_KEY_MAIN_TOOLBAR_SHOW,
@@ -1478,10 +1450,6 @@ recent_read_dynamic(char **rf_path_return, int *rf_errno_return)
         /* set dfilter combobox to have an empty line */
         dfilter_combo_add_empty();
 #endif
-        /* We prepend new capture filters, so reverse them after adding
-         * all to keep the latest first.
-         */
-        cfilter_recent_reverse_all();
         fclose(rf);
     } else {
         /* We failed to open it.  If we failed for some reason other than
