@@ -1,4 +1,5 @@
-/* recent.h
+/** @file
+ *
  * Definitions for recent "preference" handling routines
  * Copyright 2004, Ulf Lamping <ulf.lamping@web.de>
  *
@@ -100,6 +101,7 @@ typedef struct recent_settings_tag {
     bytes_view_type gui_bytes_view;
     bytes_encoding_type gui_bytes_encoding;
     gboolean    gui_packet_diagram_field_values;
+    gboolean    gui_allow_hover_selection;
 
     search_in_type  gui_search_in;
     search_char_set_type gui_search_char_set;
