@@ -1,4 +1,5 @@
-/*
+/** @file
+ *
  * Copyright 2004-2013, Irene Ruengeler <i.ruengeler [AT] fh-muenster.de>
  *
  * Wireshark - Network traffic analyzer
@@ -11,20 +12,20 @@
 #ifndef __TAP_SCTP_ANALYSIS_H__
 #define __TAP_SCTP_ANALYSIS_H__
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
 #include <epan/dissectors/packet-sctp.h>
 #include <epan/address.h>
-#ifndef _WIN32
+#ifdef _WIN32
+#include <winsock2.h>
+#else
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
-#else
-#include <winsock2.h>
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 #define CHUNK_TYPE_LENGTH	      1
 #define CHUNK_FLAGS_LENGTH	      1
 #define CHUNK_LENGTH_LENGTH	      2
@@ -159,17 +160,14 @@ typedef struct _sctp_tmp_info {
 	guint32 n_tvbs;
 } sctp_tmp_info_t;
 
-typedef struct _sctp_min_max {
-	guint32 tmp_min_secs;
-	guint32 tmp_min_usecs;
-	guint32 tmp_max_secs;
-	guint32 tmp_max_usecs;
-	guint32 tmp_min_tsn1;
-	guint32 tmp_min_tsn2;
-	guint32 tmp_max_tsn1;
-	guint32 tmp_max_tsn2;
-	gint	tmp_secs;
-} sctp_min_max_t;
+typedef struct _sctp_init_collision {
+	guint32 init_vtag;		/* initiate tag of the INIT chunk */
+	guint32 initack_vtag;		/* initiate tag of the INIT-ACK chunk */
+	guint32 init_min_tsn;		/* initial tsn of the INIT chunk */
+	guint32 initack_min_tsn;	/* initial tsn of the INIT-ACK chunk */
+	gboolean init:1;
+	gboolean initack:1;
+} sctp_init_collision_t;
 
 struct tsn_sort{
 	guint32 tsnumber;
@@ -182,7 +180,7 @@ struct tsn_sort{
 
 typedef struct _sctp_addr_chunk {
 	guint32	 direction;
-	address *addr;
+	address addr;
 	/* The array is initialized to MAX_SCTP_CHUNK_TYPE
 	 * so that there is no memory overwrite
 	 * when accessed using sctp chunk type as index.
@@ -234,8 +232,10 @@ typedef struct _sctp_assoc_info {
 	guint32	   max_window2;
 	guint32	   arwnd1;
 	guint32	   arwnd2;
-	gboolean   init;
-	gboolean   initack;
+	gboolean   init:1;
+	gboolean   initack:1;
+	gboolean   firstdata:1;
+	gboolean   init_collision:1;
 	guint16	   initack_dir;
 	guint16	   direction;
 	guint32	   min_secs;
@@ -248,6 +248,8 @@ typedef struct _sctp_assoc_info {
 	guint32	   max_tsn2;
 	guint32	   max_bytes1;
 	guint32	   max_bytes2;
+	sctp_init_collision_t *dir1;
+	sctp_init_collision_t *dir2;
 	GSList	  *min_max;
 	GList	  *frame_numbers;
 	GList	  *tsn1;
@@ -294,7 +296,7 @@ void sctp_stat_scan(void);
 
 void remove_tap_listener_sctp_stat(void);
 
-
+const sctp_assoc_info_t* get_sctp_assoc_info(guint16 assoc_id);
 const sctp_assoc_info_t* get_selected_assoc(void);
 
 #ifdef __cplusplus
@@ -302,16 +304,3 @@ const sctp_assoc_info_t* get_selected_assoc(void);
 #endif /* __cplusplus */
 
 #endif /* __TAP_SCTP_ANALYSIS_H__ */
-
-/*
- * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
