@@ -27,7 +27,6 @@
 #include "file_wrappers.h"
 #include "required_file_handlers.h"
 #include <wsutil/buffer.h>
-#include <wsutil/str_util.h>
 
 #include "lanalyzer.h"
 #include "ngsniffer.h"
@@ -113,7 +112,7 @@ add_extensions(GSList *extensions, const gchar *extension,
 	    compression_type_extension != NULL;
 	    compression_type_extension = g_slist_next(compression_type_extension)) {
 		extensions = g_slist_prepend(extensions,
-		    g_strdup_printf("%s.%s", extension,
+		    ws_strdup_printf("%s.%s", extension,
 		        (const char *)compression_type_extension->data));
 	}
 
@@ -137,7 +136,6 @@ static const struct file_extension_info file_type_extensions_base[] = {
 	{ "Wireshark/tcpdump/... - pcap", TRUE, "pcap;cap;dmp" },
 	{ "Wireshark/... - pcapng", TRUE, "pcapng;ntar" },
 	{ "Network Monitor, Surveyor, NetScaler", TRUE, "cap" },
-	{ "Sun snoop", TRUE, "snoop" },
 	{ "InfoVista 5View capture", TRUE, "5vw" },
 	{ "Sniffer (DOS)", TRUE, "cap;enc;trc;fdc;syc" },
 	{ "Cinco NetXRay, Sniffer (Windows)", TRUE, "cap;caz" },
@@ -355,17 +353,13 @@ wtap_get_all_capture_file_extensions_list(void)
  * NOTE: when adding file formats to this list you may also want to add them
  * to the following files so that the various desktop environments will
  * know that Wireshark can open the file:
- *	1) org.wireshark.Wireshark-mime.xml (for freedesktop.org environments)
- *	2) packaging/macosx/Info.plist.in (for macOS)
+ *	1) resources/freedesktop/org.wireshark.Wireshark-mime.xml (for freedesktop.org environments)
+ *	2) packaging/macosx/WiresharkInfo.plist.in (for macOS)
+ *	3) packaging/nsis/AdditionalTasksPage.ini, packaging/nsis/common.nsh,
+ *	   and packaging/wix/ComponentGroups.wxi (for Windows)
  *
- * If your file format has a commonly-used extension (e.g., ".pcap") then you
- * should probably also add it to file_type_extensions_base[] (in this file),
- * to the list of "<glob pattern=...>" entries for this file format in
- * resources/freedesktop/org.wireshark.Wireshark-mime.xml, to the
- * CFBundleTypeExtensions array for this file format in
- * packaging/macosx/WiresharkInfo.plist, and to the PushFileExtensions macro
- * in packaging/nsis/common.nsh and the File Associations in
- * packaging/wix/ComponentGroups.wxi (for Windows).
+ * If your file format has an expected extension (e.g., ".pcap") then you
+ * should probably also add it to file_type_extensions_base[] (in this file).
  */
 static const struct open_info open_info_base[] = {
 	{ "Wireshark/tcpdump/... - pcap",           OPEN_INFO_MAGIC,     libpcap_open,             "pcap",     NULL, NULL },
@@ -443,6 +437,7 @@ static const struct open_info open_info_base[] = {
 	{ "Candump log",                            OPEN_INFO_HEURISTIC, candump_open,             NULL,       NULL, NULL },
 	{ "Busmaster log",                          OPEN_INFO_HEURISTIC, busmaster_open,           NULL,       NULL, NULL },
 	{ "Ericsson eNode-B raw log",               OPEN_INFO_MAGIC,     eri_enb_log_open,         NULL,       NULL, NULL },
+	{ "Systemd Journal",                        OPEN_INFO_HEURISTIC, systemd_journal_open,     "log;jnl;journal",      NULL, NULL },
 
 	/* ASCII trace files from Telnet sessions. */
 	{ "Lucent/Ascend access server trace",      OPEN_INFO_HEURISTIC, ascend_open,              "txt",      NULL, NULL },
@@ -452,7 +447,6 @@ static const struct open_info open_info_base[] = {
 	{ "CAM Inspector file",                     OPEN_INFO_HEURISTIC, camins_open,              "camins",   NULL, NULL },
 	{ "JavaScript Object Notation",             OPEN_INFO_HEURISTIC, json_open,                "json",     NULL, NULL },
 	{ "Ruby Marshal Object",                    OPEN_INFO_HEURISTIC, ruby_marshal_open,        "",         NULL, NULL },
-	{ "Systemd Journal",                        OPEN_INFO_HEURISTIC, systemd_journal_open,     "log;jnl;journal",      NULL, NULL },
 	{ "3gpp phone log",                         OPEN_INFO_MAGIC,     log3gpp_open,             "log",      NULL, NULL },
 	{ "MP4 media file",                         OPEN_INFO_MAGIC,     mp4_open,                 "mp4",      NULL, NULL },
 
@@ -682,13 +676,7 @@ get_file_extension(const char *pathname)
 	}
 
 	/*
-	 * Yes. Fold it to lowercase, since open_routines[] has
-	 * its extensions in lowercase.
-	 */
-	ascii_strdown_inplace(filename);
-
-	/*
-	 * Split it into components separated by ".".
+	 * Yes.  Split it into components separated by ".".
 	 */
 	components = g_strsplit(filename, ".", 0);
 	g_free(filename);
@@ -2407,7 +2395,7 @@ wtap_dump_open(const char *filename, int file_type_subtype,
 }
 
 wtap_dumper *
-wtap_dump_open_tempfile(char **filenamep, const char *pfx,
+wtap_dump_open_tempfile(const char *tmpdir, char **filenamep, const char *pfx,
     int file_type_subtype, wtap_compression_type compression_type,
     const wtap_dump_params *params, int *err, gchar **err_info)
 {
@@ -2438,7 +2426,7 @@ wtap_dump_open_tempfile(char **filenamep, const char *pfx,
 	(void) g_strlcat(sfx, ext, 16);
 
 	/* Choose a random name for the file */
-	fd = create_tempfile(filenamep, pfx, sfx, NULL);
+	fd = create_tempfile(tmpdir, filenamep, pfx, sfx, NULL);
 	if (fd == -1) {
 		*err = WTAP_ERR_CANT_OPEN;
 		g_free(wdh);
@@ -2633,7 +2621,7 @@ wtap_dump_flush(wtap_dumper *wdh, int *err)
 }
 
 gboolean
-wtap_dump_close_new_temp(wtap_dumper *wdh, gboolean *needs_reload,
+wtap_dump_close(wtap_dumper *wdh, gboolean *needs_reload,
     int *err, gchar **err_info)
 {
 	gboolean ret = TRUE;
@@ -2660,17 +2648,11 @@ wtap_dump_close_new_temp(wtap_dumper *wdh, gboolean *needs_reload,
 		*needs_reload = wdh->needs_reload;
 	g_free(wdh->priv);
 	wtap_block_array_free(wdh->interface_data);
-	wtap_block_array_unref(wdh->dsbs_initial);
+	wtap_block_array_free(wdh->dsbs_initial);
 	g_free(wdh);
 	return ret;
 }
 
-gboolean
-wtap_dump_close(wtap_dumper *wdh, int *err, gchar **err_info)
-{
-	return wtap_dump_close_new_temp(wdh, NULL, err, err_info);
-}
-
 int
 wtap_dump_file_type_subtype(wtap_dumper *wdh)
 {
@@ -2730,10 +2712,6 @@ wtap_dump_discard_decryption_secrets(wtap_dumper *wdh)
 	}
 }
 
-gboolean wtap_dump_get_needs_reload(wtap_dumper *wdh) {
-        return wdh->needs_reload;
-}
-
 /* internally open a file for writing (compressed or not) */
 #ifdef HAVE_ZLIB
 static WFILE_T
