@@ -1,4 +1,4 @@
-/* wtap.h
+/** @file
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -9,14 +9,12 @@
 #ifndef __WTAP_H__
 #define __WTAP_H__
 
-#include <glib.h>
+#include <wireshark.h>
 #include <time.h>
 #include <wsutil/buffer.h>
 #include <wsutil/nstime.h>
 #include <wsutil/inet_addr.h>
 #include "wtap_opttypes.h"
-#include "ws_symbol_export.h"
-#include "ws_attributes.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -291,6 +289,7 @@ extern "C" {
 #define WTAP_ENCAP_ZWAVE_SERIAL                 211
 #define WTAP_ENCAP_ETW                          212
 #define WTAP_ENCAP_ERI_ENB_LOG                  213
+#define WTAP_ENCAP_ZBNCP			214
 
 /* After adding new item here, please also add new item to encap_table_base array */
 
@@ -533,6 +532,7 @@ struct p2p_phdr {
 #define PHDR_802_11_PHY_11AD           9 /* 802.11ad */
 #define PHDR_802_11_PHY_11AH          10 /* 802.11ah */
 #define PHDR_802_11_PHY_11AX          11 /* 802.11ax */
+#define PHDR_802_11_PHY_11BE          12 /* 802.11be - EHT */
 
 /*
  * PHY-specific information.
@@ -1338,6 +1338,7 @@ typedef struct {
 typedef struct {
     guint     rec_type;          /* what type of record is this? */
     guint32   presence_flags;    /* what stuff do we have? */
+    guint     section_number;    /* section, within file, containing this record */
     nstime_t  ts;                /* time stamp */
     int       tsprec;            /* WTAP_TSPREC_ value for this record */
     union {
@@ -1378,11 +1379,12 @@ typedef struct {
  * absent, use the file encapsulation - but it's not clear that's useful;
  * we currently do that in the module for the file format.
  *
- * Only WTAP_HAS_TS applies to all record types.
+ * Only WTAP_HAS_TS and WTAP_HAS_SECTION_NUMBER apply to all record types.
  */
-#define WTAP_HAS_TS            0x00000001  /**< time stamp */
-#define WTAP_HAS_CAP_LEN       0x00000002  /**< captured length separate from on-the-network length */
-#define WTAP_HAS_INTERFACE_ID  0x00000004  /**< interface ID */
+#define WTAP_HAS_TS             0x00000001  /**< time stamp */
+#define WTAP_HAS_CAP_LEN        0x00000002  /**< captured length separate from on-the-network length */
+#define WTAP_HAS_INTERFACE_ID   0x00000004  /**< interface ID */
+#define WTAP_HAS_SECTION_NUMBER 0x00000008  /**< section number */
 
 #ifndef MAXNAMELEN
 #define MAXNAMELEN  	64	/* max name length (hostname and port name) */
@@ -1419,8 +1421,7 @@ typedef struct addrinfo_lists {
  * @note The shb_hdr, idb_inf, and nrb_hdr arguments will be used until
  *     wtap_dump_close() is called, but will not be free'd by the dumper. If
  *     you created them, you must free them yourself after wtap_dump_close().
- *     dsbs_initial will be unreferenced by wtap_dump_close(), so to reuse
- *     them for another dump file, call wtap_block_array_ref() before closing.
+ *     dsbs_initial will be freed by wtap_dump_close(),
  *     dsbs_growing typically refers to another wth->dsbs.
  *
  * @see wtap_dump_params_init, wtap_dump_params_cleanup.
@@ -1623,46 +1624,62 @@ struct supported_block_type {
     sizeof block_type_array / sizeof block_type_array[0], block_type_array
 
 struct file_type_subtype_info {
-    /*
+    /**
      * The file type description.
      */
     const char *description;
 
-    /*
+    /**
      * The file type name, used to look up file types by name, e.g.
      * looking up a file type specified as a command-line argument.
      */
     const char *name;
 
-    /* the default file extension, used to save this type */
-    /* should be NULL if no default extension is known */
+    /**
+     * The default file extension, used to save this type.
+     * Should be NULL if no default extension is known.
+     */
     const char *default_file_extension;
 
-    /* a semicolon-separated list of additional file extensions */
-    /* used for this type */
-    /* should be NULL if no extensions, or no extensions other */
-    /* than the default extension, are known */
+    /**
+     * A semicolon-separated list of additional file extensions
+     * used for this type.
+     * Should be NULL if no extensions, or no extensions other
+     * than the default extension, are known.
+     */
     const char *additional_file_extensions;
 
-    /* when writing this file format, is seeking required? */
+    /**
+     * When writing this file format, is seeking required?
+     */
     gboolean writing_must_seek;
 
-    /* Number of block types supported. */
+    /**
+     * Number of block types supported.
+     */
     size_t num_supported_blocks;
 
-    /* Table of block types supported. */
+    /**
+     * Table of block types supported.
+     */
     const struct supported_block_type *supported_blocks;
 
-    /* can this type write this encapsulation format? */
-    /* should be NULL is this file type doesn't have write support */
+    /**
+     * Can this type write this encapsulation format?
+     * Should be NULL is this file type doesn't have write support.
+     */
     int (*can_write_encap)(int);
 
-    /* the function to open the capture file for writing */
-    /* should be NULL is this file type don't have write support */
+    /**
+     * The function to open the capture file for writing.
+     * Should be NULL if this file type doesn't have write support.
+     */
     int (*dump_open)(wtap_dumper *, int *, gchar **);
 
-    /* if can_write_encap returned WTAP_ERR_CHECK_WSLUA, then this is used instead */
-    /* this should be NULL for everyone except Lua-based file writers */
+    /**
+     * If can_write_encap returned WTAP_ERR_CHECK_WSLUA, then this is used instead.
+     * This should be NULL for everyone except Lua-based file writers.
+     */
     wtap_wslua_file_info_t *wslua_info;
 };
 
@@ -2025,6 +2042,7 @@ wtap_dumper* wtap_dump_open(const char *filename, int file_type_subtype,
 /**
  * @brief Creates a dumper for a temporary file.
  *
+ * @param tmpdir Directory in which to create the temporary file.
  * @param filenamep Points to a pointer that's set to point to the
  *        pathname of the temporary file; it's allocated with g_malloc()
  * @param pfx A string to be used as the prefix for the temporary file name
@@ -2037,7 +2055,8 @@ wtap_dumper* wtap_dump_open(const char *filename, int file_type_subtype,
  * @return The newly created dumper object, or NULL on failure.
  */
 WS_DLL_PUBLIC
-wtap_dumper* wtap_dump_open_tempfile(char **filenamep, const char *pfx,
+wtap_dumper* wtap_dump_open_tempfile(const char *tmpdir, char **filenamep,
+    const char *pfx,
     int file_type_subtype, wtap_compression_type compression_type,
     const wtap_dump_params *params, int *err, gchar **err_info);
 
@@ -2105,26 +2124,26 @@ gboolean wtap_addrinfo_list_empty(addrinfo_lists_t *addrinfo_lists);
 WS_DLL_PUBLIC
 gboolean wtap_dump_set_addrinfo_list(wtap_dumper *wdh, addrinfo_lists_t *addrinfo_lists);
 WS_DLL_PUBLIC
-gboolean wtap_dump_get_needs_reload(wtap_dumper *wdh);
-WS_DLL_PUBLIC
 void wtap_dump_discard_decryption_secrets(wtap_dumper *wdh);
 
 /**
  * Closes open file handles and frees memory associated with wdh. Note that
  * shb_hdr, idb_inf and nrb_hdr are not freed by this routine.
+ *
+ * @param wdh handle for the file we're closing.
+ * @param[out] needs_reload if not null, points to a gboolean that will
+ *    be set to TRUE if a full reload of the file would be required if
+ *    this was done as part of a "Save" or "Save As" operation, FALSE
+ *    if no full reload would be required.
+ * @param[out] err points to an int that will be set to an error code
+ *    on failure.
+ * @param[out] err_info for some errors, points to a gchar * that will
+ *    be set to a string giving more details of the error.
+ *
+ * @return TRUE on success, FALSE on failure.
  */
 WS_DLL_PUBLIC
-gboolean wtap_dump_close(wtap_dumper *wdh, int *err, gchar **err_info);
-
-/**
- * Like wtap_dump_close(), but returns a "must be reloaded" indication.
- * This will not be present in future Wireshark releases; instead,
- * wtap_dump_close() will change to have the additional needs_reload
- * argument, which can be NULL if that information isn't required by
- * the caller.
- */
-WS_DLL_PUBLIC
-gboolean wtap_dump_close_new_temp(wtap_dumper *wdh, gboolean *needs_reload,
+gboolean wtap_dump_close(wtap_dumper *wdh, gboolean *needs_reload,
     int *err, gchar **err_info);
 
 /**
@@ -2271,86 +2290,86 @@ void wtap_cleanup(void);
  * Wiretap error codes.
  */
 #define WTAP_ERR_NOT_REGULAR_FILE              -1
-    /** The file being opened for reading isn't a plain file (or pipe) */
+    /**< The file being opened for reading isn't a plain file (or pipe) */
 
 #define WTAP_ERR_RANDOM_OPEN_PIPE              -2
-    /** The file is being opened for random access and it's a pipe */
+    /**< The file is being opened for random access and it's a pipe */
 
 #define WTAP_ERR_FILE_UNKNOWN_FORMAT           -3
-    /** The file being opened is not a capture file in a known format */
+    /**< The file being opened is not a capture file in a known format */
 
 #define WTAP_ERR_UNSUPPORTED                   -4
-    /** Supported file type, but there's something in the file we
+    /**< Supported file type, but there's something in the file we
        can't support */
 
 #define WTAP_ERR_CANT_WRITE_TO_PIPE            -5
-    /** Wiretap can't save to a pipe in the specified format */
+    /**< Wiretap can't save to a pipe in the specified format */
 
 #define WTAP_ERR_CANT_OPEN                     -6
-    /** The file couldn't be opened, reason unknown */
+    /**< The file couldn't be opened, reason unknown */
 
 #define WTAP_ERR_UNWRITABLE_FILE_TYPE          -7
-    /** Wiretap can't save files in the specified format */
+    /**< Wiretap can't save files in the specified format */
 
 #define WTAP_ERR_UNWRITABLE_ENCAP              -8
-    /** Wiretap can't read or save files in the specified format with the
+    /**< Wiretap can't read or save files in the specified format with the
        specified encapsulation */
 
 #define WTAP_ERR_ENCAP_PER_PACKET_UNSUPPORTED  -9
-    /** The specified format doesn't support per-packet encapsulations */
+    /**< The specified format doesn't support per-packet encapsulations */
 
 #define WTAP_ERR_CANT_WRITE                   -10
-    /** An attempt to read failed, reason unknown */
+    /**< An attempt to read failed, reason unknown */
 
 #define WTAP_ERR_CANT_CLOSE                   -11
-    /** The file couldn't be closed, reason unknown */
+    /**< The file couldn't be closed, reason unknown */
 
 #define WTAP_ERR_SHORT_READ                   -12
-    /** An attempt to read read less data than it should have */
+    /**< An attempt to read less data than it should have */
 
 #define WTAP_ERR_BAD_FILE                     -13
-    /** The file appears to be damaged or corrupted or otherwise bogus */
+    /**< The file appears to be damaged or corrupted or otherwise bogus */
 
 #define WTAP_ERR_SHORT_WRITE                  -14
-    /** An attempt to write wrote less data than it should have */
+    /**< An attempt to write wrote less data than it should have */
 
 #define WTAP_ERR_UNC_OVERFLOW                 -15
-    /** Uncompressing Sniffer data would overflow buffer */
+    /**< Uncompressing Sniffer data would overflow buffer */
 
 #define WTAP_ERR_RANDOM_OPEN_STDIN            -16
-    /** We're trying to open the standard input for random access */
+    /**< We're trying to open the standard input for random access */
 
 #define WTAP_ERR_COMPRESSION_NOT_SUPPORTED    -17
-    /* The filetype doesn't support output compression */
+    /**< The filetype doesn't support output compression */
 
 #define WTAP_ERR_CANT_SEEK                    -18
-    /** An attempt to seek failed, reason unknown */
+    /**< An attempt to seek failed, reason unknown */
 
 #define WTAP_ERR_CANT_SEEK_COMPRESSED         -19
-    /** An attempt to seek on a compressed stream */
+    /**< An attempt to seek on a compressed stream */
 
 #define WTAP_ERR_DECOMPRESS                   -20
-    /** Error decompressing */
+    /**< Error decompressing */
 
 #define WTAP_ERR_INTERNAL                     -21
-    /** "Shouldn't happen" internal errors */
+    /**< "Shouldn't happen" internal errors */
 
 #define WTAP_ERR_PACKET_TOO_LARGE             -22
-    /** Packet being written is larger than we support; do not use when
+    /**< Packet being written is larger than we support; do not use when
         reading, use WTAP_ERR_BAD_FILE instead */
 
 #define WTAP_ERR_CHECK_WSLUA                  -23
-    /** Not really an error: the file type being checked is from a Lua
+    /**< Not really an error: the file type being checked is from a Lua
         plugin, so that the code will call wslua_can_write_encap() instead if it gets this */
 
 #define WTAP_ERR_UNWRITABLE_REC_TYPE          -24
-    /** Specified record type can't be written to that file type */
+    /**< Specified record type can't be written to that file type */
 
 #define WTAP_ERR_UNWRITABLE_REC_DATA          -25
-    /** Something in the record data can't be written to that file type */
+    /**< Something in the record data can't be written to that file type */
 
 #define WTAP_ERR_DECOMPRESSION_NOT_SUPPORTED  -26
-    /** We don't support decompressing that type of compressed file */
+    /**< We don't support decompressing that type of compressed file */
 
 #ifdef __cplusplus
 }
