@@ -1,4 +1,4 @@
-/* file_util.h
+/** @file
  * File utility definitions
  *
  * Wireshark - Network traffic analyzer
@@ -101,6 +101,10 @@ WS_DLL_PUBLIC FILE * ws_stdio_freopen (const gchar *filename, const gchar *mode,
  * These routines don't take pathnames, so they don't require
  * pathname-converting wrappers on Windows.
  */
+
+typedef unsigned int ws_file_size_t;
+typedef signed int ws_file_ssize_t;
+
 #define ws_read    _read
 #define ws_write   _write
 #define ws_close   _close
@@ -161,10 +165,6 @@ WS_DLL_PUBLIC void create_app_running_mutex(void);
  */
 WS_DLL_PUBLIC void close_app_running_mutex(void);
 
-/** Close a file descriptor if it is not open
- */
-WS_DLL_PUBLIC int ws_close_if_possible(int fd);
-
 #else	/* _WIN32 */
 
 /*
@@ -182,6 +182,9 @@ WS_DLL_PUBLIC int ws_close_if_possible(int fd);
 #define ws_fopen		fopen
 #define ws_freopen		freopen
 
+typedef size_t ws_file_size_t;
+typedef ssize_t ws_file_ssize_t;
+
 #define ws_read    read
 #define ws_write   write
 #ifdef __cplusplus
@@ -192,9 +195,6 @@ WS_DLL_PUBLIC int ws_close_if_possible(int fd);
 #else
 #define ws_close   close
 #endif
-
-#define ws_close_if_possible ws_close
-
 #define ws_dup     dup
 #ifdef HAVE_FSEEKO
 #define ws_fseek64 fseeko	/* AC_SYS_LARGEFILE should make off_t 64-bit */
