@@ -12,26 +12,174 @@
 #include <glib.h>
 #include <wsutil/utf8_entities.h>
 
-#include "str_util.h"
+#include "inet_addr.h"
 
+static void test_inet_pton4_test1(void)
+{
+    const char *str;
+    bool ok;
+    ws_in4_addr result, expect;
+
+    str = "198.51.100.200";
+    expect = g_htonl(3325256904);
+    ok = ws_inet_pton4(str, &result);
+    g_assert_true(ok);
+    g_assert_cmpint(result, ==, expect);
+}
+
+static void test_inet_ntop4_test1(void)
+{
+    char result[WS_INET_ADDRSTRLEN];
+    const char *expect, *ptr;
+    ws_in4_addr addr;
+
+    addr = g_htonl(3325256904);
+    expect = "198.51.100.200";
+    ptr = ws_inet_ntop4(&addr, result, sizeof(result));
+    g_assert_true(ptr == result);
+    g_assert_cmpstr(result, ==, expect);
+}
+
+struct in6_test {
+    char str[WS_INET6_ADDRSTRLEN];
+    ws_in6_addr addr;
+};
+
+static struct in6_test in6_test1 = {
+    .str = "2001:db8:ffaa:ddbb:1199:2288:3377:1",
+    .addr = { { 0x20, 0x01, 0x0d, 0xb8, 0xff, 0xaa, 0xdd, 0xbb,
+                0x11, 0x99, 0x22, 0x88, 0x33, 0x77, 0x00, 0x01 } }
+};
+
+static void test_inet_pton6_test1(void)
+{
+    bool ok;
+    ws_in6_addr result;
+
+    ok = ws_inet_pton6(in6_test1.str, &result);
+    g_assert_true(ok);
+    g_assert_cmpmem(&result, sizeof(result), &in6_test1.addr, sizeof(in6_test1.addr));
+}
+
+static void test_inet_ntop6_test1(void)
+{
+    char result[WS_INET6_ADDRSTRLEN];
+    const char *ptr;
+
+    ptr = ws_inet_ntop6(&in6_test1.addr, result, sizeof(result));
+    g_assert_true(ptr == result);
+    g_assert_cmpstr(result, ==, in6_test1.str);
+}
+
+#include "str_util.h"
 
 static void test_format_size(void)
 {
     char *str;
 
-    str = format_size(10000, format_size_unit_bytes);
+    str = format_size(10000, FORMAT_SIZE_UNIT_BYTES, FORMAT_SIZE_PREFIX_SI);
     g_assert_cmpstr(str, ==, "10 kB");
     g_free(str);
 
-    str = format_size(100000, format_size_unit_bytes|format_size_prefix_iec);
+    str = format_size(100000, FORMAT_SIZE_UNIT_BYTES, FORMAT_SIZE_PREFIX_IEC);
     g_assert_cmpstr(str, ==, "97 KiB");
     g_free(str);
 
-    str = format_size(20971520, format_size_unit_bits|format_size_prefix_iec);
+    str = format_size(20971520, FORMAT_SIZE_UNIT_BITS, FORMAT_SIZE_PREFIX_IEC);
     g_assert_cmpstr(str, ==, "20 Mib");
     g_free(str);
 }
 
+static void test_escape_string(void)
+{
+    char *buf;
+
+    buf = ws_escape_string(NULL, "quoted \"\\\" backslash", TRUE);
+    g_assert_cmpstr(buf, ==, "\"quoted \\\"\\\\\\\" backslash\"");
+    wmem_free(NULL, buf);
+
+    buf = ws_escape_string(NULL, "whitespace \t \n \r \f \v", TRUE);
+    g_assert_cmpstr(buf, ==, "\"whitespace \\t \\n \\r \\f \\v""\"");
+    wmem_free(NULL, buf);
+}
+
+static void test_strconcat(void)
+{
+    wmem_allocator_t   *allocator;
+    char               *new_str;
+
+    allocator = wmem_allocator_new(WMEM_ALLOCATOR_BLOCK);
+
+    new_str = wmem_strconcat(allocator, "ABC", NULL);
+    g_assert_cmpstr(new_str, ==, "ABC");
+
+    new_str = wmem_strconcat(allocator, "ABC", "DEF", NULL);
+    g_assert_cmpstr(new_str, ==, "ABCDEF");
+
+    new_str = wmem_strconcat(allocator, "", "", "ABCDEF", "", "GH", NULL);
+    g_assert_cmpstr(new_str, ==, "ABCDEFGH");
+
+    wmem_destroy_allocator(allocator);
+}
+
+static void test_strsplit(void)
+{
+    wmem_allocator_t   *allocator;
+    char              **split_str;
+
+    allocator = wmem_allocator_new(WMEM_ALLOCATOR_BLOCK);
+
+    split_str = wmem_strsplit(allocator, "A-C", "-", 2);
+    g_assert_cmpstr(split_str[0], ==, "A");
+    g_assert_cmpstr(split_str[1], ==, "C");
+    g_assert_null(split_str[2]);
+
+    split_str = wmem_strsplit(allocator, "A-C", "-", 0);
+    g_assert_cmpstr(split_str[0], ==, "A");
+    g_assert_cmpstr(split_str[1], ==, "C");
+    g_assert_null(split_str[2]);
+
+    split_str = wmem_strsplit(allocator, "--aslkf-asio--asfj-as--", "-", 10);
+    g_assert_cmpstr(split_str[0], ==, "");
+    g_assert_cmpstr(split_str[1], ==, "");
+    g_assert_cmpstr(split_str[2], ==, "aslkf");
+    g_assert_cmpstr(split_str[3], ==, "asio");
+    g_assert_cmpstr(split_str[4], ==, "");
+    g_assert_cmpstr(split_str[5], ==, "asfj");
+    g_assert_cmpstr(split_str[6], ==, "as");
+    g_assert_cmpstr(split_str[7], ==, "");
+    g_assert_cmpstr(split_str[8], ==, "");
+    g_assert_null(split_str[9]);
+
+    split_str = wmem_strsplit(allocator, "--aslkf-asio--asfj-as--", "-", 5);
+    g_assert_cmpstr(split_str[0], ==, "");
+    g_assert_cmpstr(split_str[1], ==, "");
+    g_assert_cmpstr(split_str[2], ==, "aslkf");
+    g_assert_cmpstr(split_str[3], ==, "asio");
+    g_assert_cmpstr(split_str[4], ==, "-asfj-as--");
+    g_assert_null(split_str[5]);
+
+    split_str = wmem_strsplit(allocator, "", "-", -1);
+    g_assert_null(split_str[0]);
+
+    wmem_destroy_allocator(allocator);
+}
+
+static void test_str_ascii(void)
+{
+    wmem_allocator_t   *allocator;
+    const char         *orig_str;
+    char               *new_str;
+
+    allocator = wmem_allocator_new(WMEM_ALLOCATOR_BLOCK);
+
+    orig_str = "TeStAsCiIsTrDoWn";
+    new_str = wmem_ascii_strdown(allocator, orig_str, -1);
+    g_assert_cmpstr(new_str, ==, "testasciistrdown");
+
+    wmem_destroy_allocator(allocator);
+}
+
 #include "to_str.h"
 
 static void test_word_to_hex(void)
@@ -104,6 +252,60 @@ static void test_bytes_to_str_punct(void)
     g_free(str);
 }
 
+static void test_bytes_to_str_punct_maxlen(void)
+{
+    char *str;
+
+    const guint8 buf[] = { 1, 2, 3};
+
+    str = bytes_to_str_punct_maxlen(NULL, buf, sizeof(buf), ':', 4);
+    g_assert_cmpstr(str, ==, "01:02:03");
+    g_free(str);
+
+    str = bytes_to_str_punct_maxlen(NULL, buf, sizeof(buf), ':', 3);
+    g_assert_cmpstr(str, ==, "01:02:03");
+    g_free(str);
+
+    str = bytes_to_str_punct_maxlen(NULL, buf, sizeof(buf), ':', 2);
+    g_assert_cmpstr(str, ==, "01:02:" UTF8_HORIZONTAL_ELLIPSIS);
+    g_free(str);
+
+    str = bytes_to_str_punct_maxlen(NULL, buf, sizeof(buf), ':', 1);
+    g_assert_cmpstr(str, ==, "01:" UTF8_HORIZONTAL_ELLIPSIS);
+    g_free(str);
+
+    str = bytes_to_str_punct_maxlen(NULL, buf, sizeof(buf), ':', 0);
+    g_assert_cmpstr(str, ==, "01:02:03");
+    g_free(str);
+}
+
+static void test_bytes_to_str_maxlen(void)
+{
+    char *str;
+
+    const guint8 buf[] = { 1, 2, 3};
+
+    str = bytes_to_str_maxlen(NULL, buf, sizeof(buf), 4);
+    g_assert_cmpstr(str, ==, "010203");
+    g_free(str);
+
+    str = bytes_to_str_maxlen(NULL, buf, sizeof(buf), 3);
+    g_assert_cmpstr(str, ==, "010203");
+    g_free(str);
+
+    str = bytes_to_str_maxlen(NULL, buf, sizeof(buf), 2);
+    g_assert_cmpstr(str, ==, "0102" UTF8_HORIZONTAL_ELLIPSIS);
+    g_free(str);
+
+    str = bytes_to_str_maxlen(NULL, buf, sizeof(buf), 1);
+    g_assert_cmpstr(str, ==, "01" UTF8_HORIZONTAL_ELLIPSIS);
+    g_free(str);
+
+    str = bytes_to_str_maxlen(NULL, buf, sizeof(buf), 0);
+    g_assert_cmpstr(str, ==, "010203");
+    g_free(str);
+}
+
 static void test_bytes_to_string_trunc1(void)
 {
     char *str;
@@ -294,6 +496,71 @@ static void test_int64_to_str_back(void)
     g_assert_cmpstr(str, ==, "9223372036854775807");
 }
 
+#include "nstime.h"
+#include "time_util.h"
+
+void test_nstime_from_iso8601(void)
+{
+    char *str;
+    size_t chars;
+    nstime_t result, expect;
+    struct tm tm1;
+
+    memset(&tm1, 0, sizeof(tm1));
+    tm1.tm_sec = 25;
+    tm1.tm_min = 45;
+    tm1.tm_hour = 23;
+    tm1.tm_mday = 30;
+    tm1.tm_mon = 4; /* starts at zero */
+    tm1.tm_year = 2013 - 1900;
+    tm1.tm_isdst = -1;
+
+    /* Date and time with local time. */
+    str = "2013-05-30T23:45:25.349124";
+    expect.secs = mktime(&tm1);
+    expect.nsecs = 349124 * 1000;
+    chars = iso8601_to_nstime(&result, str, ISO8601_DATETIME_AUTO);
+    g_assert_cmpuint(chars, ==, strlen(str));
+    g_assert_cmpint(result.secs, ==, expect.secs);
+    g_assert_cmpint(result.nsecs, ==, expect.nsecs);
+
+    /* Date and time with UTC timezone. */
+    str = "2013-05-30T23:45:25.349124Z";
+    expect.secs = mktime_utc(&tm1);
+    expect.nsecs = 349124 * 1000;
+    chars = iso8601_to_nstime(&result, str, ISO8601_DATETIME_AUTO);
+    g_assert_cmpuint(chars, ==, strlen(str));
+    g_assert_cmpint(result.secs, ==, expect.secs);
+    g_assert_cmpint(result.nsecs, ==, expect.nsecs);
+
+    /* Date and time with timezone offset with separator. */
+    str = "2013-05-30T23:45:25.349124+01:00";
+    expect.secs = mktime_utc(&tm1) - 1 * 60 * 60;
+    expect.nsecs = 349124 * 1000;
+    chars = iso8601_to_nstime(&result, str, ISO8601_DATETIME_AUTO);
+    g_assert_cmpuint(chars, ==, strlen(str));
+    g_assert_cmpint(result.secs, ==, expect.secs);
+    g_assert_cmpint(result.nsecs, ==, expect.nsecs);
+
+    /* Date and time with timezone offset without separator. */
+    str = "2013-05-30T23:45:25.349124+0100";
+    expect.secs = mktime_utc(&tm1) - 1 * 60 * 60;
+    expect.nsecs = 349124 * 1000;
+    chars = iso8601_to_nstime(&result, str, ISO8601_DATETIME_AUTO);
+    g_assert_cmpuint(chars, ==, strlen(str));
+    g_assert_cmpint(result.secs, ==, expect.secs);
+    g_assert_cmpint(result.nsecs, ==, expect.nsecs);
+
+    /* Date and time with timezone offset with hours only. */
+    str = "2013-05-30T23:45:25.349124+01";
+    expect.secs = mktime_utc(&tm1) - 1 * 60 * 60;
+    expect.nsecs = 349124 * 1000;
+    chars = iso8601_to_nstime(&result, str, ISO8601_DATETIME_AUTO);
+    g_assert_cmpuint(chars, ==, strlen(str));
+    g_assert_cmpint(result.secs, ==, expect.secs);
+    g_assert_cmpint(result.nsecs, ==, expect.nsecs);
+}
+
 #include "ws_getopt.h"
 
 #define ARGV_MAX 31
@@ -473,11 +740,22 @@ int main(int argc, char **argv)
 
     g_test_init(&argc, &argv, NULL);
 
+    g_test_add_func("/inet_addr/inet_pton4", test_inet_pton4_test1);
+    g_test_add_func("/inet_addr/inet_ntop4", test_inet_ntop4_test1);
+    g_test_add_func("/inet_addr/inet_pton6", test_inet_pton6_test1);
+    g_test_add_func("/inet_addr/inet_ntop6", test_inet_ntop6_test1);
+
     g_test_add_func("/str_util/format_size", test_format_size);
+    g_test_add_func("/str_util/escape_string", test_escape_string);
+    g_test_add_func("/str_util/strconcat", test_strconcat);
+    g_test_add_func("/str_util/strsplit", test_strsplit);
+    g_test_add_func("/str_util/str_ascii", test_str_ascii);
 
     g_test_add_func("/to_str/word_to_hex", test_word_to_hex);
     g_test_add_func("/to_str/bytes_to_str", test_bytes_to_str);
     g_test_add_func("/to_str/bytes_to_str_punct", test_bytes_to_str_punct);
+    g_test_add_func("/to_str/bytes_to_str_maxlen", test_bytes_to_str_maxlen);
+    g_test_add_func("/to_str/bytes_to_str_punct_maxlen", test_bytes_to_str_punct_maxlen);
     g_test_add_func("/to_str/bytes_to_str_trunc1", test_bytes_to_string_trunc1);
     g_test_add_func("/to_str/bytes_to_str_punct_trunc1", test_bytes_to_string_punct_trunc1);
     g_test_add_func("/to_str/oct_to_str_back", test_oct_to_str_back);
@@ -491,6 +769,8 @@ int main(int argc, char **argv)
     g_test_add_func("/to_str/int_to_str_back", test_int_to_str_back);
     g_test_add_func("/to_str/int64_to_str_back", test_int64_to_str_back);
 
+    g_test_add_func("/nstime/from_iso8601", test_nstime_from_iso8601);
+
     g_test_add_func("/ws_getopt/basic1", test_getopt_long_basic1);
     g_test_add_func("/ws_getopt/basic2", test_getopt_long_basic2);
     g_test_add_func("/ws_getopt/optional1", test_getopt_optional_argument1);
